import { Event } from "./Event";
import { InteractiveObject } from "../display/InteractiveObject";
export declare class FocusEvent extends Event {
    static FOCUS_IN: string;
    static FOCUS_OUT: string;
    static KEY_FOCUS_CHANGE: string;
    static MOUSE_FOCUS_CHANGE: string;
    /**
     * If true, the relatedObject property is set to null for
     * reasons related to security sandboxes.  If the nominal value of relatedObject is a reference to a
     * DisplayObject in another sandbox, relatedObject is set to
     * null unless there is permission in both directions across this sandbox boundary.  Permission is
     * established by calling Security.allowDomain() from a SWF file, or by providing
     * a policy file from the server of an image file, and setting the LoaderContext.checkPolicyFile
     * property when loading the image.
     * @langversion	3.0
     * @playerversion	Flash 10
     * @playerversion	Lite 4
     */
    isRelatedObjectInaccessible: boolean;
    /**
     * The key code value of the key pressed to trigger a keyFocusChange event.
     */
    keyCode: number;
    /**
     * A reference to the complementary InteractiveObject instance that is affected by the
     * change in focus. For example, when a focusOut event occurs, the
     * relatedObject represents the InteractiveObject instance that has gained focus.
     * The value of this property can be null in two circumstances: if there no related object,
     * or there is a related object, but it is in a security sandbox to which you don't have access.
     * Use the isRelatedObjectInaccessible() property to determine which of these reasons applies.
     */
    relatedObject: InteractiveObject;
    /**
     * Indicates whether the Shift key modifier is activated, in which case the value is
     * true. Otherwise, the value is false. This property is
     * used only if the FocusEvent is of type keyFocusChange.
     */
    shiftKey: boolean;
    clone(): Event;
    toString(): string;
}
