import * as tslib_1 from "tslib";
import { Event } from "./Event";
/**
/// @eventType	flash.events.MouseEvent.CLICK
[Event(name="click", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.CONTEXT_MENU
[Event(name="contextMenu", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.DOUBLE_CLICK
[Event(name="doubleClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_CLICK
[Event(name="middleClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_DOWN
[Event(name="middleMouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_UP
[Event(name="middleMouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_DOWN
[Event(name="mouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_MOVE
[Event(name="mouseMove", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_OUT
[Event(name="mouseOut", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_OVER
[Event(name="mouseOver", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_UP
[Event(name="mouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_WHEEL
[Event(name="mouseWheel", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_CLICK
[Event(name="rightClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_MOUSE_DOWN
[Event(name="RightMouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_MOUSE_UP
[Event(name="rightMouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.ROLL_OUT
[Event(name="rollOut", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.ROLL_OVER
[Event(name="rollOver", type="flash.events.MouseEvent")]

 * A MouseEvent object is dispatched into the event flow whenever mouse events occur.
 * A mouse event is usually generated by a user input device, such as a mouse or a trackball,
 * that uses a pointer.
 *
 *   <p class="- topic/p ">When nested nodes are involved, mouse events target the deepest possible nested node that
 * is visible in the display list. This node is called the <i class="+ topic/ph hi-d/i ">target node</i>. To have a
 * target node's ancestor receive notification of a mouse event, use
 * <codeph class="+ topic/ph pr-d/codeph ">EventDispatcher.addEventListener()</codeph> on the ancestor node with the
 * <codeph class="+ topic/ph pr-d/codeph ">type</codeph> parameter set to the specific mouse event you want to detect.</p>
 *
 *   EXAMPLE:
 *
 *   The following example uses the <codeph class="+ topic/ph pr-d/codeph ">MouseEventExample</codeph> and
 * <codeph class="+ topic/ph pr-d/codeph ">ChildSprite</codeph> classes to show how mouse events are dispatched using a simple image.
 * This example carries out the following tasks:
 * <ol class="- topic/ol "><li class="- topic/li ">The example declares properties for the size (100 x 100 pixels) and the background color
 * (orange) for later use in drawing the square.</li><li class="- topic/li ">The constructor creates a new ChildSprite object <codeph class="+ topic/ph pr-d/codeph ">child</codeph>. Its constructor first
 * draws an orange 100 x 100 pixel square at coordinates (0,0) by calling its <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph>
 * method and then adds seven event listeners/subscribers.
 * <ul class="- topic/ul "><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">click</codeph>/<codeph class="+ topic/ph pr-d/codeph ">clickHandler()</codeph>: Dispatched when the user single-clicks with the left mouse button
 * over the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">doubleClick</codeph>/<codeph class="+ topic/ph pr-d/codeph ">doubleClickHandler()</codeph>: Dispatched when the user double-clicks the left mouse button
 * over the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseDown</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph>: When the ChildSprite
 * object (the orange square) is clicked, a <codeph class="+ topic/ph pr-d/codeph ">trace()</codeph> message is printed to the screen, and then
 * <codeph class="+ topic/ph pr-d/codeph ">ChildSprite.draw()</codeph> is called, which draws a dark yellow square in place
 * of the light blue one drawn in <codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler()</codeph>.  The <codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph> method also adds a
 * <codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>event listener and the <codeph class="+ topic/ph pr-d/codeph ">mouseMoveHandler()</codeph> subscriber (described below),
 * which processes the mouse moves.  Then the <codeph class="+ topic/ph pr-d/codeph ">startDrag()</codeph> method is called, which
 * allows the Sprite object to be dragged.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOut</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseOutHandler()</codeph>: Dispatched whenever the pointer leaves the
 * square area.  The <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method is called to return the square to its normal
 * size and color.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOver</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler()</codeph>: Dispatched when the mouse pointer is over the square.
 * This method redraws the square so that it is larger and its background color is dark yellow.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseUp</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseUpHandler()</codeph>: When the user releases the mouse button, the <codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>
 * event listener is removed and <codeph class="+ topic/ph pr-d/codeph ">stopDrag</codeph> is called, which freezes the square in place.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseMoveHandler()</codeph>: Called as part of the <codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph> function, and dispatched when the user is pressing the left mouse button and dragging the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseWheel</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseWheelHandler()</codeph>: Dispatched when the user rotates the mouse
 * wheel over the square.</li></ul></li><li class="- topic/li ">The ChildSprite instance <codeph class="+ topic/ph pr-d/codeph ">child</codeph> is then added to the display list by means of
 * <codeph class="+ topic/ph pr-d/codeph ">addChild()</codeph>, which promptly draws the orange square.</li></ol><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Notes: </b></p><ul class="- topic/ul "><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">MouseEventExample</codeph> class should be the document root.</li><li class="- topic/li ">Some of the event methods listed above declare a local variable <codeph class="+ topic/ph pr-d/codeph ">sprite</codeph>, which
 * is assigned the cast of <codeph class="+ topic/ph pr-d/codeph ">event.target</codeph> to type Sprite.</li></ul><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
 
 */
var MouseEvent = (function (_super) {
    tslib_1.__extends(MouseEvent, _super);
    /**
     * Creates an Event object that contains information about mouse events.
     * Event objects are passed as parameters to event listeners.
     * @param	type	The type of the event. Possible values are: MouseEvent.CLICK,
     *   MouseEvent.DOUBLE_CLICK, MouseEvent.MOUSE_DOWN,
     *   MouseEvent.MOUSE_MOVE, MouseEvent.MOUSE_OUT,
     *   MouseEvent.MOUSE_OVER, MouseEvent.MOUSE_UP,
     *   MouseEvent.MIDDLE_CLICK, MouseEvent.MIDDLE_MOUSE_DOWN, MouseEvent.MIDDLE_MOUSE_UP,
     *   MouseEvent.RIGHT_CLICK, MouseEvent.RIGHT_MOUSE_DOWN, MouseEvent.RIGHT_MOUSE_UP,
     *   MouseEvent.MOUSE_WHEEL, MouseEvent.ROLL_OUT, and MouseEvent.ROLL_OVER.
     * @param	bubbles	Determines whether the Event object participates in the bubbling phase of the event flow.
     * @param	cancelable	Determines whether the Event object can be canceled.
     * @param	localX	The horizontal coordinate at which the event occurred relative to the containing sprite.
     * @param	localY	The vertical coordinate at which the event occurred relative to the containing sprite.
     * @param	relatedObject	The complementary InteractiveObject instance that is affected by the event. For example, when a mouseOut event occurs, relatedObject represents the display list object to which the pointing device now points.
     * @param	ctrlKey	On Windows or Linux, indicates whether the Ctrl key is activated. On Mac, indicates whether either the Ctrl key or the Command key is activated.
     * @param	altKey	Indicates whether the Alt key is activated (Windows or Linux only).
     * @param	shiftKey	Indicates whether the Shift key is activated.
     * @param	buttonDown	Indicates whether the primary mouse button is pressed.
     * @param	delta	Indicates how many lines should be scrolled for each unit the user rotates the mouse wheel. A positive delta value indicates an upward scroll; a negative value indicates a downward scroll. Typical values are 1 to 3, but faster rotation may produce larger values. This parameter is used only for the MouseEvent.mouseWheel event.
     * @param	commandKey	(AIR only) Indicates whether the Command key is activated (Mac only). This parameter is used only for the MouseEvent.click,
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleClick, MouseEvent.middleMouseDown,
     *   MouseEvent.middleMouseUp, MouseEvent.rightClick, MouseEvent.rightMouseDown, MouseEvent.rightMouseUp,
     *   and MouseEvent.doubleClick events. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     * @param	controlKey	(AIR only) Indicates whether the Control or Ctrl key is activated. This parameter is used only for the MouseEvent.click,
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleClick, MouseEvent.middleMouseDown,
     *   MouseEvent.middleMouseUp, MouseEvent.rightClick, MouseEvent.rightMouseDown, MouseEvent.rightMouseUp,
     *   and MouseEvent.doubleClick events. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     * @param	clickCount	(AIR only) Indicates whether or not the mouse event is part of a multi-click sequence. This parameter will be zero for all mouse events other than
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleMouseDown, MouseEvent.middleMouseUp,
     *   MouseEvent.rightMouseDown and MouseEvent.rightMouseUp. Listening for single clicks, double clicks, or any multi-click sequence
     *   is possible with the clickCount parameter. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     */
    function MouseEvent(type, bubbles, cancelable, localX, localY, relatedObject, ctrlKey, altKey, shiftKey, buttonDown, delta) {
        if (bubbles === void 0) { bubbles = true; }
        if (cancelable === void 0) { cancelable = false; }
        if (localX === void 0) { localX = null; }
        if (localY === void 0) { localY = null; }
        if (relatedObject === void 0) { relatedObject = null; }
        if (ctrlKey === void 0) { ctrlKey = false; }
        if (altKey === void 0) { altKey = false; }
        if (shiftKey === void 0) { shiftKey = false; }
        if (buttonDown === void 0) { buttonDown = false; }
        if (delta === void 0) { delta = 0; }
        var _this = _super.call(this, type, bubbles, cancelable) || this;
        _this.localX = localX;
        _this.localY = localY;
        _this.relatedObject = relatedObject;
        _this.ctrlKey = ctrlKey;
        _this.altKey = altKey;
        _this.shiftKey = shiftKey;
        _this.buttonDown = buttonDown;
        _this.delta = delta;
        return _this;
    }
    Object.defineProperty(MouseEvent.prototype, "altKey", {
        get: function () {
            return this._altKey;
        },
        set: function (value) {
            this._altKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "buttonDown", {
        get: function () {
            return this._buttonDown;
        },
        set: function (value) {
            this._buttonDown = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "ctrlKey", {
        get: function () {
            return this._ctrlKey;
        },
        set: function (value) {
            this._ctrlKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "delta", {
        get: function () {
            return this._delta;
        },
        set: function (value) {
            this._delta = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "isRelatedObjectInaccessible", {
        get: function () {
            return this._isRelatedObjectInaccessible;
        },
        set: function (value) {
            this._isRelatedObjectInaccessible = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "localX", {
        get: function () {
            return this._localX;
        },
        set: function (value) {
            this._localX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "localY", {
        get: function () {
            return this._localY;
        },
        set: function (value) {
            this._localY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "movementX", {
        get: function () {
            return this._movementX;
        },
        set: function (value) {
            this._movementX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "movementY", {
        get: function () {
            return this._movementY;
        },
        set: function (value) {
            this._movementY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "relatedObject", {
        get: function () {
            return this._relatedObject;
        },
        set: function (value) {
            this._relatedObject = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "shiftKey", {
        get: function () {
            return this._shiftKey;
        },
        set: function (value) {
            this._shiftKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "stageX", {
        get: function () {
            return this._stageX;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent.prototype, "stageY", {
        get: function () {
            return this._stageY;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Creates a copy of the MouseEvent object and sets the value of each property to match that of the original.
     * @return	A new MouseEvent object with property values that match those of the original.
     */
    MouseEvent.prototype.clone = function () {
        return null;
    };
    MouseEvent.prototype.fillFromJS = function (jsEvent) {
        this._stageX = (jsEvent.clientX != null) ? jsEvent.clientX : jsEvent.changedTouches[0].clientX;
        this._stageY = (jsEvent.clientY != null) ? jsEvent.clientY : jsEvent.changedTouches[0].clientY;
        this.delta = jsEvent.delta;
        if (this._stageY < 0)
            this._stageY = 0;
        this.ctrlKey = jsEvent.ctrlKey;
        this.shiftKey = jsEvent.shiftKey;
    };
    /* added to clone events from away to as3web. */
    MouseEvent.prototype.fillFromAway = function (awayEvent) {
        //console.log("cloneFromAway not implemented yet in flash/MouseEvent");
        // todo: set targets correctly
        this.target = awayEvent.target;
        //this.currentTarget = awayEvent.currentTarget;
        this.delta = awayEvent.delta;
        this.ctrlKey = awayEvent.ctrlKey;
        this.shiftKey = awayEvent.shiftKey;
        this._stageX = awayEvent.screenX;
        this._stageY = awayEvent.screenY;
        //todo: translate more stuff from awayjs to as3
        //result.screenX = this.screenX;
        //result.screenY = this.screenY;
        /*
                result.view = awayEvent.view;
                result.entity = awayEvent.entity;
                result.renderable = awayEvent.renderable;
                result.material = awayEvent.material;
                result.uv = awayEvent.uv;
                result.position = awayEvent.position;
                result.normal = awayEvent.normal;
                result.elementIndex = awayEvent.elementIndex;
        */
        //result._iParentEvent = awayEvent;
        //result._iAllowedToPropagate = awayEvent._iAllowedToPropagate;
    };
    /**
     * Returns a string that contains all the properties of the MouseEvent object. The string is in the following format:
     * [MouseEvent type=value bubbles=value cancelable=value ... delta=value]
     * @return	A string that contains all the properties of the MouseEvent object.
     */
    MouseEvent.prototype.toString = function () {
        return "";
    };
    /**
     * Instructs Flash Player or Adobe AIR to render after processing of this event completes, if the display list has been modified.
     */
    MouseEvent.prototype.updateAfterEvent = function () {
    };
    return MouseEvent;
}(Event));
export { MouseEvent };
/**
 * Defines the value of the type property of a click event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor click events, this value is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.CLICK = "click";
/**
 * The MouseEvent.CONTEXT_MENU constant defines the value of the
 * type property of a contextMenu event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the right mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.CONTEXT_MENU = "contextMenu";
/**
 * Defines the value of the type property of a doubleClick event object. The doubleClickEnabled property
 * must be true for an object to generate the doubleClick event.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor double-click events, this value is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.DOUBLE_CLICK = "doubleClick";
/**
 * Defines the value of the type property of a middleClick event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor middle-click events, this property is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.MIDDLE_CLICK = "middleClick";
/**
 * Defines the value of the type property of a middleMouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the middle mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.MIDDLE_MOUSE_DOWN = "middleMouseDown";
/**
 * Defines the value of the type property of a middleMouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the middle mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.MIDDLE_MOUSE_UP = "middleMouseUp";
/**
 * Defines the value of the type property of a mouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows and Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.MOUSE_DOWN = "mouseDown";
/**
 * Defines the value of the type property of a mouseMove event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.MOUSE_MOVE = "mouseMove";
/**
 * Defines the value of the type property of a mouseOut event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device now points.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.MOUSE_OUT = "mouseOut";
/**
 * Defines the value of the type property of a mouseOver event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device was pointing.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.MOUSE_OVER = "mouseOver";
/**
 * Defines the value of the type property of a mouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent.MOUSE_UP = "mouseUp";
/**
 * Defines the value of the type property of a mouseWheel event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.deltaThe number of lines that that each notch on the mouse wheel represents.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 */
MouseEvent.MOUSE_WHEEL = "mouseWheel";
/**
 * Defines the value of the type property of a rightClick event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor right-click events, this property is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.RIGHT_CLICK = "rightClick";
/**
 * Defines the value of the type property of a rightMouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor right-click events, this property is always true.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.RIGHT_MOUSE_DOWN = "rightMouseDown";
/**
 * Defines the value of the type property of a rightMouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the right mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent.RIGHT_MOUSE_UP = "rightMouseUp";
/**
 * Defines the value of the type property of a rollOut event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblesfalsebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device now points.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
MouseEvent.ROLL_OUT = "rollOut";
/**
 * Defines the value of the type property of a rollOver event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblesfalsebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device was pointing.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
MouseEvent.ROLL_OVER = "rollOver";
