import { EventDispatcher } from "../events/EventDispatcher";
import { SoundTransform } from "./SoundTransform";
/**
 * Dispatched when a sound has finished playing.
 * @eventType	flash.events.Event.SOUND_COMPLETE
 * [Event(name="soundComplete", type="flash.events.Event")]
 *
 * The SoundChannel class controls a sound in an application. Every sound
 * is assigned to a sound channel, and the application can have multiple
 * sound channels that are mixed together. The SoundChannel class contains a <codeph class="+ topic/ph pr-d/codeph ">stop()</codeph> method,
 * properties for monitoring the amplitude (volume) of the channel, and a property for assigning a
 * SoundTransform object to the channel.
 */
export declare class SoundChannel extends EventDispatcher {
    axCallPublicProperty(value1: any, value2: any): any;
    axGetPublicProperty(value: any): any;
    axSetPublicProperty(value: any, value2: any): any;
    axHasPublicProperty(value: any): any;
    axDeletePublicProperty(value: any): any;
    axGetEnumerableKeys(): string[];
    private _sndtranform;
    _sound: any;
    constructor();
    /**
     * The current amplitude (volume) of the left channel, from 0 (silent) to 1 (full amplitude).
     */
    readonly leftPeak: number;
    /**
     * When the sound is playing, the position property indicates in milliseconds the current point
     * that is being played in the sound file. When the sound is stopped or paused, the
     * position property indicates the last point that was played in the sound file.
     *
     *   A common use case is to save the value of the position property when the
     * sound is stopped. You can resume the sound later by restarting it from that saved position.
     * If the sound is looped, position is reset to 0 at the beginning of each loop.
     */
    readonly position: number;
    /**
     * The current amplitude (volume) of the right channel, from 0 (silent) to 1 (full amplitude).
     */
    readonly rightPeak: number;
    /**
     * The SoundTransform object assigned to the sound channel. A SoundTransform object
     * includes properties for setting volume, panning, left speaker assignment, and right
     * speaker assignment.
     */
    soundTransform: SoundTransform;
    /**
     * Stops the sound playing in the channel.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     */
    stop(): void;
}
