(function (global, factory) {
   typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@awayjs/scene'), require('@awayjs/core'), require('@awayjs/view'), require('@awayjs/materials'), require('@awayjs/stage'), require('@awayjs/graphics')) :
   typeof define === 'function' && define.amd ? define(['exports', '@awayjs/scene', '@awayjs/core', '@awayjs/view', '@awayjs/materials', '@awayjs/stage', '@awayjs/graphics'], factory) :
   (factory((global.AwayjsView = global.AwayjsView || {}),global.AwayjsScene,global.AwayjsCore,global.AwayjsView,global.AwayjsMaterials,global.AwayjsStage,global.AwayjsGraphics));
}(this, (function (exports,_awayjs_scene,_awayjs_core,_awayjs_view,_awayjs_materials,_awayjs_stage,_awayjs_graphics) { 'use strict';

/**
 * The Clipboard class provides a container for transferring data and objects through the clipboard.
 * The operating system clipboard can be accessed through the static <codeph class="+ topic/ph pr-d/codeph ">generalClipboard</codeph> property.
 *
 *   <p class="- topic/p ">A Clipboard object can contain the same information in more than one format.
 * By supplying information in multiple formats, you increase the chances that another
 * application will be able to use that information. Add data to a Clipboard object
 * with the <codeph class="+ topic/ph pr-d/codeph ">setData()</codeph> or <codeph class="+ topic/ph pr-d/codeph ">setDataHandler()</codeph> method.</p><p class="- topic/p ">The standard formats are:</p><ul class="- topic/ul "><li class="- topic/li ">BITMAP_FORMAT: a BitmapData object (AIR only)</li><li class="- topic/li ">FILE_LIST_FORMAT: an array of File objects (AIR only)</li><li class="- topic/li ">HTML_FORMAT: HTML-formatted string data</li><li class="- topic/li ">TEXT_FORMAT: string data</li><li class="- topic/li ">RICH_TEXT_FORMAT: a ByteArray containing Rich Text Format data</li><li class="- topic/li ">URL_FORMAT: a URL string (AIR only)</li></ul><p class="- topic/p ">These constants for the names of the standard formats are defined in the ClipboardFormats class.</p><p class="- topic/p ">When a transfer to or from the operating system occurs,
 * the standard formats are automatically translated between
 * <ph class="- topic/ph ">ActionScript</ph> data types and the native operating system clipboard types.</p><p class="- topic/p ">You can use application-defined formats to add
 * <ph class="- topic/ph ">ActionScript</ph> objects to a
 * Clipboard object. If an object is serializable, both a reference and a clone
 * of the object can be made available. Object references are valid only within the
 * originating application.</p><p class="- topic/p ">When it is computationally expensive to convert the information to be transferred into a
 * particular format, you can supply the name of a function that performs the conversion.
 * The function is called if and only if that format is read by the receiving component or application.
 * Add a deferred rendering function to a Clipboard object with the  <codeph class="+ topic/ph pr-d/codeph ">setDataHandler()</codeph> method.
 * Note that in some cases,
 * the operating system calls the function before a drop occurs. For example, when you use a handler function to
 * provide the data for a file dragged from an AIR application to the file system, the operating
 * system calls the data handler function as soon as the drag gesture leaves the AIR application—typically resulting
 * in an undesireable pause as the file data is downloaded or created.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note for AIR applications:</b> The clipboard object referenced by the event objects dispatched for HTML
 * drag-and-drop and copy-and-paste events are not the same type as the AIR Clipboard object.
 * The JavaScript clipboard object is described in the AIR developer's guide.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note for Flash Player applications:</b> In Flash Player 10, a paste operation from the clipboard first
 * requires a user event (such as a keyboard shortcut for the Paste command or a mouse click on the Paste command
 * in a context menu). <codeph class="+ topic/ph pr-d/codeph ">Clipboard.getData()</codeph>
 * will return the contents of the clipboard only if the InteractiveObject has received
 * and is acting on a paste event. Calling <codeph class="+ topic/ph pr-d/codeph ">Clipboard.getData()</codeph> under any other circumstances
 * will be unsuccessful. The same restriction applies in AIR for content outside the
 * application sandbox.</p><p class="- topic/p ">On Linux, clipboard data does not persist when an AIR application closes.</p>
 */
var Clipboard = (function () {
    /**
     * Creates an empty Clipboard object.
     *
     *   Create Clipboard objects to hold the data of a native drag-and-drop gesture in Adobe AIR. Clipboard
     * objects can be used for only one drag-and-drop gesture; they cannot be reused.Do not create a Clipboard object for copy-and-paste operations. Use the single
     * Clipboard.generalClipboard object instead.
     * @internal	the example located at examples\Clipboard.clipboard.1.as should not be displayed with FP10 docs because FP10 will console.log an error when new Clipboard() is called.
     * @throws	IllegalOperationError new Clipboard() is not supported in Flash Player, since only the operating system clipboard can be used in Flash Player. For copy-and-paste operations involving the operating system clipboard, use the Clipboard.generalClipboard object rather than creating a new Clipboard object. Does not console.log an error in an AIR application.
     */
    function Clipboard() {
    }
    Object.defineProperty(Clipboard.prototype, "formats", {
        //todo: only dummy class yet
        /**
         * An array of strings containing the names of the data formats available
         * in this Clipboard object.
         *
         *   String constants for the names of the standard formats are defined in the
         * ClipboardFormats class. Other, application-defined, strings may also be used as format
         * names to transfer data as an object.
         */
        get: function () {
            console.log("formats not implemented yet in flash/Clipboard");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Clipboard, "generalClipboard", {
        /**
         * The operating system clipboard.
         *
         *   Any data pasted to the system clipboard is available to other
         * applications. This may include insecure remote code running in
         * a web browser.Note: In Flash Player 10 applications, a paste operation from the clipboard first
         * requires a user event (such as a keyboard shortcut for the Paste command or a mouse click on the Paste command
         * in a context menu). Clipboard.getData()
         * will return the contents of the clipboard only if the InteractiveObject has received
         * and is acting on a paste event. Calling Clipboard.getData() under any other circumstances
         * will be unsuccessful. The same restriction applies in AIR for content outside the
         * application sandbox.The generalClipboard object is created automatically.
         * You cannot assign another instance of a Clipboard to this property.
         * Instead, you use the getData() and setData()
         * methods to read and write data to the existing object.You should always clear the clipboard before writing new data to it
         * to ensure that old data in all formats is erased.The generalClipboard object cannot be passed to the AIR NativeDragManager.
         * Create a new Clipboard object for native drag-and-drop operations in an AIR application.
         */
        get: function () {
            console.log("generalClipboard not implemented yet in flash/Clipboard");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Deletes all data representations from this Clipboard object.
     * @throws	SecurityError Call to generalClipboard.clear() is not permitted in this context.
     *   In Flash Player, you can only call this method successfully during the processing of a user event
     *   (as in a key press or mouse click). In AIR, this restriction only applies to content outside of the
     *   application security sandbox.
     */
    Clipboard.prototype.clear = function () {
        console.log("clear not implemented yet in flash/Clipboard");
    };
    /**
     * Deletes the data representation for the specified format.
     * @param	format	The data format to remove.
     * @throws	SecurityError Call to generalClipboard.clearData() is not permitted in this context.
     *   In Flash Player, you can only call this method successfully during the processing of a user event
     *   (as in a key press or mouse click). In AIR, this restriction only applies to content outside of the
     *   application security sandbox.
     */
    Clipboard.prototype.clearData = function (format) {
        console.log("clearData not implemented yet in flash/Clipboard");
    };
    /**
     * Gets the clipboard data if data in the specified format is present.
     *
     *   Flash Player requires that the getData() be called in a paste event handler.
     * In AIR, this restriction only applies to content outside of the application security sandbox.When a standard data format is accessed, the data is returned as a new
     * object of the corresponding Flash data type.When an application-defined format is accessed, the value of the
     * transferMode parameter determines whether a reference to the original
     * object or an anonymous object containing a serialized copy of the original
     * object is returned. When an originalPreferred or clonePreferred mode is specified,
     * Flash Player or AIR returns the alternate version if the preferred version is not available.
     * When an originalOnly or cloneOnly mode is specified, Flash Player or AIR returns
     * null if the requested version is not available.
     * @param	format	The data format to return. The format string can contain one of the standard
     *   names defined in the ClipboardFormats class, or an application-defined name.
     * @param	transferMode	Specifies whether to return a reference or serialized copy
     *   when an application-defined data format is accessed. The value must be one
     *   of the names defined in the ClipboardTransferMode class. This value is
     *   ignored for the standard data formats; a copy is always returned.
     * @return	An object of the type corresponding to the data format.
     * @throws	Error transferMode is not one of the names defined in the ClipboardTransferMode class.
     * @throws	IllegalOperationError The Clipboard object requested is no longer in scope (AIR only).
     * @throws	SecurityError Reading from or writing to the clipboard is not permitted in this context.
     *   In Flash Player, you can only call this method successfully during the processing of a paste event.
     *   In AIR, this restriction only applies to content outside of the application security sandbox.
     */
    Clipboard.prototype.getData = function (format, transferMode) {
        if (transferMode === void 0) { transferMode = "originalPreferred"; }
        console.log("getData not implemented yet in flash/Clipboard");
        return null;
    };
    /**
     * Checks whether data in the specified format exists in this Clipboard object.
     *
     *   Use the constants in the ClipboardFormats class to reference the standard format names.
     * @param	format	The format type to check.
     * @return	true, if data in the specified format is present.
     * @throws	IllegalOperationError The Clipboard object requested is no longer in scope.
     * @throws	SecurityError Reading from or writing to the clipboard is not permitted in this context.
     */
    Clipboard.prototype.hasFormat = function (format) {
        console.log("hasFormat not implemented yet in flash/Clipboard");
        return false;
    };
    /**
     * Adds a representation of the information to be transferred in the specified data format.
     *
     *   In the application sandbox of Adobe AIR, setData() can be called anytime. In other
     * contexts, setData() can only be called in response to a user-generated event such as
     * a key press or mouse click.Different representations of the same information can be added to the clipboard as
     * different formats, which increases the ability of other components or applications to
     * make use of the available data.
     * For example, an image could be added as bitmap data for use by image editing applications,
     * as a URL, and as an encoded PNG file for transfer to the native file system.The data parameter must be the appropriate data type for the specified format:FormatTypeDescriptionClipboardFormats.TEXT_FORMATStringstring dataClipboardFormats.HTML_FORMATStringHTML string dataClipboardFormats.URL_FORMATStringURL string (AIR only)ClipboardFormats.RICH_TEXT_FORMATByteArrayRich Text Format dataClipboardFormats.BITMAP_FORMATBitmapDatabitmap data (AIR only)ClipboardFormats.FILE_LIST_FORMATarray of Filean array of files (AIR only)Custom format nameanyobject reference and serialized cloneCustom format names cannot begin with "air:" or "flash:". To prevent name collisions
     * when using custom formats, you may want to use your application ID or a package name as a
     * prefix to the format, such as "com.example.applicationName.dataPacket".When transferring within or between applications, the serializable parameter
     * determines whether both a reference and a copy are available, or whether only a reference to
     * an object is available. Set serializable to true to make both the reference
     * and a copy of the data object available. Set serializable to false
     * to make only the object reference available. Object references are valid only within the current
     * application so setting serializable to false also means that the data
     * in that format is not available to other Flash Player or AIR applications. A component can choose to get
     * the reference or the copy of the object by setting the appropriate clipboard transfer mode
     * when accessing the data for that format.Note: The standard formats are always converted to native formats when data is pasted or
     * dragged outside a supported application, so the value of the serializable
     * parameter does not affect the availability of data in the standard formats to non-Flash-based applications.To defer rendering of the data for a format, use the setDataHandler() method instead.
     * If both the setData() and the setDataHandler() methods are used to add a
     * data representation with the same format name, then the handler function will never be called.Note: On Mac OS, when you set the format parameter to ClipboardFormats.URL_FORMAT,
     * the URL is transferred only if it is a valid URL. Otherwise, the Clipboard object is emptied (and calling
     * getData() returns null).
     * @param	format	The format of the data.
     * @param	data	The information to add.
     * @param	serializable	Specify true for objects that can be serialized (and deserialized).
     * @return	true if the data was succesfully set;
     * @throws	IllegalOperationError The Clipboard object requested is no longer in scope (which can occur
     *   with clipboards created for drag-and-drop operations).
     * @throws	SecurityError Reading from or writing to the clipboard is not permitted in this context.
     *   In Flash Player, you can only call this method successfully during the processing of a user event
     *   (as in a key press or mouse click). In AIR, this restriction only applies to content outside of the
     *   application security sandbox.
     * @throws	TypeError format or data is null.
     */
    Clipboard.prototype.setData = function (format, data, serializable) {
        if (serializable === void 0) { serializable = true; }
        console.log("setData not implemented yet in flash/Clipboard");
        return false;
    };
    /**
     * Adds a reference to a handler function that produces the data to be transfered.
     *
     *   Use a handler function to defer creation or rendering of the data until it is actually accessed.The handler function must return the appropriate data type for the specified format:FormatReturn TypeClipboardFormats.TEXT_FORMATStringClipboardFormats.HTML_FORMATStringClipboardFormats.URL_FORMATString (AIR only)ClipboardFormats.RICH_TEXT_FORMATByteArrayClipboardFormats.BITMAP_FORMATBitmapData (AIR only)ClipboardFormats.FILE_LIST_FORMATArray of File (AIR only)ClipboardFormats.FILE_PROMISE_LIST_FORMATArray of File (AIR only)Custom format nameNon-voidThe handler function is called when and only when the data in the specified format is read. Note that in some cases,
     * the operating system calls the function before a drop occurs. For example, when you use a handler function to
     * provide the data for a file dragged from an AIR application to the file system, the operating
     * system calls the data handler function as soon as the drag gesture leaves the AIR application—typically resulting
     * in an undesireable pause as the file data is downloaded or created. You can use a URLFilePromise for this purpose instead.Note that the underlying data can change between the time the handler is added and the time the data is
     * read unless your application takes steps to protect the data.
     * The behavior that occurs when data on the clipboard represented by a handler function is read more than once
     * is not guaranteed. The clipboard might return the data produced by the first function call or it might call the
     * function again. Do not rely on either behavior.In the application sandbox of Adobe AIR, setDataHandler() can be called anytime. In other
     * contexts, setDataHandler() can only be called in response to a user-generated event such as
     * a key press or mouse click.To add data directly to this Clipboard object, use the setData() method instead.
     * If both the setData() and the setDataHandler() methods are called with the same
     * format name, then the handler function is never called.Note: On Mac OS, when you set the format parameter to ClipboardFormats.URL_FORMAT,
     * the URL is transferred only if the handler function returns a valid URL. Otherwise, the Clipboard object is emptied
     * (and calling getData() returns null).
     * @param	format	A function that returns the data to be transferred.
     * @param	handler	The format of the data.
     * @param	serializable	Specify true if the object returned by handler
     *   can be serialized (and deserialized).
     * @return	true if the handler was succesfully set;
     *   false otherwise.
     * @throws	TypeError format or handler is null.
     * @throws	IllegalOperationError The Clipboard object requested is no longer in scope (AIR only).
     * @throws	SecurityError Reading from or writing to the clipboard is not permitted in this context.
     *   In Flash Player, you can only call this method successfully during the processing of a user event
     *   (such as a key press or mouse click). In AIR, this restriction only applies to content outside of the
     *   application security sandbox.
     */
    Clipboard.prototype.setDataHandler = function (format, handler, serializable) {
        if (serializable === void 0) { serializable = true; }
        console.log("setDataHandler not implemented yet in flash/Clipboard");
        return false;
    };
    return Clipboard;
}());

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};















function __values(o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
}

function __read(o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
}





function __await(v) {
    return this instanceof __await ? (this.v = v, this) : new __await(v);
}

/**
 * The ClipboardFormats class defines constants for the names of the standard data formats used with the Clipboard class.
 * Flash Player 10 only supports TEXT_FORMAT, RICH_TEXT_FORMAT, and HTML_FORMAT.
 * @internal	Clipboard, ClipboardFormats and ClipboardTransferMode were all added to AIR 1.0. These are also being added, with some exceptions listed in this file, to FP10.
 */
var ClipboardFormats = (function (_super) {
    __extends(ClipboardFormats, _super);
    function ClipboardFormats() {
        return _super.apply(this, arguments) || this;
    }
    return ClipboardFormats;
}(Object));
/**
 * Image data (AIR only).
 */
ClipboardFormats.BITMAP_FORMAT = "air:bitmap";
/**
 * An array of files (AIR only).
 */
ClipboardFormats.FILE_LIST_FORMAT = "air:file list";
/**
 * File promise list (AIR only).
 */
ClipboardFormats.FILE_PROMISE_LIST_FORMAT = "air:file promise list";
/**
 * HTML data.
 */
ClipboardFormats.HTML_FORMAT = "air:html";
/**
 * Rich Text Format data.
 */
ClipboardFormats.RICH_TEXT_FORMAT = "air:rtf";
/**
 * String data.
 */
ClipboardFormats.TEXT_FORMAT = "air:text";
/**
 * A URL string (AIR only).
 */
ClipboardFormats.URL_FORMAT = "air:url";

/*
/// @eventType	flash.events.Event.ACTIVATE
[Event(name="activate", type="flash.events.Event")]

/// @eventType	flash.events.Event.ADDED_TO_STAGE
[Event(name="addedToStage", type="flash.events.Event")]

/// @eventType	flash.events.Event.ADDED
[Event(name="added", type="flash.events.Event")]

/// @eventType	flash.events.Event.CANCEL
[Event(name="cancel", type="flash.events.Event")]

/// @eventType	flash.events.Event.CHANGE
[Event(name="change", type="flash.events.Event")]

/// @eventType	flash.events.Event.CLEAR
[Event(name="copy", type="flash.events.Event")]

/// @eventType	flash.events.Event.CLOSE
[Event(name="close", type="flash.events.Event")]

/// @eventType	flash.events.Event.CLOSING
[Event(name="closing", type="flash.events.Event")]

/// @eventType	flash.events.Event.COMPLETE
[Event(name="complete", type="flash.events.Event")]

/// @eventType	flash.events.Event.CONNECT
[Event(name="connect", type="flash.events.Event")]

/// @eventType	flash.events.Event.COPY
[Event(name="copy", type="flash.events.Event")]

/// @eventType	flash.events.Event.CUT
[Event(name="cut", type="flash.events.Event")]

/// @eventType	flash.events.Event.DEACTIVATE
[Event(name="deactivate", type="flash.events.Event")]

/// @eventType	flash.events.Event.DISPLAYING
[Event(name="displaying", type="flash.events.Event")]

/// @eventType	flash.events.Event.ENTER_FRAME
[Event(name="enterFrame", type="flash.events.Event")]

/// @eventType	flash.events.Event.EXITING
[Event(name="exiting", type="flash.events.Event")]

/// @eventType	flash.events.Event.EXIT_FRAME
[Event(name="exitFrame", type="flash.events.Event")]

/// @eventType	flash.events.Event.FRAME_CONSTRUCTED
[Event(name="frameConstructed", type="flash.events.Event")]

/// @eventType	flash.events.Event.FULLSCREEN
[Event(name="fullScreen", type="flash.events.Event")]

/// @eventType	flash.events.Event.HTML_BOUNDS_CHANGE
[Event(name="htmlBoundsChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.HTML_DOM_INITIALIZE
[Event(name="htmlDOMInitialize", type="flash.events.Event")]

/// @eventType	flash.events.Event.HTML_RENDER
[Event(name="htmlRender", type="flash.events.Event")]

/// @eventType	flash.events.Event.ID3
[Event(name="id3", type="flash.events.Event")]

/// @eventType	flash.events.Event.INIT
[Event(name="init", type="flash.events.Event")]

/// @eventType	flash.events.Event.LOCATION_CHANGE
[Event(name="locationChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.MOUSE_LEAVE
[Event(name="mouseLeave", type="flash.events.Event")]

/// @eventType	flash.events.Event.NETWORK_CHANGE
[Event(name="networkChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.OPEN
[Event(name="open", type="flash.events.Event")]

/// @eventType	flash.events.Event.PASTE
[Event(name="paste", type="flash.events.Event")]

/// @eventType	flash.events.Event.PREPARING
[Event(name="flash.events.Event", type="flash.events.Event")]

/// @eventType	flash.events.Event.REMOVED_FROM_STAGE
[Event(name="removedFromStage", type="flash.events.Event")]

/// @eventType	flash.events.Event.REMOVED
[Event(name="removed", type="flash.events.Event")]

/// @eventType	flash.events.Event.RENDER
[Event(name="render", type="flash.events.Event")]

/// @eventType	flash.events.Event.RESIZE
[Event(name="resize", type="flash.events.Event")]

/// @eventType	flash.events.Event.SCROLL
[Event(name="scroll", type="flash.events.Event")]

/// @eventType	flash.events.Event.SELECT_ALL
[Event(name="selectAll", type="flash.events.Event")]

/// @eventType	flash.events.Event.SELECT
[Event(name="select", type="flash.events.Event")]

/// @eventType	flash.events.Event.SOUND_COMPLETE
[Event(name="soundComplete", type="flash.events.Event")]

/// @eventType	flash.events.Event.STANDARD_ERROR_CLOSE
[Event(name="flash.events.Event", type="flash.events.Event")]

/// @eventType	flash.events.Event.STANDARD_INPUT_CLOSE
[Event(name="flash.events.Event", type="flash.events.Event")]

/// @eventType	flash.events.Event.STANDARD_OUTPUT_CLOSE
[Event(name="flash.events.Event", type="flash.events.Event")]

/// @eventType	flash.events.Event.TAB_CHILDREN_CHANGE
[Event(name="tabChildrenChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.TAB_ENABLED_CHANGE
[Event(name="tabEnabledChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.TAB_INDEX_CHANGE
[Event(name="tabIndexChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.TEXT_INTERACTION_MODE_CHANGE
[Event(name="textInteractionModeChange", type="flash.events.Event")]

/// @eventType	flash.events.Event.UNLOAD
[Event(name="unload", type="flash.events.Event")]

/// @eventType	flash.events.Event.USER_IDLE
[Event(name="userIdle", type="flash.events.Event")]

/// @eventType	flash.events.Event.USER_PRESENT
[Event(name="userIdle", type="flash.events.Event")]

 * The Event class is used as the base class for the creation of Event objects,
 * which are passed as parameters to event listeners when an event occurs.
 *
 *   <p class="- topic/p ">The properties of the Event class carry basic information about an event, such as
 * the event's type or whether the event's default behavior can be canceled. For many
 * events, such as the events represented by the Event class constants, this basic information
 * is sufficient. Other events, however, may require more detailed information. <ph class="- topic/ph ">Events associated
 * with a mouse click, for example, need to include additional information about the location of
 * the click event and whether any keys were pressed during the click event.  You can pass such additional
 * information to event listeners by extending the Event class, which is what
 * the MouseEvent class does. ActionScript 3.0</ph> API defines several Event subclasses for common
 * events that require additional information. Events associated with each of the Event
 * subclasses are described in the documentation for each class.</p><p class="- topic/p ">The methods of the Event class can be used in event listener functions to affect the
 * behavior of the event object. Some events have an associated default behavior.<ph class="- topic/ph "> For example,
 * the <codeph class="+ topic/ph pr-d/codeph ">doubleClick</codeph> event has an associated default behavior that highlights
 * the word under the mouse pointer at the time of the event.</ph>
 * Your event listener can cancel this
 * behavior by calling the <codeph class="+ topic/ph pr-d/codeph ">preventDefault()</codeph> method.
 * <ph class="- topic/ph ">You can also make the current
 * event listener the last one to process an event by calling the <codeph class="+ topic/ph pr-d/codeph ">stopPropagation()</codeph>
 * or <codeph class="+ topic/ph pr-d/codeph ">stopImmediatePropagation()</codeph> method.</ph></p><p class="- topic/p ">Other sources of information include:</p><ul class="- topic/ul "><li class="- topic/li ">A useful description about the timing of events, code execution, and rendering at runtime in Ted Patrick's blog entry:
 * <xref href="http://www.onflex.org/ted/2005/07/flash-player-mental-model-elastic.php" scope="external" class="- topic/xref ">Flash Player Mental Model - The Elastic Racetrack</xref>.</li><li class="- topic/li ">A blog entry by Johannes Tacskovics about the timing of frame events, such as ENTER_FRAME, EXIT_FRAME:
 * <xref href="http://blog.johannest.com/2009/06/15/the-movieclip-life-cycle-revisited-from-event-added-to-event-removed_from_stage/" scope="external" class="- topic/xref ">The MovieClip Lifecycle</xref>.</li><li class="- topic/li ">An article by Trevor McCauley about the order of ActionScript operations:
 * <xref href="http://www.senocular.com/flash/tutorials/orderofoperations/" scope="external" class="- topic/xref ">Order of Operations in ActionScript</xref>.</li><li class="- topic/li ">A blog entry by Matt Przybylski on creating custom events:
 * <xref href="http://evolve.reintroducing.com/2007/10/23/as3/as3-custom-events/" scope="external" class="- topic/xref ">AS3: Custom Events</xref>.</li></ul>
 *
 */
var Event = (function (_super) {
    __extends(Event, _super);
    /**
     * Creates an Event object to pass as a parameter to event listeners.
     * @param	type	The type of the event, accessible as Event.type.
     * @param	bubbles	Determines whether the Event object participates in the bubbling stage of the event flow. The default value is false.
     * @param	cancelable	Determines whether the Event object can be canceled. The default values is false.
     */
    function Event(type, bubbles, cancelable) {
        if (bubbles === void 0) { bubbles = false; }
        if (cancelable === void 0) { cancelable = false; }
        return _super.call(this, type) || this;
    }
    // for AVM1:
    Event.prototype.axCallPublicProperty = function (value1, value2) {
        return null;
    };
    Event.prototype.axGetPublicProperty = function (value) {
        return null;
    };
    Event.prototype.axSetPublicProperty = function (value) {
        return null;
    };
    Object.defineProperty(Event.prototype, "bubbles", {
        /**
         * Indicates whether an event is a bubbling event. If the event can bubble,
         * this value is true; otherwise it is false.
         *
         *   When an event occurs, it moves through the three phases of the event flow: the capture
         * phase, which flows from the top of the display list hierarchy to the node just before the
         * target node; the target phase, which comprises the target node; and the bubbling phase,
         * which flows from the node subsequent to the target node back up the display list hierarchy.Some events, such as the activate and unload events, do not
         * have a bubbling phase. The bubbles property has a value of
         * false for events that do not have a bubbling phase.
         */
        get: function () {
            console.log("bubbles not implemented yet in flash/Event");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Event.prototype, "cancelable", {
        /**
         * Indicates whether the behavior associated with the event can be prevented.
         * If the behavior can be canceled, this value is true; otherwise it is false.
         */
        get: function () {
            console.log("cancelable not implemented yet in flash/Event");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Event.prototype, "currentTarget", {
        /**
         * The object that is actively processing the Event object with an event listener. For example, if a user clicks an OK button, the current target could be the node containing that button or one of its ancestors that has registered an event listener for that event.
         */
        get: function () {
            return this._currentTarget;
        },
        set: function (value) {
            this._currentTarget = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Event.prototype, "eventPhase", {
        /**
         * The current phase in the event flow. This property can contain the following numeric values:
         * The capture phase (EventPhase.CAPTURING_PHASE). The target phase (EventPhase.AT_TARGET). The bubbling phase (EventPhase.BUBBLING_PHASE).
         */
        get: function () {
            console.log("eventPhase not implemented yet in flash/Event");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * The event target. This property contains the target node. For example, if a user clicks an OK button, the target node is the display list node containing that button.
     */
    /* provided because awayjs-eventbase has "target" as public property
    public get target () : any{
        console.log("target not implemented yet in flash/Event");
        return null;
    }

    /**
     * The type of event. The type is case-sensitive.
     */
    /* provided because awayjs-eventbase has "type" as public property
    public get type () : string{
        console.log("type not implemented yet in flash/Event");
        return "";
    }
    */
    /**
     * Duplicates an instance of an Event subclass.
     *
     *   Returns a new Event object that is a copy of the original instance of the Event object.
     * You do not normally call clone(); the EventDispatcher class calls it automatically
     * when you redispatch an event—that is, when you call dispatchEvent(event) from a handler
     * that is handling event.The new Event object includes all the properties of the original.When creating your own custom Event class, you must override the
     * inherited Event.clone() method in order for it to duplicate the
     * properties of your custom class. If you do not set all the properties that you add
     * in your event subclass, those properties will not have the correct values when listeners
     * handle the redispatched event.In this example, PingEvent is a subclass of Event
     * and therefore implements its own version of clone().
     * <codeblock>
     *
     *   class PingEvent extends Event {
         * var URL:String;
         *
         *   public override function clone():Event {
         * return new PingEvent(type, bubbles, cancelable, URL);
         * }
         * }
     *
     *   </codeblock>
     * @return	A new Event object that is identical to the original.
     */
    Event.prototype.clone = function () {
        console.log("clone not implemented yet in flash/Event");
        return null;
    };
    /**
     * Fill all properties from awayjs-event
     * @param	awayEvent	The awayjs-event
     *   the className parameter is PingEvent.
     */
    Event.prototype.fillFromAway = function (awayEvent) {
        console.log("flash/Event.cloneFromAway should be implemented in SubClass");
    };
    /**
     * A utility function for implementing the toString() method in custom
     * ActionScript 3.0 Event classes. Overriding the
     * toString() method is recommended, but not required.
     * class PingEvent extends Event {
         * var URL:String;
         *
         *   public override function toString():String {
         * return formatToString("PingEvent", "type", "bubbles", "cancelable", "eventPhase", "URL");
         * }
         * }
     * @param	className	The name of your custom Event class. In the previous example,
     *   the className parameter is PingEvent.
     * @param	arguments	The properties of the Event class and the
     *   properties that you add in your custom Event class. In the previous example, the ...arguments
     *   parameter includes type, bubbles, cancelable,
     *   eventPhase, and URL.
     * @return	The name of your custom Event class and the String value of your ...arguments
     *   parameter.
     */
    Event.prototype.formatToString = function (className) {
        var rest = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            rest[_i - 1] = arguments[_i];
        }
        console.log("formatToString not implemented yet in flash/Event");
        return "";
    };
    /**
     * Checks whether the preventDefault() method has been called on the event. If the
     * preventDefault() method has been called,
     * returns true; otherwise, returns false.
     * @return	If preventDefault() has been called, returns true; otherwise,
     *   returns false.
     */
    Event.prototype.isDefaultPrevented = function () {
        console.log("isDefaultPrevented not implemented yet in flash/Event");
        return false;
    };
    /**
     * Cancels an event's default behavior if that behavior can be canceled.
     *
     *   Many events have associated behaviors that are carried out by default.
     * For example, if a user types a character
     * into a text field, the default behavior is that the character is
     * displayed in the text field. Because the TextEvent.TEXT_INPUT
     * event's default behavior can be canceled, you can use the preventDefault()
     * method to prevent the character from appearing.An example of a behavior that is not cancelable is the default behavior associated with
     * the Event.REMOVED event, which is generated whenever Flash Player is about to
     * remove a display object from the display list. The default behavior (removing the element)
     * cannot be canceled, so the preventDefault() method has no effect on this
     * default behavior. You can use the Event.cancelable property to check whether you can prevent
     * the default behavior associated with a particular event. If the value of
     * Event.cancelable is true, then preventDefault() can
     * be used to cancel the event; otherwise, preventDefault() has no effect.
     */
    Event.prototype.preventDefault = function () {
        console.log("preventDefault not implemented yet in flash/Event");
    };
    /**
     * Prevents processing of any event listeners in the current node and any subsequent nodes in
     * the event flow. This method takes effect immediately, and it affects event listeners
     * in the current node. In contrast, the stopPropagation() method doesn't take
     * effect until all the event listeners in the current node finish processing.Note:  This method does not cancel the behavior associated with this event; see preventDefault() for that functionality.

     */
    Event.prototype.stopImmediatePropagation = function () {
        console.log("stopImmediatePropagation not implemented yet in flash/Event");
    };
    /**
     * Prevents processing of any event listeners in nodes subsequent to the current node in the
     * event flow. This method does not affect any event listeners in the current node
     * (currentTarget). In contrast, the stopImmediatePropagation() method
     * prevents processing of event listeners in both the current node and subsequent nodes.
     * Additional calls to this method have no effect. This method can be called in any phase
     * of the event flow.Note:  This method does not cancel the behavior associated with this event; see preventDefault() for that functionality.
     */
    Event.prototype.stopPropagation = function () {
        console.log("stopPropagation not implemented yet in flash/Event");
    };
    /**
     * Returns a string containing all the properties of the Event object. The string is in the following format:
     * [Event type=value bubbles=value cancelable=value]
     * @return	A string containing all the properties of the Event object.
     */
    Event.prototype.toString = function () {
        console.log("toString not implemented yet in flash/Event");
        return "";
    };
    return Event;
}(_awayjs_core.EventBase));
/**
 * The ACTIVATE constant defines the value of the type property of an activate event object.
 * Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.AIR for TV devices never automatically dispatch this event. You can, however, dispatch it manually.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the activate event.
 * @langversion	3.0
 */
Event.ACTIVATE = "activate";
/**
 * The Event.ADDED constant defines the value of the type property of
 * an added event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe DisplayObject instance being added to the display list.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 */
Event.ADDED = "added";
/**
 * The Event.ADDED_TO_STAGE constant defines the value of the type
 * property of an addedToStage event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe DisplayObject instance being added to the on stage display list,
 * either directly or through the addition of a sub tree in which the DisplayObject instance is contained.
 * If the DisplayObject instance is being directly added, the added event occurs before this event.
 * @langversion	3.0
 */
Event.ADDED_TO_STAGE = "addedToStage";
/**
 * The Event.CANCEL constant defines the value of the type property of a cancel event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetA reference to the object on which the operation is canceled.
 * @langversion	3.0
 */
Event.CANCEL = "cancel";
/**
 * The Event.CHANGE constant defines the value of the type property of a change event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe object that has had its value modified.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 */
Event.CHANGE = "change";
/**
 * The Event.CLEAR constant defines the value of the type property
 * of a clear event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny InteractiveObject instance with a listener registered for the clear event.Note: TextField objects do not dispatch clear, copy, cut, paste,
 * or selectAll events. TextField objects always include Cut, Copy, Paste, Clear, and Select All commands in the context menu.
 * You cannot remove these commands from the context menu for TextField objects. For TextField objects, selecting these commands
 * (or their keyboard equivalents) does not generate clear, copy, cut, paste,
 * or selectAll events. However, other classes that extend the InteractiveObject class, including components built
 * using the Flash Text Engine (FTE), will dispatch these events in response to user actions such as keyboard shortcuts and context menus.
 * @langversion	3.0
 */
Event.CLEAR = "clear";
/**
 * The Event.CLOSE constant defines the value of the type property of a close event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe object whose connection has been closed.
 * @langversion	3.0
 */
Event.CLOSE = "close";
/**
 * The Event.COMPLETE constant defines the value of the type property of a complete event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe network object that has completed loading.
 * @langversion	3.0
 */
Event.COMPLETE = "complete";
/**
 * The Event.CONNECT constant defines the value of the type property of a connect event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe Socket or XMLSocket object that has established a network connection.
 * @langversion	3.0
 */
Event.CONNECT = "connect";
/**
 * Defines the value of the type property of a copy event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny InteractiveObject instance with a listener registered for the copy event.Note: TextField objects do not dispatch clear, copy, cut, paste,
 * or selectAll events. TextField objects always include Cut, Copy, Paste, Clear, and Select All commands in the context menu.
 * You cannot remove these commands from the context menu for TextField objects. For TextField objects, selecting these commands
 * (or their keyboard equivalents) does not generate clear, copy, cut, paste,
 * or selectAll events. However, other classes that extend the InteractiveObject class, including components built
 * using the Flash Text Engine (FTE), will dispatch these events in response to user actions such as keyboard shortcuts and context menus.
 * @langversion	3.0
 */
Event.COPY = "copy";
/**
 * Defines the value of the type property of a cut event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny InteractiveObject instance with a listener registered for the cut event.Note: TextField objects do not dispatch clear, copy, cut, paste,
 * or selectAll events. TextField objects always include Cut, Copy, Paste, Clear, and Select All commands in the context menu.
 * You cannot remove these commands from the context menu for TextField objects. For TextField objects, selecting these commands
 * (or their keyboard equivalents) does not generate clear, copy, cut, paste,
 * or selectAll events. However, other classes that extend the InteractiveObject class, including components built
 * using the Flash Text Engine (FTE), will dispatch these events in response to user actions such as keyboard shortcuts and context menus.
 * @langversion	3.0
 */
Event.CUT = "cut";
/**
 * The Event.DEACTIVATE constant defines the value of the type property of a deactivate event object.
 * Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.AIR for TV devices never automatically dispatch this event. You can, however, dispatch it manually.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the deactivate event.
 */
Event.DEACTIVATE = "deactivate";
/**
 * The Event.ENTER_FRAME constant defines the value of the type property of an enterFrame event object.
 * Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the enterFrame event.
 */
Event.ENTER_FRAME = "enterFrame";
/**
 * The Event.EXIT_FRAME constant defines the value of the type property of an exitFrame event object.
 * Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the enterFrame event.
 */
Event.EXIT_FRAME = "exitFrame";
/**
 * The Event.FRAME_CONSTRUCTED constant defines the value of the type property of an frameConstructed event object.
 *
 *   Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the frameConstructed event.
 */
Event.FRAME_CONSTRUCTED = "frameConstructed";
/**
 * The Event.FULL_SCREEN constant defines the value of the type property of a fullScreen event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe Stage object.
 */
Event.FULLSCREEN = "fullScreen";
/**
 * The Event.ID3 constant defines the value of the type property of an id3 event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe Sound object loading the MP3 for which ID3 data is now available.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.ID3 = "id3";
/**
 * The Event.INIT constant defines the value of the type property of an init event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe LoaderInfo object associated with the SWF file being loaded.
 */
Event.INIT = "init";
/**
 * The Event.MOUSE_LEAVE constant defines the value of the type property of a mouseLeave event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe Stage object.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.MOUSE_LEAVE = "mouseLeave";
/**
 * The Event.OPEN constant defines the value of the type property of an open event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe network object that has opened a connection.
 */
Event.OPEN = "open";
/**
 * The Event.PASTE constant defines the value of the type property of a paste event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny InteractiveObject instance with a listener registered for the paste event.Note: TextField objects do not dispatch clear, copy, cut, paste,
 * or selectAll events. TextField objects always include Cut, Copy, Paste, Clear, and Select All commands in the context menu.
 * You cannot remove these commands from the context menu for TextField objects. For TextField objects, selecting these commands
 * (or their keyboard equivalents) does not generate clear, copy, cut, paste,
 * or selectAll events. However, other classes that extend the InteractiveObject class, including components built
 * using the Flash Text Engine (FTE), will dispatch these events in response to user actions such as keyboard shortcuts and context menus.
 */
Event.PASTE = "paste";
/**
 * The Event.REMOVED constant defines the value of the type property of
 * a removed event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe DisplayObject instance to be removed from the display list.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.REMOVED = "removed";
/**
 * The Event.REMOVED_FROM_STAGE constant defines the value of the type
 * property of a removedFromStage event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe DisplayObject instance being removed from the on stage display list,
 * either directly or through the removal of a sub tree in which the DisplayObject instance is contained.
 * If the DisplayObject instance
 */
Event.REMOVED_FROM_STAGE = "removedFromStage";
/**
 * The Event.RENDER constant defines the value of the type property of a render event object.
 * Note: This event has neither a "capture phase" nor a "bubble phase",
 * which means that event listeners must be added directly to any potential targets,
 * whether the target is on the display list or not.This event has the following properties:PropertyValuebubblesfalsecancelablefalse; the default behavior cannot be canceled.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny DisplayObject instance with a listener registered for the render event.
 * @langversion	3.0
 */
Event.RENDER = "render";
/**
 * The Event.RESIZE constant defines the value of the type property of a resize event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe Stage object.
 * @langversion	3.0
 */
Event.RESIZE = "resize";
/**
 * The Event.SCROLL constant defines the value of the type property of a scroll event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe TextField object that has been scrolled.
 * The target property is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 */
Event.SCROLL = "scroll";
/**
 * The Event.SELECT constant defines the value of the type property of a select event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe object on which an item has been selected.
 * @langversion	3.0
 */
Event.SELECT = "select";
/**
 * The Event.SELECT_ALL constant defines the value of the type property of a selectAll event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetAny InteractiveObject instance with a listener registered for the selectAll event.Note: TextField objects do not dispatch clear, copy, cut, paste,
 * or selectAll events. TextField objects always include Cut, Copy, Paste, Clear, and Select All commands in the context menu.
 * You cannot remove these commands from the context menu for TextField objects. For TextField objects, selecting these commands
 * (or their keyboard equivalents) does not generate clear, copy, cut, paste,
 * or selectAll events. However, other classes that extend the InteractiveObject class, including components built
 * using the Flash Text Engine (FTE), will dispatch these events in response to user actions such as keyboard shortcuts and context menus.
 * @langversion	3.0
 */
Event.SELECT_ALL = "selectAll";
/**
 * The Event.SOUND_COMPLETE constant defines the value of the type property of a soundComplete event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe SoundChannel object in which a sound has finished playing.
 */
Event.SOUND_COMPLETE = "soundComplete";
/**
 * The Event.TAB_CHILDREN_CHANGE constant defines the value of the type property of a tabChildrenChange event object.
 * This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe object whose tabChildren flag has changed.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.TAB_CHILDREN_CHANGE = "tabChildrenChange";
/**
 * The Event.TAB_ENABLED_CHANGE constant defines the value of the type
 * property of a tabEnabledChange event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe InteractiveObject whose tabEnabled flag has changed.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.TAB_ENABLED_CHANGE = "tabEnabledChange";
/**
 * The Event.TAB_INDEX_CHANGE constant defines the value of the
 * type property of a tabIndexChange event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe object whose tabIndex has changed.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.TAB_INDEX_CHANGE = "tabIndexChange";
/**
 * The Event.TEXT_INTERACTION_MODE_CHANGE constant defines the value of the type property of a interaction mode event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe TextField object whose interaction mode property is changed. For example on Android, one can change the interaction mode to SELECTION via context menu.
 * The target property is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
Event.TEXT_INTERACTION_MODE_CHANGE = "textInteractionModeChange";
/**
 * The Event.UNLOAD constant defines the value of the type property of an unload event object.
 *
 *   This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.currentTargetThe object that is actively processing the Event
 * object with an event listener.targetThe LoaderInfo object associated with the SWF file being unloaded or replaced.
 */
Event.UNLOAD = "unload";

/**
     * [broadcast event] Dispatched when the Flash Player or AIR application operating
     * loses system focus and is becoming inactive.
     * @eventType	flash.events.Event.DEACTIVATE
    [Event(name="deactivate", type="flash.events.Event")]

     * [broadcast event] Dispatched when the Flash Player or AIR application gains
     * operating system focus and becomes active.
     * @eventType	flash.events.Event.ACTIVATE
    [Event(name="activate", type="flash.events.Event")]
 */
var EventDispatcher$1 = (function (_super) {
    __extends(EventDispatcher$$1, _super);
    function EventDispatcher$$1(target) {
        if (target === void 0) { target = null; }
        var _this = _super.call(this, target) || this;
        _this.eventMapping = {};
        _this.eventMappingDummys = {};
        _this.eventMappingExtern = {};
        _this.eventMappingInvert = {}; //only needed in some cases, when we translate back from awayjs-type to flash-type
        _this._activateCallbackDelegate = function (event) { return _this.activateCallback(event); };
        _this.eventMapping[Event.ACTIVATE] = {
            adaptedType: "",
            addListener: _this.initActivateListener,
            removeListener: _this.removeActivateListener,
            callback: _this._activateCallbackDelegate
        };
        _this._deactivateCallbackDelegate = function (event) { return _this.deactivateCallback(event); };
        _this.eventMapping[Event.DEACTIVATE] = {
            adaptedType: "",
            addListener: _this.initDeactivateListener,
            removeListener: _this.removeDeactivateListener,
            callback: _this._deactivateCallbackDelegate
        };
        return _this;
    }
    // ---------- event mapping functions Event.ACTIVATE
    EventDispatcher$$1.prototype.initActivateListener = function (type, callback) {
        window.onfocus = callback;
    };
    EventDispatcher$$1.prototype.removeActivateListener = function (type, callback) {
        window.onfocus = null;
    };
    EventDispatcher$$1.prototype.activateCallback = function (event) {
        if (event === void 0) { event = null; }
        this.dispatchEvent(new Event(Event.ACTIVATE));
    };
    // ---------- event mapping functions Event.DEACTIVATE
    EventDispatcher$$1.prototype.initDeactivateListener = function (type, callback) {
        window.onblur = callback;
    };
    EventDispatcher$$1.prototype.removeDeactivateListener = function (type, callback) {
        window.onblur = null;
    };
    EventDispatcher$$1.prototype.deactivateCallback = function (event) {
        if (event === void 0) { event = null; }
        this.dispatchEvent(new Event(Event.DEACTIVATE));
    };
    /*overwrite*/
    EventDispatcher$$1.prototype.addEventListener = function (type, listener, useCapture, priority, useWeakReference) {
        if (useCapture === void 0) { useCapture = false; }
        if (priority === void 0) { priority = 0; }
        if (useWeakReference === void 0) { useWeakReference = false; }
        if (this.eventMappingExtern.hasOwnProperty(type)) {
            // this is a external eventMapping
            // this means that we do not need to create any mapping, and will manually dispatch the event
            // we still need to register it on superclass, so it will work if we dispatch it manually
            _super.prototype.addEventListener.call(this, type, listener);
            return;
        }
        if (this.eventMappingDummys.hasOwnProperty(type)) {
            // this is a dummy eventMapping
            // this means that this is a event-type, that is not yet supported
            // we do not need to register it on superclass
            // for now we output a warning
            //console.log("Warning - EventDispatcher:  trying to listen for unsupported event: : "+this.eventMappingDummys[type]);
            return;
        }
        if (this.eventMapping.hasOwnProperty(type)) {
            // a mapping exists for this event
            //making sure standart behaviour still works (listener is tracked in list)
            _super.prototype.addEventListener.call(this, type, listener);
            // call the provided "addListener" function
            this.eventMapping[type].addListener.call(this, this.eventMapping[type].adaptedType, this.eventMapping[type].callback);
            return;
        }
        // if we make it here, the event is not handled by this dispatcher
        // lets output a Warning for now.
        //console.log("EventDispatcher: trying to listen for unknown event: '"+type+"'")
    };
    /**
     * Remove an event listener
     * @method removeEventListener
     * @param {String} type of event to remove a listener for
     * @param {Function} listener function
     */
    EventDispatcher$$1.prototype.removeEventListener = function (type, listener) {
        _super.prototype.removeEventListener.call(this, type, listener);
        if (this.eventMapping.hasOwnProperty(type)) {
            // a mapping exists
            this.eventMapping[type].removeListener.call(this, this.eventMapping[type].adaptedType, this.eventMapping[type].callback);
        }
    };
    return EventDispatcher$$1;
}(_awayjs_core.EventDispatcher));

var DisplayObject$1 = (function (_super) {
    __extends(DisplayObject$$1, _super);
    /**
     *
     *
     * these events are handled from DisplayObjectContainer.
     * nothing really to much needs to be cnnected to awayjs.
     *
     * [broadcast event] Dispatched when the playhead is entering a new
     * frame.
     * @eventType	flash.events.Event.ENTER_FRAME
     [Event(name="enterFrame", type="flash.events.Event")]

     * [broadcast event] Dispatched after the constructors of frame displayobjects have run but before frame scripts have run.
     * @eventType	flash.events.Event.FRAME_CONSTRUCTED
     [Event(name="frameConstructed", type="flash.events.Event")]

     * [broadcast event] Dispatched when the playhead is exiting the current frame.
     * @eventType	flash.events.Event.EXIT_FRAME
     [Event(name="exitFrame", type="flash.events.Event")]

     * [broadcast event] Dispatched when the display list is about to be updated and rendered.
     * @eventType	flash.events.Event.RENDER
     [Event(name="render", type="flash.events.Event")]
     
     * Dispatched when a displayobject is about to be removed from the display list,
     * either directly or through the removal of a sub tree in which the displayobject is contained.
     * @eventType	flash.events.Event.REMOVED_FROM_STAGE
     [Event(name="removedFromStage", type="flash.events.Event")]

     * Dispatched when a displayobject is about to be removed from the display list.
     * @eventType	flash.events.Event.REMOVED
     [Event(name="removed", type="flash.events.Event")]

     * Dispatched when a displayobject is added to the on stage display list,
     * either directly or through the addition of a sub tree in which the displayobject is contained.
     * @eventType	flash.events.Event.ADDED_TO_STAGE
     [Event(name="addedToStage", type="flash.events.Event")]

     * Dispatched when a displayobject is added to the display list.
     * @eventType	flash.events.Event.ADDED
     [Event(name="added", type="flash.events.Event")]

     * The DisplayObject class is the base class for all anys that can be placed on
     * the display list. The display list manages all anys displayed in the Flash runtimes.
     * Use the DisplayObjectContainer class to arrange the displayobjects in the display list.
     * DisplayObjectContainer anys can have child displayobjects, while other displayobjects, such as
     * Shape and TextField anys, are "leaf" nodes that have only parents and siblings, no children.
     *
     *   <p class="- topic/p ">The DisplayObject class supports basic ality like the <i class="+ topic/ph hi-d/i ">x</i> and <i class="+ topic/ph hi-d/i ">y</i> position of
     * an any, as well as more advanced properties of the any such as its transformation matrix.
     * </p><p class="- topic/p ">DisplayObject is an abstract base class; therefore, you cannot call DisplayObject directly. Invoking
     * <codeph class="+ topic/ph pr-d/codeph ">new DisplayObject()</codeph> console.logs an <codeph class="+ topic/ph pr-d/codeph ">ArgumentError</codeph> exception. </p><p class="- topic/p ">All displayobjects inherit from the DisplayObject class.</p><p class="- topic/p ">The DisplayObject class itself does not include any APIs for rendering content onscreen.
     * For that reason, if you want create a custom subclass of the DisplayObject class, you will want
     * to extend one of its subclasses that do have APIs for rendering content onscreen,
     * such as the Shape, Sprite, Bitmap, SimpleButton, TextField, or MovieClip class.</p><p class="- topic/p ">The DisplayObject class contains several broadcast events. Normally, the target
     * of any particular event is a specific DisplayObject instance. For example,
     * the target of an <codeph class="+ topic/ph pr-d/codeph ">added</codeph> event is the specific DisplayObject instance
     * that was added to the display list. Having a single target restricts the placement of
     * event listeners to that target and in some cases the target's ancestors on the display list.
     * With broadcast events, however, the target is not a specific DisplayObject instance,
     * but rather all DisplayObject instances, including those that are not on the display list.
     * This means that you can add a listener to any DisplayObject instance to listen for broadcast events.
     * In addition to the broadcast events listed in the DisplayObject class's Events table,
     * the DisplayObject class also inherits two broadcast events from the EventDispatcher
     * class: <codeph class="+ topic/ph pr-d/codeph ">activate</codeph> and <codeph class="+ topic/ph pr-d/codeph ">deactivate</codeph>.</p><p class="- topic/p ">Some properties previously used in the ActionScript 1.0 and 2.0 MovieClip, TextField, and Button
     * classes (such as <codeph class="+ topic/ph pr-d/codeph ">_alpha</codeph>, <codeph class="+ topic/ph pr-d/codeph ">_height</codeph>, <codeph class="+ topic/ph pr-d/codeph ">_name</codeph>, <codeph class="+ topic/ph pr-d/codeph ">_width</codeph>,
     * <codeph class="+ topic/ph pr-d/codeph ">_x</codeph>, <codeph class="+ topic/ph pr-d/codeph ">_y</codeph>, and others) have equivalents in the ActionScript 3.0
     * DisplayObject class that are renamed so that they no longer begin with the underscore (_) character.</p><p class="- topic/p ">For more information, see the "Display Programming" chapter of the <i class="+ topic/ph hi-d/i ">ActionScript 3.0 Developer's Guide</i>.</p>

     */
    function DisplayObject$$1(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        var _this = _super.call(this) || this;
        _this._blockedByScript = false;
        _this._ctBlockedByScript = false;
        _this._visibilityByScript = false;
        _this.adaptee = adaptee || new _awayjs_scene.DisplayObject();
        // needed, because `this.stage` must already be available when constructor of extending classes are executed
        _this._stage = DisplayObject$$1.activeStage;
        // no eventMapping needed for the DisplayObject-events.
        // they can all be dispatched without listening on other objects
        // still need to create a dummy mapping with empty message, in order to have them registered
        // (we want unknown events to fail when they try to register in addEventListener
        _this.eventMappingExtern[Event.ENTER_FRAME] = "";
        _this.eventMappingExtern[Event.FRAME_CONSTRUCTED] = "";
        _this.eventMappingExtern[Event.EXIT_FRAME] = "";
        _this.eventMappingExtern[Event.RENDER] = "";
        //this.eventMappingExtern[Event.REMOVED_FROM_STAGE]="";
        _this.eventMappingExtern[Event.REMOVED] = "";
        //this.eventMappingExtern[Event.ADDED_TO_STAGE]="";
        _this.eventMappingExtern[Event.ADDED] = "";
        return _this;
    }
    Object.defineProperty(DisplayObject$$1, "activeStage", {
        get: function () {
            if (DisplayObject$$1._activeStage == null) {
            }
            return DisplayObject$$1._activeStage;
        },
        set: function (value) {
            DisplayObject$$1._activeStage = value;
        },
        enumerable: true,
        configurable: true
    });
    //		use to dispatch events on a object and all its childs
    //		overwritten in DisplayObjectContainer to work recursivly on children
    // 		used for:
    // 		- ENTER_FRAME
    // 		- FRAME_CONSTRUCTED
    // 		- EXIT_FRAME
    //		- RENDER
    //		- REMOVED_FROM_STAGE
    //		- ADDED_TO_STAGE
    DisplayObject$$1.prototype.dispatchEventRecursive = function (event) { this.dispatchEvent(event); };
    Object.defineProperty(DisplayObject$$1.prototype, "adaptee", {
        // --------------------- stuff needed because of implementing the existing IDisplayObjectAdapter
        get: function () {
            return this._adaptee;
        },
        set: function (value) {
            if (this._adaptee == value)
                return;
            if (this._adaptee)
                this._adaptee.adapter = null;
            this._adaptee = value;
            if (this._adaptee) {
                if (!this._adaptee.partition)
                    this._adaptee.partition = new _awayjs_scene.SceneGraphPartition(this._adaptee);
                this._adaptee.adapter = this;
            }
        },
        enumerable: true,
        configurable: true
    });
    DisplayObject$$1.prototype.doInitEvents = function () {
    };
    DisplayObject$$1.prototype.isBlockedByScript = function () {
        //console.log("isBlockedByScript not implemented yet in flash/DisplayObject");
        return this._blockedByScript;
    };
    DisplayObject$$1.prototype.isVisibilityByScript = function () {
        //console.log("isVisibilityByScript not implemented yet in flash/DisplayObject");
        return this._visibilityByScript;
    };
    DisplayObject$$1.prototype.isColorTransformByScript = function () {
        //console.log("isVisibilityByScript not implemented yet in flash/DisplayObject");
        return this._ctBlockedByScript;
    };
    DisplayObject$$1.prototype.freeFromScript = function () {
        //console.log("freeFromScript not implemented yet in flash/DisplayObject");
        this._blockedByScript = false;
        this._ctBlockedByScript = false;
        this._visibilityByScript = false;
    };
    DisplayObject$$1.prototype.clone = function () {
        return new DisplayObject$$1(this._adaptee.clone());
    };
    DisplayObject$$1.prototype.dispose = function () {
        throw new _awayjs_core.AbstractMethodError();
    };
    /**
     * @inheritDoc
     */
    DisplayObject$$1.prototype.disposeValues = function () {
        this.adaptee = null;
    };
    Object.defineProperty(DisplayObject$$1.prototype, "accessibilityProperties", {
        //---------------------------original as3 properties / methods:
        /**
         * The current accessibility options for this displayobject. If you modify the accessibilityProperties
         * property or any of the fields within accessibilityProperties, you must call
         * the Accessibility.updateProperties() method to make your changes take effect.
         *
         *   Note: For an any created in the Flash authoring environment, the value of accessibilityProperties
         * is prepopulated with any information you entered in the Accessibility panel for
         * that any.
         */
        get: function () {
            console.log("accessibilityProperties not implemented yet in flash/DisplayObject");
            //todo: flash.accessibility.AccessibilityProperties
            return null;
        },
        set: function (value) {
            console.log("accessibilityProperties not implemented yet in flash/DisplayObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "alpha", {
        /**
         * Indicates the alpha transparency value of the any specified.
         * Valid values are 0 (fully transparent) to 1 (fully opaque).
         * The default value is 1. displayobjects with alpha
         * set to 0 are active, even though they are invisible.
         */
        get: function () {
            return this.adaptee.alpha;
        },
        set: function (value) {
            this._ctBlockedByScript = true;
            this.adaptee.alpha = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "blendMode", {
        /**
         * A value from the BlendMode class that specifies which blend mode to use.
         * A bitmap can be drawn internally in two ways. If you have a blend mode enabled or an
         * external clipping mask, the bitmap is drawn by adding a bitmap-filled square shape to the vector
         * render. If you attempt to set this property to an invalid value, Flash runtimes set the value
         * to BlendMode.NORMAL.
         *
         *   The blendMode property affects each pixel of the displayobject.
         * Each pixel is composed of three constituent
         * colors (red, green, and blue), and each constituent color has a value between 0x00 and 0xFF.
         * Flash Player or Adobe AIR compares each constituent color of one pixel in the movie clip with
         * the corresponding color of the pixel in the background. For example, if blendMode
         * is set to BlendMode.LIGHTEN, Flash Player or Adobe AIR compares the red value of the displayobject with
         * the red value of the background, and uses the lighter of the two as the
         * value for the red component of the displayed color.The following table describes the blendMode settings.
         * The BlendMode class defines string values you can use.
         * The illustrations in the table show blendMode values applied to a circular
         * displayobject (2) superimposed on another displayobject (1).BlendMode ConstantIllustrationDescriptionBlendMode.NORMALThe displayobject appears in front of the background. Pixel values of the displayobject
         * override those of the background. Where the displayobject is transparent, the background is
         * visible.BlendMode.LAYERForces the creation of a transparency group for the displayobject. This means that the display
         * any is pre-composed in a temporary buffer before it is processed further. This is done
         * automatically if the displayobject is pre-cached using bitmap caching or if the displayobject is
         * a displayobject container with at least one child any with a blendMode
         * setting other than BlendMode.NORMAL. Not supported under GPU rendering.
         * BlendMode.MULTIPLYMultiplies the values of the displayobject constituent colors by the colors of the background color,
         * and then normalizes by dividing by 0xFF,
         * resulting in darker colors. This setting is commonly used for shadows and depth effects.
         *
         *   For example, if a constituent color (such as red) of one pixel in the displayobject and the
         * corresponding color of the pixel in the background both have the value 0x88, the multiplied
         * result is 0x4840. Dividing by 0xFF yields a value of 0x48 for that constituent color,
         * which is a darker shade than the color of the displayobject or the color of the background.BlendMode.SCREENMultiplies the complement (inverse) of the displayobject color by the complement of the background
         * color, resulting in a bleaching effect. This setting is commonly used for highlights or to remove black
         * areas of the displayobject.BlendMode.LIGHTENSelects the lighter of the constituent colors of the displayobject and the color of the background (the
         * colors with the larger values). This setting is commonly used for superimposing type.
         *
         *   For example, if the displayobject has a pixel with an RGB value of 0xFFCC33, and the background
         * pixel has an RGB value of 0xDDF800, the resulting RGB value for the displayed pixel is
         * 0xFFF833 (because 0xFF > 0xDD, 0xCC < 0xF8, and 0x33 > 0x00 = 33). Not supported under GPU rendering.BlendMode.DARKENSelects the darker of the constituent colors of the displayobject and the colors of the
         * background (the colors with the smaller values). This setting is commonly used for superimposing type.
         *
         *   For example, if the displayobject has a pixel with an RGB value of 0xFFCC33, and the background
         * pixel has an RGB value of 0xDDF800, the resulting RGB value for the displayed pixel is
         * 0xDDCC00 (because 0xFF > 0xDD, 0xCC < 0xF8, and 0x33 > 0x00 = 33). Not supported under GPU rendering.BlendMode.DIFFERENCECompares the constituent colors of the displayobject with the colors of its background, and subtracts
         * the darker of the values of the two constituent colors from the lighter value. This setting is commonly
         * used for more vibrant colors.
         *
         *   For example, if the displayobject has a pixel with an RGB value of 0xFFCC33, and the background
         * pixel has an RGB value of 0xDDF800, the resulting RGB value for the displayed pixel is
         * 0x222C33 (because 0xFF - 0xDD = 0x22, 0xF8 - 0xCC = 0x2C, and 0x33 - 0x00 = 0x33).BlendMode.ADDAdds the values of the constituent colors of the displayobject to the colors of its background, applying a
         * ceiling of 0xFF. This setting is commonly used for animating a lightening dissolve between
         * two anys.
         *
         *   For example, if the displayobject has a pixel with an RGB value of 0xAAA633, and the background
         * pixel has an RGB value of 0xDD2200, the resulting RGB value for the displayed pixel is
         * 0xFFC833 (because 0xAA + 0xDD > 0xFF, 0xA6 + 0x22 = 0xC8, and 0x33 + 0x00 = 0x33).BlendMode.SUBTRACTSubtracts the values of the constituent colors in the displayobject from the values of the
         * background color, applying a floor of 0. This setting is commonly used for animating a
         * darkening dissolve between two anys.
         *
         *   For example, if the displayobject has a pixel with an RGB value of 0xAA2233, and the background
         * pixel has an RGB value of 0xDDA600, the resulting RGB value for the displayed pixel is
         * 0x338400 (because 0xDD - 0xAA = 0x33, 0xA6 - 0x22 = 0x84, and 0x00 - 0x33 < 0x00).BlendMode.INVERTInverts the background.BlendMode.ALPHAApplies the alpha value of each pixel of the displayobject to the background.
         * This requires the blendMode setting of the parent displayobject to be set to
         * BlendMode.LAYER.
         * For example, in the illustration, the parent displayobject, which is a white background,
         * has blendMode = BlendMode.LAYER. Not supported under GPU rendering.BlendMode.ERASEErases the background based on the alpha value of the displayobject. This requires the
         * blendMode of the parent displayobject to be set to
         * BlendMode.LAYER. For example, in the
         * illustration, the parent displayobject, which is a white background, has
         * blendMode = BlendMode.LAYER. Not supported under GPU rendering.BlendMode.OVERLAYAdjusts the color of each pixel based on the darkness of the background.
         * If the background is lighter than 50% gray, the displayobject and background colors are
         * screened, which results in a lighter color. If the background is darker than 50% gray,
         * the colors are multiplied, which results in a darker color.
         * This setting is commonly used for shading effects. Not supported under GPU rendering.BlendMode.HARDLIGHTAdjusts the color of each pixel based on the darkness of the displayobject.
         * If the displayobject is lighter than 50% gray, the displayobject and background colors are
         * screened, which results in a lighter color. If the displayobject is darker than 50% gray,
         * the colors are multiplied, which results in a darker color.
         * This setting is commonly used for shading effects. Not supported under GPU rendering.BlendMode.SHADERN/AAdjusts the color using a custom shader routine. The shader that is used is specified
         * as the Shader instance assigned to the blendShader property. Setting the
         * blendShader property of a displayobject to a Shader instance
         * automatically sets the displayobject's blendMode property to
         * BlendMode.SHADER. If the blendMode property is set to
         * BlendMode.SHADER without first setting the blendShader property,
         * the blendMode property is set to BlendMode.NORMAL. Not supported under GPU rendering.
         */
        get: function () {
            console.log("blendMode not implemented yet in flash/DisplayObject");
            // todo: translate awayblendmode to as3blendmode
            return "";
        },
        set: function (value) {
            console.log("blendMode not implemented yet in flash/DisplayObject");
            //this._adaptee.blendMode=value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "blendShader", {
        /**
         * Sets a shader that is used for blending the foreground and background. When the
         * blendMode property is set to BlendMode.SHADER, the specified
         * Shader is used to create the blend mode output for the displayobject.
         *
         *   Setting the blendShader property of a displayobject to a Shader instance
         * automatically sets the displayobject's blendMode property to
         * BlendMode.SHADER. If the blendShader property is set (which sets the
         * blendMode property to BlendMode.SHADER), then the value of the
         * blendMode property is changed, the blend mode can be reset to use the blend
         * shader simply by setting the blendMode property to BlendMode.SHADER.
         * The blendShader property does not need to be set again except to change the
         * shader that's used for the blend mode.The Shader assigned to the blendShader property must specify at least two
         * image4 inputs. The inputs do not need to be specified in code using the
         * associated ShaderInput anys' input properties. The background displayobject
         * is automatically
         * used as the first input (the input with index 0). The foreground displayobject
         * is used as the second input (the input with index 1). A shader used as a blend
         * shader can specify more than two inputs. In that case, any additional input must be specified
         * by setting its ShaderInput instance's input property.When you assign a Shader instance to this property the shader is copied internally. The
         * blend operation uses that internal copy, not a reference to the original shader. Any changes
         * made to the shader, such as changing a parameter value, input, or bytecode, are not applied
         * to the copied shader that's used for the blend mode.
         * @langversion	3.0
         * @playerversion	Flash 10
         * @playerversion	AIR 1.5
         * @console.logs	ArgumentError When the shader output type is not compatible with this operation
         *   (the shader must specify a pixel4
         *   output).
         * @console.logs	ArgumentError When the shader specifies fewer than two image inputs or the first
         *   two inputs are not image4 inputs.
         * @console.logs	ArgumentError When the shader specifies an image input that isn't provided.
         * @console.logs	ArgumentError When a Byte[] or Vector.<number> instance is used as
         *   an input and the width
         *   and height properties aren't specified for the
         *   ShaderInput, or the specified values don't match the amount of
         *   data in the input any. See the ShaderInput.input
         *   property for more information.
         */
        set: function (value) {
            console.log("blendShader not implemented yet in flash/DisplayObject");
            //todo (if ever)
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "cacheAsBitmap", {
        /**
         * If set to true, Flash runtimes cache an internal bitmap representation of the
         * displayobject. This caching can increase performance for displayobjects that contain complex
         * vector content.
         *
         *   All vector data for a displayobject that has a cached bitmap is drawn to the bitmap
         * instead of the main display. If cacheAsBitmapMatrix is null or unsupported,
         * the bitmap is then copied to the main display as unstretched, unrotated pixels snapped to
         * the nearest pixel boundaries. Pixels are mapped 1 to 1 with
         * the parent any. If the bounds of the bitmap change, the bitmap is recreated instead
         * of being stretched.If cacheAsBitmapMatrix is non-null and supported, the any is drawn to the off-screen bitmap
         * using that matrix and the stretched and/or rotated results of that rendering are used
         * to draw the any to the main display.No internal bitmap is created unless the cacheAsBitmap property is set to
         * true.After you set the cacheAsBitmap property to true,
         * the rendering does not change, however the displayobject performs pixel snapping
         * automatically. The animation speed can be significantly faster depending
         * on the complexity of the vector content.
         * The cacheAsBitmap property is automatically set to true
         * whenever you apply a filter to a displayobject (when its filter [] is not empty),
         * and if a displayobject has a filter applied to it, cacheAsBitmap is reported as
         * true for that displayobject, even if you set the property to false.
         * If you clear all filters for a displayobject, the cacheAsBitmap setting changes to
         * what it was last set to.A displayobject does not use a bitmap even if the cacheAsBitmap
         * property is set to true and instead renders from vector data in the following cases:The bitmap is too large.
         * In  AIR 1.5 and Flash Player 10, the maximum size for a bitmap image is 8,191 pixels in width or height,
         * and the total number of pixels cannot exceed 16,777,215 pixels. (So, if a bitmap image is 8,191 pixels
         * wide, it can only be 2,048 pixels high.) In Flash Player 9 and earlier, the limitation is
         * is 2880 pixels in height and 2,880 pixels in width.The bitmap fails to allocate (out of memory error). The cacheAsBitmap property is best used with movie clips that have
         * mostly static content and that do not scale and rotate frequently. With such movie
         * clips, cacheAsBitmap can lead to performance increases when the
         * movie clip is translated (when its x and y position is changed).
         */
        get: function () {
            console.log("cacheAsBitmap not implemented yet in flash/DisplayObject");
            return false;
        },
        set: function (value) {
            console.log("cacheAsBitmap not implemented yet in flash/DisplayObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "filters", {
        /**
         * An indexed [] that contains each filter any currently associated with the displayobject.
         * The flash.filters package contains several classes that define specific filters you can
         * use.
         *
         *   Filters can be applied in Flash Professional at design time, or at run time by using
         * ActionScript code. To apply a filter by using ActionScript, you must make a temporary copy of the
         * entire filters [], modify the temporary [], then assign the value
         * of the temporary [] back to the filters []. You cannot directly
         * add a new filter any to the filters [].To add a filter by using ActionScript, perform the following steps (assume that the
         * target displayobject is named myDisplayObject):Create a new filter any by using the constructor method of your chosen filter
         * class.Assign the value of the myDisplayObject.filters [] to a temporary [], such
         * as one named myFilters.Add the new filter any to the myFilters temporary [].Assign the value of the temporary [] to the myDisplayObject.filters [].If the filters [] is undefined, you do not need to use a temporary [].
         * Instead, you can directly assign an [] literal that contains one or more filter anys that
         * you create. The first example in the Examples section adds a drop shadow filter by using
         * code that handles both defined and undefined filters []s.To modify an existing filter any,
         * you must use the technique of modifying a copy of the filters []:Assign the value of the filters [] to a temporary [], such as one
         * named myFilters.Modify the property by using the temporary [], myFilters. For example,
         * to set the quality property of the first filter in the [], you could use the
         * following code: myFilters[0].quality = 1;Assign the value of the temporary [] to the filters [].At load time, if a displayobject has an associated filter, it is marked to cache itself as a
         * transparent bitmap. From this point forward, as long as the displayobject has a valid filter list,
         * the player caches the displayobject as a bitmap. This source bitmap is used as a source
         * image for the filter effects. Each displayobject usually has two bitmaps: one with the
         * original unfiltered source displayobject and another for the final image after filtering.
         * The final image is used when rendering. As long as the displayobject does not
         * change, the final image does not need updating.The flash.filters package includes classes for filters. For example, to create a DropShadow
         * filter, you would write:
         * <codeblock>
         *
         *   import flash.filters.DropShadowFilter
         * var myFilter:DropShadowFilter = new DropShadowFilter (distance, angle, color, alpha, blurX, blurY, quality, inner, knockout)
         *
         *   </codeblock>
         * You can use the is operator to determine the type of filter assigned to
         * each index position in the filter []. For example, the following code shows
         * how to determine the position of the first filter in the filters [] that
         * is a DropShadowFilter:
         *
         *   <codeblock>
         *
         *   import flash.text.TextField;
         * import flash.filters.~~;
         * var tf:TextField = new TextField();
         * var filter1:DropShadowFilter = new DropShadowFilter();
         * var filter2:GradientGlowFilter = new GradientGlowFilter();
         * tf.filters = [filter1, filter2];
         *
         *   tf.text = "DropShadow index: " + filterPosition(tf, DropShadowFilter).tostring(); // 0
         * addChild(tf)
         *
         *    filterPosition(DisplayObject:DisplayObject, filterClass:Class):int {
             * for (var i:uint = 0; i < DisplayObject.filters.length; i++) {
             * if (DisplayObject.filters[i] is filterClass) {
             * return i;
             * }
             * }
             * return -1;
             * }
         *
         *   </codeblock>
         * Note: Since you cannot directly add a new filter any to the
         * DisplayObject.filters [], the following code has no
         * effect on the target displayobject, named myDisplayObject:
         * <codeblock>
         *
         *   myDisplayObject.filters.push(myDropShadow);
         *
         *   </codeblock>
         * @langversion	3.0
         * @playerversion	Flash 9
         * @console.logs	ArgumentError When filters includes a ShaderFilter and the shader
         *   output type is not compatible with this operation
         *   (the shader must specify a pixel4
         *   output).
         * @console.logs	ArgumentError When filters includes a ShaderFilter and the shader
         *   doesn't specify any image input or the first
         *   input is not an image4 input.
         * @console.logs	ArgumentError When filters includes a ShaderFilter and the shader
         *   specifies an image input that isn't provided.
         * @console.logs	ArgumentError When filters includes a ShaderFilter, a
         *   Byte[] or Vector.<number> instance as
         *   a shader input, and the width
         *   and height properties aren't specified for the
         *   ShaderInput any, or the specified values don't match the amount of
         *   data in the input data. See the ShaderInput.input
         *   property for more information.
         */
        get: function () {
            //console.log("filters not implemented yet in flash/DisplayObject");
            return [];
        },
        set: function (value) {
            //console.log("filters not implemented yet in flash/DisplayObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "height", {
        /**
         * Indicates the height of the displayobject, in pixels. The height is calculated based on the bounds of the content of the displayobject.
         * When you set the height property, the scaleY property is adjusted accordingly, as shown in the
         * following code:
         *
         *   <codeblock>
         *
         *   var rect:Shape = new Shape();
         * rect.graphics.beginFill(0xFF0000);
         * rect.graphics.drawRect(0, 0, 100, 100);
         * trace(rect.scaleY) // 1;
         * rect.height = 200;
         * trace(rect.scaleY) // 2;
         * </codeblock>
         * Except for TextField and Video anys, a displayobject with no content (such as an empty sprite) has a height
         * of 0, even if you try to set height to a different value.
         */
        get: function () {
            if (!this._adaptee.partition) {
                console.warn("Trying to get Display.height on orphan child!");
                return 100;
            }
            var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).getBoxBounds(this.adaptee);
            return (box == null) ? 0 : box.height;
        },
        set: function (value) {
            if (isNaN(value))
                return;
            if (!this._adaptee.partition) {
                console.warn("Trying to set Display.height on orphan child!");
                return;
            }
            _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).height = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "loaderInfo", {
        /**
         * Returns a LoaderInfo any containing information about loading the file
         * to which this displayobject belongs. The loaderInfo property is defined only
         * for the root displayobject of a SWF file or for a loaded Bitmap (not for a Bitmap that is drawn
         * with ActionScript). To find the loaderInfo any associated with the SWF file that contains
         * a displayobject named myDisplayObject, use myDisplayObject.root.loaderInfo.
         *
         *   A large SWF file can monitor its download by calling
         * this.root.loaderInfo.addEventListener(Event.COMPLETE, func).
         */
        get: function () {
            //console.log("loaderInfo not implemented yet in flash/DisplayObject");
            //this._adaptee.loaderInfo
            return this._loaderInfo;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "mask", {
        /**
         * The calling displayobject is masked by the specified mask any.
         * To ensure that masking works when the Stage is scaled, the mask displayobject
         * must be in an active part of the display list. The mask any itself is not drawn.
         * Set mask to null to remove the mask.
         *
         *   To be able to scale a mask any, it must be on the display list. To be able to drag a mask Sprite any
         * (by calling its startDrag() method), it must be on the display list. To call the
         * startDrag() method for a mask sprite based on a mouseDown event
         * being dispatched by the sprite, set the sprite's buttonMode property to true.When displayobjects are cached by setting the cacheAsBitmap property to
         * true an the cacheAsBitmapMatrix property to a Matrix any,
         * both the mask and the displayobject being masked must be part of the same cached
         * bitmap. Thus, if the displayobject is cached, then the mask must be a child of the displayobject.
         * If an ancestor of the displayobject on the display list is cached, then the mask must be a child of
         * that ancestor or one of its descendents. If more than one ancestor of the masked any is cached,
         * then the mask must be a descendent of the cached container closest to the masked any in the display list.Note: A single mask any cannot be used to mask more than one calling displayobject.
         * When the mask is assigned to a second displayobject, it is removed as the mask of the first
         * any, and that any's mask property becomes null.
         */
        get: function () {
            if (this.adaptee.masks == null) {
                return null;
            }
            if (this.adaptee.masks.length == 0) {
                return null;
            }
            return this.adaptee.masks[0].adapter;
        },
        set: function (value) {
            if (value == null) {
                if (this.adaptee.masks != null) {
                    this.adaptee.masks[0].maskMode = false;
                }
                this.adaptee.masks = null;
                return;
            }
            value.adaptee.maskMode = true;
            this.adaptee.masks = [value.adaptee];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "metaData", {
        get: function () {
            console.log("mask not implemented yet in flash/DisplayObject");
            return null;
        },
        set: function (data) {
            console.log("mask not implemented yet in flash/DisplayObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "mouseX", {
        /**
         * Indicates the x coordinate of the mouse or user input device position, in pixels.
         *
         *   Note: For a DisplayObject that has been rotated, the returned x coordinate will reflect the
         * non-rotated any.
         */
        get: function () {
            //console.log("mouseX not implemented yet in flash/DisplayObject");
            //todo: theres probably a faster option than this
            return this.adaptee.transform.globalToLocal(new _awayjs_core.Point(this.stage.mouseX, 0)).x;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "mouseY", {
        /**
         * Indicates the y coordinate of the mouse or user input device position, in pixels.
         *
         *   Note: For a DisplayObject that has been rotated, the returned y coordinate will reflect the
         * non-rotated any.
         */
        get: function () {
            //todo: theres probably a faster option than this
            return this.adaptee.transform.globalToLocal(new _awayjs_core.Point(0, this.stage.mouseY)).y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "name", {
        /**
         * Indicates the instance name of the DisplayObject. The any can be identified in
         * the child list of its parent displayobject container by calling the
         * getChildByName() method of the displayobject container.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         * @console.logs	IllegalOperationError If you are attempting to set this property on an any that was
         *   placed on the timeline in the Flash authoring tool.
         */
        get: function () {
            return this.adaptee.name;
        },
        set: function (value) {
            this.adaptee.name = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "opaqueBackground", {
        /**
         * Specifies whether the displayobject is opaque with a certain background color.
         * A transparent bitmap contains alpha
         * channel data and is drawn transparently. An opaque bitmap has no alpha channel (and renders faster
         * than a transparent bitmap). If the bitmap is opaque, you specify its own background color to use.
         *
         *   If set to a number value, the surface is opaque (not transparent) with the RGB background
         * color that the number specifies. If set to null (the default value), the display
         * any has a transparent background.The opaqueBackground property is intended mainly for use with the
         * cacheAsBitmap property, for rendering optimization. For displayobjects in which the
         * cacheAsBitmap property is set to true, setting opaqueBackground can
         * improve rendering performance.The opaque background region is not matched when calling the hitTestPoint()
         * method with the shapeFlag parameter set to true.The opaque background region does not respond to mouse events.
         */
        get: function () {
            console.log("opaqueBackground not implemented yet in flash/DisplayObject");
            return null;
        },
        set: function (value) {
            console.log("opaqueBackground not implemented yet in flash/DisplayObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "parent", {
        /**
         * Indicates the DisplayObjectContainer any that contains this displayobject. Use the parent
         * property to specify a relative path to displayobjects that are above the
         * current displayobject in the display list hierarchy.
         *
         *   You can use parent to move up multiple levels in the display list as in the following:
         * @console.logs	SecurityError The parent displayobject belongs to a security sandbox
         *   to which you do not have access. You can avoid this situation by having
         *   the parent movie call the Security.allowDomain() method.
         */
        get: function () {
            if (this.adaptee.parent == null) {
                return null;
            }
            return this.adaptee.parent.adapter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "root", {
        /**
         * For a displayobject in a loaded SWF file, the root property is the
         * top-most displayobject in the portion of the display list's tree structure represented by that SWF file.
         * For a Bitmap any representing a loaded image file, the root property is the Bitmap any
         * itself. For the instance of the main class of the first SWF file loaded, the root property is the
         * displayobject itself. The root property of the Stage any is the Stage any itself. The root
         * property is set to null for any displayobject that has not been added to the display list, unless
         * it has been added to a displayobject container that is off the display list but that is a child of the
         * top-most displayobject in a loaded SWF file.
         *
         *   For example, if you create a new Sprite any by calling the Sprite() constructor method,
         * its root property is null until you add it to the display list (or to a display
         * any container that is off the display list but that is a child of the top-most displayobject in a SWF file).For a loaded SWF file, even though the Loader any used to load the file may not be on the display list,
         * the top-most displayobject in the SWF file has its root property set to itself.  The Loader any
         * does not have its root property set until it is added as a child of a displayobject for which the
         * root property is set.
         */
        get: function () {
            console.log("root not implemented yet in flash/DisplayObject");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "rotation", {
        /**
         * Indicates the rotation of the DisplayObject instance, in degrees, from its original orientation. Values from 0 to 180 represent
         * clockwise rotation; values from 0 to -180 represent counterclockwise rotation. Values outside this range are added to or
         * subtracted from 360 to obtain a value within the range. For example, the statement my_video.rotation = 450 is the
         * same as  my_video.rotation = 90.
         */
        get: function () {
            return this.adaptee.rotationZ;
        },
        set: function (value) {
            this.adaptee.rotationZ = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "rotationX", {
        /**
         * Indicates the x-axis rotation of the DisplayObject instance, in degrees, from its original orientation relative to the 3D parent container. Values from 0 to 180 represent
         * clockwise rotation; values from 0 to -180 represent counterclockwise rotation. Values outside this range are added to or
         * subtracted from 360 to obtain a value within the range.
         */
        get: function () {
            return this.adaptee.rotationX;
        },
        set: function (value) {
            this.adaptee.rotationX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "rotationY", {
        /**
         * Indicates the y-axis rotation of the DisplayObject instance, in degrees, from its original orientation relative to the 3D parent container. Values from 0 to 180 represent
         * clockwise rotation; values from 0 to -180 represent counterclockwise rotation. Values outside this range are added to or
         * subtracted from 360 to obtain a value within the range.
         * @langversion	3.0
         * @playerversion	Flash 10
         * @playerversion	AIR 1.5
         * @playerversion	Lite 4
         */
        get: function () {
            return this.adaptee.rotationY;
        },
        set: function (value) {
            this.adaptee.rotationY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "rotationZ", {
        /**
         * Indicates the z-axis rotation of the DisplayObject instance, in degrees, from its original orientation relative to the 3D parent container. Values from 0 to 180 represent
         * clockwise rotation; values from 0 to -180 represent counterclockwise rotation. Values outside this range are added to or
         * subtracted from 360 to obtain a value within the range.
         */
        get: function () {
            return this.adaptee.rotationZ;
        },
        set: function (value) {
            this.adaptee.rotationZ = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "scale9Grid", {
        /**
         * The current scaling grid that is in effect. If set to null,
         * the entire displayobject is scaled normally when any scale transformation is
         * applied.
         *
         *   When you define the scale9Grid property, the displayobject is divided into a
         * grid with nine regions based on the scale9Grid rectangle, which defines the
         * center region of the grid. The eight other regions of the grid are the following areas: The upper-left corner outside of the rectangleThe area above the rectangle The upper-right corner outside of the rectangleThe area to the left of the rectangleThe area to the right of the rectangleThe lower-left corner outside of the rectangleThe area below the rectangleThe lower-right corner outside of the rectangleYou can think of the eight regions outside of the center (defined by the rectangle)
         * as being like a picture frame that has special rules applied to it when scaled.When the scale9Grid property is set and a displayobject is scaled, all text and
         * gradients are scaled normally; however, for other types of anys the following rules apply:Content in the center region is scaled normally. Content in the corners is not scaled. Content in the top and bottom regions is scaled horizontally only. Content in the
         * left and right regions is scaled vertically only.All fills (including bitmaps, video, and gradients) are stretched to fit their shapes.If a displayobject is rotated, all subsequent scaling is normal (and the
         * scale9Grid property is ignored).For example, consider the following displayobject and a rectangle that is applied as the display
         * any's scale9Grid:The displayobject.The red rectangle shows the scale9Grid.When the displayobject is scaled or stretched, the anys within the rectangle scale
         * normally, but the anys outside of the rectangle scale according to the
         * scale9Grid rules:Scaled to 75%:Scaled to 50%:Scaled to 25%:Stretched horizontally 150%: A common use for setting scale9Grid is to set up a displayobject to be used
         * as a component, in which edge regions retain the same width when the component is scaled.
         * @maelexample	The following creates a movie clip that contains a 20-pixel line (which forms a border)
         *   and a gradient fill. The movie clip scales based on the mouse position, and because of the
         *   <code>scale9Grid</code> set for the movie clip, the thickness of the 20-pixel line does not
         *   vary when the clip scales (although the gradient in the movie clip <em>does</em> scale):
         *
         *     <listing version="2.0">
         *   import Rectangle;
         *   import flash.geom.Matrix;
         *
         *     this.createEmptyMovieClip("my_mc", this.getNextHighestDepth());
         *
         *     var grid:Rectangle = new Rectangle(20, 20, 260, 260);
         *   my_mc.scale9Grid = grid ;
         *
         *     my_mc._x = 50;
         *   my_mc._y = 50;
         *
         *      onMouseMove()
         *   {
             *   my_mc._width  = _xmouse;
             *   my_mc._height = _ymouse;
             *   }
         *
         *     my_mc.lineStyle(20, 0xff3333, 100);
         *   var gradient_matrix:Matrix = new Matrix();
         *   gradient_matrix.createGradientBox(15, 15, Math.PI, 10, 10);
         *   my_mc.beginGradientFill("radial", [0xffff00, 0x0000ff],
         *   [100, 100], [0, 0xFF], gradient_matrix,
         *   "reflect", "RGB", 0.9);
         *   my_mc.moveTo(0, 0);
         *   my_mc.lineTo(0, 300);
         *   my_mc.lineTo(300, 300);
         *   my_mc.lineTo(300, 0);
         *   my_mc.lineTo(0, 0);
         *   my_mc.endFill();
         *   </listing>
         * @console.logs	ArgumentError If you pass an invalid argument to the method.
         */
        get: function () {
            return this.adaptee.scale9Grid;
        },
        set: function (innerRectangle) {
            this.adaptee.scale9Grid = innerRectangle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "scaleX", {
        /**
         * Indicates the horizontal scale (percentage) of the any as applied from the registration point. The default
         * registration point is (0,0). 1.0 equals 100% scale.
         *
         *   Scaling the local coordinate system changes the x and y property values, which are defined in
         * whole pixels.
         */
        get: function () {
            return this.adaptee.scaleX;
        },
        set: function (value) {
            this.adaptee.scaleX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "scaleY", {
        /**
         * Indicates the vertical scale (percentage) of an any as applied from the registration point of the any. The
         * default registration point is (0,0). 1.0 is 100% scale.
         *
         *   Scaling the local coordinate system changes the x and y property values, which are defined in
         * whole pixels.
         */
        get: function () {
            return this.adaptee.scaleY;
        },
        set: function (value) {
            this.adaptee.scaleY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "scaleZ", {
        /**
         * Indicates the depth scale (percentage) of an any as applied from the registration point of the any. The
         * default registration point is (0,0). 1.0 is 100% scale.
         *
         *   Scaling the local coordinate system changes the x, y and z property values, which are defined in
         * whole pixels.
         */
        get: function () {
            return this.adaptee.scaleZ;
        },
        set: function (value) {
            this.adaptee.scaleZ = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "scrollRect", {
        /**
         * The scroll rectangle bounds of the displayobject. The displayobject is cropped to the size
         * defined by the rectangle, and it scrolls within the rectangle when you change the
         * x and y properties of the scrollRect any.
         *
         *   The properties of the scrollRect Rectangle any use the displayobject's coordinate space
         * and are scaled just like the overall displayobject. The corner bounds of the cropped window on the scrolling
         * displayobject are the origin of the displayobject (0,0) and the point defined by the
         * width and height of the rectangle. They are not centered around the origin, but
         * use the origin to define the upper-left corner of the area. A scrolled displayobject always
         * scrolls in whole pixel increments. You can scroll an any left and right by setting the x property of the
         * scrollRect Rectangle any. You can scroll an any up and down by setting
         * the y property of the scrollRect Rectangle any. If the displayobject
         * is rotated 90° and you scroll it left and right, the displayobject actually scrolls up and down.
         */
        get: function () {
            return this.adaptee.scrollRect;
        },
        set: function (value) {
            this.adaptee.scrollRect = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "stage", {
        /**
         * The Stage of the displayobject. A Flash runtime application has only one Stage any.
         * For example, you can create and load multiple displayobjects into the display list, and the
         * stage property of each displayobject refers to the same Stage any (even if the
         * displayobject belongs to a loaded SWF file).
         *
         *   If a displayobject is not added to the display list, its stage property is set to
         * null.
         */
        get: function () {
            return this._stage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "transform", {
        /**
         * An any with properties pertaining to a displayobject's matrix, color transform, and pixel bounds.
         * The specific properties — matrix, colorTransform, and three read-only properties
         * (concatenatedMatrix, concatenatedColorTransform,
         * and pixelBounds) — are described in the entry for the Transform class.
         *
         *   Each of the transform any's properties is itself an any. This concept is important because the only
         * way to set new values for the matrix or colorTransform anys is to create a new any and copy that
         * any into the transform.matrix or transform.colorTransform property.For example, to increase the tx value of a displayobject's matrix, you must make a
         * copy of the entire matrix any, then copy the new any into the matrix property of the transform
         * any:
         * var myMatrix:Matrix = myDisplayObject.transform.matrix;
         * myMatrix.tx += 10;
         * myDisplayObject.transform.matrix = myMatrix;
         * You cannot directly set the tx property. The following code has
         * no effect on myDisplayObject:
         * myDisplayObject.transform.matrix.tx += 10;
         * You can also copy an entire transform any and assign it to another
         * displayobject's transform property. For example, the following code
         * copies the entire transform any from myOldDisplayObj to
         * myNewDisplayObj:myNewDisplayObj.transform = myOldDisplayObj.transform;The resulting displayobject, myNewDisplayObj, now has the same values for its
         * matrix, color transform, and pixel bounds as the old displayobject, myOldDisplayObj.Note that AIR for TV devices use hardware acceleration, if it is available, for color transforms.
         */
        get: function () {
            this._ctBlockedByScript = true;
            return this.adaptee.transform;
        },
        set: function (value) {
            console.log("DisplayObject:setter for transform not yet implemented");
            //this._adaptee.transform=value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "visible", {
        /**
         * Whether or not the displayobject is visible. displayobjects that are not visible
         * are disabled. For example, if visible=false for an Interactiveany instance,
         * it cannot be clicked.
         */
        get: function () {
            return this.adaptee.visible;
        },
        set: function (value) {
            this._visibilityByScript = true;
            this.adaptee.visible = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "width", {
        /**
         * Indicates the width of the displayobject, in pixels. The width is calculated based on the bounds of the content of the displayobject.
         * When you set the width property, the scaleX property is adjusted accordingly, as shown in the
         * following code:
         *
         *   <codeblock>
         *
         *   var rect:Shape = new Shape();
         * rect.graphics.beginFill(0xFF0000);
         * rect.graphics.drawRect(0, 0, 100, 100);
         * trace(rect.scaleX) // 1;
         * rect.width = 200;
         * trace(rect.scaleX) // 2;
         * </codeblock>
         * Except for TextField and Video anys, a displayobject with no content (such as an empty sprite) has a width
         * of 0, even if you try to set width to a different value.
         */
        get: function () {
            //todo2019
            if (!this.adaptee.partition) {
                console.warn("Trying to get Display.width on orphan child!");
                return 100;
            }
            var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).getBoxBounds(this.adaptee);
            return (box == null) ? 0 : box.width;
        },
        set: function (value) {
            if (!this.adaptee.partition) {
                console.warn("Trying to set Display.width on orphan child!");
                return;
            }
            //todo2019
            if (isNaN(value))
                return;
            _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).width = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "x", {
        /**
         * Indicates the x coordinate of the DisplayObject instance relative to the local coordinates of
         * the parent DisplayObjectContainer. If the any is inside a DisplayObjectContainer that has
         * transformations, it is in the local coordinate system of the enclosing DisplayObjectContainer.
         * Thus, for a DisplayObjectContainer rotated 90° counterclockwise, the DisplayObjectContainer's
         * children inherit a coordinate system that is rotated 90° counterclockwise.
         * The any's coordinates refer to the registration point position.
         */
        get: function () {
            return this.adaptee.x;
        },
        set: function (value) {
            this.adaptee.x = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "y", {
        /**
         * Indicates the y coordinate of the DisplayObject instance relative to the local coordinates of
         * the parent DisplayObjectContainer. If the any is inside a DisplayObjectContainer that has
         * transformations, it is in the local coordinate system of the enclosing DisplayObjectContainer.
         * Thus, for a DisplayObjectContainer rotated 90° counterclockwise, the DisplayObjectContainer's
         * children inherit a coordinate system that is rotated 90° counterclockwise.
         * The any's coordinates refer to the registration point position.
         */
        get: function () {
            return this.adaptee.y;
        },
        set: function (value) {
            this.adaptee.y = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObject$$1.prototype, "z", {
        /**
         * Indicates the z coordinate position along the z-axis of the DisplayObject
         * instance relative to the 3D parent container. The z property is used for
         * 3D coordinates, not screen or pixel coordinates.
         * When you set a z property for a displayobject to something other than the default
         * value of 0, a corresponding Matrix3D any is automatically created. for adjusting a
         * displayobject's position and orientation
         * in three dimensions. When working with the z-axis,
         * the existing behavior of x and y properties changes from screen or pixel coordinates to
         * positions relative to the 3D parent container.For example, a child of the _root  at position x = 100, y = 100, z = 200
         * is not drawn at pixel location (100,100). The child is drawn wherever the 3D projection
         * calculation puts it. The calculation is: (x~~cameraFocalLength/cameraRelativeZPosition, y~~cameraFocalLength/cameraRelativeZPosition)
         */
        get: function () {
            return this.adaptee.z;
        },
        set: function (value) {
            this.adaptee.z = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Returns a rectangle that defines the area of the displayobject relative to the coordinate system
     * of the targetCoordinateSpace any.
     * Consider the following code, which shows how the rectangle returned can vary depending on the
     * targetCoordinateSpace parameter that you pass to the method:
     *
     *   <codeblock>
     *
     *   var container:Sprite = new Sprite();
     * container.x = 100;
     * container.y = 100;
     * this.addChild(container);
     * var contents:Shape = new Shape();
     * contents.graphics.drawCircle(0,0,100);
     * container.addChild(contents);
     * trace(contents.getBounds(container));
     * // (x=-100, y=-100, w=200, h=200)
     * trace(contents.getBounds(this));
     * // (x=0, y=0, w=200, h=200)
     *
     *   </codeblock>
     * Note: Use the localToGlobal() and
     * globalToLocal() methods to convert the displayobject's local coordinates
     * to display coordinates, or display coordinates to local coordinates, respectively.The getBounds() method is similar to the getRect() method;
     * however, the Rectangle returned by the getBounds() method includes any strokes
     * on shapes, whereas the Rectangle returned by the getRect() method does not.
     * For an example, see the description of the getRect() method.
     * @param	targetCoordinateSpace	The displayobject that defines the coordinate system to use.
     * @return	The rectangle that defines the area of the displayobject relative to
     *   the targetCoordinateSpace any's coordinate system.
     */
    DisplayObject$$1.prototype.getBounds = function (targetCoordinateSpace) {
        //console.log("DisplayObject:getBounds not yet implemented");
        var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).getBoxBounds(this.adaptee);
        return new _awayjs_core.Rectangle(box.x, box.y, box.width, box.height);
    };
    /**
     * Returns a rectangle that defines the boundary of the displayobject,
     * based on the coordinate system defined by the targetCoordinateSpace
     * parameter, excluding any strokes on shapes. The values that the getRect() method
     * returns are the same or smaller than those returned by the getBounds() method.
     *
     *   Note: Use localToGlobal() and globalToLocal() methods
     * to convert the displayobject's local coordinates to Stage coordinates, or Stage coordinates to
     * local coordinates, respectively.
     * @param	targetCoordinateSpace	The displayobject that defines the coordinate system to use.
     * @return	The rectangle that defines the area of the displayobject relative to
     *   the targetCoordinateSpace any's coordinate system.
     */
    DisplayObject$$1.prototype.getRect = function (targetCoordinateSpace) {
        console.log("DisplayObject:getRect not yet implemented");
        return new _awayjs_core.Rectangle(); //this._adaptee.getBounds();
    };
    /**
     * Converts the point any from the Stage (global) coordinates
     * to the displayobject's (local) coordinates.
     *
     *   To use this method, first create an instance of the Point class. The
     * x and y values that you assign represent global coordinates because they
     * relate to the origin (0,0) of the main display area. Then pass the Point instance
     * as the parameter to the globalToLocal() method. The method returns a new Point any with
     * x and y values that relate to the origin of the displayobject
     * instead of the origin of the Stage.
     * @param	point	An any created with the Point class. The Point any
     *   specifies the x and y coordinates as properties.
     * @return	A Point any with coordinates relative to the displayobject.
     */
    DisplayObject$$1.prototype.globalToLocal = function (point) {
        return this.adaptee.transform.globalToLocal(point);
    };
    /**
     * Converts a two-dimensional point from the Stage (global) coordinates to a
     * three-dimensional displayobject's (local) coordinates.
     *
     *   To use this method, first create an instance of the Point class.
     * The x and y values that you assign to the Point any represent global
     * coordinates because they are relative to the origin (0,0) of the main display area.
     * Then pass the Point any to the globalToLocal3D()
     * method as the point parameter. The method returns three-dimensional
     * coordinates as a Vector3D any containing x, y, and
     * z values that are relative to the origin
     * of the three-dimensional displayobject.
     * @param	point	A two dimensional Point any representing global x and y coordinates.
     * @return	A Vector3D any with coordinates relative to the three-dimensional
     *   displayobject.
     */
    DisplayObject$$1.prototype.globalToLocal3D = function (point) {
        console.log("DisplayObject:globalToLocal3D not yet implemented");
        return new _awayjs_core.Vector3D(); //todo: works with vector3D-input instead of pouibnt: this.adaptee.globalToLocal3D();
    };
    /**
     * Evaluates the bounding box of the displayobject to see if it overlaps or intersects with the
     * bounding box of the obj displayobject.
     * @param	obj	The displayobject to test against.
     * @return	true if the bounding boxes of the displayobjects intersect; false if not.
     */
    DisplayObject$$1.prototype.hitTestObject = function (obj) {
        return _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).hitTestObject(_awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(obj.adaptee.partition));
    };
    /**
     * Evaluates the displayobject to see if it overlaps or intersects with the
     * point specified by the x and y parameters.
     * The x and y parameters specify a point in the
     * coordinate space of the Stage, not the displayobject container that contains the
     * displayobject (unless that displayobject container is the Stage).
     * @param	x	The x coordinate to test against this any.
     * @param	y	The y coordinate to test against this any.
     * @param	shapeFlag	Whether to check against the actual pixels of the any (true)
     *   or the bounding box (false).
     * @return	true if the displayobject overlaps or intersects with the specified point;
     *   false otherwise.
     */
    DisplayObject$$1.prototype.hitTestPoint = function (x, y, shapeFlag) {
        if (shapeFlag === void 0) { shapeFlag = false; }
        return _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(this.adaptee.partition).hitTestPoint(x, y, shapeFlag);
    };
    DisplayObject$$1.prototype._getObjectsUnderPointInternal = function (point, children) {
        //nothing to do here
    };
    /**
     * Converts a three-dimensional point of the three-dimensional display
     * any's (local) coordinates to a two-dimensional point in the Stage (global) coordinates.
     *
     *   For example, you can only use two-dimensional coordinates (x,y) to
     * draw with the display.Graphics methods. To draw a three-dimensional
     * any, you need to map the three-dimensional coordinates of a
     * displayobject to two-dimensional coordinates. First, create an instance of
     * the Vector3D class that holds the x-, y-, and z- coordinates of the three-dimensional
     * displayobject. Then pass the Vector3D any to the local3DToGlobal()
     * method as the point3d parameter. The method returns a two-dimensional Point
     * any that can be used
     * with the Graphics API to draw the three-dimensional any.
     * @param	point3d	A Vector3D any containing either a three-dimensional point or
     *   the coordinates of the three-dimensional displayobject.
     * @return	A two-dimensional point representing a three-dimensional point
     *   in two-dimensional space.
     */
    DisplayObject$$1.prototype.local3DToGlobal = function (point3d) {
        console.log("DisplayObject:local3DToGlobal not yet implemented");
        return new _awayjs_core.Point(); //this._adaptee.getBounds();
    };
    /**
     * Converts the point any from the displayobject's (local) coordinates to the
     * Stage (global) coordinates.
     *
     *   This method allows you to convert any given x and y coordinates from
     * values that are relative to the origin (0,0) of a specific displayobject (local coordinates)
     * to values that are relative to the origin of the Stage (global coordinates).To use this method, first create an instance of the Point class. The
     * x and y values that you assign represent local coordinates because they
     * relate to the origin of the displayobject.You then pass the Point instance that you created as the parameter to
     * the localToGlobal() method. The method returns a new Point any with
     * x and y values that relate to the origin of the Stage
     * instead of the origin of the displayobject.
     * @param	point	The name or identifier of a point created with the Point class, specifying the
     *   x and y coordinates as properties.
     * @return	A Point any with coordinates relative to the Stage.
     */
    DisplayObject$$1.prototype.localToGlobal = function (point) {
        return this.adaptee.transform.localToGlobal(point);
    };
    return DisplayObject$$1;
}(EventDispatcher$1));
DisplayObject$1._activeStage = null;

/**
 * The Bitmap class represents display objects that represent bitmap images. These can be images
 * that you load with the flash.display.Loader class, or they can be images that you create with
 * the <codeph class="+ topic/ph pr-d/codeph ">Bitmap()</codeph> constructor.
 *
 *   <p class="- topic/p ">The <codeph class="+ topic/ph pr-d/codeph ">Bitmap()</codeph> constructor allows you to create a Bitmap object that
 * contains a reference to a BitmapData object. After you create a Bitmap object, use the
 * <codeph class="+ topic/ph pr-d/codeph ">addChild()</codeph> or <codeph class="+ topic/ph pr-d/codeph ">addChildAt()</codeph> method of the parent DisplayObjectContainer
 * instance to place the bitmap on the display list.</p><p class="- topic/p ">A Bitmap object can share its BitmapData reference among several Bitmap objects,
 * independent of translation or rotation properties. Because you can create multiple Bitmap
 * objects that reference the same BitmapData object, multiple display objects can use the
 * same complex BitmapData object without incurring the memory overhead of a BitmapData
 * object for each display object instance.</p><p class="- topic/p ">A BitmapData object can be drawn to the screen by a Bitmap object in one of two ways:
 * by using the vector renderer as a fill-bitmap shape, or by using a faster pixel-copying routine.
 * The pixel-copying routine is substantially faster than the vector renderer, but the Bitmap object
 * must meet certain conditions to use it:</p><ul class="- topic/ul "><li class="- topic/li "> No stretching, rotation, or skewing can be applied to the Bitmap object.</li><li class="- topic/li "> No color transform can be applied to the Bitmap object. </li><li class="- topic/li "> No blend mode can be applied to the Bitmap object. </li><li class="- topic/li "> No clipping can be done through mask layers or <codeph class="+ topic/ph pr-d/codeph ">setMask()</codeph> methods. </li><li class="- topic/li "> The image itself cannot be a mask. </li><li class="- topic/li "> The destination coordinates must be on a whole pixel boundary. </li></ul><p class="- topic/p ">If you load a Bitmap object from a domain other than that of the Loader object used to
 * load the image, and there is no URL policy file that permits access to the domain of
 * the Loader object, then a script in that domain cannot access the Bitmap
 * object or its properties and methods. For more information, see the Flash Player Developer Center Topic:
 * <xref href="http://www.adobe.com/go/devnet_security_en" scope="external" class="- topic/xref ">Security</xref>.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b> The Bitmap class is not a subclass of the InteractiveObject class, so
 * it cannot dispatch mouse events. However, you can use the <codeph class="+ topic/ph pr-d/codeph ">addEventListener()</codeph> method
 * of the display object container that contains the Bitmap object.</p>
 */
var Bitmap = (function (_super) {
    __extends(Bitmap, _super);
    /**
     * Initializes a Bitmap object to refer to the specified BitmapData object.
     * @param	bitmapData	The BitmapData object being referenced.
     * @param	pixelSnapping	Whether or not the Bitmap object is snapped to the nearest pixel.
     * @param	smoothing	Whether or not the bitmap is smoothed when scaled. For example, the
     *   following examples show the same bitmap scaled by a factor of 3, with
     *   smoothing set to false (left) and true (right):
     */
    function Bitmap(bitmapData, pixelSnapping, smoothing) {
        if (bitmapData === void 0) { bitmapData = null; }
        if (pixelSnapping === void 0) { pixelSnapping = "auto"; }
        if (smoothing === void 0) { smoothing = false; }
        var _this;
        var newMaterial = bitmapData ? new _awayjs_materials.MethodMaterial(bitmapData.adaptee) : new _awayjs_materials.MethodMaterial(0x0);
        newMaterial.alphaBlending = true;
        newMaterial.useColorTransform = true;
        _this = _super.call(this, _awayjs_scene.Billboard.getNewBillboard(newMaterial, pixelSnapping, smoothing)) || this;
        _this._bitmapData = bitmapData;
        if (_this._bitmapData)
            _this._bitmapData._addOwner(_this);
        return _this;
    }
    Bitmap.getNewBitmap = function (bitmapData, pixelSnapping, smoothing) {
        if (bitmapData === void 0) { bitmapData = null; }
        if (pixelSnapping === void 0) { pixelSnapping = "auto"; }
        if (smoothing === void 0) { smoothing = false; }
        if (Bitmap._bitmaps.length) {
            var newMaterial = bitmapData ? new _awayjs_materials.MethodMaterial(bitmapData.adaptee) : new _awayjs_materials.MethodMaterial(0x0);
            newMaterial.alphaBlending = true;
            newMaterial.useColorTransform = true;
            var bitmap = Bitmap._bitmaps.pop();
            bitmap.adaptee = _awayjs_scene.Billboard.getNewBillboard(newMaterial, pixelSnapping, smoothing);
            return bitmap;
        }
        return new Bitmap(bitmapData, pixelSnapping, smoothing);
    };
    Bitmap.prototype.clone = function () {
        var newInstance = Bitmap.getNewBitmap(this._bitmapData);
        this._adaptee.copyTo(newInstance.adaptee);
        return newInstance;
    };
    /**
     * @inheritDoc
     */
    Bitmap.prototype.dispose = function () {
        this.disposeValues();
        Bitmap._bitmaps.push(this);
    };
    Bitmap.prototype.disposeValues = function () {
        this.bitmapData = null;
        _super.prototype.disposeValues.call(this);
    };
    Object.defineProperty(Bitmap.prototype, "bitmapData", {
        /**
         * The BitmapData object being referenced.
         */
        get: function () {
            return this._bitmapData;
        },
        set: function (value) {
            if (this._bitmapData == value)
                return;
            if (this._bitmapData)
                this._bitmapData._removeOwner(this);
            this._bitmapData = value;
            if (this._bitmapData)
                this._bitmapData._addOwner(this);
            var material = this._adaptee.material;
            if (this._bitmapData) {
                if (!material.ambientMethod.texture)
                    material.ambientMethod.texture = new _awayjs_materials.ImageTexture2D();
                material.style.image = this._bitmapData.adaptee;
            }
            else {
                if (material.ambientMethod.texture)
                    material.ambientMethod.texture = null;
                material.style.image = null;
                material.style.color = 0x0;
            }
            material.invalidateTextures();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Bitmap.prototype, "pixelSnapping", {
        /**
         * Controls whether or not the Bitmap object is snapped to the nearest pixel. The PixelSnapping
         * class includes possible values:
         *
         *   PixelSnapping.NEVER—No pixel snapping occurs.PixelSnapping.ALWAYS—The image is always snapped to the nearest
         * pixel, independent of transformation.PixelSnapping.AUTO—The image is snapped
         * to the nearest pixel if it is drawn with no rotation
         * or skew and it is drawn at a scale factor of 99.9% to 100.1%. If these conditions are satisfied,
         * the bitmap image is drawn at 100% scale, snapped to the nearest pixel. Internally, this value allows the image
         * to be drawn as fast as possible using the vector renderer.
         */
        get: function () {
            return "";
        },
        set: function (value) {
            console.log("pixelSnapping not implemented yet in flash/Bitmap");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Bitmap.prototype, "smoothing", {
        /**
         * Controls whether or not the bitmap is smoothed when scaled. If true, the bitmap is
         * smoothed when scaled. If false, the bitmap is not smoothed when scaled.
         */
        get: function () {
            console.log("smoothing not implemented yet in flash/Bitmap");
            return false;
        },
        set: function (value) {
            console.log("smoothing not implemented yet in flash/Bitmap");
        },
        enumerable: true,
        configurable: true
    });
    return Bitmap;
}(DisplayObject$1));
Bitmap._bitmaps = new Array();

var BitmapData = (function () {
    function BitmapData(width, height, transparent, fillColor) {
        if (transparent === void 0) { transparent = true; }
        if (fillColor === void 0) { fillColor = 0xffffffff; }
        this._owners = new Array();
        this._adaptee = new _awayjs_scene.SceneImage2D(width, height, transparent, fillColor, false, _awayjs_stage.StageManager.getInstance().getStageAt(0));
        this._adaptee.adapter = this;
    }
    // for AVM1:
    BitmapData.prototype.compare = function (other) {
        return true;
    };
    Object.defineProperty(BitmapData.prototype, "adaptee", {
        get: function () {
            return this._adaptee;
        },
        enumerable: true,
        configurable: true
    });
    BitmapData.loadBitmap = function (id) {
        console.log("loadBitmap not implemented yet in flash/BitmapData");
        return null;
    };
    Object.defineProperty(BitmapData.prototype, "transparent", {
        get: function () {
            return this._adaptee.transparent;
        },
        set: function (value) {
            this._adaptee.transparent = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitmapData.prototype, "width", {
        get: function () {
            return this._adaptee.width;
        },
        set: function (value) {
            this._adaptee.width = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitmapData.prototype, "height", {
        get: function () {
            return this._adaptee.height;
        },
        set: function (value) {
            this._adaptee.height = value;
        },
        enumerable: true,
        configurable: true
    });
    BitmapData.prototype.clone = function () {
        var clone = new BitmapData(this._adaptee.width, this._adaptee.height, this._adaptee.transparent, 0x0);
        clone.copyPixels(this, this.rect, new _awayjs_core.Point());
        return clone;
    };
    Object.defineProperty(BitmapData.prototype, "rect", {
        get: function () {
            return this._adaptee.rect;
        },
        enumerable: true,
        configurable: true
    });
    BitmapData.prototype.getPixel = function (x, y) {
        return this._adaptee.getPixel(x, y);
    };
    BitmapData.prototype.getPixel32 = function (x, y) {
        return this._adaptee.getPixel32(x, y);
    };
    BitmapData.prototype.setPixel = function (x, y, color) {
        this._adaptee.setPixel(x, y, color);
    };
    BitmapData.prototype.setPixel32 = function (x, y, color) {
        this._adaptee.setPixel32(x, y, color);
    };
    BitmapData.prototype.applyFilter = function (sourceBitmap, sourceRect, destPoint, filter) {
        console.log("applyFilter not implemented yet in flash/BitmapData");
        return 0;
    };
    BitmapData.prototype.colorTransform = function (rect, colorTransform) {
        this._adaptee.colorTransform(rect, colorTransform);
    };
    BitmapData.prototype.copyChannel = function (sourceBitmap, sourceRect, destPoint, sourceChannel, destChannel) {
        this._adaptee.copyChannel(sourceBitmap.adaptee, sourceRect, destPoint, sourceChannel, destChannel);
    };
    BitmapData.prototype.copyPixels = function (sourceBitmap, sourceRect, destPoint, alphaBitmapData, alphaPoint, mergeAlpha) {
        if (alphaBitmapData === void 0) { alphaBitmapData = null; }
        if (alphaPoint === void 0) { alphaPoint = null; }
        if (mergeAlpha === void 0) { mergeAlpha = false; }
        this._adaptee.copyPixels(sourceBitmap.adaptee, sourceRect, destPoint);
    };
    BitmapData.prototype.dispose = function () {
        this._adaptee.dispose();
        this._adaptee = null;
    };
    BitmapData.prototype.draw = function (source, matrix, colorTransform, blendMode, clipRect, smooth) {
        if (colorTransform === void 0) { colorTransform = null; }
        if (blendMode === void 0) { blendMode = ""; }
        if (clipRect === void 0) { clipRect = null; }
        if (smooth === void 0) { smooth = false; }
        this._adaptee.draw(source.adaptee, matrix, colorTransform, blendMode, clipRect, smooth);
    };
    BitmapData.prototype.fillRect = function (rect, color) {
        this._adaptee.fillRect(rect, color);
    };
    BitmapData.prototype.floodFill = function (x, y, color) {
        console.log("floodFill not implemented yet in flash/BitmapData");
    };
    BitmapData.prototype.generateFilterRect = function (sourceRect, filter) {
        console.log("generateFilterRect not implemented yet in flash/BitmapData");
        return null;
    };
    BitmapData.prototype.getColorBoundsRect = function (mask, color, findColor) {
        console.log("getColorBoundsRect not implemented yet in flash/BitmapData");
        return null;
    };
    BitmapData.prototype.hitTest = function (firstPoint, firstAlphaThreshold, secondObject, secondBitmapPoint, secondAlphaThreshold) {
        if (secondBitmapPoint === void 0) { secondBitmapPoint = new _awayjs_core.Point(0, 0); }
        if (secondAlphaThreshold === void 0) { secondAlphaThreshold = 0; }
        console.log("hitTest not implemented yet in flash/BitmapData");
        return false;
    };
    BitmapData.prototype.lock = function () {
        this._adaptee.lock();
    };
    BitmapData.prototype.merge = function (sourceBitmap, sourceRect, destPoint, redMult, greenMult, blueMult, alphaMult) {
        this._adaptee.merge(sourceBitmap.adaptee, sourceBitmap.rect, destPoint, redMult, greenMult, blueMult, alphaMult);
    };
    BitmapData.prototype.noise = function (randomSeed, low, high, channelOptions, grayScale) {
        console.log("noise not implemented yet in flash/BitmapData");
    };
    BitmapData.prototype.paletteMap = function (sourceBitmap, sourceRect, destPoint, redArray, greenArray, blueArray, alphaArray) {
        console.log("paletteMap not implemented yet in flash/BitmapData");
    };
    BitmapData.prototype.perlinNoise = function (baseX, baseY, numOctaves, randomSeed, stitch, fractalNoise, channelOptions, grayScale, offsets) {
        console.log("perlinNoise not implemented yet in flash/BitmapData");
    };
    BitmapData.prototype.pixelDissolve = function (sourceBitmap, sourceRect, destPoint, randomSeed, numberOfPixels, fillColor) {
        console.log("pixelDissolve not implemented yet in flash/BitmapData");
        return 0;
    };
    BitmapData.prototype.scroll = function (x, y) {
        console.log("scroll not implemented yet in flash/BitmapData");
    };
    BitmapData.prototype.threshold = function (sourceBitmap, sourceRect, destPoint, operation, threshold, color, mask, copySource) {
        console.log("threshold not implemented yet in flash/BitmapData");
        return 0;
    };
    BitmapData.prototype.unlock = function () {
        this._adaptee.unlock();
    };
    BitmapData.prototype._addOwner = function (owner) {
        if (this._owners.indexOf(owner) == -1)
            this._owners.push(owner);
    };
    BitmapData.prototype._removeOwner = function (owner) {
        var index = this._owners.indexOf(owner);
        if (index != -1)
            this._owners.splice(index, 1);
        if (!this._owners.length)
            this._adaptee.clear();
    };
    return BitmapData;
}());

/**
/// @eventType	flash.events.MouseEvent.CLICK
[Event(name="click", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.CONTEXT_MENU
[Event(name="contextMenu", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.DOUBLE_CLICK
[Event(name="doubleClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_CLICK
[Event(name="middleClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_DOWN
[Event(name="middleMouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_UP
[Event(name="middleMouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_DOWN
[Event(name="mouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_MOVE
[Event(name="mouseMove", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_OUT
[Event(name="mouseOut", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_OVER
[Event(name="mouseOver", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_UP
[Event(name="mouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.MOUSE_WHEEL
[Event(name="mouseWheel", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_CLICK
[Event(name="rightClick", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_MOUSE_DOWN
[Event(name="RightMouseDown", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.RIGHT_MOUSE_UP
[Event(name="rightMouseUp", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.ROLL_OUT
[Event(name="rollOut", type="flash.events.MouseEvent")]

/// @eventType	flash.events.MouseEvent.ROLL_OVER
[Event(name="rollOver", type="flash.events.MouseEvent")]

 * A MouseEvent object is dispatched into the event flow whenever mouse events occur.
 * A mouse event is usually generated by a user input device, such as a mouse or a trackball,
 * that uses a pointer.
 *
 *   <p class="- topic/p ">When nested nodes are involved, mouse events target the deepest possible nested node that
 * is visible in the display list. This node is called the <i class="+ topic/ph hi-d/i ">target node</i>. To have a
 * target node's ancestor receive notification of a mouse event, use
 * <codeph class="+ topic/ph pr-d/codeph ">EventDispatcher.addEventListener()</codeph> on the ancestor node with the
 * <codeph class="+ topic/ph pr-d/codeph ">type</codeph> parameter set to the specific mouse event you want to detect.</p>
 *
 *   EXAMPLE:
 *
 *   The following example uses the <codeph class="+ topic/ph pr-d/codeph ">MouseEventExample</codeph> and
 * <codeph class="+ topic/ph pr-d/codeph ">ChildSprite</codeph> classes to show how mouse events are dispatched using a simple image.
 * This example carries out the following tasks:
 * <ol class="- topic/ol "><li class="- topic/li ">The example declares properties for the size (100 x 100 pixels) and the background color
 * (orange) for later use in drawing the square.</li><li class="- topic/li ">The constructor creates a new ChildSprite object <codeph class="+ topic/ph pr-d/codeph ">child</codeph>. Its constructor first
 * draws an orange 100 x 100 pixel square at coordinates (0,0) by calling its <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph>
 * method and then adds seven event listeners/subscribers.
 * <ul class="- topic/ul "><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">click</codeph>/<codeph class="+ topic/ph pr-d/codeph ">clickHandler()</codeph>: Dispatched when the user single-clicks with the left mouse button
 * over the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">doubleClick</codeph>/<codeph class="+ topic/ph pr-d/codeph ">doubleClickHandler()</codeph>: Dispatched when the user double-clicks the left mouse button
 * over the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseDown</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph>: When the ChildSprite
 * object (the orange square) is clicked, a <codeph class="+ topic/ph pr-d/codeph ">trace()</codeph> message is printed to the screen, and then
 * <codeph class="+ topic/ph pr-d/codeph ">ChildSprite.draw()</codeph> is called, which draws a dark yellow square in place
 * of the light blue one drawn in <codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler()</codeph>.  The <codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph> method also adds a
 * <codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>event listener and the <codeph class="+ topic/ph pr-d/codeph ">mouseMoveHandler()</codeph> subscriber (described below),
 * which processes the mouse moves.  Then the <codeph class="+ topic/ph pr-d/codeph ">startDrag()</codeph> method is called, which
 * allows the Sprite object to be dragged.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOut</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseOutHandler()</codeph>: Dispatched whenever the pointer leaves the
 * square area.  The <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method is called to return the square to its normal
 * size and color.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOver</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler()</codeph>: Dispatched when the mouse pointer is over the square.
 * This method redraws the square so that it is larger and its background color is dark yellow.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseUp</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseUpHandler()</codeph>: When the user releases the mouse button, the <codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>
 * event listener is removed and <codeph class="+ topic/ph pr-d/codeph ">stopDrag</codeph> is called, which freezes the square in place.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseMove</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseMoveHandler()</codeph>: Called as part of the <codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler()</codeph> function, and dispatched when the user is pressing the left mouse button and dragging the square.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseWheel</codeph>/<codeph class="+ topic/ph pr-d/codeph ">mouseWheelHandler()</codeph>: Dispatched when the user rotates the mouse
 * wheel over the square.</li></ul></li><li class="- topic/li ">The ChildSprite instance <codeph class="+ topic/ph pr-d/codeph ">child</codeph> is then added to the display list by means of
 * <codeph class="+ topic/ph pr-d/codeph ">addChild()</codeph>, which promptly draws the orange square.</li></ol><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Notes: </b></p><ul class="- topic/ul "><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">MouseEventExample</codeph> class should be the document root.</li><li class="- topic/li ">Some of the event methods listed above declare a local variable <codeph class="+ topic/ph pr-d/codeph ">sprite</codeph>, which
 * is assigned the cast of <codeph class="+ topic/ph pr-d/codeph ">event.target</codeph> to type Sprite.</li></ul><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
 
 */
var MouseEvent$1 = (function (_super) {
    __extends(MouseEvent$$1, _super);
    /**
     * Creates an Event object that contains information about mouse events.
     * Event objects are passed as parameters to event listeners.
     * @param	type	The type of the event. Possible values are: MouseEvent.CLICK,
     *   MouseEvent.DOUBLE_CLICK, MouseEvent.MOUSE_DOWN,
     *   MouseEvent.MOUSE_MOVE, MouseEvent.MOUSE_OUT,
     *   MouseEvent.MOUSE_OVER, MouseEvent.MOUSE_UP,
     *   MouseEvent.MIDDLE_CLICK, MouseEvent.MIDDLE_MOUSE_DOWN, MouseEvent.MIDDLE_MOUSE_UP,
     *   MouseEvent.RIGHT_CLICK, MouseEvent.RIGHT_MOUSE_DOWN, MouseEvent.RIGHT_MOUSE_UP,
     *   MouseEvent.MOUSE_WHEEL, MouseEvent.ROLL_OUT, and MouseEvent.ROLL_OVER.
     * @param	bubbles	Determines whether the Event object participates in the bubbling phase of the event flow.
     * @param	cancelable	Determines whether the Event object can be canceled.
     * @param	localX	The horizontal coordinate at which the event occurred relative to the containing sprite.
     * @param	localY	The vertical coordinate at which the event occurred relative to the containing sprite.
     * @param	relatedObject	The complementary InteractiveObject instance that is affected by the event. For example, when a mouseOut event occurs, relatedObject represents the display list object to which the pointing device now points.
     * @param	ctrlKey	On Windows or Linux, indicates whether the Ctrl key is activated. On Mac, indicates whether either the Ctrl key or the Command key is activated.
     * @param	altKey	Indicates whether the Alt key is activated (Windows or Linux only).
     * @param	shiftKey	Indicates whether the Shift key is activated.
     * @param	buttonDown	Indicates whether the primary mouse button is pressed.
     * @param	delta	Indicates how many lines should be scrolled for each unit the user rotates the mouse wheel. A positive delta value indicates an upward scroll; a negative value indicates a downward scroll. Typical values are 1 to 3, but faster rotation may produce larger values. This parameter is used only for the MouseEvent.mouseWheel event.
     * @param	commandKey	(AIR only) Indicates whether the Command key is activated (Mac only). This parameter is used only for the MouseEvent.click,
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleClick, MouseEvent.middleMouseDown,
     *   MouseEvent.middleMouseUp, MouseEvent.rightClick, MouseEvent.rightMouseDown, MouseEvent.rightMouseUp,
     *   and MouseEvent.doubleClick events. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     * @param	controlKey	(AIR only) Indicates whether the Control or Ctrl key is activated. This parameter is used only for the MouseEvent.click,
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleClick, MouseEvent.middleMouseDown,
     *   MouseEvent.middleMouseUp, MouseEvent.rightClick, MouseEvent.rightMouseDown, MouseEvent.rightMouseUp,
     *   and MouseEvent.doubleClick events. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     * @param	clickCount	(AIR only) Indicates whether or not the mouse event is part of a multi-click sequence. This parameter will be zero for all mouse events other than
     *   MouseEvent.mouseDown, MouseEvent.mouseUp, MouseEvent.middleMouseDown, MouseEvent.middleMouseUp,
     *   MouseEvent.rightMouseDown and MouseEvent.rightMouseUp. Listening for single clicks, double clicks, or any multi-click sequence
     *   is possible with the clickCount parameter. This parameter is for Adobe AIR only; do not set it for Flash Player content.
     */
    function MouseEvent$$1(type, bubbles, cancelable, localX, localY, relatedObject, ctrlKey, altKey, shiftKey, buttonDown, delta) {
        if (bubbles === void 0) { bubbles = true; }
        if (cancelable === void 0) { cancelable = false; }
        if (localX === void 0) { localX = null; }
        if (localY === void 0) { localY = null; }
        if (relatedObject === void 0) { relatedObject = null; }
        if (ctrlKey === void 0) { ctrlKey = false; }
        if (altKey === void 0) { altKey = false; }
        if (shiftKey === void 0) { shiftKey = false; }
        if (buttonDown === void 0) { buttonDown = false; }
        if (delta === void 0) { delta = 0; }
        var _this = _super.call(this, type, bubbles, cancelable) || this;
        _this.localX = localX;
        _this.localY = localY;
        _this.relatedObject = relatedObject;
        _this.ctrlKey = ctrlKey;
        _this.altKey = altKey;
        _this.shiftKey = shiftKey;
        _this.buttonDown = buttonDown;
        _this.delta = delta;
        return _this;
    }
    Object.defineProperty(MouseEvent$$1.prototype, "altKey", {
        get: function () {
            return this._altKey;
        },
        set: function (value) {
            this._altKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "buttonDown", {
        get: function () {
            return this._buttonDown;
        },
        set: function (value) {
            this._buttonDown = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "ctrlKey", {
        get: function () {
            return this._ctrlKey;
        },
        set: function (value) {
            this._ctrlKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "delta", {
        get: function () {
            return this._delta;
        },
        set: function (value) {
            this._delta = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "isRelatedObjectInaccessible", {
        get: function () {
            return this._isRelatedObjectInaccessible;
        },
        set: function (value) {
            this._isRelatedObjectInaccessible = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "localX", {
        get: function () {
            return this._localX;
        },
        set: function (value) {
            this._localX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "localY", {
        get: function () {
            return this._localY;
        },
        set: function (value) {
            this._localY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "movementX", {
        get: function () {
            return this._movementX;
        },
        set: function (value) {
            this._movementX = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "movementY", {
        get: function () {
            return this._movementY;
        },
        set: function (value) {
            this._movementY = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "relatedObject", {
        get: function () {
            return this._relatedObject;
        },
        set: function (value) {
            this._relatedObject = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "shiftKey", {
        get: function () {
            return this._shiftKey;
        },
        set: function (value) {
            this._shiftKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "stageX", {
        get: function () {
            return this._stageX;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MouseEvent$$1.prototype, "stageY", {
        get: function () {
            return this._stageY;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Creates a copy of the MouseEvent object and sets the value of each property to match that of the original.
     * @return	A new MouseEvent object with property values that match those of the original.
     */
    MouseEvent$$1.prototype.clone = function () {
        return null;
    };
    MouseEvent$$1.prototype.fillFromJS = function (jsEvent) {
        this._stageX = (jsEvent.clientX != null) ? jsEvent.clientX : jsEvent.changedTouches[0].clientX;
        this._stageY = (jsEvent.clientY != null) ? jsEvent.clientY : jsEvent.changedTouches[0].clientY;
        this.delta = jsEvent.delta;
        if (this._stageY < 0)
            this._stageY = 0;
        this.ctrlKey = jsEvent.ctrlKey;
        this.shiftKey = jsEvent.shiftKey;
    };
    /* added to clone events from away to as3web. */
    MouseEvent$$1.prototype.fillFromAway = function (awayEvent) {
        //console.log("cloneFromAway not implemented yet in flash/MouseEvent");
        // todo: set targets correctly
        this.target = awayEvent.target;
        //this.currentTarget = awayEvent.currentTarget;
        this.delta = awayEvent.delta;
        this.ctrlKey = awayEvent.ctrlKey;
        this.shiftKey = awayEvent.shiftKey;
        this._stageX = awayEvent.screenX;
        this._stageY = awayEvent.screenY;
        //todo: translate more stuff from awayjs to as3
        //result.screenX = this.screenX;
        //result.screenY = this.screenY;
        /*
                result.view = awayEvent.view;
                result.entity = awayEvent.entity;
                result.renderable = awayEvent.renderable;
                result.material = awayEvent.material;
                result.uv = awayEvent.uv;
                result.position = awayEvent.position;
                result.normal = awayEvent.normal;
                result.elementIndex = awayEvent.elementIndex;
        */
        //result._iParentEvent = awayEvent;
        //result._iAllowedToPropagate = awayEvent._iAllowedToPropagate;
    };
    /**
     * Returns a string that contains all the properties of the MouseEvent object. The string is in the following format:
     * [MouseEvent type=value bubbles=value cancelable=value ... delta=value]
     * @return	A string that contains all the properties of the MouseEvent object.
     */
    MouseEvent$$1.prototype.toString = function () {
        return "";
    };
    /**
     * Instructs Flash Player or Adobe AIR to render after processing of this event completes, if the display list has been modified.
     */
    MouseEvent$$1.prototype.updateAfterEvent = function () {
    };
    return MouseEvent$$1;
}(Event));
/**
 * Defines the value of the type property of a click event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor click events, this value is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.CLICK = "click";
/**
 * The MouseEvent.CONTEXT_MENU constant defines the value of the
 * type property of a contextMenu event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the right mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.CONTEXT_MENU = "contextMenu";
/**
 * Defines the value of the type property of a doubleClick event object. The doubleClickEnabled property
 * must be true for an object to generate the doubleClick event.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor double-click events, this value is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.DOUBLE_CLICK = "doubleClick";
/**
 * Defines the value of the type property of a middleClick event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor middle-click events, this property is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.MIDDLE_CLICK = "middleClick";
/**
 * Defines the value of the type property of a middleMouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the middle mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.MIDDLE_MOUSE_DOWN = "middleMouseDown";
/**
 * Defines the value of the type property of a middleMouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the middle mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.MIDDLE_MOUSE_UP = "middleMouseUp";
/**
 * Defines the value of the type property of a mouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows and Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.MOUSE_DOWN = "mouseDown";
/**
 * Defines the value of the type property of a mouseMove event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.MOUSE_MOVE = "mouseMove";
/**
 * Defines the value of the type property of a mouseOut event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device now points.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.MOUSE_OUT = "mouseOut";
/**
 * Defines the value of the type property of a mouseOver event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device was pointing.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.MOUSE_OVER = "mouseOver";
/**
 * Defines the value of the type property of a mouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
MouseEvent$1.MOUSE_UP = "mouseUp";
/**
 * Defines the value of the type property of a mouseWheel event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.deltaThe number of lines that that each notch on the mouse wheel represents.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	Flash 9
 */
MouseEvent$1.MOUSE_WHEEL = "mouseWheel";
/**
 * Defines the value of the type property of a rightClick event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor right-click events, this property is always false.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.RIGHT_CLICK = "rightClick";
/**
 * Defines the value of the type property of a rightMouseDown event object.
 * This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDownFor right-click events, this property is always true.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.RIGHT_MOUSE_DOWN = "rightMouseDown";
/**
 * Defines the value of the type property of a rightMouseUp event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblestruebuttonDowntrue if the right mouse button is pressed; false otherwise.cancelablefalse; the default behavior cannot be canceled.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.clickCountCount of the number of mouse clicks to indicate whether the event is part of a multi-click sequence.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 * @langversion	3.0
 * @playerversion	AIR 1.0
 * @playerversion	Lite 4
 */
MouseEvent$1.RIGHT_MOUSE_UP = "rightMouseUp";
/**
 * Defines the value of the type property of a rollOut event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblesfalsebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device now points.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
MouseEvent$1.ROLL_OUT = "rollOut";
/**
 * Defines the value of the type property of a rollOver event object.
 *
 *   This event has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows).bubblesfalsebuttonDowntrue if the primary mouse button is pressed; false otherwise.cancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.relatedObjectThe display list object to which the pointing device was pointing.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.shiftKeytrue if the Shift key is active; false if it is inactive.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the pointing device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
MouseEvent$1.ROLL_OVER = "rollOver";

/**
/// @eventType	flash.events.KeyboardEvent.KEY_DOWN
[Event(name="keyDown", type="flash.events.KeyboardEvent")]

/// @eventType	flash.events.KeyboardEvent.KEY_UP
[Event(name="keyUp", type="flash.events.KeyboardEvent")]

 * A KeyboardEvent object id dispatched in response to user input through a keyboard.
 * There are two types of keyboard events: <codeph class="+ topic/ph pr-d/codeph ">KeyboardEvent.KEY_DOWN</codeph> and
 * <codeph class="+ topic/ph pr-d/codeph ">KeyboardEvent.KEY_UP</codeph><p class="- topic/p ">Because mappings between keys and specific characters vary by device
 * and operating system, use the TextEvent event type for processing character input.</p><p class="- topic/p ">To listen globally for key events, listen on the Stage for the capture and target
 * or bubble phase.</p>
 */
var KeyboardEvent = (function (_super) {
    __extends(KeyboardEvent, _super);
    /**
     * Creates an Event object that contains specific information about keyboard events.
     * Event objects are passed as parameters to event listeners.
     * @param	type	The type of the event. Possible values are:
     *   KeyboardEvent.KEY_DOWN and KeyboardEvent.KEY_UP
     * @param	bubbles	Determines whether the Event object participates in the bubbling stage of the event flow.
     * @param	cancelable	Determines whether the Event object can be canceled.
     * @param	charCodeValue	The character code value of the key pressed or released. The character code values returned are English keyboard values. For example, if you press Shift+3, the Keyboard.charCode() property returns # on a Japanese keyboard, just as it does on an English keyboard.
     * @param	keyCodeValue	The key code value of the key pressed or released.
     * @param	keyLocationValue	The location of the key on the keyboard.
     * @param	ctrlKeyValue	On Windows, indicates whether the Ctrl key is activated. On Mac, indicates whether either the Ctrl key or the Command key is activated.
     * @param	altKeyValue	Indicates whether the Alt key modifier is activated (Windows only).
     * @param	shiftKeyValue	Indicates whether the Shift key modifier is activated.
     * @param	controlKeyValue	Indicates whether the Control key is activated on Mac, and whether the Control or Ctrl keys are activated on WIndows and Linux.
     * @param	commandKeyValue	Indicates whether the Command key is activated (Mac only).
     */
    function KeyboardEvent(type, bubbles, cancelable, charCodeValue, keyCodeValue, keyLocationValue, ctrlKeyValue, altKeyValue, shiftKeyValue) {
        if (bubbles === void 0) { bubbles = true; }
        if (cancelable === void 0) { cancelable = false; }
        if (charCodeValue === void 0) { charCodeValue = 0; }
        if (keyCodeValue === void 0) { keyCodeValue = 0; }
        if (keyLocationValue === void 0) { keyLocationValue = 0; }
        if (ctrlKeyValue === void 0) { ctrlKeyValue = false; }
        if (altKeyValue === void 0) { altKeyValue = false; }
        if (shiftKeyValue === void 0) { shiftKeyValue = false; }
        return _super.call(this, type, bubbles, cancelable) || this;
    }
    Object.defineProperty(KeyboardEvent.prototype, "altKey", {
        get: function () {
            return this._altKey;
        },
        set: function (value) {
            this._altKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyboardEvent.prototype, "charCode", {
        get: function () {
            return this._charCode;
        },
        set: function (value) {
            this._charCode = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyboardEvent.prototype, "ctrlKey", {
        get: function () {
            return this._ctrlKey;
        },
        set: function (value) {
            this._ctrlKey = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyboardEvent.prototype, "keyCode", {
        get: function () {
            return this._keyCode;
        },
        set: function (value) {
            this._keyCode = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyboardEvent.prototype, "keyLocation", {
        /**
         * Indicates the location of the key on the keyboard. This is useful for differentiating keys
         * that appear more than once on a keyboard. For example, you can differentiate between the
         * left and right Shift keys by the value of this property: KeyLocation.LEFT
         * for the left and KeyLocation.RIGHT for the right. Another example is
         * differentiating between number keys pressed on the standard keyboard
         * (KeyLocation.STANDARD) versus the numeric keypad (KeyLocation.NUM_PAD).
         */
        get: function () {
            console.log("keyLocation not implemented yet in flash/KeyboardEvent");
            return 0;
        },
        set: function (value) {
            console.log("keyLocation not implemented yet in flash/KeyboardEvent");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(KeyboardEvent.prototype, "shiftKey", {
        get: function () {
            return this._shiftKey;
        },
        set: function (value) {
            this._shiftKey = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Creates a copy of the KeyboardEvent object and sets the value of each property to match that of the original.
     * @return	A new KeyboardEvent object with property values that match those of the original.
     */
    KeyboardEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/KeyboardEvent");
        return null;
    };
    /**
     * Returns a string that contains all the properties of the KeyboardEvent object. The string
     * is in the following format:
     * [KeyboardEvent type=value bubbles=value cancelable=value ... shiftKey=value]
     * @return	A string that contains all the properties of the KeyboardEvent object.
     */
    KeyboardEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/KeyboardEvent");
        return "";
    };
    /**
     * Indicates that the display should be rendered after processing of this event completes, if the display
     * list has been modified
     */
    KeyboardEvent.prototype.updateAfterEvent = function () {
        console.log("updateAfterEvent not implemented yet in flash/KeyboardEvent");
    };
    return KeyboardEvent;
}(Event));
/**
 * The KeyboardEvent.KEY_DOWN constant defines the value of the type property of a keyDown event object.
 *
 *   This event has the following properties:PropertyValuebubblestruecancelabletrue in AIR, false in Flash Player;
 * in AIR, canceling this event prevents the character from being entered into a text field.charCodeThe character code value of the key pressed or released.commandKeytrue on Mac if the Command key is active. Otherwise, falsecontrolKeytrue on Windows and Linux if the Ctrl key is active. true on Mac if either the Control key is active. Otherwise, falsectrlKeytrue on Windows and Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.keyCodeThe key code value of the key pressed or released.keyLocationThe location of the key on the keyboard.shiftKeytrue if the Shift key is active; false if it is inactive.targetThe InteractiveObject instance with focus.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
KeyboardEvent.KEY_DOWN = "keyDown";
/**
 * The KeyboardEvent.KEY_UP constant defines the value of the type property of a keyUp event object.
 * This event has the following properties:PropertyValuebubblestruecancelablefalse; there is no default behavior to cancel.charCodeContains the character code value of the key pressed or released.commandKeytrue on Mac if the Command key is active. Otherwise, falsecontrolKeytrue on Windows and Linux if the Ctrl key is active. true on Mac if either the Control key is active. Otherwise, falsectrlKeytrue on Windows if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.keyCodeThe key code value of the key pressed or released.keyLocationThe location of the key on the keyboard.shiftKeytrue if the Shift key is active; false if it is inactive.targetThe InteractiveObject instance with focus.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.
 */
KeyboardEvent.KEY_UP = "keyUp";

var InteractiveObject = (function (_super) {
    __extends(InteractiveObject, _super);
    /** these should be able to get setup:
     

     // listen on key directly
     
     * Dispatched when the user releases a key.
     * @eventType	flash.events.KeyboardEvent.KEY_UP
     [Event(name="keyUp", type="flash.events.KeyboardEvent")]
     
     * Dispatched when the user presses a key.
     * @eventType	flash.events.KeyboardEvent.KEY_DOWN
     [Event(name="keyDown", type="flash.events.KeyboardEvent")]
     
     // listen on awayjs adapter and translate
     
     * Dispatched when a user releases the pointing device button over an
     * InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.RIGHT_MOUSE_UP
     [Event(name="rightMouseUp", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses the pointing device button over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.RIGHT_MOUSE_DOWN
     [Event(name="rightMouseDown", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses and releases the right button of the user's
     * pointing device over the same InteractiveObject.
     * @eventType	flash.events.MouseEvent.RIGHT_CLICK
     [Event(name="rightClick", type="flash.events.MouseEvent")]
     
     * Dispatched when a user releases the pointing device button over an
     * InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_UP
     [Event(name="middleMouseUp", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses the middle pointing device button over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MIDDLE_MOUSE_DOWN
     [Event(name="middleMouseDown", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses and releases the middle button of the user's
     * pointing device over the same InteractiveObject.
     * @eventType	flash.events.MouseEvent.MIDDLE_CLICK
     [Event(name="middleClick", type="flash.events.MouseEvent")]
     
     
     * Dispatched when the user moves a pointing device over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.ROLL_OVER
     [Event(name="rollOver", type="flash.events.MouseEvent")]
     
     * Dispatched when the user moves a pointing device away from an InteractiveObject
     * instance.
     * @eventType	flash.events.MouseEvent.ROLL_OUT
     [Event(name="rollOut", type="flash.events.MouseEvent")]
     
     * Dispatched when a mouse wheel is spun over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MOUSE_WHEEL
     [Event(name="mouseWheel", type="flash.events.MouseEvent")]
     
     * Dispatched when a user releases the pointing device button over an
     * InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MOUSE_UP
     [Event(name="mouseUp", type="flash.events.MouseEvent")]
     
     * Dispatched when the user moves a pointing device over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MOUSE_OVER
     [Event(name="mouseOver", type="flash.events.MouseEvent")]
     
     * Dispatched when the user moves a pointing device away from an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MOUSE_OUT
     [Event(name="mouseOut", type="flash.events.MouseEvent")]
     
     * Dispatched when a user moves the pointing device while it is over an InteractiveObject.
     * @eventType	flash.events.MouseEvent.MOUSE_MOVE
     [Event(name="mouseMove", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses the pointing device button over an InteractiveObject instance.
     * @eventType	flash.events.MouseEvent.MOUSE_DOWN
     [Event(name="mouseDown", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses and releases the main button of a pointing device twice in
     * rapid succession over the same InteractiveObject when that object's
     * doubleClickEnabled flag is set to true.
     * @eventType	flash.events.MouseEvent.DOUBLE_CLICK
     [Event(name="doubleClick", type="flash.events.MouseEvent")]
     
     * Dispatched when a user presses and releases the main button of the user's
     * pointing device over the same InteractiveObject.
     * @eventType	flash.events.MouseEvent.CLICK
     [Event(name="click", type="flash.events.MouseEvent")]

     */
    /**
    * Dispatched immediately after the soft keyboard is lowered.
    * @eventType	flash.events.SoftKeyboardEvent.SOFT_KEYBOARD_DEACTIVATE
    [Event(name="softKeyboardDeactivate", type="flash.events.SoftKeyboardEvent")]

    * Dispatched immediately after the soft keyboard is raised.
    * @eventType	flash.events.SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATE
    [Event(name="softKeyboardActivate", type="flash.events.SoftKeyboardEvent")]

    * Dispatched immediately before the soft keyboard is raised.
    * @eventType	flash.events.SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATING
    [Event(name="softKeyboardActivating", type="flash.events.SoftKeyboardEvent")]

    * Dispatched when a user enters one or more
    * characters of text.
    * @eventType	flash.events.TextEvent.TEXT_INPUT
    [Event(name="textInput", type="flash.events.TextEvent")]
    /// This event is dispatched to any client app that supports inline input with an IME
    [Event(name="imeStartComposition", type="flash.events.IMEEvent")]

    * Dispatched when a user gesture triggers the context menu associated with this interactive
    * object in an AIR application.
    * @eventType	flash.events.MouseEvent.CONTEXT_MENU
    [Event(name="contextMenu", type="flash.events.MouseEvent")]

    * Dispatched by the drag initiator InteractiveObject when the user releases the drag gesture.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_COMPLETE
    [Event(name="nativeDragComplete", type="flash.events.NativeDragEvent")]

    * Dispatched during a drag operation by the InteractiveObject that is
    * specified as the drag initiator in the DragManager.doDrag() call.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_UPDATE
    [Event(name="nativeDragUpdate", type="flash.events.NativeDragEvent")]

    * Dispatched at the beginning of a drag operation by the InteractiveObject that is
    * specified as the drag initiator in the DragManager.doDrag() call.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_START
    [Event(name="nativeDragStart", type="flash.events.NativeDragEvent")]

    * Dispatched by an InteractiveObject when a drag gesture leaves its boundary.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_EXIT
    [Event(name="nativeDragExit", type="flash.events.NativeDragEvent")]

    * Dispatched by the target InteractiveObject when a dragged object is
    * dropped on it and the drop has been accepted with a call to
    * DragManager.acceptDragDrop().
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_DROP
    [Event(name="nativeDragDrop", type="flash.events.NativeDragEvent")]

    * Dispatched by an InteractiveObject continually while a drag gesture remains within its
    * boundary.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_OVER
    [Event(name="nativeDragOver", type="flash.events.NativeDragEvent")]

    * Dispatched by an InteractiveObject when a drag gesture enters its boundary.
    * @eventType	flash.events.NativeDragEvent.NATIVE_DRAG_ENTER

    * Dispatched when the value of the object's tabIndex property changes.
    * @eventType	flash.events.Event.TAB_INDEX_CHANGE
    [Event(name="tabIndexChange", type="flash.events.Event")]

    * Dispatched when the object's tabEnabled flag changes.
    * @eventType	flash.events.Event.TAB_ENABLED_CHANGE
    [Event(name="tabEnabledChange", type="flash.events.Event")]

    * Dispatched when the value of the object's tabChildren flag changes.
    * @eventType	flash.events.Event.TAB_CHILDREN_CHANGE
    [Event(name="tabChildrenChange", type="flash.events.Event")]

    * Dispatched when the user performs a swipe gesture at a point of contact with an InteractiveObject instance (such as touching three
    * fingers to a screen and then moving them in parallel over a display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TransformGestureEvent.GESTURE_SWIPE
    [Event(name="gestureSwipe", type="flash.events.TransformGestureEvent")]

    * Dispatched when the user performs a zoom gesture at a point of contact with an InteractiveObject instance (such as touching two
    * fingers to a screen and then quickly spreading the fingers apart over a display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TransformGestureEvent.GESTURE_ZOOM
    [Event(name="gestureZoom", type="flash.events.TransformGestureEvent")]

    * Dispatched when the user performs a rotation gesture at a point of contact with an InteractiveObject instance (such as touching two fingers
    * and rotating them over a display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TransformGestureEvent.GESTURE_ROTATE
    [Event(name="gestureRotate", type="flash.events.TransformGestureEvent")]

    * Dispatched when the user creates a point of contact with an InteractiveObject instance, then taps
    * on a touch-enabled device (such as placing several fingers over a display object to open a menu and then taps one finger to select a menu item
    * on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.PressAndTapGestureEvent.GESTURE_PRESS_AND_TAP
    [Event(name="gesturePressAndTap", type="flash.events.PressAndTapGestureEvent")]

    * Dispatched when the user moves a point of contact over the InteractiveObject instance
    * on a touch-enabled device (such as moving a finger from left to right over a display object
    * on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TransformGestureEvent.GESTURE_PAN
    [Event(name="gesturePan", type="flash.events.TransformGestureEvent")]

    * Dispatched when the user presses two points of contact over the same InteractiveObject instance
    * on a touch-enabled device (such as presses and releases two fingers over a display object
    * on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.GestureEvent.GESTURE_TWO_FINGER_TAP
    [Event(name="gestureTwoFingerTap", type="flash.events.GestureEvent")]

    * Dispatched when the user lifts the point of contact over the same InteractiveObject instance on which the contact was initiated
    * on a touch-enabled device (such as presses and releases a finger from a single point over a display object
    * on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_TAP
    [Event(name="touchTap", type="flash.events.TouchEvent")]

    * Dispatched when the user moves the point of contact over an InteractiveObject instance on a touch-enabled device
    * (such as drags a finger from a point outside a display object to a point over a display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_ROLL_OVER
    [Event(name="touchRollOver", type="flash.events.TouchEvent")]

    * Dispatched when the user moves the point of contact away from an InteractiveObject instance on a touch-enabled device
    * (such as drags a finger from over a display object to a point outside the display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_ROLL_OUT
    [Event(name="touchRollOut", type="flash.events.TouchEvent")]

    * Dispatched when the user moves the point of contact over an InteractiveObject instance on a touch-enabled device
    * (such as drags a finger from a point outside a display object to a point over a display object on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_OVER
    [Event(name="touchOver", type="flash.events.TouchEvent")]

    * Dispatched when the user moves the point of contact away from InteractiveObject instance on a touch-enabled device
    * (such as drags a finger from one display object to another on a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_OUT
    [Event(name="touchOut", type="flash.events.TouchEvent")]

    * Dispatched when the user moves the point of contact with a touch-enabled device (such as drags a finger across a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_MOVE
    [Event(name="touchMove", type="flash.events.TouchEvent")]

    * Dispatched when the user removes contact with a touch-enabled device (such as lifts a finger off a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_END
    [Event(name="touchEnd", type="flash.events.TouchEvent")]

    * Dispatched when the user first contacts a touch-enabled device (such as touches a finger to a mobile phone or tablet with a touch screen).
    * @eventType	flash.events.TouchEvent.TOUCH_BEGIN
    [Event(name="touchBegin", type="flash.events.TouchEvent")]

    * Dispatched when the user attempts to change focus by using a pointer device.
    * @eventType	flash.events.FocusEvent.MOUSE_FOCUS_CHANGE
    [Event(name="mouseFocusChange", type="flash.events.FocusEvent")]

    * Dispatched when the user attempts to change focus by using keyboard navigation.
    * @eventType	flash.events.FocusEvent.KEY_FOCUS_CHANGE
    *
    * Dispatched after a display object loses focus.
    * @eventType	flash.events.FocusEvent.FOCUS_OUT
    [Event(name="focusOut", type="flash.events.FocusEvent")]

    * Dispatched after a display object gains focus.
    * @eventType	flash.events.FocusEvent.FOCUS_IN
    [Event(name="focusIn", type="flash.events.FocusEvent")]

    * Dispatched when the user activates the platform-specific accelerator key combination for a select all operation
    * or selects 'Select All' from the text context menu.
    * @eventType	flash.events.Event.SELECT_ALL
    [Event(name="selectAll", type="flash.events.Event")]

    * Dispatched when the user activates the platform-specific accelerator key combination for a paste operation
    * or selects 'Paste' from the text context menu.
    * @eventType	flash.events.Event.PASTE
    [Event(name="paste", type="flash.events.Event")]

    * Dispatched when the user activates the platform-specific accelerator key combination for a cut operation
    * or selects 'Cut' from the text context menu.
    * @eventType	flash.events.Event.CUT
    [Event(name="cut", type="flash.events.Event")]

    * Dispatched when the user activates the platform-specific accelerator key combination for a copy operation
    * or selects 'Copy' from the text context menu.
    * @eventType	flash.events.Event.COPY
    [Event(name="copy", type="flash.events.Event")]

    * Dispatched when the user selects 'Clear' (or 'Delete') from the text context menu.
    * @eventType	flash.events.Event.CLEAR
    [Event(name="clear", type="flash.events.Event")]
    */
    /**

   * The InteractiveObject class is the abstract base class for all display objects with which the user can
    * interact, using the mouse, keyboard, or other user input device.
    *
    *   <p class="- topic/p ">You cannot instantiate the InteractiveObject class directly. A call to the <codeph class="+ topic/ph pr-d/codeph ">new
    * InteractiveObject()</codeph> constructor throws an <codeph class="+ topic/ph pr-d/codeph ">ArgumentError</codeph> exception.</p><p class="- topic/p ">The InteractiveObject class itself does not include any APIs for rendering content onscreen.
    * To create a custom subclass of the InteractiveObject class,
    * extend one of the subclasses that do have APIs for rendering content onscreen,
    * such as the Sprite, SimpleButton, TextField, or MovieClip classes.</p>
    *
    *   EXAMPLE:
    *
    *   The following example uses the <codeph class="+ topic/ph pr-d/codeph ">InteractiveObjectExample</codeph> class, which in
    * turn uses the <codeph class="+ topic/ph pr-d/codeph ">ChildSprite</codeph> class to draw a rectangle and then manipulate that rectangle
    * based on various mouse events.  This task is accomplished by performing the following steps:
    * <ol class="- topic/ol "><li class="- topic/li ">In the <codeph class="+ topic/ph pr-d/codeph ">InteractiveObjectExample</codeph> constructor, a new ChildSprite object of type Sprite
    * called <codeph class="+ topic/ph pr-d/codeph ">child</codeph> is created, which calls the ChildSprite constructor method to draw the shape
    * and add mouse events for the shape (as explained in the following steps).  The <codeph class="+ topic/ph pr-d/codeph ">child</codeph>
    * object is added to the top of the display list at coordinates <i class="+ topic/ph hi-d/i ">x = 0, y = 0</i>.  </li><li class="- topic/li ">In the <codeph class="+ topic/ph pr-d/codeph ">ChildSprite</codeph> class, declare the <codeph class="+ topic/ph pr-d/codeph ">size</codeph> and
    * <codeph class="+ topic/ph pr-d/codeph ">overSize</codeph> properties that are used later in the <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method and
    * MouseEvent methods.</li><li class="- topic/li ">Declare properties that set the background color to orange, the mouse-over color to
    * dark yellow, and the mouse-down color to light blue.</li><li class="- topic/li ">In the <codeph class="+ topic/ph pr-d/codeph ">ChildSprite</codeph> constructor, an orange square is drawn by using methods from
    * the Graphics class and the <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method.</li><li class="- topic/li ">The constructor adds four MouseEvent event listener methods:
    *
    *   <ul class="- topic/ul "><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler</codeph>: redraws a larger 60 x 60 pixel square with a dark-yellow color
    * at the original coordinates.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseOutHandler</codeph>: returns the square to its original size and color.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseDownHandler</codeph>: redraws a larger 60 x 60 pixel square with a light-blue color
    * at the original coordinates.</li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseUpHandler</codeph>: same as <codeph class="+ topic/ph pr-d/codeph ">mouseOverHandler</codeph>.</li></ul></li></ol><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
    *
    * Calling the new InteractiveObject() constructor
    * throws an ArgumentError exception.
    * You can, however, call constructors for the following subclasses of InteractiveObject:
    *
    *   new SimpleButton()new TextField()new Loader()new Sprite()new MovieClip()
    */
    function InteractiveObject(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        var _this = _super.call(this, adaptee) || this;
        // these events can not be mapped from awayjs: //todo (?)
        _this.eventMappingDummys[MouseEvent$1.RIGHT_MOUSE_UP] = "InteractiveObject:MouseEvent.RIGHT_MOUSE_UP";
        _this.eventMappingDummys[MouseEvent$1.RIGHT_MOUSE_DOWN] = "InteractiveObject:MouseEvent.RIGHT_MOUSE_DOWN";
        _this.eventMappingDummys[MouseEvent$1.RIGHT_MOUSE_DOWN] = "InteractiveObject:MouseEvent.RIGHT_MOUSE_DOWN";
        _this.eventMappingDummys[MouseEvent$1.RIGHT_CLICK] = "InteractiveObject:MouseEvent.RIGHT_CLICK";
        _this.eventMappingDummys[MouseEvent$1.MIDDLE_MOUSE_UP] = "InteractiveObject:MouseEvent.MIDDLE_MOUSE_UP";
        _this.eventMappingDummys[MouseEvent$1.MIDDLE_MOUSE_DOWN] = "InteractiveObject:MouseEvent.MIDDLE_MOUSE_DOWN";
        _this.eventMappingDummys[MouseEvent$1.MIDDLE_CLICK] = "InteractiveObject:MouseEvent.MIDDLE_CLICK";
        /*
        //todo
        this.eventMappingDummys[SoftKeyboardEvent.SOFT_KEYBOARD_DEACTIVATE]="SoftKeyboardEvent.SOFT_KEYBOARD_DEACTIVATE";
        this.eventMappingDummys[SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATE]="SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATE";
        this.eventMappingDummys[SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATING]="SoftKeyboardEvent.SOFT_KEYBOARD_ACTIVATING";
        this.eventMappingDummys[TextEvent.TEXT_INPUT]="TextEvent.TEXT_INPUT";
        this.eventMappingDummys[MouseEvent.CONTEXT_MENU]="MouseEvent.CONTEXT_MENU";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_COMPLETE]="NativeDragEvent.NATIVE_DRAG_COMPLETE";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_UPDATE]="NativeDragEvent.NATIVE_DRAG_UPDATE";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_START]="NativeDragEvent.NATIVE_DRAG_START";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_EXIT]="NativeDragEvent.NATIVE_DRAG_EXIT";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_DROP]="NativeDragEvent.NATIVE_DRAG_DROP";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_OVER]="NativeDragEvent.NATIVE_DRAG_OVER";
        this.eventMappingDummys[NativeDragEvent.NATIVE_DRAG_ENTER]="NativeDragEvent.NATIVE_DRAG_ENTER";
        this.eventMappingDummys[Event.TAB_INDEX_CHANGE]="Event.TAB_INDEX_CHANGE";
        this.eventMappingDummys[Event.TAB_ENABLED_CHANGE]="Event.TAB_ENABLED_CHANGE";
        this.eventMappingDummys[Event.TAB_CHILDREN_CHANGE]="Event.TAB_CHILDREN_CHANGE";
        this.eventMappingDummys[TransformGestureEvent.GESTURE_SWIPE]="TransformGestureEvent.GESTURE_SWIPE";
        this.eventMappingDummys[TransformGestureEvent.GESTURE_ROTATE]="TransformGestureEvent.GESTURE_ROTATE";
        this.eventMappingDummys[TransformGestureEvent.GESTURE_PRESS_AND_TAP]="TransformGestureEvent.GESTURE_PRESS_AND_TAP";
        this.eventMappingDummys[GestureEvent.GESTURE_PAN]="GestureEvent.GESTURE_PAN";
        this.eventMappingDummys[GestureEvent.GESTURE_TWO_FINGER_TAP]="GestureEvent.GESTURE_TWO_FINGER_TAP";
        this.eventMappingDummys[TouchEvent.TOUCH_TAP]="TouchEvent.TOUCH_TAP";
        this.eventMappingDummys[TouchEvent.TOUCH_ROLL_OVER]="TouchEvent.TOUCH_ROLL_OVER";
        this.eventMappingDummys[TouchEvent.TOUCH_ROLL_OUT]="TouchEvent.TOUCH_ROLL_OUT";
        this.eventMappingDummys[TouchEvent.TOUCH_OVER]="TouchEvent.TOUCH_OVER";
        this.eventMappingDummys[TouchEvent.TOUCH_OUT]="TouchEvent.TOUCH_OUT";
        this.eventMappingDummys[TouchEvent.TOUCH_MOVE]="TouchEvent.TOUCH_MOVE";
        this.eventMappingDummys[TouchEvent.TOUCH_END]="TouchEvent.TOUCH_END";
        this.eventMappingDummys[TouchEvent.TOUCH_BEGIN]="TouchEvent.TOUCH_BEGIN";
        this.eventMappingDummys[FocusEvent.MOUSE_FOCUS_CHANGE]="FocusEvent.MOUSE_FOCUS_CHANGE";
        this.eventMappingDummys[FocusEvent.KEY_FOCUS_CHANGE]="FocusEvent.KEY_FOCUS_CHANGE";
        this.eventMappingDummys[FocusEvent.FOCUS_OUT]="FocusEvent.FOCUS_OUT";
        this.eventMappingDummys[FocusEvent.FOCUS_IN]="FocusEvent.FOCUS_IN";
        this.eventMappingDummys[Event.SELECT_ALL]="Event.SELECT_ALL";
        this.eventMappingDummys[Event.PASTE]="Event.PASTE";
        this.eventMappingDummys[Event.CUT]="Event.CUT";
        this.eventMappingDummys[Event.COPY]="Event.COPY";
        this.eventMappingDummys[Event.CLEAR]="Event.CLEAR";
         */
        // KeyboardEvent events adapt to js-events. they listen on document.onKeyUp / onKeyDown:
        _this._keyUpCallbackDelegate = function (event) { return _this.keyUpCallback(event); };
        _this.eventMapping[KeyboardEvent.KEY_UP] = {
            adaptedType: "",
            addListener: _this.initKeyUpListener,
            removeListener: _this.removeKeyUpListener,
            callback: _this._keyUpCallbackDelegate
        };
        _this._keyDownCallbackDelegate = function (event) { return _this.keyDownCallback(event); };
        _this.eventMapping[KeyboardEvent.KEY_DOWN] = {
            adaptedType: "",
            addListener: _this.initKeyDownListener,
            removeListener: _this.removeKeyDownListener,
            callback: _this._keyDownCallbackDelegate
        };
        // MouseEvent events adapt to awayjs-MouseEvents. they listen on adapter:
        // these mapping share the same callback, thats why we need the setup the eventMappingInvert to
        _this._mouseCallbackDelegate = function (event) { return _this.mouseCallback(event); };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_WHEEL] = MouseEvent$1.MOUSE_WHEEL;
        _this.eventMapping[MouseEvent$1.MOUSE_WHEEL] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_WHEEL,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_UP] = MouseEvent$1.MOUSE_UP;
        _this.eventMapping[MouseEvent$1.MOUSE_UP] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_UP,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_OVER] = MouseEvent$1.MOUSE_OVER;
        _this.eventMapping[MouseEvent$1.MOUSE_OVER] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_OVER,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_OUT] = MouseEvent$1.MOUSE_OUT;
        _this.eventMapping[MouseEvent$1.MOUSE_OUT] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_OUT,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_MOVE] = MouseEvent$1.MOUSE_MOVE;
        _this.eventMapping[MouseEvent$1.MOUSE_MOVE] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_MOVE,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_DOWN] = MouseEvent$1.MOUSE_DOWN;
        _this.eventMapping[MouseEvent$1.MOUSE_DOWN] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_DOWN,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.DOUBLE_CLICK] = MouseEvent$1.DOUBLE_CLICK;
        _this.eventMapping[MouseEvent$1.DOUBLE_CLICK] = {
            adaptedType: _awayjs_scene.MouseEvent.DOUBLE_CLICK,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.CLICK] = MouseEvent$1.CLICK;
        _this.eventMapping[MouseEvent$1.CLICK] = {
            adaptedType: _awayjs_scene.MouseEvent.CLICK,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_OUT] = MouseEvent$1.ROLL_OUT;
        _this.eventMapping[MouseEvent$1.ROLL_OUT] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_OUT,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        _this.eventMappingInvert[_awayjs_scene.MouseEvent.MOUSE_OVER] = MouseEvent$1.ROLL_OVER;
        _this.eventMapping[MouseEvent$1.ROLL_OVER] = {
            adaptedType: _awayjs_scene.MouseEvent.MOUSE_OVER,
            addListener: _this.initMouseListener,
            removeListener: _this.removeMouseListener,
            callback: _this._mouseCallbackDelegate
        };
        return _this;
    }
    // ---------- event mapping functions for KeyboardEvent.KEY_UP:
    InteractiveObject.prototype.initKeyUpListener = function (type, callback) {
        document.addEventListener("keyup", callback);
        document.addEventListener("keypress", callback);
    };
    InteractiveObject.prototype.removeKeyUpListener = function (type, callback) {
        document.removeEventListener("keyup", callback);
    };
    InteractiveObject.prototype.keyUpCallback = function (event) {
        if (event === void 0) { event = null; }
        if (window.event) {
            window.event.returnValue = false;
        }
        event.preventDefault ? event.preventDefault() : (event.returnValue = false);
        var newkeyBoardEvent = new KeyboardEvent(KeyboardEvent.KEY_UP);
        newkeyBoardEvent.keyCode = event.keyCode;
        newkeyBoardEvent.charCode = event.charCode;
        newkeyBoardEvent.shiftKey = event.shiftKey;
        newkeyBoardEvent.ctrlKey = event.ctrlKey;
        newkeyBoardEvent.altKey = event.altKey;
        this.dispatchEvent(newkeyBoardEvent);
        return false;
    };
    // ---------- event mapping functions for KeyboardEvent.KEY_DOWN:
    InteractiveObject.prototype.initKeyDownListener = function (type, callback) {
        document.addEventListener("keydown", callback);
        document.addEventListener("keypress", callback);
    };
    InteractiveObject.prototype.removeKeyDownListener = function (type, callback) {
        document.removeEventListener("keydown", callback);
        document.removeEventListener("keypress", callback);
    };
    InteractiveObject.prototype.keyDownCallback = function (event) {
        if (event === void 0) { event = null; }
        if (window.event) {
            window.event.returnValue = false;
        }
        event.preventDefault ? event.preventDefault() : (event.returnValue = false);
        var newkeyBoardEvent = new KeyboardEvent(KeyboardEvent.KEY_DOWN);
        newkeyBoardEvent.keyCode = event.keyCode;
        newkeyBoardEvent.charCode = event.charCode;
        newkeyBoardEvent.shiftKey = event.shiftKey;
        newkeyBoardEvent.ctrlKey = event.ctrlKey;
        newkeyBoardEvent.altKey = event.altKey;
        this.dispatchEvent(newkeyBoardEvent);
        return false;
    };
    // ---------- event mapping functions for MouseEvents:
    InteractiveObject.prototype.initMouseListener = function (type, callback) {
        this.adaptee.addEventListener(type, callback);
    };
    InteractiveObject.prototype.removeMouseListener = function (type, callback) {
        this.adaptee.removeEventListener(type, callback);
    };
    InteractiveObject.prototype.mouseCallback = function (event) {
        var adaptedEvent = new MouseEvent$1(this.eventMappingInvert[event.type]);
        adaptedEvent.fillFromAway(event);
        adaptedEvent.target = this;
        adaptedEvent.currentTarget = this;
        this.dispatchEvent(adaptedEvent);
    };
    Object.defineProperty(InteractiveObject.prototype, "accessibilityImplementation", {
        //---------------------------stuff added to make it work:
        //---------------------------original as3 properties / methods:
        /**
         * The current accessibility implementation (AccessibilityImplementation)
         * for this InteractiveObject instance.
         * @langversion	3.0
         */
        get: function () {
            console.log("accessibilityImplementation not implemented yet in flash/InteractiveObject");
            //todo flash.accessibility.AccessibilityImplementation;
            return null;
        },
        set: function (value) {
            //todo
            console.log("accessibilityImplementation not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "contextMenu", {
        /**
         * Specifies the context menu associated with this object.
         *
         *   For content running in Flash Player, this property is a ContextMenu object. In the AIR runtime,
         * the ContextMenu class extends the NativeMenu class, however Flash Player only supports the
         * ContextMenu class, not the NativeMenu class.
         * Note: TextField objects always include a clipboard menu in the context menu. The clipboard menu contains
         * Cut, Copy, Paste, Clear, and Select All commands. You cannot remove these commands from the context menu for TextField objects.
         * For TextField objects, selecting these commands (or their keyboard equivalents) does not generate clear,
         * copy, cut, paste, or selectAll events.
         */
        get: function () {
            console.log("contextMenu not implemented yet in flash/InteractiveObject");
            //todo flash.display.NativeMenu;
            return null;
        },
        set: function (cm) {
            //todo
            console.log("contextMenu not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "doubleClickEnabled", {
        /**
         * Specifies whether the object receives doubleClick events. The default value
         * is false, which means that by default an InteractiveObject instance does not receive
         * doubleClick events. If the doubleClickEnabled property is set to
         * true, the instance receives doubleClick events within its bounds.
         * The mouseEnabled property of the InteractiveObject instance must also be
         * set to true for the object to receive doubleClick events.
         *
         *   No event is dispatched by setting this property. You must use the
         * addEventListener() method to add an event listener
         * for the doubleClick event.
         */
        get: function () {
            //todo
            console.log("doubleClickEnabled not implemented yet in flash/InteractiveObject");
            return false;
        },
        set: function (enabled) {
            //todo
            console.log("doubleClickEnabled not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "focusRect", {
        /**
         * Specifies whether this object displays a focus rectangle. It can take one of three
         * values: true, false, or null. Values of true
         * and false work as expected, specifying whether or not the focus rectangle
         * appears. A value of null indicates that this object obeys the
         * stageFocusRect property of the Stage.
         */
        get: function () {
            //todo
            console.log("focusRect not implemented yet in flash/InteractiveObject");
            return null;
        },
        set: function (focusRect) {
            //todo
            console.log("focusRect not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "mouseEnabled", {
        /**
         * Specifies whether this object receives mouse, or other user input, messages. The default value is true,
         * which means that by default any InteractiveObject instance that is on the display list
         * receives mouse events or other user input events.
         * If mouseEnabled is set to false, the instance does not receive any
         * mouse events (or other user input events like keyboard events). Any children of this instance on the display list are not affected. To change
         * the mouseEnabled behavior for all children of an object on the display list, use
         * flash.display.DisplayObjectContainer.mouseChildren.
         * No event is dispatched by setting this property. You must use the
         * addEventListener() method to create interactive functionality.
         */
        //private _mouseEnabled:boolean=true;
        get: function () {
            return this.adaptee.mouseEnabled;
        },
        set: function (enabled) {
            this.adaptee.mouseEnabled = enabled;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "needsSoftKeyboard", {
        /**
         * Specifies whether a virtual keyboard (an on-screen, software keyboard) should display
         * when this InteractiveObject instance receives focus.
         *
         *   By default, the value is false and focusing an InteractiveObject instance does
         * not raise a soft keyboard. If the needsSoftKeyboard property is set to true,
         * the runtime raises a soft keyboard when the InteractiveObject instance is ready to accept user input.
         * An InteractiveObject instance is ready to accept user input after a programmatic call to set the Stage
         * focus property or a user interaction, such as a "tap." If the client system has a
         * hardware keyboard available or does not support virtual keyboards, then the soft keyboard is not raised.The InteractiveObject instance dispatches softKeyboardActivating,
         * softKeyboardActivate, and softKeyboardDeactivate events
         * when the soft keyboard raises and lowers.Note: This property is not supported in AIR applications on iOS.
         */
        get: function () {
            //todo
            console.log("needsSoftKeyboard not implemented yet in flash/InteractiveObject");
            return false;
        },
        set: function (value) {
            //todo
            console.log("needsSoftKeyboard not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "softKeyboardInputAreaOfInterest", {
        /**
         * Defines the area that should remain on-screen when a soft keyboard is displayed.
         *
         *   If the needsSoftKeyboard property of this InteractiveObject is
         * true, then the runtime adjusts the display as needed to keep the
         * object in view while the user types. Ordinarily, the runtime uses the object
         * bounds obtained from the DisplayObject.getBounds() method. You can
         * specify a different area using this softKeyboardInputAreaOfInterest
         * property.Specify the softKeyboardInputAreaOfInterest in stage coordinates.Note: On Android, the softKeyboardInputAreaOfInterest is not
         * respected in landscape orientations.
         */
        get: function () {
            //todo
            console.log("softKeyboardInputAreaOfInterest not implemented yet in flash/InteractiveObject");
            return null;
        },
        set: function (value) {
            //todo
            console.log("softKeyboardInputAreaOfInterest not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "tabEnabled", {
        /**
         * Specifies whether this object is in the tab order. If this object is in the tab order,
         * the value is true; otherwise, the value is false. By default,
         * the value is false, except for the following:
         * For a SimpleButton object, the value is true.For a TextField object with type = "input", the value is true.For a Sprite object or MovieClip object with buttonMode = true, the value is true.
         */
        get: function () {
            //todo
            //console.log("tabEnabled not implemented yet in flash/InteractiveObject");
            return false;
        },
        set: function (enabled) {
            //todo
            //console.log("tabEnabled not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InteractiveObject.prototype, "tabIndex", {
        /**
         * Specifies the tab ordering of objects in a SWF file. The tabIndex
         * property is -1 by default, meaning no tab index is set for the object.
         *
         *   If any currently displayed object in the SWF file contains a tabIndex property, automatic
         * tab ordering is disabled, and the tab ordering is calculated from the tabIndex properties of
         * objects in the SWF file. The custom tab ordering includes only objects that have tabIndex
         * properties.The tabIndex property can be a non-negative integer. The objects are ordered according to
         * their tabIndex properties, in ascending order. An object with a tabIndex
         * value of 1 precedes an object with a tabIndex value of 2. Do not use the same tabIndex
         *
         *   value for multiple objects.The custom tab ordering that the tabIndex property defines is flat.
         * This means that no attention is paid to the hierarchical relationships of objects in the SWF file.
         * All objects in the SWF file with tabIndex properties are placed in the tab order, and the
         * tab order is determined by the order of the tabIndex values. Note: To set the tab order for TLFTextField instances, cast the display object child
         * of the TLFTextField as an InteractiveObject, then set the tabIndex property. For example:
         *
         *   InteractiveObject(tlfInstance.getChildAt(1)).tabIndex = 3;
         *
         *   To reverse the tab order from the default setting for three instances of a TLFTextField object
         * (tlfInstance1, tlfInstance2 and tlfInstance3), use:
         *
         *   InteractiveObject(tlfInstance1.getChildAt(1)).tabIndex = 3;
         * InteractiveObject(tlfInstance2.getChildAt(1)).tabIndex = 2;
         * InteractiveObject(tlfInstance3.getChildAt(1)).tabIndex = 1;
         */
        get: function () {
            //todo
            console.log("tabIndex not implemented yet in flash/InteractiveObject");
            return 0;
        },
        set: function (index) {
            //todo
            console.log("tabIndex not implemented yet in flash/InteractiveObject");
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Raises a virtual keyboard.
     *
     *   Calling this method focuses the InteractiveObject instance and raises the soft keyboard, if necessary.
     * The needsSoftKeyboard must also be true. A keyboard is not raised
     * if a hardware keyboard is available, or if the client system does not support virtual keyboards.Note: This method is not supported in AIR applications on iOS.
     * @return	A value of true means that the soft keyboard request was granted; false means that the soft keyboard was not raised.
     */
    InteractiveObject.prototype.requestSoftKeyboard = function () {
        //todo
        console.log("requestSoftKeyboard not implemented yet in flash/InteractiveObject");
        return false;
    };
    return InteractiveObject;
}(DisplayObject$1));

var DisplayObjectContainer$1 = (function (_super) {
    __extends(DisplayObjectContainer$$1, _super);
    /**
     * The DisplayObjectContainer class is the base class for all objects that can serve as display object containers on
     * the display list. The display list manages all objects displayed in the Flash runtimes.
     * Use the DisplayObjectContainer class to arrange the display objects in the display list.
     * Each DisplayObjectContainer object has its own child list for organizing the z-order of the objects.
     * The z-order is the front-to-back order that determines which object is drawn in front, which is behind,
     * and so on.
     *
     *   <p class="- topic/p ">DisplayObject is an abstract base class; therefore, you cannot call DisplayObject directly. Invoking
     * <codeph class="+ topic/ph pr-d/codeph ">new DisplayObject()</codeph> throws an <codeph class="+ topic/ph pr-d/codeph ">ArgumentError</codeph> exception.</p>
     *
     *   The DisplayObjectContainer class is an abstract base class for all objects that can contain child objects.
     * It cannot be instantiated directly; calling the <codeph class="+ topic/ph pr-d/codeph ">new DisplayObjectContainer()</codeph> constructor
     * throws an <codeph class="+ topic/ph pr-d/codeph ">ArgumentError</codeph> exception.
     *
     *   <p class="- topic/p ">For more information, see the "Display Programming" chapter of the <i class="+ topic/ph hi-d/i ">ActionScript 3.0 Developer's Guide</i>.</p>

     /**
     * Calling the new DisplayObjectContainer() constructor throws an
     * ArgumentError exception. You can, however, call constructors for
     * the following subclasses of DisplayObjectContainer:
     *
     *   new Loader()new Sprite()new MovieClip()
     */
    function DisplayObjectContainer$$1(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        var _this = _super.call(this, adaptee || new _awayjs_scene.DisplayObjectContainer()) || this;
        _this._eventRemoved = new Event(Event.REMOVED);
        _this._eventAdded = new Event(Event.ADDED);
        return _this;
    }
    DisplayObjectContainer$$1.prototype.addTimelineObjectAtDepth = function (child, depth) {
    };
    DisplayObjectContainer$$1.prototype.getTimelineObjectAtDepth = function (depth) {
        return null;
    };
    DisplayObjectContainer$$1.prototype._lookupChildByName = function (name, lookupOptions) {
        if (lookupOptions === void 0) { lookupOptions = null; }
    };
    DisplayObjectContainer$$1.prototype._lookupChildByIndex = function (idx, lookupOptions) {
        if (lookupOptions === void 0) { lookupOptions = null; }
    };
    //---------------------------stuff added to make it work:
    DisplayObjectContainer$$1.prototype.clone = function () {
        return new DisplayObjectContainer$$1(this._adaptee.clone());
    };
    /* gets called from stage in order to move the playhead of the root-movieclips to next frame.
     the DisplayObjectContainer should call this function on all children if they extend DisplayObjectContainer themself.
     if any child is a MovieClip this function will not be called on its childrens adapter.
     */
    DisplayObjectContainer$$1.prototype.advanceFrame = function (events) {
        this.dispatchEvent(events[0]); //ENTER_FRAME
        var i = this._adaptee._children.length;
        while (i > 0) {
            i--;
            var oneChild = this._adaptee._children[i];
            if (oneChild.isAsset(_awayjs_scene.DisplayObjectContainer)) {
                if (oneChild.adapter) {
                    oneChild.adapter.advanceFrame(events);
                }
            }
            else if (oneChild.isAsset(_awayjs_scene.Sprite)) {
                if (oneChild.adapter) {
                    oneChild.adapter.advanceFrame(events);
                }
            }
            else if (oneChild.isAsset(_awayjs_scene.MovieClip)) {
                oneChild.update(events);
            }
        }
        this.dispatchEvent(events[1]); //EXIT_FRAME
    };
    DisplayObjectContainer$$1.prototype.debugDisplayGraph = function (obj) {
        obj.object = this;
        obj.rectangle = "x:" + this.x + ", y:" + this.y + ", width:" + this.width + ", height:" + this.height;
        obj.children = {};
        var i = 0;
        for (i = 0; i < this._adaptee.numChildren; i++) {
            var oneChild = this._adaptee.getChildAt(i);
            var childname = "child_" + i + " " + oneChild.adapter.constructor.name;
            if (oneChild.isAsset(_awayjs_scene.Sprite) || oneChild.isAsset(_awayjs_scene.DisplayObjectContainer)) {
                if (oneChild.adapter) {
                    obj.children[childname] = {};
                    oneChild.adapter.debugDisplayGraph(obj.children[childname]);
                }
            }
            else if (oneChild.isAsset(_awayjs_scene.Billboard)) {
                obj.children[childname] = {};
                obj.children[childname].object = oneChild.adapter;
                obj.children[childname].name = oneChild.name;
                obj.children[childname].rectangle = "x:" + oneChild.x + ", y:" + oneChild.y; //+", width:"+oneChild.width+", height:"+oneChild.height;
                var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(oneChild.partition).getBoxBounds(oneChild);
                obj.children[childname].width = (box == null) ? 0 : box.width;
                obj.children[childname].height = (box == null) ? 0 : box.height;
            }
            else if (oneChild.isAsset(_awayjs_scene.MovieClip)) {
                obj.children[childname] = {};
                obj.children[childname].object = oneChild.adapter;
                obj.children[childname].name = oneChild.name;
                obj.children[childname].rectangle = "x:" + oneChild.x + ", y:" + oneChild.y; //+", width:"+oneChild.width+", height:"+oneChild.height;
                var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(oneChild.partition).getBoxBounds(oneChild);
                obj.children[childname].width = (box == null) ? 0 : box.width;
                obj.children[childname].height = (box == null) ? 0 : box.height;
            }
            else if (oneChild.isAsset(_awayjs_scene.TextField)) {
                obj.children[childname] = {};
                obj.children[childname].object = oneChild.adapter;
                obj.children[childname].text = oneChild.text;
                obj.children[childname].rectangle = "x:" + oneChild.x + ", y:" + oneChild.y; //+", width:"+oneChild.width+", height:"+oneChild.height;
                var box = _awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(oneChild.partition).getBoxBounds(oneChild);
                obj.children[childname].width = (box == null) ? 0 : box.width;
                obj.children[childname].height = (box == null) ? 0 : box.height;
            }
        }
    };
    Object.defineProperty(DisplayObjectContainer$$1.prototype, "mouseChildren", {
        /*
        //	overwrite
        public dispatchEventRecursive(event:Event) {
            this.dispatchEvent(event);
    
            if((<AwayDisplayObjectContainer> this._adaptee)){
                var i:number=(<AwayDisplayObjectContainer> this._adaptee).numChildren;
                while(i>0){
                    i--;
                    var oneChild:AwayDisplayObject=(<AwayDisplayObjectContainer> this._adaptee).getChildAt(i);
                    if(oneChild.adapter){
                        (<DisplayObject>oneChild.adapter).dispatchEventRecursive(event);
                    }
                }
            }
        };
        */
        //---------------------------original as3 properties / methods:
        /**
         * Determines whether or not the children of the object are mouse, or user input device, enabled.
         * If an object is enabled, a user can interact with it by using a mouse or user input device. The default is true.
         *
         *   This property is useful when you create a button with an instance of the Sprite class
         * (instead of using the SimpleButton class). When you use a Sprite instance to create a button,
         * you can choose to decorate the button by using the addChild() method to add additional
         * Sprite instances. This process can cause unexpected behavior with mouse events because
         * the Sprite instances you add as children can become the target object of a mouse event
         * when you expect the parent instance to be the target object. To ensure that the parent
         * instance serves as the target objects for mouse events, you can set the
         * mouseChildren property of the parent instance to false. No event is dispatched by setting this property. You must use the
         * addEventListener() method to create interactive functionality.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         */
        get: function () {
            return this._adaptee.mouseChildren;
        },
        set: function (enable) {
            this._adaptee.mouseChildren = enable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObjectContainer$$1.prototype, "numChildren", {
        /**
         * Returns the number of children of this object.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         */
        get: function () {
            return this._adaptee.numChildren;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObjectContainer$$1.prototype, "tabChildren", {
        /**
         * Determines whether the children of the object are tab enabled. Enables or disables tabbing for the
         * children of the object. The default is true.
         * Note: Do not use the tabChildren property with Flex.
         * Instead, use the mx.core.UIComponent.hasFocusableChildren property.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         * @throws	IllegalOperationError Calling this property of the Stage object
         *   throws an exception. The Stage object does not implement this property.
         */
        get: function () {
            //todo
            //console.warn("tabChildren not implemented yet in flash/DisplayObjectContainer");
            return false;
        },
        set: function (enable) {
            //console.warn("tabChildren not implemented yet in flash/DisplayObjectContainer");
            //todo
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DisplayObjectContainer$$1.prototype, "textSnapshot", {
        /**
         * Returns a TextSnapshot object for this DisplayObjectContainer instance.
         * @langversion	3.0
         * @playerversion	Flash 9
         */
        get: function () {
            throw ("textSnapshot not implemented yet in flash/DisplayObjectContainer");
            // todo: flash.text.TextSnapshot;
            //return null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Adds a child DisplayObject instance to this DisplayObjectContainer instance. The child is added
     * to the front (top) of all other children in this DisplayObjectContainer instance. (To add a child to a
     * specific index position, use the addChildAt() method.)
     *
     *   If you add a child object that already has a different display object container as
     * a parent, the object is removed from the child list of the other display object container. Note: The command stage.addChild() can cause problems with a published SWF file,
     * including security problems and conflicts with other loaded SWF files. There is only one Stage within a Flash runtime instance,
     * no matter how many SWF files you load into the runtime. So, generally, objects
     * should not be added to the Stage, directly, at all. The only object the Stage should
     * contain is the root object. Create a DisplayObjectContainer to contain all of the items on the
     * display list. Then, if necessary, add that DisplayObjectContainer instance to the Stage.
     * @param	child	The DisplayObject instance to add as a child of this DisplayObjectContainer instance.
     * @return	The DisplayObject instance that you pass in the
     *   child parameter.
     * @throws	ArgumentError Throws if the child is the same as the parent.  Also throws if
     *   the caller is a child (or grandchild etc.) of the child being added.
     */
    DisplayObjectContainer$$1.prototype.addChild = function (child) {
        //child.dispatchEventRecursive(new Event(Event.ADDED_TO_STAGE));
        child.dispatchEvent(this._eventAdded);
        this._adaptee.addChild(child.adaptee);
        return child;
    };
    /**
     * Adds a child DisplayObject instance to this DisplayObjectContainer
     * instance.  The child is added
     * at the index position specified. An index of 0 represents the back (bottom)
     * of the display list for this DisplayObjectContainer object.
     *
     *   For example, the following example shows three display objects, labeled a, b, and c, at
     * index positions 0, 2, and 1, respectively:If you add a child object that already has a different display object container as
     * a parent, the object is removed from the child list of the other display object container.
     * @param	child	The DisplayObject instance to add as a child of this
     *   DisplayObjectContainer instance.
     * @param	index	The index position to which the child is added. If you specify a
     *   currently occupied index position, the child object that exists at that position and all
     *   higher positions are moved up one position in the child list.
     * @return	The DisplayObject instance that you pass in the
     *   child parameter.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	RangeError Throws if the index position does not exist in the child list.
     * @throws	ArgumentError Throws if the child is the same as the parent.  Also throws if
     *   the caller is a child (or grandchild etc.) of the child being added.
     */
    DisplayObjectContainer$$1.prototype.addChildAt = function (child, index) {
        //child.dispatchEventRecursive(new Event(Event.ADDED_TO_STAGE));
        child.dispatchEvent(this._eventAdded);
        // todo: this should be done much more efficient (in awayjs)
        var allChildren = [];
        for (var i = 0; i < this._adaptee.numChildren; i++) {
            if (child.adaptee.id != this._adaptee._children[i].id) {
                allChildren[allChildren.length] = this._adaptee._children[i];
            }
        }
        for (i = 0; i < allChildren.length; i++) {
            this._adaptee.removeChild(allChildren[i]);
        }
        var newChildCnt = 0;
        for (i = 0; i < allChildren.length + 1; i++) {
            if (i == index) {
                this._adaptee.addChild(child.adaptee);
            }
            else {
                this._adaptee.addChild(allChildren[newChildCnt++]);
            }
        }
        //(<AwayDisplayObjectContainer>(<AwayDisplayObjectContainer> this._adaptee)).addChildAt(child.adaptee, index);
        return child;
    };
    /**
     * Indicates whether the security restrictions
     * would cause any display objects to be omitted from the list returned by calling
     * the DisplayObjectContainer.getObjectsUnderPoint() method
     * with the specified point point. By default, content from one domain cannot
     * access objects from another domain unless they are permitted to do so with a call to the
     * Security.allowDomain() method. For more information, related to security,
     * see the Flash Player Developer Center Topic:
     * Security.
     *
     *   The point parameter is in the coordinate space of the Stage,
     * which may differ from the coordinate space of the display object container (unless the
     * display object container is the Stage). You can use the globalToLocal() and
     * the localToGlobal() methods to convert points between these coordinate
     * spaces.
     * @param	point	The point under which to look.
     * @return	true if the point contains child display objects with security restrictions.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     */
    DisplayObjectContainer$$1.prototype.areInaccessibleObjectsUnderPoint = function (point) {
        //todo
        throw ("areInaccessibleObjectsUnderPoint not implemented yet in flash/DisplayObjectContainer");
        //return false;
    };
    /**
     * Determines whether the specified display object is a child of the DisplayObjectContainer instance or
     * the instance itself.
     * The search includes the entire display list including this DisplayObjectContainer instance. Grandchildren,
     * great-grandchildren, and so on each return true.
     * @param	child	The child object to test.
     * @return	true if the child object is a child of the DisplayObjectContainer
     *   or the container itself; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     */
    DisplayObjectContainer$$1.prototype.contains = function (child) {
        return this._adaptee.contains(child.adaptee);
    };
    /**
     * Returns the child display object instance that exists at the specified index.
     * @param	index	The index position of the child object.
     * @return	The child display object at the specified index position.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	RangeError Throws if the index does not exist in the child list.
     * @throws	SecurityError This child display object belongs to a sandbox
     *   to which you do not have access. You can avoid this situation by having
     *   the child movie call Security.allowDomain().
     */
    DisplayObjectContainer$$1.prototype.getChildAt = function (index) {
        return this._adaptee.getChildAt(index).adapter;
    };
    /**
     * Returns the child display object that exists with the specified name.
     * If more that one child display object has the specified name,
     * the method returns the first object in the child list.
     *
     *   The getChildAt() method is faster than the
     * getChildByName() method. The getChildAt() method accesses
     * a child from a cached array, whereas the getChildByName() method
     * has to traverse a linked list to access a child.
     * @param	name	The name of the child to return.
     * @return	The child display object with the specified name.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	SecurityError This child display object belongs to a sandbox
     *   to which you do not have access. You can avoid this situation by having
     *   the child movie call the Security.allowDomain() method.
     */
    DisplayObjectContainer$$1.prototype.getChildByName = function (name) {
        return this._adaptee.getChildByName(name) ? this._adaptee.getChildByName(name).adapter : null;
    };
    /**
     * Returns the index position of a child DisplayObject instance.
     * @param	child	The DisplayObject instance to identify.
     * @return	The index position of the child display object to identify.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	ArgumentError Throws if the child parameter is not a child of this object.
     */
    DisplayObjectContainer$$1.prototype.getChildIndex = function (child) {
        return this._adaptee.getChildIndex(child.adaptee);
    };
    /**
     * Returns an array of objects that lie under the specified point and are children
     * (or grandchildren, and so on) of this DisplayObjectContainer instance. Any child objects that
     * are inaccessible for security reasons are omitted from the returned array. To determine whether
     * this security restriction affects the returned array, call the
     * areInaccessibleObjectsUnderPoint() method.
     *
     *   The point parameter is in the coordinate space of the Stage,
     * which may differ from the coordinate space of the display object container (unless the
     * display object container is the Stage). You can use the globalToLocal() and
     * the localToGlobal() methods to convert points between these coordinate
     * spaces.
     * @param	point	The point under which to look.
     * @return	An array of objects that lie under the specified point and are children
     *   (or grandchildren, and so on) of this DisplayObjectContainer instance.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     */
    DisplayObjectContainer$$1.prototype.getObjectsUnderPoint = function (point) {
        var children = [];
        this._getObjectsUnderPointInternal(point, children);
        return children;
    };
    DisplayObjectContainer$$1.prototype._getObjectsUnderPointInternal = function (point, children) {
        var numChildren = this._adaptee.numChildren;
        var child;
        for (var i = 0; i < numChildren; i++) {
            child = this._adaptee._children[i];
            if (child.visible) {
                if (_awayjs_view.PickGroup.getInstance(this._stage.view).getBoundsPicker(child.adaptee.partition).hitTestPoint(point.x, point.y, true))
                    children.push(child.adapter);
                child.adapter._getObjectsUnderPointInternal(point, children);
            }
        }
    };
    /**
     * Removes the specified child DisplayObject instance from the child list of the DisplayObjectContainer instance.
     * The parent property of the removed child is set to null
     * , and the object is garbage collected if no other
     * references to the child exist. The index positions of any display objects above the child in the
     * DisplayObjectContainer are decreased by 1.
     *
     *   The garbage collector reallocates unused memory space. When a variable
     * or object is no longer actively referenced or stored somewhere, the garbage collector sweeps
     * through and wipes out the memory space it used to occupy if no other references to it exist.
     * @param	child	The DisplayObject instance to remove.
     * @return	The DisplayObject instance that you pass in the
     *   child parameter.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	ArgumentError Throws if the child parameter is not a child of this object.
     */
    DisplayObjectContainer$$1.prototype.removeChild = function (child) {
        //child.dispatchEventRecursive(new Event(Event.REMOVED_FROM_STAGE));
        child.dispatchEvent(this._eventRemoved);
        this._adaptee.removeChild(child.adaptee);
        //console.log("removeChild not implemented yet in flash/DisplayObjectContainer");
        return child;
    };
    /**
     * Removes a child DisplayObject from the specified index position in the child list of
     * the DisplayObjectContainer. The parent property of the removed child is set to
     * null, and the object is garbage collected if no other references to the child exist. The index
     * positions of any display objects above the child in the DisplayObjectContainer are decreased by 1.
     *
     *   The garbage collector reallocates unused memory space. When a variable or
     * object is no longer actively referenced or stored somewhere, the garbage collector sweeps
     * through and wipes out the memory space it used to occupy if no other references to it exist.
     * @param	index	The child index of the DisplayObject to remove.
     * @return	The DisplayObject instance that was removed.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	SecurityError This child display object belongs to a sandbox
     *   to which the calling object does not have access. You can avoid this situation by having
     *   the child movie call the Security.allowDomain() method.
     * @throws	RangeError Throws if the index does not exist in the child list.
     */
    DisplayObjectContainer$$1.prototype.removeChildAt = function (index) {
        var awayChild = this._adaptee.removeChildAt(index);
        var childadapter = awayChild.adapter;
        //childadapter.dispatchEventRecursive(new Event(Event.REMOVED_FROM_STAGE));
        childadapter.dispatchEvent(new Event(Event.REMOVED));
        //console.log("removeChildAt not implemented yet in flash/DisplayObjectContainer");
        return childadapter;
    };
    DisplayObjectContainer$$1.prototype.removeChildren = function (beginIndex, endIndex) {
        if (beginIndex === void 0) { beginIndex = 0; }
        if (endIndex === void 0) { endIndex = 2147483647; }
        if (endIndex >= this._adaptee.numChildren) {
            endIndex = this._adaptee.numChildren - 1;
        }
        for (var i = beginIndex; i <= endIndex; i++) {
            var oneChild = this._adaptee._children[i];
            if (oneChild.adapter) {
                //(<DisplayObject>oneChild.adapter).dispatchEventRecursive(new Event(Event.REMOVED_FROM_STAGE));
                oneChild.adapter.dispatchEvent(this._eventRemoved);
            }
        }
        this._adaptee.removeChildren(beginIndex, endIndex + 1);
        //console.log("removeChildren not implemented yet in flash/DisplayObjectContainer");
    };
    /**
     * Changes the  position of an existing child in the display object container.
     * This affects the layering of child objects. For example, the following example shows three
     * display objects, labeled a, b, and c, at index positions 0, 1, and 2, respectively:
     *
     *   When you use the setChildIndex() method and specify an index position
     * that is already occupied, the only positions that change are those in between the display object's former and new position.
     * All others will stay the same.
     * If a child is moved to an index LOWER than its current index, all children in between will INCREASE by 1 for their index reference.
     * If a child is moved to an index HIGHER than its current index, all children in between will DECREASE by 1 for their index reference.
     * For example, if the display object container
     * in the previous example is named container, you can swap the position
     * of the display objects labeled a and b by calling the following code:
     * <codeblock>
     * container.setChildIndex(container.getChildAt(1), 0);
     * </codeblock>
     * This code results in the following arrangement of objects:
     * @param	child	The child DisplayObject instance for which you want to change
     *   the index number.
     * @param	index	The resulting index number for the child display object.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	RangeError Throws if the index does not exist in the child list.
     * @throws	ArgumentError Throws if the child parameter is not a child of this object.
     */
    DisplayObjectContainer$$1.prototype.setChildIndex = function (child, index) {
        // todo: this should be done much more efficient (in awayjs)
        var allChildren = [];
        for (var i = 0; i < this._adaptee.numChildren; i++) {
            allChildren[allChildren.length] = this._adaptee._children[i];
        }
        for (i = 0; i < allChildren.length; i++) {
            this._adaptee.removeChild(allChildren[i]);
        }
        var newChildCnt = 0;
        var oldChild;
        for (i = 0; i < allChildren.length; i++) {
            if (i == index) {
                this._adaptee.addChild(child.adaptee);
            }
            else {
                oldChild = allChildren[newChildCnt++];
                if (oldChild.id != child.adaptee.id) {
                    this._adaptee.addChild(oldChild);
                }
                else {
                    oldChild = allChildren[newChildCnt++];
                    this._adaptee.addChild(oldChild);
                }
            }
        }
    };
    DisplayObjectContainer$$1.prototype.stopAllMovieClips = function () {
        //todo
        throw ("stopAllMovieClips not implemented yet in flash/DisplayObjectContainer");
    };
    /**
     * Swaps the z-order (front-to-back order) of the two specified child objects.  All other child
     * objects in the display object container remain in the same index positions.
     * @param	child1	The first child object.
     * @param	child2	The second child object.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	ArgumentError Throws if either child parameter is not a child of this object.
     */
    DisplayObjectContainer$$1.prototype.swapChildren = function (child1, child2) {
        this._adaptee.swapChildren(child1.adaptee, child2.adaptee);
    };
    /**
     * Swaps the z-order (front-to-back order) of the child objects at the two specified index positions in the
     * child list. All other child objects in the display object container remain in the same index positions.
     * @param	index1	The index position of the first child object.
     * @param	index2	The index position of the second child object.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @throws	RangeError If either index does not exist in the child list.
     */
    DisplayObjectContainer$$1.prototype.swapChildrenAt = function (index1, index2) {
        //todo
        throw ("swapChildrenAt not implemented yet in flash/DisplayObjectContainer");
    };
    return DisplayObjectContainer$$1;
}(InteractiveObject));

var TextEvent = (function (_super) {
    __extends(TextEvent, _super);
    function TextEvent(type, bubbles, cancelable, text) {
        if (bubbles === void 0) { bubbles = false; }
        if (cancelable === void 0) { cancelable = false; }
        if (text === void 0) { text = ""; }
        return _super.call(this, type, bubbles, cancelable) || this;
    }
    Object.defineProperty(TextEvent.prototype, "text", {
        get: function () {
            console.log("text not implemented yet in flash/IOErrorEvent");
            return "";
        },
        set: function (value) {
            console.log("text not implemented yet in flash/IOErrorEvent");
        },
        enumerable: true,
        configurable: true
    });
    TextEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/IOErrorEvent");
        return null;
    };
    TextEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/IOErrorEvent");
        return "";
    };
    return TextEvent;
}(Event));
TextEvent.LINK = "link";
TextEvent.TEXT_INPUT = "textInput";
TextEvent.NETWORK_ERROR = "networkError";
TextEvent.VERIFY_ERROR = "verifyError";

var ErrorEvent = (function (_super) {
    __extends(ErrorEvent, _super);
    function ErrorEvent(type, bubbles, cancelable, text, id) {
        if (bubbles === void 0) { bubbles = false; }
        if (cancelable === void 0) { cancelable = false; }
        if (text === void 0) { text = ""; }
        if (id === void 0) { id = 0; }
        return _super.call(this, type, bubbles, cancelable, text) || this;
    }
    Object.defineProperty(ErrorEvent.prototype, "errorID", {
        get: function () {
            console.log("errorID not implemented yet in flash/ErrorEvent");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    ErrorEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/ErrorEvent");
        return null;
    };
    ErrorEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/ErrorEvent");
        return "";
    };
    return ErrorEvent;
}(TextEvent));
ErrorEvent.ERROR = "error";

var IOErrorEvent = (function (_super) {
    __extends(IOErrorEvent, _super);
    function IOErrorEvent() {
        return _super.apply(this, arguments) || this;
    }
    IOErrorEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/IOErrorEvent");
        return null;
    };
    IOErrorEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/IOErrorEvent");
        return "";
    };
    return IOErrorEvent;
}(ErrorEvent));
IOErrorEvent.IO_ERROR = "ioError";
IOErrorEvent.DISK_ERROR = "diskError";
IOErrorEvent.NETWORK_ERROR = "networkError";
IOErrorEvent.VERIFY_ERROR = "verifyError";

var ProgressEvent = (function (_super) {
    __extends(ProgressEvent, _super);
    function ProgressEvent(type, bubbles, cancelable, byteLoaded, bytesTotal) {
        if (bubbles === void 0) { bubbles = true; }
        if (cancelable === void 0) { cancelable = false; }
        if (byteLoaded === void 0) { byteLoaded = 0; }
        if (bytesTotal === void 0) { bytesTotal = 0; }
        var _this = _super.call(this, type, bubbles, cancelable) || this;
        _this._byteLoaded = byteLoaded;
        _this._bytesTotal = bytesTotal;
        return _this;
    }
    Object.defineProperty(ProgressEvent.prototype, "bytesTotal", {
        get: function () {
            return this._bytesTotal;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ProgressEvent.prototype, "bytesLoaded", {
        get: function () {
            return this._byteLoaded;
        },
        enumerable: true,
        configurable: true
    });
    ProgressEvent.prototype.clone = function () {
        return new ProgressEvent(this.type, null, null, this._byteLoaded, this._bytesTotal);
    };
    return ProgressEvent;
}(Event));
ProgressEvent.PROGRESS = "progress";
ProgressEvent.SOCKET_DATA = "socketData";
ProgressEvent.STANDARD_ERROR_DATA = "standardErrorData";
ProgressEvent.STANDARD_OUTPUT_DATA = "standardOutputData";

/**
 * Dispatched when a network request is made over HTTP and an HTTP status code can be detected.
 * @eventType	flash.events.HTTPStatusEvent.HTTP_STATUS

[Event(name="httpStatus", type="flash.events.HTTPStatusEvent")]

 * Dispatched by a LoaderInfo object whenever a loaded object is removed by using the unload()
 * method of the Loader object, or when a second load is performed by the same Loader object and the
 * original content is removed prior to the load beginning.
 * @eventType	flash.events.Event.UNLOAD

[Event(name="unload", type="flash.events.Event")]

 * Dispatched when data is received as the download operation progresses.
 * @eventType	flash.events.ProgressEvent.PROGRESS
 
[Event(name="progress", type="flash.events.ProgressEvent")]

 * Dispatched when a load operation starts.
 * @eventType	flash.events.Event.OPEN

[Event(name="open", type="flash.events.Event")]

 * Dispatched when an input or output error occurs that causes a load operation to fail.
 * @eventType	flash.events.IOErrorEvent.IO_ERROR
 
[Event(name="ioError", type="flash.events.IOErrorEvent")]

 * Dispatched when the properties and methods of a loaded SWF file are
 * accessible and ready for use.
 * @eventType	flash.events.Event.INIT
 
[Event(name="init", type="flash.events.Event")]

 * Dispatched when data has loaded successfully.
 * @eventType	flash.events.Event.COMPLETE
 
[Event(name="complete", type="flash.events.Event")]

 * The LoaderInfo class provides information about a loaded SWF file or a loaded image file
 * (JPEG, GIF, or PNG).  LoaderInfo objects are available for any display object.
 * The information provided includes load progress, the URLs of the loader and
 * loaded content, the number of bytes total for the media, and the nominal height and width of the
 * media.
 *
 *   <p class="- topic/p ">You can access LoaderInfo objects in two ways: </p><ul class="- topic/ul "><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph> property of a flash.display.Loader object—
 * The <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph> property is always available for any Loader object.
 * For a Loader object that has not called the <codeph class="+ topic/ph pr-d/codeph ">load()</codeph> or <codeph class="+ topic/ph pr-d/codeph ">loadBytes()</codeph>
 * method, or that has not sufficiently loaded, attempting to access many of the properties of the
 * <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph> property throws an error.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> property of a display object. </li></ul><p class="- topic/p ">The <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph> property of a Loader object provides information about
 * the content that the Loader object is loading, whereas the <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> property of
 * a DisplayObject provides information about the root SWF file for that display object. </p><p class="- topic/p ">When you use a Loader object to load a display object (such as a SWF file or a bitmap), the
 * <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> property of the display object is the same as the <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph>
 * property of the Loader object (<codeph class="+ topic/ph pr-d/codeph ">DisplayObject.loaderInfo = Loader.contentLoaderInfo</codeph>).
 * Because the instance of the main class of the SWF file has
 * no Loader object, the <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> property is the only way to
 * access the LoaderInfo for the instance of the main class of the SWF file.</p><p class="- topic/p ">The following diagram shows the different uses of the LoaderInfo object—for the instance of the main class of
 * the SWF file, for the <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph> property of a Loader object, and for the <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph>
 * property of a loaded object:</p><p class="- topic/p "><adobeimage alt="An image of different LoaderInfo situations" href="../../images/loaderInfo_object.jpg" placement="inline" class="+ topic/image adobe-d/adobeimage " /></p><p class="- topic/p ">When a loading operation is not complete, some properties of the <codeph class="+ topic/ph pr-d/codeph ">contentLoaderInfo</codeph>
 * property of a Loader object are not available.  You can obtain some properties, such as
 * <codeph class="+ topic/ph pr-d/codeph ">bytesLoaded</codeph>, <codeph class="+ topic/ph pr-d/codeph ">bytesTotal</codeph>, <codeph class="+ topic/ph pr-d/codeph ">url</codeph>, <codeph class="+ topic/ph pr-d/codeph ">loaderURL</codeph>,
 * and <codeph class="+ topic/ph pr-d/codeph ">applicationDomain</codeph>. When the <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> object dispatches the
 * <codeph class="+ topic/ph pr-d/codeph ">init</codeph> event, you can access all properties of the <codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph> object and
 * the loaded image or SWF file.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b> All properties of LoaderInfo objects are read-only.</p><p class="- topic/p ">The <codeph class="+ topic/ph pr-d/codeph ">EventDispatcher.dispatchEvent()</codeph> method
 *
 *   is not applicable to LoaderInfo objects. If you call <codeph class="+ topic/ph pr-d/codeph ">dispatchEvent()</codeph>
 * on a LoaderInfo object, an IllegalOperationError exception is thrown.</p>
 *
 *   EXAMPLE:
 *
 *   The following example uses the LoaderInfoExample class to display an image on
 * the stage.  This is accomplished by performing the following steps:
 * <ol class="- topic/ol "><li class="- topic/li ">A property <codeph class="+ topic/ph pr-d/codeph ">url</codeph> is created, which is the location and name of the image.</li><li class="- topic/li ">The class constructor creates a Loader object named <codeph class="+ topic/ph pr-d/codeph ">loader</codeph>.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">loader</codeph> object instantiates an event listener to ensure that the image loads properly.</li><li class="- topic/li ">The constructor creates a new instance of a URLRequest object, <codeph class="+ topic/ph pr-d/codeph ">request</codeph>,
 * with <codeph class="+ topic/ph pr-d/codeph ">url</codeph> passed so that the file name and location are known.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">request</codeph> object is then passed to the <codeph class="+ topic/ph pr-d/codeph ">load()</codeph> method of the
 * <codeph class="+ topic/ph pr-d/codeph ">loader</codeph> object, which loads the image onto the display list.</li></ol><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Important:</b> This example requires that you add a file named Image.gif in the same directory
 * as the compiled SWF file. Use an image that has an area that fits within the dimensions of the main SWF file.</p><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
 * package {
     * import flash.display.Loader;
     * import flash.display.LoaderInfo;
     * import flash.display.Sprite;
     * import flash.events.*;
     * import flash.net.URLRequest;
     *
     *   public class LoaderInfoExample extends Sprite {
     * private var url:String = "Image.gif";
     *
     *   public function LoaderInfoExample() {
     * var loader:Loader = new Loader();
     * loader.contentLoaderInfo.addEventListener(Event.INIT, initHandler);
     * loader.contentLoaderInfo.addEventListener(IOErrorEvent.IO_ERROR, ioErrorHandler);
     * var request:URLRequest = new URLRequest(url);
     * loader.load(request);
     * addChild(loader);
     * }
     *
     *   private function initHandler(event:Event):void {
     * var loader:Loader = Loader(event.target.loader);
     * var info:LoaderInfo = LoaderInfo(loader.contentLoaderInfo);
     * trace("initHandler: loaderURL=" + info.loaderURL + " url=" + info.url);
     * }
     *
     *   private function ioErrorHandler(event:IOErrorEvent):void {
     * trace("ioErrorHandler: " + event);
     * }
     * }
     * }
 * </codeblock>
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 * @internal	Update the places LoaderInfo can be obtained from (playerglobal.as) and double-check loader vs. loadee.
 */
var LoaderInfo = (function (_super) {
    __extends(LoaderInfo, _super);
    function LoaderInfo(target) {
        if (target === void 0) { target = null; }
        var _this = _super.call(this, target) || this;
        // for now all LoaderInfo-Events will be handled in Loader.ts
        // Events that are supposed to be working are registered as eventMappingExtern:
        _this.eventMappingExtern[Event.COMPLETE] = "LoaderInfo:Event.COMPLETE";
        _this.eventMappingExtern[ProgressEvent.PROGRESS] = "LoaderInfo:ProgressEvent.PROGRESS";
        // Events not supported yet are registered as eventMappingDummys:
        _this.eventMappingDummys[Event.UNLOAD] = "LoaderInfo:Event.UNLOAD";
        _this.eventMappingDummys[IOErrorEvent.IO_ERROR] = "LoaderInfo:IOErrorEvent.IO_ERROR";
        //this.eventMappingDummys[HTTPStatusEvent.IO_ERROR]="HTTPStatusEvent.IO_ERROR";
        _this.eventMappingDummys[Event.OPEN] = "LoaderInfo:Event.OPEN";
        _this.eventMappingDummys[Event.INIT] = "LoaderInfo:Event.INIT";
        return _this;
    }
    Object.defineProperty(LoaderInfo.prototype, "actionScriptVersion", {
        /**
         * The ActionScript version of the loaded SWF file.
         *
         *   The language version is specified by using the enumerations in the
         * ActionScriptVersion class, such as ActionScriptVersion.ACTIONSCRIPT2
         * and ActionScriptVersion.ACTIONSCRIPT3.
         *
         *   Note: This property always has a value of either ActionScriptVersion.ACTIONSCRIPT2 or
         * ActionScriptVersion.ACTIONSCRIPT3.  ActionScript 1.0 and 2.0 are
         * both reported as ActionScriptVersion.ACTIONSCRIPT2 (version 2.0).  This property
         * only distinguishes ActionScript 1.0 and 2.0 from ActionScript 3.0.
         * @throws	Error If the file is not downloaded sufficiently to retrieve the requested information.
         * @throws	Error If the file is not a SWF file.
         */
        get: function () {
            console.log("actionScriptVersion not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    LoaderInfo.prototype.getSymbolById = function (value) { };
    Object.defineProperty(LoaderInfo.prototype, "applicationDomain", {
        /**
         * When an external SWF file is loaded, all ActionScript 3.0 definitions contained in the loaded
         * class are stored in the applicationDomain property.
         *
         *   All code in a SWF file is defined to exist in an application domain. The current application
         * domain is where your main application runs. The system domain contains all application domains,
         * including the current domain and all classes used by Flash Player or Adobe AIR.All application domains, except the system domain, have an associated parent domain.
         * The parent domain of your main application's applicationDomain is the system domain.
         * Loaded classes are defined only when their parent doesn't already define them.
         * You cannot override a loaded class definition with a newer definition.For usage examples of application domains, see the "Client System Environment" chapter
         * in the ActionScript 3.0 Developer's Guide.
         * @internal	Need better description and example.
         * @throws	SecurityError This security sandbox of the caller is not allowed to access this ApplicationDomain.
         */
        get: function () {
            //console.log("applicationDomain not implemented yet in flash/LoaderInfo");
            return this._applicationDomain;
        },
        set: function (value) {
            //console.log("applicationDomain not implemented yet in flash/LoaderInfo");
            this._applicationDomain = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "bytes", {
        /**
         * The bytes associated with a LoaderInfo object.
         * @throws	SecurityError If the object accessing this API is prevented from
         *   accessing the loaded object due to security restrictions. This situation can occur,
         *   for instance, when a Loader object attempts to access the contentLoaderInfo.content
         *   property and it is not granted security permission to access the loaded content.
         *
         *     For more information related to security, see the Flash Player Developer Center Topic:
         *   Security.
         */
        get: function () {
            console.log("bytes not implemented yet in flash/LoaderInfo");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "bytesLoaded", {
        /**
         * The number of bytes that are loaded for the media. When this number equals
         * the value of bytesTotal, all of the bytes are loaded.
         */
        get: function () {
            console.log("bytesLoaded not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "bytesTotal", {
        /**
         * The number of compressed bytes in the entire media file.
         *
         *   Before the first progress event is dispatched by
         * this LoaderInfo object's corresponding Loader object, bytesTotal is 0.
         * After the first progress event from the Loader object, bytesTotal
         * reflects the actual number of bytes to be downloaded.
         */
        get: function () {
            console.log("bytesTotal not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "childAllowsParent", {
        /**
         * Expresses the trust relationship from content (child) to the Loader (parent).
         * If the child has allowed the parent access, true; otherwise,
         * false. This property is set to true if the child object
         * has called the allowDomain() method to grant permission to the parent domain
         * or if a URL policy is loaded at the child domain that grants permission
         * to the parent domain. If child and parent are in
         * the same domain, this property is set to true.
         *
         *   For more information related to security, see the Flash Player Developer Center Topic:
         * Security.
         * @throws	Error  Thrown if the file is not downloaded sufficiently
         *   to retrieve the requested information.
         */
        get: function () {
            console.log("childAllowsParent not implemented yet in flash/LoaderInfo");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "childSandboxBridge", {
        /**
         * A object that can be set by the loaded content's code to expose properties and methods that can be accessed
         * by code in the Loader object's sandbox. This sandbox bridge lets content from a non-application domain have
         * controlled access to scripts in the AIR application sandbox, and vice versa. The sandbox bridge serves as a gateway between
         * the sandboxes, providing explicit interaction between application and non-application security sandboxes.
         * @throws	SecurityError Only content in the loaded content's sandbox can set this property.
         */
        get: function () {
            console.log("childSandboxBridge not implemented yet in flash/LoaderInfo");
            return null;
        },
        set: function (door) {
            console.log("childSandboxBridge not implemented yet in flash/LoaderInfo");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "contentType", {
        /**
         * The MIME type of the loaded file. The value is null if not enough of the file has loaded
         * in order to determine the type. The following list gives the possible values:
         *
         *   "application/x-shockwave-flash"
         *   "image/jpeg"
         *   "image/gif"
         *   "image/png"
         */
        get: function () {
            console.log("contentType not implemented yet in flash/LoaderInfo");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "frameRate", {
        /**
         * The nominal frame rate, in frames per second, of the loaded SWF file. This
         * number is often an integer, but need not be.
         *
         *   This value may differ from the actual frame rate in use.
         * Flash Player or Adobe AIR only uses a single frame rate for all loaded SWF files at
         * any one time, and this frame rate is determined by the nominal
         * frame rate of the main SWF file. Also, the main frame rate may not be able to be achieved, depending on hardware, sound synchronization,
         * and other factors.
         * @throws	Error If the file is not downloaded sufficiently to retrieve the requested information.
         * @throws	Error If the file is not a SWF file.
         */
        get: function () {
            console.log("frameRate not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "height", {
        /**
         * The nominal height of the loaded file. This value might differ from the actual
         * height at which the content is displayed, since the loaded content or its parent
         * display objects might be scaled.
         * @throws	Error If the file is not downloaded sufficiently to retrieve the requested information.
         */
        get: function () {
            //console.log("height not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "isURLInaccessible", {
        /**
         * Indicates if the LoaderInfo.url property has been
         * truncated. When the isURLInaccessible value is true the
         * LoaderInfo.url value is only the domain of the final URL from which the content loaded.
         * For example, the property is truncated if the content is loaded from http://www.adobe.com/assets/hello.swf,
         * and the LoaderInfo.url property has the value http://www.adobe.com. The isURLInaccessible
         * value is true only when all of the following are also true:
         *
         *   An HTTP redirect occurred while loading the content.The SWF file calling Loader.load() is from a different domain than
         * the content's final URL.The SWF file calling Loader.load() does not have permission to access
         * the content. Permission is granted to access the content the same way permission is granted for
         * BitmapData.draw():
         * call Security.allowDomain() to access a SWF file
         * (or for non-SWF file content, establish a policy file and use the LoaderContext.checkPolicyFile
         * property).Note: The isURLInaccessible property was added for Flash Player 10.1 and AIR 2.0.
         * However, this property is made available to SWF files of all versions when the
         * Flash runtime supports it. So, using some authoring tools in "strict mode" causes a compilation error. To work around the error
         * use the indirect syntax myLoaderInfo["isURLInaccessible"], or disable strict mode. If you are using Flash Professional CS5
         * or Flex SDK 4.1, you can use and compile this API for runtimes released before Flash Player 10.1 and AIR 2.For application content in AIR, the value of this property is always false.
         */
        get: function () {
            console.log("isURLInaccessible not implemented yet in flash/LoaderInfo");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "loader", {
        /**
         * The Loader object associated with this LoaderInfo object. If this LoaderInfo object
         * is the loaderInfo property of the instance of the main class of the SWF file, no
         * Loader object is associated.
         * @throws	SecurityError If the object accessing this API is prevented from
         *   accessing the Loader object because of security restrictions. This can occur,
         *   for instance, when a loaded SWF file attempts to access its loaderInfo.loader
         *   property and it is not granted security permission to access the loading SWF file.
         *
         *     For more information related to security, see the Flash Player Developer Center Topic:
         *   Security.
         */
        get: function () {
            console.log("loader not implemented yet in flash/LoaderInfo");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "loaderURL", {
        /**
         * The URL of the SWF file that initiated the loading of the media
         * described by this LoaderInfo object.  For the instance of the main class of the SWF file, this
         * URL is the same as the SWF file's own URL.
         */
        get: function () {
            console.log("loaderURL not implemented yet in flash/LoaderInfo");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "parameters", {
        /**
         * An object that contains name-value pairs that represent the parameters provided
         * to the loaded SWF file.
         *
         *   You can use a for-in loop to extract all the names and values
         * from the parameters object.The two sources of parameters are: the query string in the
         * URL of the main SWF file, and the value of the FlashVars HTML parameter (this affects
         * only the main SWF file).The parameters property replaces the ActionScript 1.0 and 2.0 technique of
         * providing SWF file parameters as properties of the main timeline.The value of the parameters property is null for Loader objects
         * that contain SWF files that use ActionScript 1.0 or 2.0. It is only
         * non-null for Loader objects that contain SWF files that use ActionScript 3.0.
         */
        get: function () {
            console.log("parameters not implemented yet in flash/LoaderInfo");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "parentAllowsChild", {
        /**
         * Expresses the trust relationship from Loader (parent) to the content (child).
         * If the parent has allowed the child access, true; otherwise,
         * false. This property is set to true if the parent object
         * called the allowDomain() method to grant permission to the child domain
         * or if a URL policy file is loaded at the parent domain granting permission
         * to the child domain. If child and parent are in
         * the same domain, this property is set to true.
         *
         *   For more information related to security, see the Flash Player Developer Center Topic:
         * Security.
         * @throws	Error  Thrown if the file is not downloaded sufficiently
         *   to retrieve the requested information.
         */
        get: function () {
            console.log("parentAllowsChild not implemented yet in flash/LoaderInfo");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "parentSandboxBridge", {
        /**
         * A object that can be set by code in the Loader object's sandbox to expose properties and methods that can be accessed
         * by the loaded content's code. This sandbox bridge lets content from a non-application domain have controlled
         * access to scripts in the AIR application sandbox, and vice versa. The sandbox bridge serves as a gateway between
         * the sandboxes, providing explicit interaction between application and non-application security sandboxes.
         * @throws	SecurityError Only content in the Loader object's sandbox can set this property.
         */
        get: function () {
            console.log("parentSandboxBridge not implemented yet in flash/LoaderInfo");
            return null;
        },
        set: function (door) {
            console.log("parentSandboxBridge not implemented yet in flash/LoaderInfo");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "sameDomain", {
        /**
         * Expresses the domain relationship between the loader and the content: true if they have
         * the same origin domain; false otherwise.
         * @throws	Error  Thrown if the file is not downloaded sufficiently
         *   to retrieve the requested information.
         */
        get: function () {
            console.log("sameDomain not implemented yet in flash/LoaderInfo");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "sharedEvents", {
        /**
         * An EventDispatcher instance that can be used to exchange events across security boundaries.
         * Even when the Loader object and the loaded content originate from security domains that do not trust
         * one another, both can access sharedEvents and send and receive events via this object.
         */
        get: function () {
            console.log("sharedEvents not implemented yet in flash/LoaderInfo");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "swfVersion", {
        /**
         * The file format version of the loaded SWF file.
         *
         *   The file format is specified using the enumerations in the
         * SWFVersion class, such as SWFVersion.FLASH7 and SWFVersion.FLASH9.
         * @throws	Error If the file is not downloaded sufficiently to retrieve the requested information.
         * @throws	Error If the file is not a SWF file.
         */
        get: function () {
            console.log("swfVersion not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "uncaughtErrorEvents", {
        /**
         * An object that dispatches an uncaughtError event when an unhandled error
         * occurs in code in this LoaderInfo object's SWF file. An uncaught error happens when
         * an error is thrown outside of any try..catch blocks or when an ErrorEvent
         * object is dispatched with no registered listeners.
         *
         *   This property is created when the SWF associated with this LoaderInfo has finished
         * loading. Until then the uncaughtErrorEvents property is null.
         * In an ActionScript-only project, you can access this property during or after the execution
         * of the constructor function of the main class of the SWF file. For a Flex project,
         * the uncaughtErrorEvents property is available after the
         * applicationComplete event is dispatched.
         */
        get: function () {
            //todo: any is UncaughtErrorEvents
            console.log("uncaughtErrorEvents not implemented yet in flash/LoaderInfo");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "url", {
        /**
         * The URL of the media being loaded.
         *
         *   Before the first progress event is dispatched by this LoaderInfo
         * object's corresponding Loader object, the value of the url property
         * might reflect only the initial URL specified in the call to the load()
         * method  of the Loader object.  After the first progress event, the
         * url property reflects the media's final URL, after any redirects and relative
         * URLs are resolved.In some cases, the value of the url property is truncated; see the
         * isURLInaccessible property for details.
         */
        get: function () {
            console.log("url not implemented yet in flash/LoaderInfo");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LoaderInfo.prototype, "width", {
        /**
         * The nominal width of the loaded content. This value might differ from the actual
         * width at which the content is displayed, since the loaded content or its parent
         * display objects might be scaled.
         * @throws	Error If the file is not downloaded sufficiently to retrieve the requested information.
         */
        get: function () {
            //console.log("width not implemented yet in flash/LoaderInfo");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    /*
        public dispatchEvent (event:Event) : boolean{
            console.log("dispatchEvent not implemented yet in flash/LoaderInfo");
            return false;
            
        }
        */
    /**
     * Returns the LoaderInfo object associated with a SWF file defined as an object.
     * @param	object	The object for which you want to get an associated LoaderInfo object.
     * @return	The associated LoaderInfo object. Returns null when called
     *   in non-debugger builds (or when debugging is not enabled) or if the referenced object
     *   does not have an associated LoaderInfo object (such as some objects used by the AIR runtime).

     * @throws	SecurityError The caller is not running in the local trusted sandbox.
     */
    LoaderInfo.getLoaderInfoByDefinition = function (object) {
        console.log("getLoaderInfoByDefinition not implemented yet in flash/LoaderInfo");
        return null;
    };
    return LoaderInfo;
}(EventDispatcher$1));

var Sprite$1 = (function (_super) {
    __extends(Sprite$$1, _super);
    /**
     * The Sprite class is a basic display list building block: a display list node that can display
     * graphics and can also contain children.
     *
     *   <p class="- topic/p ">A Sprite object is similar to a movie clip, but does not have a timeline. Sprite is an
     * appropriate base class for objects that do not require timelines. For example, Sprite would be a
     * logical base class for user numbererface (UI) components that typically do not use the timeline.</p><p class="- topic/p ">The Sprite class is new in ActionScript 3.0. It provides an alternative to the functionality of
     * the MovieClip class, which retains all the functionality of previous ActionScript releases to
     * provide backward compatibility.</p>
     *
     * Creates a new Sprite instance. After you create the Sprite instance, call the
     * DisplayObjectContainer.addChild() or DisplayObjectContainer.addChildAt()
     * method to add the Sprite to a parent DisplayObjectContainer.
     */
    function Sprite$$1(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        return _super.call(this, adaptee || _awayjs_scene.Sprite.getNewSprite()) || this;
    }
    Sprite$$1.getNewSprite = function (adaptee) {
        if (Sprite$$1._sprites.length) {
            var sprite = Sprite$$1._sprites.pop();
            sprite.adaptee = adaptee;
            return sprite;
        }
        return new Sprite$$1(adaptee);
    };
    //---------------------------stuff added to make it work:
    Sprite$$1.prototype.clone = function () {
        var clone = Sprite$$1.getNewSprite(_awayjs_scene.Sprite.getNewSprite(null, this.adaptee.material));
        this.adaptee.copyTo(clone.adaptee);
        return clone;
    };
    /**
     * @inheritDoc
     */
    Sprite$$1.prototype.dispose = function () {
        this.disposeValues();
        Sprite$$1._sprites.push(this);
    };
    Object.defineProperty(Sprite$$1.prototype, "buttonMode", {
        //---------------------------original as3 properties / methods:
        /**
         * Specifies the button mode of this sprite. If true, this
         * sprite behaves as a button, which means that it triggers the display
         * of the hand cursor when the ponumberer passes over the sprite and can
         * receive a click event if the enter or space keys are pressed
         * when the sprite has focus. You can suppress the display of the hand cursor
         * by setting the useHandCursor property to false,
         * in which case the ponumberer is displayed.
         *
         *   Although it is better to use the SimpleButton class to create buttons,
         * you can use the buttonMode property to give a sprite
         * some button-like functionality. To include a sprite in the tab order,
         * set the tabEnabled property (inherited from the
         * numbereractiveObject class and false by default) to
         * true. Additionally, consider whether you want
         * the children of your sprite to be user input enabled. Most buttons
         * do not enable user input numbereractivity for their child objects because
         * it confuses the event flow. To disable user input numbereractivity for all child
         * objects, you must set the mouseChildren property (inherited
         * from the DisplayObjectContainer class) to false.If you use the buttonMode property with the MovieClip class (which is a
         * subclass of the Sprite class), your button might have some added
         * functionality. If you include frames labeled _up, _over, and _down,
         * Flash Player provides automatic state changes (functionality
         * similar to that provided in previous versions of ActionScript for movie
         * clips used as buttons). These automatic state changes are
         * not available for sprites, which have no timeline, and thus no frames
         * to label.
         */
        get: function () {
            //todo
            console.log("buttonMode not implemented yet in flash/Sprite");
            return false;
        },
        set: function (value) {
            //todo
            console.log("buttonMode not implemented yet in flash/Sprite");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sprite$$1.prototype, "dropTarget", {
        /**
         * Specifies the display object over which the sprite is being dragged, or on
         * which the sprite was dropped.
         */
        get: function () {
            //todo
            console.log("dropTarget not implemented yet in flash/Sprite");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sprite$$1.prototype, "graphics", {
        /**
         * Specifies the Graphics object that belongs to this sprite where vector
         * drawing commands can occur.
         */
        get: function () {
            return this._adaptee.graphics;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sprite$$1.prototype, "hitArea", {
        /**
         * Designates another sprite to serve as the hit area for a sprite. If the hitArea
         * property does not exist or the value is null or undefined, the
         * sprite itself is used as the hit area. The value of the hitArea property can
         * be a reference to a Sprite object.
         *
         *   You can change the hitArea property at any time; the modified sprite immediately
         * uses the new hit area behavior. The sprite designated as the hit area does not need to be
         * visible; its graphical shape, although not visible, is still detected as the hit area.Note: You must set to false the mouseEnabled
         * property of the sprite designated as the hit area. Otherwise, your sprite button might
         * not work because the sprite designated as the hit area receives the user input events instead
         * of your sprite button.
         */
        get: function () {
            //todo
            console.log("hitArea not implemented yet in flash/Sprite");
            return null;
        },
        set: function (value) {
            //todo
            console.log("hitArea not implemented yet in flash/Sprite");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sprite$$1.prototype, "soundTransform", {
        /**
         * Controls sound within this sprite.
         *
         *   Note: This property does not affect HTML content in an HTMLControl object (in Adobe AIR).
         */
        get: function () {
            // todo: any = SoundTransform
            console.log("soundTransform not implemented yet in flash/Sprite");
            return null;
        },
        set: function (sndTransform) {
            //todo
            console.log("soundTransform not implemented yet in flash/Sprite");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sprite$$1.prototype, "useHandCursor", {
        /**
         * A boolean value that indicates whether the ponumbering hand (hand cursor) appears when the ponumberer rolls
         * over a sprite in which the buttonMode property is set to true.
         * The default value of the useHandCursor property is true.
         * If useHandCursor is set to true, the ponumbering hand used for buttons
         * appears when the ponumberer rolls over a button sprite. If useHandCursor is
         * false, the arrow ponumberer is used instead.
         *
         *   You can change the useHandCursor property at any time; the modified sprite
         * immediately takes on the new cursor appearance. Note: In Flex or Flash Builder, if your sprite has child sprites, you might want to
         * set the mouseChildren property to false. For example, if you want a hand
         * cursor to appear over a Flex <mx:Label> control, set the useHandCursor and
         * buttonMode properties to true, and the mouseChildren property
         * to false.
         */
        get: function () {
            //todo
            console.log("useHandCursor not implemented yet in flash/Sprite");
            return false;
        },
        set: function (value) {
            //todo
            console.log("useHandCursor not implemented yet in flash/Sprite");
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Lets the user drag the specified sprite. The sprite remains draggable until explicitly
     * stopped through a call to the Sprite.stopDrag() method, or until
     * another sprite is made draggable. Only one sprite is draggable at a time.
     * Three-dimensional display objects follow the ponumberer and
     * Sprite.startDrag() moves the object within
     * the three-dimensional plane defined by the display object. Or, if the display object is a two-dimensional object
     * and the child of a three-dimensional object, the two-dimensional object
     * moves within the three dimensional plane defined by the three-dimensional parent object.
     * @param	lockCenter	Specifies whether the draggable sprite is locked to the center of
     *   the ponumberer position (true), or locked to the ponumber where the user first clicked the
     *   sprite (false).
     * @param	bounds	Value relative to the coordinates of the Sprite's parent that specify a constranumber
     *   rectangle for the Sprite.
     */
    Sprite$$1.prototype.startDrag = function (lockCenter, bounds) {
        if (lockCenter === void 0) { lockCenter = false; }
        if (bounds === void 0) { bounds = null; }
        //todo
        console.log("startDrag not implemented yet in flash/Sprite");
    };
    /**
     * Lets the user drag the specified sprite on a touch-enabled device. The sprite remains draggable until explicitly
     * stopped through a call to the Sprite.stopTouchDrag() method, or until
     * another sprite is made draggable. Only one sprite is draggable at a time.
     * Three-dimensional display objects follow the ponumberer and
     * Sprite.startTouchDrag() moves the object within
     * the three-dimensional plane defined by the display object. Or, if the display object is a two-dimensional object
     * and the child of a three-dimensional object, the two-dimensional object
     * moves within the three dimensional plane defined by the three-dimensional parent object.
     * @param	touchPonumberID	An numbereger to assign to the touch ponumber.
     * @param	lockCenter	Specifies whether the draggable sprite is locked to the center of
     *   the ponumberer position (true), or locked to the ponumber where the user first clicked the
     *   sprite (false).
     * @param	bounds	Value relative to the coordinates of the Sprite's parent that specify a constranumber
     *   rectangle for the Sprite.
     */
    Sprite$$1.prototype.startTouchDrag = function (touchPonumberID, lockCenter, bounds) {
        if (lockCenter === void 0) { lockCenter = false; }
        if (bounds === void 0) { bounds = null; }
        //todo
        console.log("startTouchDrag not implemented yet in flash/Sprite");
    };
    /**
     * Ends the startDrag() method. A sprite that was made draggable with the
     * startDrag() method remains draggable until a
     * stopDrag() method is added, or until another
     * sprite becomes draggable. Only one sprite is draggable at a time.
     */
    Sprite$$1.prototype.stopDrag = function () {
        //todo
        console.log("startTouchDrag not implemented yet in flash/Sprite");
    };
    /**
     * Ends the startTouchDrag() method, for use with touch-enabled devices. A sprite that was made draggable with the
     * startTouchDrag() method remains draggable until a
     * stopTouchDrag() method is added, or until another
     * sprite becomes draggable. Only one sprite is draggable at a time.
     * @param	touchPonumberID	The numbereger assigned to the touch ponumber in the startTouchDrag method.
     */
    Sprite$$1.prototype.stopTouchDrag = function (touchPonumberID) {
        //todo
        console.log("startTouchDrag not implemented yet in flash/Sprite");
    };
    return Sprite$$1;
}(DisplayObjectContainer$1));
Sprite$1._sprites = new Array();

var includeString = ''; //TODO
/**
 * The MovieClip class inherits from the following classes: Sprite, DisplayObjectContainer,
 * InteractiveObject, DisplayObject, and EventDispatcher.
 *
 *   <p class="- topic/p ">Unlike the Sprite object, a MovieClip object has a timeline.</p><p class="- topic/p ">&gt;In Flash Professional, the methods for the MovieClip class provide the same functionality
 * as actions that target movie clips. Some additional methods do not have equivalent
 * actions in the Actions toolbox in the Actions panel in the Flash authoring tool. </p><p class="- topic/p ">Children instances placed on the Stage in Flash Professional cannot be accessed by code from within the
 * constructor of a parent instance since they have not been created at that ponumber in code execution.
 * Before accessing the child, the parent must instead either create the child instance
 * by code or delay access to a callback that listens for the child to dispatch
 * its <codeph class="+ topic/ph pr-d/codeph ">Event.ADDED_TO_STAGE</codeph> event.</p><p class="- topic/p ">If you modify any of the following properties of a MovieClip object that contains a motion tween,
 * the playhead is stopped in that MovieClip object: <codeph class="+ topic/ph pr-d/codeph ">alpha</codeph>, <codeph class="+ topic/ph pr-d/codeph ">blendMode</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">filters</codeph>, <codeph class="+ topic/ph pr-d/codeph ">height</codeph>, <codeph class="+ topic/ph pr-d/codeph ">opaqueBackground</codeph>, <codeph class="+ topic/ph pr-d/codeph ">rotation</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">scaleX</codeph>, <codeph class="+ topic/ph pr-d/codeph ">scaleY</codeph>, <codeph class="+ topic/ph pr-d/codeph ">scale9Grid</codeph>, <codeph class="+ topic/ph pr-d/codeph ">scrollRect</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">transform</codeph>, <codeph class="+ topic/ph pr-d/codeph ">visible</codeph>, <codeph class="+ topic/ph pr-d/codeph ">width</codeph>, <codeph class="+ topic/ph pr-d/codeph ">x</codeph>,
 * or <codeph class="+ topic/ph pr-d/codeph ">y</codeph>. However, it does not stop the playhead in any child MovieClip objects of that
 * MovieClip object.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b>Flash Lite 4 supports the MovieClip.opaqueBackground property only if
 * FEATURE_BITMAPCACHE is defined. The default configuration of Flash Lite 4 does not define
 * FEATURE_BITMAPCACHE. To enable the MovieClip.opaqueBackground property for a suitable device,
 * define FEATURE_BITMAPCACHE in your project.</p>*/
var MovieClip$1 = (function (_super) {
    __extends(MovieClip$$1, _super);
    /**
     * Creates a new MovieClip instance. After creating the MovieClip, call the
     * addChild() or addChildAt() method of a
     * display object container that is onstage.
     */
    function MovieClip$$1(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        return _super.call(this, adaptee || _awayjs_scene.MovieClip.getNewMovieClip()) || this;
    }
    MovieClip$$1.getNewMovieClip = function (adaptee) {
        if (MovieClip$$1._movieClips.length) {
            var movieClip = MovieClip$$1._movieClips.pop();
            movieClip.adaptee = adaptee;
            return movieClip;
        }
        return new MovieClip$$1(adaptee);
    };
    //forAVM1:
    MovieClip$$1.prototype._getAbsFrameNumber = function (param1, param2) {
        return 0;
    };
    MovieClip$$1.prototype.callFrame = function (param1) {
    };
    MovieClip$$1.prototype._callFrame = function (param1) {
    };
    MovieClip$$1.prototype.addScript = function (param1) {
        return param1;
    };
    MovieClip$$1.prototype.executeScript = function (scriptsFN) {
        for (var k = 0; k < scriptsFN.length; k++) {
            scriptsFN[k].apply(this);
        }
        // used in AVM1. we just need a stub here to implement IMovieClipAdapter
    };
    // --------------------- stuff needed because of implementing the existing IMovieClipAdapter
    MovieClip$$1.prototype.evalScript = function (str) {
        var tag = document.createElement('script');
        tag.text = 'var __framescript__ = function() {\n' + includeString + str + '\n}';
        //add and remove script tag to dom to trigger compilation
        var sibling = document.scripts[0];
        sibling.parentNode.insertBefore(tag, sibling).parentNode.removeChild(tag);
        var script = __framescript__;
        window['__framescript__'] = null;
        return script;
    };
    MovieClip$$1.prototype.registerScriptObject = function (child) {
        if (child.name)
            this[child.name] = child._adapter ? child.adapter : child;
    };
    MovieClip$$1.prototype.unregisterScriptObject = function (child) {
        delete this[child.name];
        if (child.isAsset(_awayjs_scene.MovieClip))
            child.removeButtonListeners();
    };
    MovieClip$$1.prototype.freeFromScript = function () {
        //this.stopAllSounds();
        _super.prototype.freeFromScript.call(this);
    };
    MovieClip$$1.prototype.clone = function () {
        var clone = MovieClip$$1.getNewMovieClip(_awayjs_scene.MovieClip.getNewMovieClip(this.adaptee.timeline));
        this.adaptee.copyTo(clone.adaptee);
        return clone;
    };
    /**
     * @inheritDoc
     */
    MovieClip$$1.prototype.dispose = function () {
        this.disposeValues();
        MovieClip$$1._movieClips.push(this);
    };
    Object.defineProperty(MovieClip$$1.prototype, "currentFrame", {
        //---------------------------original as3 properties / methods:
        /**
         * Specifies the number of the frame in which the playhead is located in the timeline of
         * the MovieClip instance. If the movie clip has multiple scenes, this value is the
         * frame number in the current scene.
         */
        get: function () {
            return this._adaptee.currentFrameIndex + 1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "currentFrameLabel", {
        /**
         * The label at the current frame in the timeline of the MovieClip instance.
         * If the current frame has no label, currentLabel is null.
         */
        get: function () {
            //todo
            console.log("currentFrameLabel not implemented yet in flash/MovieClip");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "currentLabel", {
        /**
         * The current label in which the playhead is located in the timeline of the MovieClip instance.
         * If the current frame has no label, currentLabel is set to the name of the previous frame
         * that includes a label. If the current frame and previous frames do not include a label,
         * currentLabel returns null.
         */
        get: function () {
            //todo
            console.log("currentLabel not implemented yet in flash/MovieClip");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "currentLabels", {
        /**
         * Returns an array of FrameLabel objects from the current scene. If the MovieClip instance does
         * not use scenes, the array includes all frame labels from the entire MovieClip instance.
         */
        get: function () {
            //todo
            console.log("currentFrameLabel not implemented yet in flash/MovieClip");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "currentScene", {
        /**
         * The current scene in which the playhead is located in the timeline of the MovieClip instance.
         */
        get: function () {
            //todo
            console.log("currentScene not implemented yet in flash/MovieClip");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "enabled", {
        /**
         * A boolean value that indicates whether a movie clip is enabled. The default value of enabled
         * is true. If enabled is set to false, the movie clip's
         * Over, Down, and Up frames are disabled. The movie clip
         * continues to receive events (for example, mouseDown,
         * mouseUp, keyDown, and keyUp).
         *
         *   The enabled property governs only the button-like properties of a movie clip. You
         * can change the enabled property at any time; the modified movie clip is immediately
         * enabled or disabled. If enabled is set to false, the object is not
         * included in automatic tab ordering.
         */
        get: function () {
            //todo
            //console.log("enabled not implemented yet in flash/MovieClip");
            return false;
        },
        set: function (value) {
            //todo
            //console.log("enabled not implemented yet in flash/MovieClip");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "framesLoaded", {
        /**
         * The number of frames that are loaded from a streaming SWF file. You can use the framesLoaded
         * property to determine whether the contents of a specific frame and all the frames before it
         * loaded and are available locally in the browser. You can also use it to monitor the downloading
         * of large SWF files. For example, you might want to display a message to users indicating that
         * the SWF file is loading until a specified frame in the SWF file finishes loading.
         *
         *   If the movie clip contains multiple scenes, the framesLoaded property returns the number
         * of frames loaded for all scenes in the movie clip.
         */
        get: function () {
            //todo
            console.log("framesLoaded not implemented yet in flash/MovieClip");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "isPlaying", {
        get: function () {
            //todo
            console.log("isPlaying not implemented yet in flash/MovieClip");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "scenes", {
        /**
         * An array of Scene objects, each listing the name, the number of frames,
         * and the frame labels for a scene in the MovieClip instance.
         */
        get: function () {
            //todo
            console.log("scenes not implemented yet in flash/MovieClip");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "totalFrames", {
        /**
         * The total number of frames in the MovieClip instance.
         *
         *   If the movie clip contains multiple frames, the totalFrames property returns
         * the total number of frames in all scenes in the movie clip.
         */
        get: function () {
            return this._adaptee.numFrames;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(MovieClip$$1.prototype, "trackAsMenu", {
        /**
         * Indicates whether other display objects that are SimpleButton or MovieClip objects can receive
         * mouse release events or other user input release events. The trackAsMenu property lets you create menus. You
         * can set the trackAsMenu property on any SimpleButton or MovieClip object.
         * The default value of the trackAsMenu property is false.
         *
         *   You can change the trackAsMenu property at any time; the modified movie
         * clip immediately uses the new behavior.
         */
        get: function () {
            //todo
            console.log("trackAsMenu not implemented yet in flash/MovieClip");
            return false;
        },
        set: function (value) {
            //todo
            console.log("trackAsMenu not implemented yet in flash/MovieClip");
        },
        enumerable: true,
        configurable: true
    });
    MovieClip$$1.prototype.addFrameScript = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        //todo
        console.log("addFrameScript not implemented yet in flash/MovieClip");
    };
    /**
     * Starts playing the SWF file at the specified frame.  This happens after all
     * remaining actions in the frame have finished executing.  To specify a scene
     * as well as a frame, specify a value for the scene parameter.
     * @param	frame	A number representing the frame number, or a string representing the label of the
     *   frame, to which the playhead is sent. If you specify a number, it is relative to the
     *   scene you specify. If you do not specify a scene, the current scene determines the global frame number to play. If you do specify a scene, the playhead
     *   jumps to the frame number in the specified scene.
     * @param	scene	The name of the scene to play. This parameter is optional.
     */
    MovieClip$$1.prototype.gotoAndPlay = function (frame, scene) {
        if (scene === void 0) { scene = null; }
        if (frame == null)
            return;
        if (typeof frame === "string") {
            if (this.adaptee.timeline._labels[frame.toLowerCase()] == null) {
                frame = parseInt(frame);
                if (!isNaN(frame)) {
                    this.adaptee.currentFrameIndex = frame - 1;
                    this.adaptee.play();
                }
                return;
            }
        }
        if (typeof frame === "number" && frame <= 0)
            return;
        this.play();
        this._gotoFrame(frame);
    };
    /**
     * Brings the playhead to the specified frame of the movie clip and stops it there.  This happens after all
     * remaining actions in the frame have finished executing.  If you want to specify a scene in addition to a frame,
     * specify a scene parameter.
     * @param	frame	A number representing the frame number, or a string representing the label of the
     *   frame, to which the playhead is sent. If you specify a number, it is relative to the
     *   scene you specify. If you do not specify a scene, the current scene determines the global frame number at which to go to and stop. If you do specify a scene,
     *   the playhead goes to the frame number in the specified scene and stops.
     * @param	scene	The name of the scene. This parameter is optional.
     * @throws	ArgumentError If the scene or frame specified are
     *   not found in this movie clip.
     */
    MovieClip$$1.prototype.gotoAndStop = function (frame, scene) {
        if (scene === void 0) { scene = null; }
        if (frame == null)
            return;
        if (typeof frame === "string") {
            if (this.adaptee.timeline._labels[frame.toLowerCase()] == null) {
                frame = parseInt(frame);
                if (!isNaN(frame)) {
                    this.adaptee.currentFrameIndex = frame - 1;
                    this.adaptee.stop();
                }
                return;
            }
        }
        if (typeof frame === "number" && frame <= 0)
            return;
        this.stop();
        this._gotoFrame(frame);
    };
    MovieClip$$1.prototype._gotoFrame = function (frame) {
        if (typeof frame === "string") {
            this._adaptee.jumpToLabel(frame);
            return;
        }
        if (typeof frame === "number" && frame <= 0)
            return;
        this._adaptee.currentFrameIndex = frame - 1;
    };
    /**
     * Sends the playhead to the next frame and stops it.  This happens after all
     * remaining actions in the frame have finished executing.
     */
    MovieClip$$1.prototype.nextFrame = function () {
        //todo
        console.log("nextFrame not implemented yet in flash/MovieClip");
    };
    /**
     * Moves the playhead to the next scene of the MovieClip instance.  This happens after all
     * remaining actions in the frame have finished executing.
     */
    MovieClip$$1.prototype.nextScene = function () {
        //todo
        console.log("nextScene not implemented yet in flash/MovieClip");
    };
    /**
     * Moves the playhead in the timeline of the movie clip.
     */
    MovieClip$$1.prototype.play = function () {
        return this._adaptee.play();
    };
    /**
     * Sends the playhead to the previous frame and stops it.  This happens after all
     * remaining actions in the frame have finished executing.
     */
    MovieClip$$1.prototype.prevFrame = function () {
        if (this._adaptee.currentFrameIndex > 0) {
            this._adaptee.currentFrameIndex = this._adaptee.currentFrameIndex - 1;
        }
    };
    /**
     * Moves the playhead to the previous scene of the MovieClip instance.  This happens after all
     * remaining actions in the frame have finished executing.
     */
    MovieClip$$1.prototype.prevScene = function () {
        //todo
        console.log("prevScene not implemented yet in flash/MovieClip");
    };
    /**
     * Stops the playhead in the movie clip.
     */
    MovieClip$$1.prototype.stop = function () {
        return this._adaptee.stop();
    };
    return MovieClip$$1;
}(Sprite$1));
MovieClip$1._movieClips = new Array();

/**
 * Flash Player dispatches the textInteractionModeChange event when a user
 * changes the interaction mode of a text field.
 [Event(name="textInteractionModeChange", type="flash.events.Event")]

 * Flash Player dispatches the textInput event when a user enters one or more
 * characters of text.
 * @eventType	flash.events.TextEvent.TEXT_INPUT
 [Event(name="textInput", type="flash.events.TextEvent")]

 * Dispatched by a TextField object after the user scrolls.
 * @eventType	flash.events.Event.SCROLL
 [Event(name="scroll", type="flash.events.Event")]

 * Dispatched when a user clicks a hyperlink in an
 * HTML-enabled text field, where the URL begins with "event:".
 * @eventType	flash.events.TextEvent.LINK
 *
 [Event(name="link", type="flash.events.TextEvent")]

 * Dispatched after a control value is modified, unlike
 * the textInput event, which is dispatched before the value is modified.
 * @eventType	flash.events.Event.CHANGE
 [Event(name="change", type="flash.events.Event")]

 * The TextField class is used to create display objects for text display and input.
 * <ph outputclass="flexonly" class="- topic/ph ">You can use the TextField class to perform low-level text rendering.
 * However, in Flex, you typically use the Label, Text, TextArea, and TextInput controls to process text.</ph><ph outputclass="flashonly" class="- topic/ph ">You can give a text field an instance name in the Property inspector and
 * use the methods and properties of the TextField class to manipulate it with ActionScript.
 * TextField instance names are displayed in the Movie Explorer and in the Insert Target Path dialog box
 * in the Actions panel.</ph><p class="- topic/p ">To create a text field dynamically, use the <codeph class="+ topic/ph pr-d/codeph ">TextField()</codeph> constructor.</p><p class="- topic/p ">The methods of the TextField class let you set, select, and manipulate text in a dynamic or input
 * text field that you create during authoring or at runtime. </p><p class="- topic/p ">ActionScript provides several ways to
 * format your text at runtime. The TextFormat class lets you set character and paragraph formatting
 * for TextField objects. You can apply Cascading Style Sheets (CSS) styles
 * to text fields by using the <codeph class="+ topic/ph pr-d/codeph ">TextField.styleSheet</codeph> property and the StyleSheet class. You can use CSS to
 * style built-in HTML tags, define new formatting tags, or apply styles.
 * You can assign HTML formatted text, which optionally uses CSS styles, directly to a text
 * field. HTML text that you assign to a text field can contain embedded
 * media (movie clips, SWF files, GIF files, PNG files, and JPEG files). The text wraps around the
 * embedded media in the same way that a web browser wraps text around media embedded in an HTML document. </p><p class="- topic/p ">Flash Player supports a subset of HTML tags that you can use to format text. See the list of supported
 * HTML tags in the description of the <codeph class="+ topic/ph pr-d/codeph ">htmlText</codeph> property.</p>
 */
var TextField$1 = (function (_super) {
    __extends(TextField$$1, _super);
    /**
     * Creates a new TextField instance. After you create the TextField instance, call the
     * addChild() or addChildAt() method of the parent
     * DisplayObjectContainer object to add the TextField instance to the display list.
     * The default size for a text field is 100 x 100 pixels.
     */
    function TextField$$1(adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        var _this = _super.call(this, adaptee || _awayjs_scene.TextField.getNewTextField()) || this;
        _this.adaptee.autoSize = _awayjs_scene.TextFieldAutoSize.NONE;
        _this.adaptee.textFormat.align = _awayjs_scene.TextFormatAlign.CENTER;
        //(<AwayTextField> this._adaptee).width=100;//80pro!
        // register all events for Textfield as dummys right now
        _this.eventMappingDummys[TextEvent.TEXT_INPUT] = "TextField:TextEvent.TEXT_INPUT";
        _this.eventMappingDummys[TextEvent.LINK] = "TextField:TextEvent.LINK";
        _this.eventMappingDummys[Event.SCROLL] = "TextField:Event.SCROLL";
        _this.eventMappingDummys[Event.CHANGE] = "TextField:Event.CHANGE";
        _this.eventMappingDummys[Event.TEXT_INTERACTION_MODE_CHANGE] = "TextField:Event.TEXT_INTERACTION_MODE_CHANGE";
        return _this;
    }
    TextField$$1.getNewTextField = function (adaptee) {
        if (adaptee === void 0) { adaptee = null; }
        if (TextField$$1._textFields.length) {
            var textField = TextField$$1._textFields.pop();
            textField.adaptee = adaptee || _awayjs_scene.TextField.getNewTextField();
            return textField;
        }
        return new TextField$$1(adaptee);
    };
    TextField$$1.prototype.dispatchKeyEvent = function (charCode, isShift, isCTRL, isAlt) {
    };
    TextField$$1.prototype.selectTextField = function () {
    };
    TextField$$1.prototype.clone = function () {
        var clone = TextField$$1.getNewTextField(_awayjs_scene.TextField.getNewTextField());
        this.adaptee.copyTo(clone.adaptee);
        return clone;
    };
    /**
     * @inheritDoc
     */
    TextField$$1.prototype.dispose = function () {
        this.disposeValues();
        TextField$$1._textFields.push(this);
    };
    Object.defineProperty(TextField$$1.prototype, "alwaysShowSelection", {
        /**
         * When set to true and the text field is not in focus, Flash Player highlights the
         * selection in the text field in gray. When set to false and the text field is not in
         * focus, Flash Player does not highlight the selection in the text field.
         */
        get: function () {
            return this._adaptee.alwaysShowSelection;
        },
        set: function (value) {
            this._adaptee.alwaysShowSelection = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "antiAliasType", {
        /**
         * The type of anti-aliasing used for this text field. Use flash.text.AntiAliasType
         * constants for this property. You can control this setting only if the font is
         * embedded (with the embedFonts property set to true).
         * The default setting is flash.text.AntiAliasType.NORMAL.
         *
         *   To set values for this property, use the following string values:String valueDescriptionflash.text.AntiAliasType.NORMALApplies the regular text anti-aliasing. This value matches the type of anti-aliasing that
         * Flash Player 7 and earlier versions used.flash.text.AntiAliasType.ADVANCEDApplies advanced anti-aliasing, which makes text more legible. (This feature became
         * available in Flash Player 8.) Advanced anti-aliasing allows for high-quality rendering
         * of font faces at small sizes. It is best used with applications
         * with a lot of small text. Advanced anti-aliasing is not recommended for
         * fonts that are larger than 48 points.
         */
        get: function () {
            return ""; //(<AwayTextField> this._adaptee).antiAliasType;
        },
        set: function (antiAliasType) {
            //(<AwayTextField> this._adaptee).antiAliasType=value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "autoSize", {
        /**
         * Controls automatic sizing and alignment of text fields.
         * Acceptable values for the TextFieldAutoSize constants: TextFieldAutoSize.NONE (the default),
         * TextFieldAutoSize.LEFT, TextFieldAutoSize.RIGHT, and TextFieldAutoSize.CENTER.
         *
         *   If autoSize is set to TextFieldAutoSize.NONE (the default) no resizing occurs.If autoSize is set to TextFieldAutoSize.LEFT, the text is
         * treated as left-justified text, meaning that the left margin of the text field remains fixed and any
         * resizing of a single line of the text field is on the right margin. If the text includes a line break
         * (for example, "\n" or "\r"), the bottom is also resized to fit the next
         * line of text. If wordWrap is also set to true, only the bottom
         * of the text field is resized and the right side remains fixed.If autoSize is set to TextFieldAutoSize.RIGHT, the text is treated as
         * right-justified text, meaning that the right margin of the text field remains fixed and any resizing
         * of a single line of the text field is on the left margin. If the text includes a line break
         * (for example, "\n" or "\r"), the bottom is also resized to fit the next
         * line of text. If wordWrap is also set to true, only the bottom
         * of the text field is resized and the left side remains fixed.If autoSize is set to TextFieldAutoSize.CENTER, the text is treated as
         * center-justified text, meaning that any resizing of a single line of the text field is equally distributed
         * to both the right and left margins. If the text includes a line break (for example, "\n" or
         * "\r"), the bottom is also resized to fit the next line of text. If wordWrap is also
         * set to true, only the bottom of the text field is resized and the left and
         * right sides remain fixed.
         * @throws	ArgumentError The autoSize specified is not a member of flash.text.TextFieldAutoSize.
         */
        get: function () {
            return this._adaptee.autoSize;
        },
        set: function (value) {
            this._adaptee.autoSize = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "background", {
        /**
         * Specifies whether the text field has a background fill. If true, the text field has a
         * background fill. If false, the text field has no background fill.
         * Use the backgroundColor property to set the background color of a text field.
         */
        get: function () {
            return this._adaptee.background;
        },
        set: function (value) {
            this._adaptee.background = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "backgroundColor", {
        /**
         * The color of the text field background. The default value is 0xFFFFFF (white).
         * This property can be retrieved or set, even if there currently is no background, but the
         * color is visible only if the text field has the background property set to
         * true.
         */
        get: function () {
            return this._adaptee.backgroundColor;
        },
        set: function (value) {
            this._adaptee.backgroundColor = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "border", {
        /**
         * Specifies whether the text field has a border. If true, the text field has a border.
         * If false, the text field has no border. Use the borderColor property
         * to set the border color.
         */
        get: function () {
            return this._adaptee.border;
        },
        set: function (value) {
            this._adaptee.border = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "borderColor", {
        /**
         * The color of the text field border. The default value is 0x000000 (black).
         * This property can be retrieved or set, even if there currently is no border, but the
         * color is visible only if the text field has the border property set to
         * true.
         */
        get: function () {
            return this._adaptee.borderColor;
        },
        set: function (value) {
            this._adaptee.borderColor = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "bottomScrollV", {
        /**
         * An integer (1-based index) that indicates the bottommost line that is currently visible in
         * the specified text field. Think of the text field as a window onto a block of text.
         * The scrollV property is the 1-based index of the topmost visible line
         * in the window.
         *
         *   All the text between the lines indicated by scrollV and bottomScrollV
         * is currently visible in the text field.
         */
        get: function () {
            //todo
            throw ("bottomScrollV not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "caretIndex", {
        /**
         * The index of the insertion point (caret) position. If no insertion point is displayed,
         * the value is the position the insertion point would be if you restored focus to the field (typically where the
         * insertion point last was, or 0 if the field has not had focus).
         *
         *   Selection span indexes are zero-based (for example, the first position is 0,
         * the second position is 1, and so on).
         */
        get: function () {
            //todo
            throw ("caretIndex not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "condenseWhite", {
        /**
         * A Boolean value that specifies whether extra white space (spaces, line breaks, and so on)
         * in a text field with HTML text is removed. The default value is false.
         * The condenseWhite property only affects text set with
         * the htmlText property, not the text property. If you set
         * text with the text property, condenseWhite is ignored.
         *
         *   If condenseWhite is set to true, use standard HTML commands such as
         * <BR> and <P> to place line breaks in the text field.Set the condenseWhite property before setting the htmlText property.
         */
        get: function () {
            //todo
            throw ("condenseWhite not implemented yet in flash/TextField");
        },
        set: function (value) {
            //todo
            throw ("condenseWhite not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "defaultTextFormat", {
        /**
         * Specifies the format applied to newly inserted text, such as text entered by a user or text inserted with the
         * replaceSelectedText() method.
         *
         *   Note: When selecting characters to be replaced with setSelection() and
         * replaceSelectedText(), the defaultTextFormat will be applied only if the
         * text has been selected up to and including the last character. Here is an example:
         * var my_txt:TextField new TextField();
         * my_txt.text = "Flash Macintosh version";
         * var my_fmt:TextFormat = new TextFormat();
         * my_fmt.color = 0xFF0000;
         * my_txt.defaultTextFormat = my_fmt;
         * my_txt.setSelection(6,15); // partial text selected - defaultTextFormat not applied
         * my_txt.setSelection(6,23); // text selected to end - defaultTextFormat applied
         * my_txt.replaceSelectedText("Windows version");
         * When you access the defaultTextFormat property, the returned TextFormat object has all
         * of its properties defined. No property is null.Note: You can't set this property if a style sheet is applied to the text field.
         * @throws	Error This method cannot be used on a text field with a style sheet.
         */
        get: function () {
            return this._adaptee.textFormat;
        },
        set: function (format) {
            this._adaptee.textFormat = format;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "displayAsPassword", {
        /**
         * Specifies whether the text field is a password text field. If the value of this property is true,
         * the text field is treated as a password text field and hides the input characters using asterisks instead of the
         * actual characters. If false, the text field is not treated as a password text field. When password mode
         * is enabled, the Cut and Copy commands and their corresponding keyboard shortcuts will
         * not function.  This security mechanism prevents an unscrupulous user from using the shortcuts to discover
         * a password on an unattended computer.
         */
        get: function () {
            return this._adaptee.displayAsPassword;
        },
        set: function (value) {
            this._adaptee.displayAsPassword = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "embedFonts", {
        /**
         * Specifies whether to render by using embedded font outlines.
         * If false, Flash Player renders the text field by using
         * device fonts.
         *
         *   If you set the embedFonts property to true for a text field,
         * you must specify a font for that text by using the font property of
         * a TextFormat object applied to the text field.
         * If the specified font is not embedded in the SWF file, the text is not displayed.
         */
        get: function () {
            //todo
            //console.log("embedFonts not implemented yet in flash/TextField");
            return false;
        },
        set: function (value) {
            //todo
            //console.log("embedFonts not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "gridFitType", {
        /**
         * The type of grid fitting used for this text field. This property applies only if the
         * flash.text.AntiAliasType property of the text field is set to flash.text.AntiAliasType.ADVANCED.
         *
         *   The type of grid fitting used determines whether Flash Player forces strong horizontal and
         * vertical lines to fit to a pixel or subpixel grid, or not at all.For the flash.text.GridFitType property, you can use the following string values:String valueDescriptionflash.text.GridFitType.NONESpecifies no grid fitting. Horizontal and vertical lines in the glyphs are not
         * forced to the pixel grid. This setting is recommended for animation or
         * for large font sizes.flash.text.GridFitType.PIXELSpecifies that strong horizontal and vertical lines are fit to the
         * pixel grid. This setting works only for left-aligned text fields.
         * To use this setting, the flash.dispaly.AntiAliasType property of the text field
         * must be set to flash.text.AntiAliasType.ADVANCED.
         * This setting generally provides the best legibility for
         * left-aligned text.flash.text.GridFitType.SUBPIXELSpecifies that strong horizontal and vertical lines are fit to the subpixel grid on
         * an LCD monitor. To use this setting, the
         * flash.text.AntiAliasType property of the text field must be set to
         * flash.text.AntiAliasType.ADVANCED. The flash.text.GridFitType.SUBPIXEL setting is often good
         * for right-aligned or centered
         * dynamic text, and it is sometimes a useful trade-off for animation versus text quality.
         */
        get: function () {
            //todo
            return "";
            //throw("gridFitType not implemented yet in flash/TextField");
        },
        set: function (gridFitType) {
            //todo
            //throw("gridFitType not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "htmlText", {
        /**
         * Contains the HTML representation of the text field contents.
         *
         *   Flash Player supports the following HTML tags:
         * Tag
         *
         *   Description
         *
         *   Anchor tag
         *
         *   The <a> tag creates a hypertext link and supports the following attributes:
         * target: Specifies the name of the target window where you load the page.
         * Options include _self, _blank, _parent, and
         * _top. The _self option specifies the current frame in the current window,
         * _blank specifies a new window, _parent specifies the parent of the
         * current frame, and _top specifies the top-level frame in the current window.
         * href: Specifies a URL or an ActionScript link event.The URL can
         * be either absolute or relative to the location of the SWF file that
         * is loading the page. An example of an absolute reference to a URL is
         * http://www.adobe.com; an example of a relative reference is
         * /index.html. Absolute URLs must be prefixed with
         * http://; otherwise, Flash Player or AIR treats them as relative URLs.
         *
         *   You can use the link event to cause the link to execute an ActionScript
         * function in a SWF file instead of opening a URL. To specify a link event, use
         * the event scheme instead of the http scheme in your href attribute. An example
         * is href="event:myText" instead of href="http://myURL"; when the
         * user clicks a hypertext link that contains the event scheme, the text field dispatches a
         * link TextEvent with its text property set to "myText". You can then create an ActionScript
         * function that executes whenever the link TextEvent is dispatched.
         *
         *   You can also define a:link, a:hover, and a:active
         * styles for anchor tags by using style sheets.
         *
         *   Bold tag
         *
         *   The <b> tag renders text as bold. A bold typeface must be available for the font used.
         *
         *   Break tag
         *
         *   The <br> tag creates a line break in the text field. Set the text field to
         * be a multiline text field to use this tag.
         *
         *   Font tag
         *
         *   The <font> tag specifies a font or list of fonts to display the text.The font tag
         * supports the following attributes:
         * color: Only hexadecimal color (#FFFFFF) values are supported.
         * face: Specifies the name of the font to use. As shown in the following example,
         * you can specify a list of comma-delimited font names, in which case Flash Player selects the first available
         * font. If the specified font is not installed on the local computer system or isn't embedded in the SWF file,
         * Flash Player selects a substitute font.
         * size: Specifies the size of the font. You can use absolute pixel sizes, such as 16 or 18,
         * or relative point sizes, such as +2 or -4.
         *
         *   Image tag
         *
         *   The <img> tag lets you embed external image files (JPEG, GIF, PNG), SWF files, and
         * movie clips inside text fields. Text automatically flows around images you embed in text fields. You
         * must set the text field to be multiline to wrap text around an image.
         *
         *   The <img> tag supports the following attributes: src: Specifies the URL to an image or SWF file, or the linkage identifier for a movie clip
         * symbol in the library. This attribute is required; all other attributes are optional. External files (JPEG, GIF, PNG,
         * and SWF files) do not show until they are downloaded completely.
         * width: The width of the image, SWF file, or movie clip being inserted, in pixels.
         * height: The height of the image, SWF file, or movie clip being inserted, in pixels.
         * align: Specifies the horizontal alignment of the embedded image within the text field.
         * Valid values are left and right. The default value is left.
         * hspace: Specifies the amount of horizontal space that surrounds the image where
         * no text appears. The default value is 8.
         * vspace: Specifies the amount of vertical space that surrounds the image where no
         * text appears. The default value is 8.
         * id: Specifies the name for the movie clip instance (created by Flash Player) that contains
         * the embedded image file, SWF file, or movie clip. This approach is used to control the embedded content with
         * ActionScript.
         * checkPolicyFile: Specifies that Flash Player checks for a URL policy file
         * on the server associated with the image domain. If a policy file exists, SWF files in the domains
         * listed in the file can access the data of the loaded image, for example, by calling the
         * BitmapData.draw() method with this image as the source parameter.
         * For more information related to security, see the Flash Player Developer Center Topic:
         * Security.
         *
         *   Flash displays media embedded in a text field at full size. To specify the dimensions of the media
         * you are embedding, use the <img> tag height and width
         * attributes. In general, an image embedded in a text field appears on the line following the
         * <img> tag. However, when the <img> tag
         * is the first character in the text field, the image appears on the first line of the text field. For AIR content in the application security sandbox, AIR ignores img tags in
         * HTML content in ActionScript TextField objects. This is to prevent possible phishing attacks,
         * Italic tag
         *
         *   The <i> tag displays the tagged text in italics. An italic typeface must be available
         * for the font used.
         *
         *   List item tag
         *
         *   The <li> tag places a bullet in front of the text that it encloses.
         * Note: Because Flash Player and AIR do not recognize ordered and unordered list tags (<ol>
         * and <ul>, they do not modify how your list is rendered. All lists are unordered and all
         * list items use bullets.
         *
         *   Paragraph tag
         *
         *   The <p> tag creates a new paragraph. The text field must be set to be a multiline
         * text field to use this tag.
         *
         *   The <p> tag supports the following attributes:
         *
         *   align: Specifies alignment of text within the paragraph; valid values are left, right, justify, and center.
         *
         *   class: Specifies a CSS style class defined by a flash.text.StyleSheet object.
         *
         *   Span tag
         *
         *   The <span> tag is available only for use with CSS text styles. It supports the
         * following attribute:
         *
         *   class: Specifies a CSS style class defined by a flash.text.StyleSheet object.
         *
         *   Text format tag
         * The <textformat> tag lets you use a subset of paragraph formatting
         * properties of the TextFormat class within text fields, including line leading, indentation,
         * margins, and tab stops. You can combine <textformat> tags with the
         * built-in HTML tags. The <textformat> tag has the following attributes: blockindent: Specifies the block indentation in points; corresponds to
         * TextFormat.blockIndent.
         * indent: Specifies the indentation from the left margin to the first character
         * in the paragraph; corresponds to TextFormat.indent. Both positive and negative
         * numbers are acceptable.
         * leading: Specifies the amount of leading (vertical space) between lines;
         * corresponds to TextFormat.leading. Both positive and negative numbers are acceptable.
         * leftmargin: Specifies the left margin of the paragraph, in points; corresponds
         * to TextFormat.leftMargin.
         * rightmargin: Specifies the right margin of the paragraph, in points; corresponds
         * to TextFormat.rightMargin.
         * tabstops: Specifies custom tab stops as an array of non-negative integers;
         * corresponds to TextFormat.tabStops.
         *
         *   Underline tag
         *
         *   The <u> tag underlines the tagged text.
         * Flash Player and AIR support the following HTML entities:
         * Entity
         *
         *   Description
         *
         *   &amp;lt;
         *
         *   < (less than)
         *
         *   &amp;gt;
         *
         *   > (greater than)
         *
         *   &amp;amp;
         *
         *   & (ampersand)
         *
         *   &amp;quot;
         *
         *   " (double quotes)
         *
         *   &amp;apos;
         *
         *   ' (apostrophe, single quote)
         *
         *   Flash Player and AIR also support explicit character codes, such as
         * &#38; (ASCII ampersand) and &#x20AC; (Unicode € symbol).
         */
        get: function () {
            return this.adaptee.htmlText;
        },
        set: function (value) {
            this.adaptee.htmlText = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "length", {
        /**
         * The number of characters in a text field. A character such as tab (\t) counts as one
         * character.
         */
        get: function () {
            //todo
            return this._adaptee.length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "maxChars", {
        /**
         * The maximum number of characters that the text field can contain, as entered by a user.
         * A script can insert more text than maxChars allows; the maxChars property
         * indicates only how much text a user can enter. If the value of this property is 0,
         * a user can enter an unlimited amount of text.
         */
        get: function () {
            //todo
            console.log("maxChars not implemented yet in flash/TextField");
            return 0;
        },
        set: function (value) {
            //todo
            console.log("maxChars not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "maxScrollH", {
        /**
         * The maximum value of scrollH.
         */
        get: function () {
            //todo
            //console.log("maxScrollH not implemented yet in flash/TextField");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "maxScrollV", {
        /**
         * The maximum value of scrollV.
         */
        get: function () {
            //todo
            //console.log("maxScrollV not implemented yet in flash/TextField");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "mouseWheelEnabled", {
        /**
         * A Boolean value that indicates whether Flash Player automatically scrolls multiline
         * text fields when the user clicks a text field and rolls the mouse wheel.
         * By default, this value is true. This property is useful if you want to prevent
         * mouse wheel scrolling of text fields, or implement your own text field scrolling.
         */
        get: function () {
            //todo
            //console.log("mouseWheelEnabled not implemented yet in flash/TextField");
            return false;
        },
        set: function (value) {
            //todo
            //console.log("mouseWheelEnabled not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "multiline", {
        /**
         * Indicates whether field is a multiline text field. If the value is true,
         * the text field is multiline; if the value is false, the text field is a single-line
         * text field. In a field of type TextFieldType.INPUT, the multiline value
         * determines whether the Enter key creates a new line (a value of false,
         * and the Enter key is ignored).
         * If you paste text into a TextField with a multiline value of false,
         * newlines are stripped out of the text.
         */
        get: function () {
            //todo
            //console.log("multiline not implemented yet in flash/TextField");
            return this._adaptee.multiline;
        },
        set: function (value) {
            //todo
            //console.log("multiline not implemented yet in flash/TextField");
            this._adaptee.multiline = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "numLines", {
        /**
         * Defines the number of text lines in a multiline text field.
         * If wordWrap property is set to true,
         * the number of lines increases when text wraps.
         */
        get: function () {
            //todo
            console.log("numLines not implemented yet in flash/TextField");
            return this._adaptee.numLines;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "restrict", {
        /**
         * Indicates the set of characters that a user can enter into the text field. If the value of the
         * restrict property is null, you can enter any character. If the value of
         * the restrict property is an empty string, you cannot enter any character. If the value
         * of the restrict property is a string of characters, you can enter only characters in
         * the string into the text field. The string is scanned from left to right. You can specify a range by
         * using the hyphen (-) character. Only user interaction is restricted; a script can put any text into the
         * text field. This property does not synchronize with the Embed font options
         * in the Property inspector.If the string begins with a caret (^) character, all characters are initially accepted and
         * succeeding characters in the string are excluded from the set of accepted characters. If the string does
         * not begin with a caret (^) character, no characters are initially accepted and succeeding characters in the
         * string are included in the set of accepted characters.The following example allows only uppercase characters, spaces, and numbers to be entered into
         * a text field:
         * my_txt.restrict = "A-Z 0-9";
         * The following example includes all characters, but excludes lowercase letters:
         * my_txt.restrict = "^a-z";
         * You can use a backslash to enter a ^ or - verbatim. The accepted backslash sequences are \-, \^ or \\.
         * The backslash must be an actual character in the string, so when specified in ActionScript, a double backslash
         * must be used. For example, the following code includes only the dash (-) and caret (^):
         * my_txt.restrict = "\\-\\^";
         * The ^ can be used anywhere in the string to toggle between including characters and excluding characters.
         * The following code includes only uppercase letters, but excludes the uppercase letter Q:
         * my_txt.restrict = "A-Z^Q";
         * You can use the \u escape sequence to construct restrict strings.
         * The following code includes only the characters from ASCII 32 (space) to ASCII 126 (tilde).
         * my_txt.restrict = "\u0020-\u007E";
         */
        get: function () {
            return this.adaptee.restrict;
        },
        set: function (value) {
            this.adaptee.restrict = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "scrollH", {
        /**
         * The current horizontal scrolling position. If the scrollH property is 0, the text
         * is not horizontally scrolled. This property value is an integer that represents the horizontal
         * position in pixels.
         *
         *   The units of horizontal scrolling are pixels, whereas the units of vertical scrolling are lines.
         * Horizontal scrolling is measured in pixels because most fonts you typically use are proportionally
         * spaced; that is, the characters can have different widths. Flash Player performs vertical scrolling by
         * line because users usually want to see a complete line of text rather than a
         * partial line. Even if a line uses multiple fonts, the height of the line adjusts to fit
         * the largest font in use.Note: The scrollH property is zero-based, not 1-based like
         * the scrollV vertical scrolling property.
         */
        get: function () {
            //todo
            console.log("scrollH not implemented yet in flash/TextField");
            return 0;
        },
        set: function (value) {
            //todo
            console.log("scrollH not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "scrollV", {
        /**
         * The vertical position of text in a text field. The scrollV property is useful for
         * directing users to a specific paragraph in a long passage, or creating scrolling text fields.
         *
         *   The units of vertical scrolling are lines, whereas the units of horizontal scrolling are pixels.
         * If the first line displayed is the first line in the text field, scrollV is set to 1 (not 0).
         * Horizontal scrolling is measured in pixels because most fonts are proportionally
         * spaced; that is, the characters can have different widths. Flash performs vertical scrolling by line
         * because users usually want to see a complete line of text rather than a partial line.
         * Even if there are multiple fonts on a line, the height of the line adjusts to fit the largest font in
         * use.
         */
        get: function () {
            //todo
            console.log("scrollV not implemented yet in flash/TextField");
            return 0;
        },
        set: function (value) {
            //todo
            console.log("scrollV not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "selectable", {
        /**
         * A Boolean value that indicates whether the text field is selectable. The value true
         * indicates that the text is selectable. The selectable property controls whether
         * a text field is selectable, not whether a text field is editable. A dynamic text field can
         * be selectable even if it is not editable. If a dynamic text field is not selectable, the user
         * cannot select its text.
         *
         *   If selectable is set to false, the text in the text field does not
         * respond to selection commands from the mouse or keyboard, and the text cannot be copied with the
         * Copy command. If selectable is set to true, the text in the text field
         * can be selected with the mouse or keyboard, and the text can be copied with the Copy command.
         * You can select text this way even if the text field is a dynamic text field instead of an input text field.
         */
        get: function () {
            //todo
            //console.log("selectable not implemented yet in flash/TextField");
            return false;
        },
        set: function (value) {
            //todo
            this._adaptee.selectable = value;
            //console.log("selectable not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "selectedText", {
        get: function () {
            //todo
            console.log("selectedText not implemented yet in flash/TextField");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "selectionBeginIndex", {
        /**
         * The zero-based character index value of the first character in the current selection.
         * For example, the first character is 0, the second character is 1, and so on. If no
         * text is selected, this property is the value of caretIndex.
         */
        get: function () {
            //todo
            console.log("selectionBeginIndex not implemented yet in flash/TextField");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "selectionEndIndex", {
        /**
         * The zero-based character index value of the last character in the current selection.
         * For example, the first character is 0, the second character is 1, and so on. If no
         * text is selected, this property is the value of caretIndex.
         */
        get: function () {
            //todo
            console.log("selectionEndIndex not implemented yet in flash/TextField");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "sharpness", {
        /**
         * The sharpness of the glyph edges in this text field. This property applies
         * only if the flash.text.AntiAliasType property of the text field is set to
         * flash.text.AntiAliasType.ADVANCED. The range for
         * sharpness is a number from -400 to 400. If you attempt to set
         * sharpness to a value outside that range, Flash sets the property to
         * the nearest value in the range (either -400 or 400).
         */
        get: function () {
            //todo
            console.log("sharpness not implemented yet in flash/TextField");
            return 0;
        },
        set: function (value) {
            //todo
            console.log("sharpness not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "styleSheet", {
        /**
         * Attaches a style sheet to the text field. For information on creating style sheets, see the StyleSheet class
         * and the ActionScript 3.0 Developer's Guide.
         *
         *   You can change the style sheet associated with a text field at any time. If you change
         * the style sheet in use, the text field is redrawn with the new style sheet.
         * You can set the style sheet to null or undefined
         * to remove the style sheet. If the style sheet in use is removed, the text field is redrawn without a style sheet. Note: If the style sheet is removed, the contents of both TextField.text and
         * TextField.htmlText change to incorporate the formatting previously applied by the style sheet. To preserve
         * the original TextField.htmlText contents without the formatting, save the value in a variable before
         * removing the style sheet.
         */
        get: function () {
            //todo
            console.log("styleSheet not implemented yet in flash/TextField");
            return null;
        },
        set: function (value) {
            //todo
            console.log("styleSheet not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "text", {
        /**
         * A string that is the current text in the text field. Lines are separated by the carriage
         * return character ('\r', ASCII 13). This property contains unformatted text in the text
         * field, without HTML tags.
         *
         *   To get the text in HTML form, use the htmlText property.
         */
        get: function () {
            return this._adaptee.text;
        },
        set: function (value) {
            this._adaptee.text = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "textColor", {
        /**
         * The color of the text in a text field, in hexadecimal format.
         * The hexadecimal color system uses six digits to represent
         * color values. Each digit has 16 possible values or characters. The characters range from
         * 0-9 and then A-F. For example, black is 0x000000; white is
         * 0xFFFFFF.
         */
        get: function () {
            return this._adaptee.textColor;
        },
        set: function (value) {
            this._adaptee.textColor = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "textHeight", {
        /**
         * The height of the text in pixels.
         */
        get: function () {
            return this._adaptee.textHeight;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "textInteractionMode", {
        /**
         * The interaction mode property, Default value is TextInteractionMode.NORMAL.
         * On mobile platforms, the normal mode implies that the text can be scrolled but not selected.
         * One can switch to the selectable mode through the in-built context menu on the text field.
         * On Desktop, the normal mode implies that the text is in scrollable as well as selection mode.
         */
        get: function () {
            //todo
            console.log("textInteractionMode not implemented yet in flash/TextField");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "textWidth", {
        /**
         * The width of the text in pixels.
         */
        get: function () {
            return this._adaptee.textWidth;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "thickness", {
        /**
         * The thickness of the glyph edges in this text field. This property applies only
         * when flash.text.AntiAliasType is set to flash.text.AntiAliasType.ADVANCED.
         *
         *   The range for thickness is a number from -200 to 200. If you attempt to
         * set thickness to a value outside that range, the property is set to the
         * nearest value in the range (either -200 or 200).
         */
        get: function () {
            //todo
            console.log("thickness not implemented yet in flash/TextField");
            return 0;
        },
        set: function (value) {
            //todo
            console.log("thickness not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "type", {
        /**
         * The type of the text field.
         * Either one of the following TextFieldType constants: TextFieldType.DYNAMIC,
         * which specifies a dynamic text field, which a user cannot edit, or TextFieldType.INPUT,
         * which specifies an input text field, which a user can edit.
         * @throws	ArgumentError The type specified is not a member of flash.text.TextFieldType.
         */
        get: function () {
            //todo
            console.log("type not implemented yet in flash/TextField");
            return "";
        },
        set: function (value) {
            //this.adaptee.
            //todo
            console.log("type not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "useRichTextClipboard", {
        /**
         * Specifies whether to copy and paste the text formatting along with the text. When set to true,
         * Flash Player copies and pastes formatting (such as alignment, bold, and italics) when you copy and paste between text fields. Both the origin and destination text fields for the copy and paste procedure must have
         * useRichTextClipboard set to true. The default value
         * is false.
         */
        get: function () {
            //todo
            console.log("useRichTextClipboard not implemented yet in flash/TextField");
            return false;
        },
        set: function (value) {
            //todo
            console.log("useRichTextClipboard not implemented yet in flash/TextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField$$1.prototype, "wordWrap", {
        /**
         * A Boolean value that indicates whether the text field has word wrap. If the value of
         * wordWrap is true, the text field has word wrap;
         * if the value is false, the text field does not have word wrap. The default
         * value is false.
         */
        get: function () {
            return this._adaptee.wordWrap;
        },
        set: function (value) {
            this._adaptee.wordWrap = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Appends the string specified by the newText parameter to the end of the text
     * of the text field. This method is more efficient than an addition assignment (+=) on
     * a text property (such as someTextField.text += moreText),
     * particularly for a text field that contains a significant amount of content.
     * @param	newText	The string to append to the existing text.
     */
    TextField$$1.prototype.appendText = function (newText) {
        this._adaptee.appendText(newText);
    };
    TextField$$1.prototype.copyRichText = function () {
        //todo
        console.log("copyRichText not implemented yet in flash/TextField");
        return "";
    };
    /**
     * Returns a rectangle that is the bounding box of the character.
     * @param	charIndex	The zero-based index value for the character (for example, the first
     *   position is 0, the second position is 1, and so on).
     * @return	A rectangle with x and y minimum and maximum values
     *   defining the bounding box of the character.
     */
    TextField$$1.prototype.getCharBoundaries = function (charIndex) {
        //todo
        console.log("getCharBoundaries not implemented yet in flash/TextField");
        return null;
    };
    /**
     * Returns the zero-based index value of the character at the point specified by the x
     * and y parameters.
     * @param	x	The x coordinate of the character.
     * @param	y	The y coordinate of the character.
     * @return	The zero-based index value of the character (for example, the first position is 0,
     *   the second position is 1, and so on).  Returns -1 if the point is not over any character.
     */
    TextField$$1.prototype.getCharIndexAtPoint = function (x, y) {
        //todo
        console.log("getCharIndexAtPoint not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Given a character index, returns the index of the first character in the same paragraph.
     * @param	charIndex	The zero-based index value of the character (for example, the first character is 0,
     *   the second character is 1, and so on).
     * @return	The zero-based index value of the first character in the same paragraph.
     * @throws	RangeError The character index specified is out of range.
     */
    TextField$$1.prototype.getFirstCharInParagraph = function (charIndex) {
        //todo
        console.log("getFirstCharInParagraph not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Returns a DisplayObject reference for the given id, for an image or SWF file
     * that has been added to an HTML-formatted text field by using an <img> tag.
     * The <img> tag is in the following format:
     *
     *   <img src = 'filename.jpg' id = 'instanceName' >
     * @param	id	The id to match (in the id attribute of the
     *   <img> tag).
     * @return	The display object corresponding to the image or SWF file with the matching id
     *   attribute in the <img> tag of the text field. For media loaded from an external source,
     *   this object is a Loader object, and, once loaded, the media object is a child of that Loader object. For media
     *   embedded in the SWF file, it is the loaded object. If no <img> tag with
     *   the matching id exists, the method returns null.
     */
    TextField$$1.prototype.getImageReference = function (id) {
        //todo
        console.log("getImageReference not implemented yet in flash/TextField");
        return null;
    };
    /**
     * Returns the zero-based index value of the line at the point specified by the x
     * and y parameters.
     * @param	x	The x coordinate of the line.
     * @param	y	The y coordinate of the line.
     * @return	The zero-based index value of the line (for example, the first line is 0, the
     *   second line is 1, and so on).  Returns -1 if the point is not over any line.
     */
    TextField$$1.prototype.getLineIndexAtPoint = function (x, y) {
        //todo
        console.log("getLineIndexAtPoint not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Returns the zero-based index value of the line containing the character specified
     * by the charIndex parameter.
     * @param	charIndex	The zero-based index value of the character (for example, the first character is 0,
     *   the second character is 1, and so on).
     * @return	The zero-based index value of the line.
     */
    TextField$$1.prototype.getLineIndexOfChar = function (charIndex) {
        //todo
        console.log("getLineIndexOfChar not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Returns the number of characters in a specific text line.
     * @param	lineIndex	The line number for which you want the length.
     * @return	The number of characters in the line.
     * @throws	RangeError The line number specified is out of range.
     */
    TextField$$1.prototype.getLineLength = function (lineIndex) {
        //todo
        console.log("getLineLength not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Returns metrics information about a given text line.
     * @param	lineIndex	The line number for which you want metrics information.
     * @return	A TextLineMetrics object.
     * @throws	RangeError The line number specified is out of range.
     */
    TextField$$1.prototype.getLineMetrics = function (lineIndex) {
        //todo
        console.log("getLineMetrics not implemented yet in flash/TextField");
        return null;
    };
    /**
     * Returns the character index of the first character in the line that
     * the lineIndex parameter specifies.
     * @param	lineIndex	The zero-based index value of the line (for example, the first line is 0,
     *   the second line is 1, and so on).
     * @return	The zero-based index value of the first character in the line.
     * @throws	RangeError The line number specified is out of range.
     */
    TextField$$1.prototype.getLineOffset = function (lineIndex) {
        //todo
        console.log("getLineOffset not implemented yet in flash/TextField");
        return 0;
    };
    /**
     * Returns the text of the line specified by the lineIndex parameter.
     * @param	lineIndex	The zero-based index value of the line (for example, the first line is 0,
     *   the second line is 1, and so on).
     * @return	The text string contained in the specified line.
     * @throws	RangeError The line number specified is out of range.
     */
    TextField$$1.prototype.getLineText = function (lineIndex) {
        //todo
        console.log("getLineText not implemented yet in flash/TextField");
        return "";
    };
    /**
     * Given a character index, returns the length of the paragraph containing the given character.
     * The length is relative to the first character in the paragraph (as returned by
     * getFirstCharInParagraph()), not to the character index passed in.
     * @param	charIndex	The zero-based index value of the character (for example, the first character is 0,
     *   the second character is 1, and so on).
     * @return	Returns the number of characters in the paragraph.
     * @throws	RangeError The character index specified is out of range.
     */
    TextField$$1.prototype.getParagraphLength = function (charIndex) {
        //todo
        console.log("getParagraphLength not implemented yet in flash/TextField");
        return 0;
    };
    TextField$$1.prototype.getRawText = function () {
        //todo
        console.log("getRawText not implemented yet in flash/TextField");
        return "";
    };
    /**
     * Returns a TextFormat object that contains formatting information for the range of text that the
     * beginIndex and endIndex parameters specify. Only properties
     * that are common to the entire text specified are set in the resulting TextFormat object.
     * Any property that is mixed, meaning that it has different values
     * at different points in the text, has a value of null.
     *
     *   If you do not specify
     * values for these parameters, this method is applied to all the text in the text field.  The following table describes three possible usages:UsageDescriptionmy_textField.getTextFormat()Returns a TextFormat object containing formatting information for all text in a text field.
     * Only properties that are common to all text in the text field are set in the resulting TextFormat
     * object. Any property that is mixed, meaning that it has different values at different
     * points in the text, has a value of null.my_textField.getTextFormat(beginIndex:Number)Returns a TextFormat object containing a copy of the text format of the character at the
     * beginIndex position.my_textField.getTextFormat(beginIndex:Number,endIndex:Number)Returns a TextFormat object containing formatting information for the span of
     * text from beginIndex to endIndex-1. Only properties that are common
     * to all of the text in the specified range are set in the resulting TextFormat object. Any property
     * that is mixed (that is, has different values at different points in the range) has its value set to null.
     * @param	beginIndex	Optional; an integer that specifies the starting location of a range of text within the text field.
     * @param	endIndex	Optional; an integer that specifies the position of the first character after the desired
     *   text span. As designed, if you specify beginIndex and endIndex values,
     *   the text from beginIndex to endIndex-1 is read.
     * @return	The TextFormat object that represents the formatting properties for the specified text.
     * @throws	RangeError The beginIndex or endIndex specified is out of range.
     */
    TextField$$1.prototype.getTextFormat = function (beginIndex, endIndex) {
        if (beginIndex === void 0) { beginIndex = -1; }
        if (endIndex === void 0) { endIndex = -1; }
        // todo: support multiple formats
        return this._adaptee.textFormat;
    };
    TextField$$1.prototype.getTextRuns = function (beginIndex, endIndex) {
        if (beginIndex === void 0) { beginIndex = 0; }
        if (endIndex === void 0) { endIndex = 2147483647; }
        //todo
        console.log("getTextRuns not implemented yet in flash/TextField");
        return [];
    };
    TextField$$1.prototype.getXMLText = function (beginIndex, endIndex) {
        if (beginIndex === void 0) { beginIndex = 0; }
        if (endIndex === void 0) { endIndex = 2147483647; }
        //todo
        console.log("getXMLText not implemented yet in flash/TextField");
        return "";
    };
    TextField$$1.prototype.insertXMLText = function (beginIndex, endIndex, richText, pasting) {
        if (pasting === void 0) { pasting = false; }
        //todo
        console.log("insertXMLText not implemented yet in flash/TextField");
    };
    /**
     * Returns true if an embedded font is available with the specified fontName and fontStyle
     * where Font.fontType is flash.text.FontType.EMBEDDED.  Starting with Flash Player 10,
     * two kinds of embedded fonts can appear in a SWF file.  Normal embedded fonts are only used with
     * TextField objects.
     * CFF embedded fonts are only used with the flash.text.engine classes.  The two types are distinguished by the
     * fontType property of the Font class, as returned by the enumerateFonts() function.
     *
     *   TextField cannot use a font of type EMBEDDED_CFF. If embedFonts is set to true
     * and the only font available at run time with the specified name and style is of type EMBEDDED_CFF,
     * Flash Player fails to render the text, as if no embedded font were available with the specified name and style.If both EMBEDDED and EMBEDDED_CFF fonts are available with the same name and style, the EMBEDDED
     * font is selected and text renders with the EMBEDDED font.
     * @param	fontName	The name of the embedded font to check.
     * @param	fontStyle	Specifies the font style to check.  Use flash.text.FontStyle
     * @return	true if a compatible embedded font is available, otherwise false.
     * @throws	ArgumentError The fontStyle specified is not a member of flash.text.FontStyle.
     */
    TextField$$1.isFontCompatible = function (fontName, fontStyle) {
        //todo
        console.log("isFontCompatible not implemented yet in flash/TextField");
        return false;
    };
    TextField$$1.prototype.pasteRichText = function (richText) {
        //todo
        console.log("pasteRichText not implemented yet in flash/TextField");
        return false;
    };
    /**
     * Replaces the current selection with the contents of the value parameter.
     * The text is inserted at the position of the current selection, using the current default character
     * format and default paragraph format. The text is not treated as HTML.
     *
     *   You can use the replaceSelectedText() method to insert and delete text without disrupting
     * the character and paragraph formatting of the rest of the text.Note: This method does not work if a style sheet is applied to the text field.
     * @param	value	The string to replace the currently selected text.
     * @throws	Error This method cannot be used on a text field with a style sheet.
     */
    TextField$$1.prototype.replaceSelectedText = function (value) {
        //todo
        console.log("replaceSelectedText not implemented yet in flash/TextField");
    };
    /**
     * Replaces the range of characters that the beginIndex and
     * endIndex parameters specify with the contents
     * of the newText parameter. As designed, the text from
     * beginIndex to endIndex-1 is replaced.
     * Note: This method does not work if a style sheet is applied to the text field.
     * @param	beginIndex	The zero-based index value for the start position of the replacement range.
     * @param	endIndex	The zero-based index position of the first character after the desired
     *   text span.
     * @param	newText	The text to use to replace the specified range of characters.
     * @throws	Error This method cannot be used on a text field with a style sheet.
     */
    TextField$$1.prototype.replaceText = function (beginIndex, endIndex, newText) {
        //todo
        console.log("replaceText not implemented yet in flash/TextField");
    };
    /**
     * Sets as selected the text designated by the index values of the
     * first and last characters, which are specified with the beginIndex
     * and endIndex parameters. If the two parameter values are the same,
     * this method sets the insertion point, as if you set the
     * caretIndex property.
     * @param	beginIndex	The zero-based index value of the first character in the selection
     *   (for example, the first character is 0, the second character is 1, and so on).
     * @param	endIndex	The zero-based index value of the last character in the selection.
     * @internal	Need to add an example.
     */
    TextField$$1.prototype.setSelection = function (beginIndex, endIndex) {
        //todo
        console.log("setSelection not implemented yet in flash/TextField");
    };
    /**
     * Applies the text formatting that the format parameter specifies to the specified text in a text field.
     * The value of format must be a TextFormat object that specifies the
     * desired text formatting changes. Only the non-null properties of format are applied
     * to the text field. Any property of format that is set to null is not
     * applied. By default, all of the properties of a newly created TextFormat object are set to null.
     * Note: This method does not work if a style sheet is applied to the text field.The setTextFormat() method changes the text formatting applied to a range of
     * characters or to the entire body of text in a text field. To apply the properties of format to all text in the text
     * field, do not specify values for beginIndex and endIndex. To apply the
     * properties of the format to a range of text, specify values for the beginIndex and
     * the endIndex parameters. You can use the length property to determine
     * the index values.The two types of formatting information in a TextFormat object are
     * character level formatting and paragraph level formatting.
     * Each character in a text field can have its own character formatting
     * settings, such as font name, font size, bold, and italic.For paragraphs, the first character of the paragraph is examined for the paragraph formatting
     * settings for the entire paragraph. Examples of paragraph formatting settings are left margin,
     * right margin, and indentation.Any text inserted manually by the user, or replaced by the
     * replaceSelectedText() method, receives the default text field formatting for new text,
     * and not the formatting specified for the text insertion point. To set the default
     * formatting for new text, use defaultTextFormat.
     * @param	format	A TextFormat object that contains character and paragraph formatting information.
     * @param	beginIndex	Optional; an integer that specifies the zero-based index position specifying the
     *   first character of the desired range of text.
     * @param	endIndex	Optional; an integer that specifies the first character after the desired text span.
     *   As designed, if you specify beginIndex and endIndex values,
     *   the text from beginIndex to endIndex-1 is updated.
     *
     *     UsageDescriptionmy_textField.setTextFormat(textFormat:TextFormat)Applies the properties of textFormat to all text in the text
     *   field.my_textField.setTextFormat(textFormat:TextFormat, beginIndex:int)Applies the properties of textFormat to the text starting with the
     *   beginIndex position.my_textField.setTextFormat(textFormat:TextFormat, beginIndex:int,
     *   endIndex:int)Applies the properties of the textFormat parameter to the span of
     *   text from the beginIndex position to the endIndex-1 position.Notice that any text inserted manually by the user, or replaced by the
     *   replaceSelectedText() method, receives the default text field formatting for new
     *   text, and not the formatting specified for the text insertion point. To set a text field's
     *   default formatting for new text, use the defaultTextFormat property.
     * @throws	Error This method cannot be used on a text field with a style sheet.
     * @throws	RangeError The beginIndex or endIndex specified is out of range.
     */
    TextField$$1.prototype.setTextFormat = function (format, beginIndex, endIndex) {
        if (beginIndex === void 0) { beginIndex = -1; }
        if (endIndex === void 0) { endIndex = -1; }
        //todo implement for multi-formats
        this._adaptee.setTextFormat(format, beginIndex, endIndex);
    };
    return TextField$$1;
}(InteractiveObject));
TextField$1._textFields = new Array();

var FlashSceneGraphFactory = (function (_super) {
    __extends(FlashSceneGraphFactory, _super);
    function FlashSceneGraphFactory() {
        var _this = _super.apply(this, arguments) || this;
        _this.imageStore = {};
        return _this;
    }
    FlashSceneGraphFactory.prototype.creatematerial = function () {
        return null;
    };
    FlashSceneGraphFactory.prototype.createSprite = function (prefab, graphics) {
        if (prefab === void 0) { prefab = null; }
        if (graphics === void 0) { graphics = null; }
        return new Sprite$1(_awayjs_scene.Sprite.getNewSprite(graphics)).adaptee;
    };
    FlashSceneGraphFactory.prototype.createDisplayObjectContainer = function () {
        return new DisplayObjectContainer$1().adaptee;
    };
    FlashSceneGraphFactory.prototype.createMovieClip = function (timeline) {
        if (timeline === void 0) { timeline = null; }
        return new MovieClip$1(new _awayjs_scene.MovieClip(timeline)).adaptee;
    };
    FlashSceneGraphFactory.prototype.createTextField = function () {
        return new TextField$1().adaptee;
    };
    FlashSceneGraphFactory.prototype.createBillboard = function (material) {
        return new Bitmap(material.style.image.adapter).adaptee;
    };
    FlashSceneGraphFactory.prototype.createImage2D = function (width, height, transparent, fillColor, powerOfTwo) {
        if (transparent === void 0) { transparent = true; }
        if (fillColor === void 0) { fillColor = null; }
        if (powerOfTwo === void 0) { powerOfTwo = true; }
        return new BitmapData(width, height, transparent, fillColor).adaptee;
    };
    return FlashSceneGraphFactory;
}(_awayjs_scene.DefaultSceneGraphFactory));

// todo: define all methods (start new with converting as3-Loader to ts ?)
var Loader$1 = (function (_super) {
    __extends(Loader$$1, _super);
    function Loader$$1(parser) {
        var _this = _super.call(this) || this;
        _this._onLoaderProgressDelegate = function (event) { return _this.onLoaderProgress(event); };
        _this._onLoaderCompleteDelegate = function (event) { return _this.onLoaderComplete(event); };
        _this._onAssetCompleteDelegate = function (event) { return _this.onAssetComplete(event); };
        _this._parser = parser;
        _this._loaderInfo = new LoaderInfo();
        _this._factory = new FlashSceneGraphFactory();
        return _this;
    }
    Loader$$1.prototype.onLoaderProgress = function (event) {
        var newEvent = new ProgressEvent(ProgressEvent.PROGRESS, null, null, event.urlLoader.bytesLoaded, event.urlLoader.bytesTotal);
        newEvent.currentTarget = this._loaderInfo;
        this._loaderInfo.dispatchEvent(newEvent);
    };
    Loader$$1.prototype.onLoaderComplete = function (event) {
        var newEvent = new Event(Event.COMPLETE);
        newEvent.currentTarget = this._loaderInfo;
        this._loaderInfo.dispatchEvent(newEvent);
        this._loader.removeEventListener(_awayjs_core.LoaderEvent.LOAD_COMPLETE, this._onLoaderCompleteDelegate);
        this._loader.removeEventListener(_awayjs_core.AssetEvent.ASSET_COMPLETE, this._onAssetCompleteDelegate);
        this._loader = null;
        //AssetLibrary.removeEventListener(LoaderEvent.LOAD_COMPLETE, this._onLoaderCompleteDelegate);
        //AssetLibrary.removeEventListener(AssetEvent.ASSET_COMPLETE, this._onAssetCompleteDelegate);
    };
    Loader$$1.prototype.onAssetComplete = function (event) {
        // 	todo: take care of all needed asset-types (sounds / fonts / textfield)
        //	todo: update awd to support as3-class-identifier as extra property. 
        //  atm the name of the exported symbols will be the as3-class name, 
        //  and all exported symbols are handled as if exposed to as3
        var asset = event.asset;
        if (asset.isAsset(_awayjs_scene.TextField)) {
            this._loaderContext.applicationDomain.addDefinition(asset.name, asset);
        }
        else if (asset.isAsset(_awayjs_scene.SceneImage2D)) {
            this._loaderContext.applicationDomain.addDefinition(asset.name, asset);
            // we should only do this for bitmaps loaded from jpg or png
            if (this._isImage)
                this.addChild(this._loaderInfo.content = new Bitmap(asset.adapter));
        }
        else if (asset.isAsset(_awayjs_core.WaveAudio)) {
            this._loaderContext.applicationDomain.addAudioDefinition(asset.name, asset);
        }
        else if (asset.isAsset(_awayjs_scene.Font)) {
            this._loaderContext.applicationDomain.addFontDefinition(asset.name, asset);
        }
        else if (asset.isAsset(_awayjs_scene.Sprite)) {
            //if((<AwaySprite> asset).material)
            //	(<AwaySprite> asset).material.bothSides=false;
            this._loaderContext.applicationDomain.addDefinition(asset.name, asset);
        }
        else if (asset.isAsset(_awayjs_scene.MovieClip)) {
            this._loaderContext.applicationDomain.addDefinition(asset.name, asset);
            // if this is the "Scene 1", we make it a child of the loader
            if (asset.name == "Scene 1" || (asset.name == "scene")) {
                this.addChild(this._loaderInfo.content = asset.adapter);
            }
        }
    };
    Loader$$1.prototype.load = function (url, context) {
        if (context === void 0) { context = null; }
        console.log("start loading the url:" + url.url);
        var ext = url.url.substr(-3);
        this._isImage = (ext == "jpg" || ext == "png");
        url.url = url.url.replace(".swf", ".awd");
        this._loaderContext = context;
        this._loaderInfo.applicationDomain = context.applicationDomain;
        this._loader = new _awayjs_core.Loader();
        this._loader.addEventListener(_awayjs_core.URLLoaderEvent.LOAD_PROGRESS, this._onLoaderProgressDelegate);
        this._loader.addEventListener(_awayjs_core.LoaderEvent.LOAD_COMPLETE, this._onLoaderCompleteDelegate);
        this._loader.addEventListener(_awayjs_core.AssetEvent.ASSET_COMPLETE, this._onAssetCompleteDelegate);
        this._loader.load(url, null, null, (this._isImage) ? new _awayjs_stage.Image2DParser(this._factory) : this._parser);
    };
    Loader$$1.prototype.loadData = function (buffer, context) {
        if (context === void 0) { context = null; }
        console.log("start loading swfdata", buffer);
        this._loaderContext = context;
        this._loaderInfo.applicationDomain = context.applicationDomain;
        this._loader = new _awayjs_core.Loader();
        this._loader.addEventListener(_awayjs_core.URLLoaderEvent.LOAD_PROGRESS, this._onLoaderProgressDelegate);
        this._loader.addEventListener(_awayjs_core.LoaderEvent.LOAD_COMPLETE, this._onLoaderCompleteDelegate);
        this._loader.addEventListener(_awayjs_core.AssetEvent.ASSET_COMPLETE, this._onAssetCompleteDelegate);
        this._loader.loadData(buffer, null, null, null, this._parser);
    };
    Object.defineProperty(Loader$$1.prototype, "contentLoaderInfo", {
        get: function () {
            return this._loaderInfo;
        },
        set: function (value) {
            this._loaderInfo = value;
        },
        enumerable: true,
        configurable: true
    });
    return Loader$$1;
}(DisplayObjectContainer$1));

/*
import { DisplayObject } from "./DisplayObject";
import { Graphics } from "./Graphics";
import { Sprite } from "./Sprite";
*/
/**
 * This class is used to create lightweight shapes using the ActionScript drawing application program interface (API).
 * The Shape class includes a <codeph class="+ topic/ph pr-d/codeph ">graphics</codeph> property, which lets you access methods from the Graphics class.
 *
 *   <p class="- topic/p ">The Sprite class also includes a <codeph class="+ topic/ph pr-d/codeph ">graphics</codeph>property, and it includes other features not available to the
 * Shape class. For example, a Sprite object is a display object container, whereas a Shape object is not (and cannot contain
 * child display objects). For this reason, Shape objects consume less memory than Sprite objects that contain the
 * same graphics. However, a Sprite object supports user input events, while a Shape object does not.</p>
 */
/*
export class Shape extends DisplayObject
{
*/
/**
 * Creates a new Shape object.
 */
/*
constructor (){
    super(null)//todo;
}
*/
/**
 * Specifies the Graphics object belonging to this Shape object, where vector
 * drawing commands can occur.
 */
/*
    public get graphics () : Graphics{
        console.log("graphics not implemented yet in flash/Shape");
        return null;
    }
}
*/

/**
 * The SimpleButton class lets you control all instances of button symbols in a SWF
 * file.
 *
 *   <p class="- topic/p ">In Flash Professional, you can give a button an instance name in the
 * Property inspector. SimpleButton instance names are displayed in the Movie
 * Explorer and in the Insert Target Path dialog box in the Actions
 * panel. After you create an instance of a button in Flash Professional, you can
 * use the methods and properties of the SimpleButton class to manipulate buttons
 * with ActionScript.</p><p class="- topic/p ">In ActionScript 3.0, you use the <codeph class="+ topic/ph pr-d/codeph ">new SimpleButton()</codeph> constructor to create a
 * SimpleButton instance.</p><p class="- topic/p ">The SimpleButton class inherits from the InteractiveObject class.</p>
 *
 *   EXAMPLE:
 *
 *   The following example uses the SimpleButtonExample class, which in
 * turn uses the CustomSimpleButton class, and this class then instantiates four
 * ButtonDisplayState objects.  The result is a button that is created in the shape of
 * a square, whose background color changes based on the mouse state by overriding instance properties of
 * the SimpleButton class.  This is accomplished by performing the following steps:
 * <ol class="- topic/ol "><li class="- topic/li ">In the <codeph class="+ topic/ph pr-d/codeph ">SimpleButtonExample()</codeph> constructor, a new CustomSimpleButton object of type
 * SimpleButton, called <codeph class="+ topic/ph pr-d/codeph ">button</codeph>, is created, which calls the <codeph class="+ topic/ph pr-d/codeph ">CustomSimpleButton</codeph> constructor
 * method.  The <codeph class="+ topic/ph pr-d/codeph ">button</codeph> object is the added to the display list.  The button's color and size are
 * determined in the steps that follow.</li><li class="- topic/li ">In the CustomSimpleButton class, instance properties are declared that are later used
 * to control the size and background color of <codeph class="+ topic/ph pr-d/codeph ">button</codeph>, based on the state it is in (orange
 * in the normal state, dark yellow in the mouse over state, an light blue in the mouse down state).
 * In all of the <codeph class="+ topic/ph pr-d/codeph ">button</codeph>'s states, the size of the square is set to 80 pixels by using the
 * <codeph class="+ topic/ph pr-d/codeph ">size</codeph> property.</li><li class="- topic/li ">The constructor function for the CustomSimpleButton class sets the
 * <codeph class="+ topic/ph pr-d/codeph ">downState</codeph>, <codeph class="+ topic/ph pr-d/codeph ">overState</codeph>, <codeph class="+ topic/ph pr-d/codeph ">upState</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">hitTestState</codeph>, and <codeph class="+ topic/ph pr-d/codeph ">useHandCursor</codeph> properties with
 * four instances of the ButtonDisplayState class.</li><li class="- topic/li ">In the ButtonDisplayState class, the constructor sets the value of the
 * square's size and background color and calls the <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">draw()</codeph> method redraws the square with the size and background color set in
 * the constructor based on the button's state.</li></ol><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">

 */
var SimpleButton = (function (_super) {
    __extends(SimpleButton, _super);
    /**
     * Creates a new SimpleButton instance. Any or all of the display objects that represent
     * the various button states can be set as parameters in the constructor.
     * @param	upState	The initial value for the SimpleButton up state.
     * @param	overState	The initial value for the SimpleButton over state.
     * @param	downState	The initial value for the SimpleButton down state.
     * @param	hitTestState	The initial value for the SimpleButton hitTest state.
     */
    function SimpleButton(upState, overState, downState, hitTestState) {
        if (upState === void 0) { upState = null; }
        if (overState === void 0) { overState = null; }
        if (downState === void 0) { downState = null; }
        if (hitTestState === void 0) { hitTestState = null; }
        return _super.call(this) || this;
    }
    Object.defineProperty(SimpleButton.prototype, "downState", {
        /**
         * Specifies a display object that is used as the visual
         * object for the button "Down" state —the state that the button is in when the user
         * selects the hitTestState object.
         */
        get: function () {
            console.log("downState not implemented yet in flash/SimpleButton");
            return null;
        },
        set: function (value) {
            console.log("downState not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "enabled", {
        /**
         * A Boolean value that specifies whether a button is enabled. When a
         * button is disabled (the enabled property is set to false),
         * the button is visible but cannot be clicked. The default value is
         * true. This property is useful if you want to
         * disable part of your navigation; for example, you might want to disable a
         * button in the currently displayed page so that it can't be clicked and
         * the page cannot be reloaded.
         *
         *   Note: To prevent mouseClicks on a button, set both the enabled
         * and mouseEnabled properties to false.
         */
        get: function () {
            console.log("enabled not implemented yet in flash/SimpleButton");
            return false;
        },
        set: function (value) {
            console.log("enabled not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "hitTestState", {
        /**
         * Specifies a display object that is used as the hit testing object for the button. For a basic button, set the
         * hitTestState property to the same display object as the overState
         * property. If you do not set the hitTestState property, the SimpleButton
         * is inactive — it does not respond to user input events.
         */
        get: function () {
            console.log("hitTestState not implemented yet in flash/SimpleButton");
            return null;
        },
        set: function (value) {
            console.log("hitTestState not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "overState", {
        /**
         * Specifies a display object that is used as the visual
         * object for the button over state — the state that the button is in when
         * the pointer is positioned over the button.
         */
        get: function () {
            console.log("overState not implemented yet in flash/SimpleButton");
            return null;
        },
        set: function (value) {
            console.log("overState not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "soundTransform", {
        /**
         * The SoundTransform object assigned to this button. A SoundTransform object
         * includes properties for setting volume, panning, left speaker assignment, and right
         * speaker assignment. This SoundTransform object applies to all states of the button.
         * This SoundTransform object affects only embedded sounds.
         * @internal	Should information from AS2 setTransform be here? e.g. percentage values indicating
         *   how much of the left input to play in the left speaker or right speaker; it is generally
         *   best to use 22-KHZ 6-bit mono sounds?
         */
        get: function () {
            console.log("soundTransform not implemented yet in flash/SimpleButton");
            return null;
        },
        set: function (sndTransform) {
            console.log("soundTransform not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "trackAsMenu", {
        /**
         * Indicates whether other display objects that are SimpleButton or MovieClip objects can receive
         * user input release events. The trackAsMenu property lets you create menus. You
         * can set the trackAsMenu property on any SimpleButton or MovieClip object.
         * If the trackAsMenu property does not exist, the default behavior is
         * false.
         *
         *   You can change the trackAsMenu property at any time; the
         * modified button immediately takes on the new behavior.
         */
        get: function () {
            console.log("trackAsMenu not implemented yet in flash/SimpleButton");
            return false;
        },
        set: function (value) {
            console.log("trackAsMenu not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "upState", {
        /**
         * Specifies a display object that is used as the visual
         * object for the button up state — the state that the button is in when
         * the pointer is not positioned over the button.
         */
        get: function () {
            console.log("upState not implemented yet in flash/SimpleButton");
            return null;
        },
        set: function (value) {
            console.log("upState not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SimpleButton.prototype, "useHandCursor", {
        /**
         * A Boolean value that, when set to true, indicates whether
         * the hand cursor is shown when the pointer rolls over a button.
         * If this property is set to false, the arrow pointer cursor is displayed
         * instead. The default is true.
         *
         *   You can change the useHandCursor property at any time;
         * the modified button immediately uses the new cursor behavior.
         * @maelexample	Create two buttons on the Stage with the instance names <code>myBtn1_btn</code> and <code>myBtn2_btn</code>. Enter the following ActionScript in Frame 1 of the Timeline:
         *   <listing>
         *   myBtn1_btn.useHandCursor = false;
         *   myBtn1_btn.onRelease = buttonClick;
         *   myBtn2_btn.onRelease = buttonClick;
         *   function buttonClick() {
             *   trace(this._name);
             *   }
         *   </listing><p class="- topic/p ">When the mouse is over and clicks <code>myBtn1_btn</code>, there is no pointing hand. However, you see the pointing hand when the button is over and clicks <code>myBtn2_btn</code>.</p>
         */
        get: function () {
            console.log("useHandCursor not implemented yet in flash/SimpleButton");
            return false;
        },
        set: function (value) {
            console.log("useHandCursor not implemented yet in flash/SimpleButton");
        },
        enumerable: true,
        configurable: true
    });
    return SimpleButton;
}(InteractiveObject));

var StageAlign = (function () {
    function StageAlign() {
    }
    return StageAlign;
}());
StageAlign.BOTTOM = "B";
StageAlign.BOTTOM_LEFT = "BL";
StageAlign.BOTTOM_RIGHT = "BR";
StageAlign.LEFT = "L";
StageAlign.RIGHT = "R";
StageAlign.TOP = "T";
StageAlign.TOP_LEFT = "TL";
StageAlign.TOP_RIGHT = "TR";

var StageScaleMode = (function () {
    function StageScaleMode() {
    }
    return StageScaleMode;
}());
StageScaleMode.EXACT_FIT = "EXACT_FIT";
StageScaleMode.NO_BORDER = "noBorder";
StageScaleMode.NO_SCALE = "noScale";
StageScaleMode.SHOW_ALL = "showAll";

/**
 * Dispatched by the Stage object when the state of the stageVideos property changes.
 * @eventType	flash.events.StageVideoAvailabilityEvent.STAGE_VIDEO_AVAILABILITY
 [Event(name="stageVideoAvailability", type="flash.events.StageVideoAvailabilityEvent")]

 * Dispatched by the Stage object when the stage orientation changes.
 * @eventType	flash.events.StageOrientationEvent.ORIENTATION_CHANGE
 [Event(name="orientationChange", type="flash.events.StageOrientationEvent")]

 * Dispatched by the Stage object when the stage orientation begins changing.
 * @eventType	flash.events.StageOrientationEvent.ORIENTATION_CHANGING
 [Event(name="orientationChanging", type="flash.events.StageOrientationEvent")]

 * Dispatched when the Stage object enters, or leaves, full-screen mode.
 * @eventType	flash.events.FullScreenEvent.FULL_SCREEN
 [Event(name="fullScreen", type="flash.events.FullScreenEvent")]

 * Dispatched when the scaleMode property of the Stage object is set to
 * StageScaleMode.NO_SCALE and the SWF file is resized.
 * @eventType	flash.events.Event.RESIZE
 [Event(name="resize", type="flash.events.Event")]

 * Dispatched by the Stage object when the pointer moves out of the
 * stage area.
 * @eventType	flash.events.Event.MOUSE_LEAVE
 [Event(name="mouseLeave", type="flash.events.Event")]

 * The Stage class represents the main drawing area.
 *
 *   <p class="- topic/p ">For SWF content running in the browser (in
 * Flash<sup class="+ topic/ph hi-d/sup ">®</sup> Player), the Stage represents the entire area where Flash
 * content is shown. For content running in AIR on desktop operating systems, each NativeWindow object has a corresponding
 * Stage object.</p><p class="- topic/p ">The Stage object is not globally accessible. You need to access it through the
 * <codeph class="+ topic/ph pr-d/codeph ">stage</codeph> property of a DisplayObject instance.</p><p class="- topic/p ">The Stage class has several ancestor classes — DisplayObjectContainer, InteractiveObject,
 * DisplayObject, and EventDispatcher — from which it inherits properties and methods.
 * Many of these properties and methods are either inapplicable to Stage objects,
 * or require security checks when called on a Stage object.  The properties and methods that
 * require security checks are documented as part of the Stage class.</p><p class="- topic/p ">In addition, the following inherited properties are inapplicable to Stage objects. If you
 * try to set them, an IllegalOperationError is thrown. These properties may always be read, but
 * since they cannot be set, they will always contain default values.</p><ul class="- topic/ul "><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">accessibilityProperties</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">alpha</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">blendMode</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">cacheAsBitmap</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">contextMenu</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">filters</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">focusRect</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">loaderInfo</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mask</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">mouseEnabled</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">name</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">opaqueBackground</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">rotation</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">scale9Grid</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">scaleX</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">scaleY</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">scrollRect</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">tabEnabled</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">tabIndex</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">transform</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">visible</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">x</codeph></li><li class="- topic/li "><codeph class="+ topic/ph pr-d/codeph ">y</codeph></li></ul><p class="- topic/p ">Some events that you might expect to be a part of the Stage class,
 * such as <codeph class="+ topic/ph pr-d/codeph ">enterFrame</codeph>, <codeph class="+ topic/ph pr-d/codeph ">exitFrame</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">frameConstructed</codeph>, and <codeph class="+ topic/ph pr-d/codeph ">render</codeph>,
 * cannot be Stage events because a reference to the Stage object
 * cannot be guaranteed to exist in every situation where these events
 * are used. Because these events cannot be dispatched by the Stage
 * object, they are instead dispatched by every DisplayObject instance,
 * which means that you can add an event listener to
 * any DisplayObject instance to listen for these events.
 * These events, which are part of the DisplayObject class,
 * are called broadcast events to differentiate them from events
 * that target a specific DisplayObject instance.
 * Two other broadcast events, <codeph class="+ topic/ph pr-d/codeph ">activate</codeph> and <codeph class="+ topic/ph pr-d/codeph ">deactivate</codeph>,
 * belong to DisplayObject's superclass, EventDispatcher.
 * The <codeph class="+ topic/ph pr-d/codeph ">activate</codeph> and <codeph class="+ topic/ph pr-d/codeph ">deactivate</codeph> events
 * behave similarly to the DisplayObject broadcast events, except
 * that these two events are dispatched not only by all DisplayObject
 * instances, but also by all EventDispatcher instances and instances
 * of other EventDispatcher subclasses.
 * For more information on broadcast events, see the DisplayObject class.</p>
 *
 *   EXAMPLE:
 *
 *   The following example uses the <codeph class="+ topic/ph pr-d/codeph ">StageExample</codeph> class to dispatch
 * events whenever the stage is activated or resized.  This is accomplished by performing the following steps:
 * <ol class="- topic/ol "><li class="- topic/li ">The class constructor first sets the Flash application to be fixed, regardless of the size of
 * the Flash Player window and then adds two event listeners with the
 * <codeph class="+ topic/ph pr-d/codeph ">activateHandler()</codeph> and <codeph class="+ topic/ph pr-d/codeph ">resizeHandler()</codeph> methods.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">activateHandler()</codeph> method runs when the left mouse button is clicked.</li><li class="- topic/li ">The <codeph class="+ topic/ph pr-d/codeph ">resizeHandler()</codeph> method runs when the stage is resized.</li></ol><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
 * package {
     * import flash.display.Sprite;
     * import flash.display.StageAlign;
     * import flash.display.StageScaleMode;
     * import flash.events.Event;
     *
     *   public class StageExample extends Sprite {
     *
     *   public StageExample() {
     * stage.scaleMode = StageScaleMode.NO_SCALE;
     * stage.align = StageAlign.TOP_LEFT;
     * stage.addEventListener(Event.ACTIVATE, activateHandler);
     * stage.addEventListener(Event.RESIZE, resizeHandler);
     * }
     *
     *   private activateHandler(event:Event):void {
     * trace("activateHandler: " + event);
     * }
     *
     *   private resizeHandler(event:Event):void {
     * trace("resizeHandler: " + event);
     * trace("stageWidth: " + stage.stageWidth + " stageHeight: " + stage.stageHeight);
     * }
     * }
     * }
 * </codeblock>
 */
var Stage = (function (_super) {
    __extends(Stage, _super);
    function Stage(startClass, width, height, backgroundColor, frameRate, showFPS) {
        if (width === void 0) { width = 550; }
        if (height === void 0) { height = 400; }
        if (backgroundColor === void 0) { backgroundColor = null; }
        if (frameRate === void 0) { frameRate = 30; }
        if (showFPS === void 0) { showFPS = false; }
        var _this = _super.call(this) || this;
        _this._frameRate = 30;
        _this._currentFps = 0;
        _this._time = 0;
        _this.SHOW_FRAME_RATE = false;
        _this._debugtimer = 0;
        _this.SHOW_FRAME_RATE = showFPS;
        _this._stageWidth = width;
        _this._stageHeight = height;
        _this._eventOnEnter = new Event(Event.ENTER_FRAME);
        _this._eventFrameConstructed = new Event(Event.FRAME_CONSTRUCTED);
        _this._eventExitFrame = new Event(Event.EXIT_FRAME);
        _this._eventRender = new Event(Event.RENDER);
        _this._events = [_this._eventOnEnter, _this._eventExitFrame];
        _this._scaleMode = StageScaleMode.NO_SCALE;
        _this._align = StageAlign.TOP_LEFT;
        _this._stage3Ds = [];
        //this._stage3Ds[this._stage3Ds.length]=new AwayStage(null, );
        _awayjs_core.AudioManager.setVolume(1);
        //todo: better implement this in graphics (this function provides the drawing api with materials for a color / alpha)
        _awayjs_graphics.Graphics.get_material_for_color = function (color, alpha) {
            if (alpha === void 0) { alpha = 1; }
            if (color == 0) {
                color = 0x000001;
            }
            if (color == 0xFF8100) {
                alpha = 1;
            }
            //color=0xFF8100;
            //alpha=0.5;
            var texObj = {};
            if (Stage._useTextureAtlasForColors) {
                texObj = _awayjs_graphics.TextureAtlas.getTextureForColor(color, alpha);
                if (Stage._colorMaterials[texObj.bitmap.id]) {
                    texObj.material = Stage._colorMaterials[texObj.bitmap.id];
                    return texObj;
                }
                var newmat = new _awayjs_materials.MethodMaterial(texObj.bitmap);
                newmat.alphaBlending = true;
                newmat.useColorTransform = true;
                newmat.bothSides = true;
                Stage._colorMaterials[texObj.bitmap.id] = newmat;
                texObj.material = newmat;
                return texObj;
            }
            var colorstr = color + "_" + Math.round(alpha * 100).toString();
            if (Stage._colorMaterials[colorstr]) {
                texObj.material = Stage._colorMaterials[colorstr];
                return texObj;
            }
            var newmat = new _awayjs_materials.MethodMaterial(color, alpha);
            newmat.alphaBlending = true;
            newmat.useColorTransform = true;
            newmat.bothSides = true;
            texObj.material = newmat;
            Stage._colorMaterials[colorstr] = newmat;
            return texObj;
        };
        _awayjs_graphics.Graphics.get_material_for_gradient = function (gradient) {
            var texObj = _awayjs_graphics.TextureAtlas.getTextureForGradient(gradient);
            /*if(alpha==0){
             alpha=1;
             }*/
            /*if(color==0xffffff){
             color=0xcccccc;
             }*/
            var lookupstr = texObj.bitmap.id + gradient.type;
            if (Stage._textureMaterials[lookupstr]) {
                texObj.material = Stage._textureMaterials[lookupstr];
                return texObj;
            }
            var newmat = new _awayjs_materials.MethodMaterial(texObj.bitmap);
            newmat.useColorTransform = true;
            newmat.alphaBlending = true;
            newmat.bothSides = true;
            Stage._textureMaterials[lookupstr] = newmat;
            texObj.material = newmat;
            return texObj;
        };
        /*
        //todo
        this.eventMappingDummys[StageVideoAvailabilityEvent.STAGE_VIDEO_AVAILABILITY]="StageVideoAvailabilityEvent.STAGE_VIDEO_AVAILABILITY";
        this.eventMappingDummys[StageOrientationEvent.ORIENTATION_CHANGE]="StageOrientationEvent.ORIENTATION_CHANGE";
        this.eventMappingDummys[StageOrientationEvent.ORIENTATION_CHANGING]="StageOrientationEvent.ORIENTATION_CHANGING";
        this.eventMappingDummys[FullScreenEvent.FULL_SCREEN]="FullScreenEvent.FULL_SCREEN";
        */
        // resize event listens on window
        _this._resizeCallbackDelegate = function (event) { return _this.resizeCallback(event); };
        _this.eventMapping[Event.RESIZE] = {
            adaptedType: "",
            addListener: _this.initResizeListener,
            removeListener: _this.removeResizeListener,
            callback: _this._resizeCallbackDelegate
        };
        // mouse leave event listens on window
        _this._mouseLeaveCallbackDelegate = function (event) { return _this.mouseLeaveCallback(event); };
        _this.eventMapping[Event.MOUSE_LEAVE] = {
            adaptedType: "",
            addListener: _this.initMouseLeaveListener,
            removeListener: _this.removeMouseLeaveListener,
            callback: _this._mouseLeaveCallbackDelegate
        };
        // set this as active stage.
        // this makes sure all DisplayObject.constructor can set a reference to stage,
        // befor constructors of Sprite or MovieClips are processed
        DisplayObject$1.activeStage = _this;
        _this._stage = _this;
        // init awayengine
        _this.initEninge();
        _this._resizeCallbackDelegate(null);
        _this.adaptee.partition = new _awayjs_scene.SceneGraphPartition(_this.adaptee, true);
        // create new Partition for the adaptee and make it child of the awayjs-scene
        //this._view.setPartition(this.adaptee, new SceneGraphPartition(this.adaptee));
        _this._scene.root.addChild(_this.adaptee);
        // helps with mouse-events:
        //this._view.mousePicker.onlyMouseEnabled=false;
        //this._view.renderer.stage.container.style.display="none";
        // create the entrance-class
        // this is the moment the converted as3-code is executed
        _this._scene.renderer.view.backgroundColor = (isNaN(backgroundColor)) ? 0xFFFFFF : backgroundColor;
        _this._frameRate = frameRate;
        // make sure we have a background, so any mousedowns on stage are registered even if no object is hit
        // it might make more sense to put this bg on the stage, but if i try to draw into the stage,
        // the shape is the only thing that shows up, the _mainSprite is than no longer rendered
        /*this._mainSprite.graphics.clear();
        this._mainSprite.graphics.beginFill(0xffff00, 0.5);
        this._mainSprite.graphics.drawRect(0,0,window.innerWidth, window.innerHeight);
        this._mainSprite.graphics.endFill();*/
        // prevent backspace and other default shortcutz for our document:
        /*document.onkeydown = function (event) {

            if (!event) { // This will happen in IE
                event = <any>window.event;
            }

            var keyCode = event.keyCode;

            if (keyCode == 8 &&
                ((<any>(event.target || event.srcElement)).tagName != "TEXTAREA") &&
                ((<any>(event.target || event.srcElement)).tagName != "INPUT")) {

                if (navigator.userAgent.toLowerCase().indexOf("msie") == -1) {
                    event.stopPropagation();
                } else {
                    alert("prevented");
                    event.returnValue = false;
                }

                return false;
            }
            /*
            window.location.href += "#";

            var _hash = "";
            window.setTimeout(function () {
                window.location.href += "";
            }, 50);

            window.onhashchange = function () {
                if (window.location.hash !== _hash) {
                    window.location.hash = _hash;
                }
            };
        }
            */
        if (_this.SHOW_FRAME_RATE) {
            _this._fpsTextField = document.createElement('div'); // disable in RC
            _this._fpsTextField.style.cssFloat = 'none';
            _this._fpsTextField.style.position = 'fixed';
            _this._fpsTextField.style.top = '5px';
            _this._fpsTextField.style.width = '100px';
            _this._fpsTextField.style.height = '20px';
            _this._fpsTextField.style.right = '5px';
            _this._fpsTextField.style.textAlign = 'center';
            _this._fpsTextField.style.color = '#ff0000';
            _this._fpsTextField.style.fontSize = '16';
            _this._fpsTextField.innerHTML = "";
            document.body.appendChild(_this._fpsTextField);
            setInterval(function () { return _this.updateFPS(); }, 1000);
        }
        if (startClass) {
            _this._mainSprite = new startClass();
            _this.addChild(_this._mainSprite);
            _this.initListeners();
            console.log("constructed Stage and create the entranceclass");
        }
        _this._rendererStage.container.style.visibility = "visible";
        return _this;
        // inits the resize listener
    }
    Stage.prototype.init = function (startClass) {
        this._mainSprite = new startClass();
        this.addChild(this._mainSprite);
        this.initListeners();
        this._resizeCallbackDelegate(null);
        this._rendererStage.container.style.visibility = "visible";
    };
    Object.defineProperty(Stage.prototype, "view", {
        get: function () {
            return this._scene.renderer.view;
        },
        enumerable: true,
        configurable: true
    });
    Stage.prototype.updateFPS = function () {
        this._fpsTextField.innerText = this._currentFps.toFixed(2) + '/' + this._frameRate + " fps";
        this._currentFps = 0;
    };
    Object.defineProperty(Stage.prototype, "onlyMouseEnabled", {
        set: function (value) {
            // todo2019: what is this supposed to do ?
            //this._scene.mousePicker.onlyMouseEnabled = value;
        },
        enumerable: true,
        configurable: true
    });
    // ---------- event mapping functions Event.RESIZE
    Stage.prototype.initResizeListener = function (type, callback) {
        window.addEventListener("resize", callback);
    };
    Stage.prototype.removeResizeListener = function (type, callback) {
        window.removeEventListener("resize", callback);
    };
    Stage.prototype.resizeCallback = function (event) {
        // todo: correctly implement all StageScaleModes;
        if (event === void 0) { event = null; }
        var newWidth = window.innerWidth;
        var newHeight = window.innerHeight;
        var newX = 0;
        var newY = 0;
        switch (this.scaleMode) {
            case StageScaleMode.NO_SCALE:
                this._projection.fieldOfView = Math.atan(window.innerHeight / 1000 / 2) * 360 / Math.PI;
                break;
            case StageScaleMode.SHOW_ALL:
                newHeight = window.innerHeight;
                newWidth = (this._stageWidth / this._stageHeight) * newHeight;
                if (newWidth > window.innerWidth) {
                    newWidth = window.innerWidth;
                    newHeight = newWidth * (this._stageHeight / this._stageWidth);
                }
                newX = (window.innerWidth - newWidth) / 2;
                newY = (window.innerHeight - newHeight) / 2;
                this._projection.fieldOfView = Math.atan(this._stageHeight / 1000 / 2) * 360 / Math.PI;
                break;
            case StageScaleMode.EXACT_FIT:
            case StageScaleMode.NO_BORDER:
            default:
                throw ("Stage: only implemented StageScaleMode are NO_SCALE, SHOW_ALL");
        }
        // todo: correctly implement all alignModes;
        switch (this.align) {
            case StageAlign.TOP_LEFT:
                this._scene.renderer.view.y = 0;
                this._scene.renderer.view.x = 0;
                break;
            default:
                throw ("Stage: only implemented StageAlign is TOP_LEFT");
        }
        //console.log("test28");
        if (this._mainSprite) {
            this._mainSprite.graphics.clear();
            this._mainSprite.graphics.beginFill(0xffffff, 0);
            this._mainSprite.graphics.drawRect(0, 0, newWidth, newHeight);
            this._mainSprite.graphics.endFill();
        }
        this.updateSize(newX, newY, newWidth, newHeight);
        //this._scene.view.preserveFocalLength = true;
        /*
        if(aspectRatio>=1){
            this._projection.fieldOfView = Math.atan(window.innerHeight/1000/2)*360/Math.PI;
        }
        else{
            this._projection.fieldOfView = Math.atan(window.innerWidth/1000/2)*360/Math.PI;
        }
        */
        //this._projection.originX = (0.5 - 0.5*(window.innerHeight/newHeight)*(this._stageWidth/window.innerWidth));
        this.dispatchEvent(new Event(Event.RESIZE));
    };
    Stage.prototype.show = function () {
        //this._view.renderer.stage.container.style.display="initial";
    };
    // ---------- event mapping functions Event.MOUSE_LEAVE
    Stage.prototype.initMouseLeaveListener = function (type, callback) {
        window.addEventListener("mouseleave", callback);
    };
    Stage.prototype.removeMouseLeaveListener = function (type, callback) {
        window.removeEventListener("mouseleave", callback);
    };
    Stage.prototype.mouseLeaveCallback = function (event) {
        if (event === void 0) { event = null; }
        this.dispatchEvent(new Event(Event.MOUSE_LEAVE));
    };
    //---------------------------stuff added to make it work:
    Stage.prototype.initEninge = function () {
        //create the view
        this._scene = new _awayjs_scene.Scene((new _awayjs_view.BasicPartition(new _awayjs_scene.DisplayObjectContainer())));
        this._rendererStage = this._scene.view.stage;
        this._rendererStage.container.style.visibility = "hidden";
        this._rendererStage.antiAlias = 0;
        this._scene.renderer.renderableSorter = null; //new RenderableSort2D();
        this._projection = new _awayjs_core.PerspectiveProjection();
        this._projection.coordinateSystem = _awayjs_core.CoordinateSystem.RIGHT_HANDED;
        this._projection.originX = -1;
        this._projection.originY = 1;
        var camera = new _awayjs_scene.Camera();
        camera.projection = this._projection;
        this._scene.camera = camera;
        this._projection.fieldOfView = Math.atan(window.innerHeight / 1000 / 2) * 360 / Math.PI;
        //this._projection.fieldOfView = Math.atan(this._stageHeight/1000/2)*360/Math.PI;
    };
    Stage.prototype.updateSize = function (x, y, w, h) {
        //this._stageWidth=w;
        //this._stageHeight=h;
        this._scene.view.x = x;
        this._scene.view.y = y;
        this._rendererStage.x = x;
        this._rendererStage.y = y;
        //	this._rendererStage.container.style.zIndex="-100";
        this._rendererStage.width = w;
        this._rendererStage.height = h;
        this._scene.view.width = w;
        this._scene.view.height = h;
        if (this._fpsTextField)
            this._fpsTextField.style.left = window.innerWidth * 0.5 - 100 + 'px';
    };
    
    /**
     * Initialise the listeners
     */
    Stage.prototype.initListeners = function () {
        console.log("init listeners");
        window.addEventListener("resize", this._resizeCallbackDelegate);
        this._timer = new _awayjs_core.RequestAnimationFrame(this.onEnterFrame, this);
        this._timer.start();
        this._resizeCallbackDelegate(null);
    };
    /**
     * Render loop
     */
    Stage.prototype.onEnterFrame = function (dt) {
        var frameMarker = Math.floor(1000 / this._frameRate);
        this._time += Math.min(dt, frameMarker);
        if (this._time >= frameMarker) {
            this._time -= frameMarker;
            this._rendererStage.clear();
            //this.dispatchEventRecursive(this._eventOnEnter);
            this.advanceFrame(this._events);
            //this.dispatchEventRecursive(this._eventFrameConstructed);
            // todo: move Framescriptexecution and rest from frame-update logic from Movieclip.update to here
            //this.dispatchEventRecursive(this._eventExitFrame);
            //this.dispatchEventRecursive(this._eventRender);
            this._scene.render();
            this._currentFps++;
        }
    };
    Stage.prototype.render = function () {
        this._rendererStage.clear();
        this.advanceFrame(this._events);
        this._scene.render();
    };
    Object.defineProperty(Stage.prototype, "rendererStage", {
        get: function () {
            return this._rendererStage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "mouseX", {
        //---------------------------original as3 properties / methods:
        get: function () {
            //console.log("mouseX not implemented yet in flash/DisplayObject");
            return this._scene.mouseX;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "mouseY", {
        /**
         * Indicates the y coordinate of the mouse or user input device position, in pixels.
         *
         *   Note: For a DisplayObject that has been rotated, the returned y coordinate will reflect the
         * non-rotated any.
         */
        get: function () {
            //console.log("mouseY not implemented yet in flash/DisplayObject");
            return this._scene.mouseY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "accessibilityImplementation", {
        set: function (value) {
            //todo: any is AccessibilityImplementation
            console.log("textSnapshot not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "align", {
        /**
         * A value from the StageAlign class that specifies the alignment of the stage in
         * Flash Player or the browser. The following are valid values:
         *
         *   ValueVertical AlignmentHorizontalStageAlign.TOPTopCenterStageAlign.BOTTOMBottomCenterStageAlign.LEFTCenterLeftStageAlign.RIGHTCenterRightStageAlign.TOP_LEFTTopLeftStageAlign.TOP_RIGHTTopRightStageAlign.BOTTOM_LEFTBottomLeftStageAlign.BOTTOM_RIGHTBottomRightThe align property is only available to an object that is in the same security sandbox
         * as the Stage owner (the main SWF file).
         * To avoid this, the Stage owner can grant permission to the domain of the
         * calling object by calling the Security.allowDomain() method or the Security.alowInsecureDomain() method.
         * For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            return this._align;
        },
        set: function (value) {
            value = this._align;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "allowsFullScreen", {
        /**
         * Specifies whether this stage allows the use of the full screen mode
         * @langversion	3.0
         * @playerversion	Flash 10.2
         * @oldexample	The following example traces the value of this read-only property:
         *   <pre xml:space="preserve" class="- topic/pre ">
         *   trace(Stage.allowsFullsreen);
         *   </pre>
         */
        get: function () {
            //todo
            console.log("allowsFullScreen not implemented yet in flash/Stage");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "allowsFullScreenInteractive", {
        get: function () {
            //todo
            console.log("allowsFullScreenInteractive not implemented yet in flash/Stage");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "browserZoomFactor", {
        get: function () {
            //todo
            console.log("browserZoomFactor not implemented yet in flash/Stage");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "color", {
        get: function () {
            return this._scene.renderer.view.backgroundColor;
        },
        set: function (color) {
            this._scene.renderer.view.backgroundColor = color;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "colorCorrection", {
        /**
         * Controls Flash runtime color correction for displays.
         * Color correction works only if the main monitor is assigned a valid ICC color profile, which specifies
         * the device's particular color attributes.
         * By default, the Flash runtime tries to match the color correction of its host (usually a browser).
         *
         *   Use the Stage.colorCorrectionSupport property
         * to determine if color correction is available on the current system and the default state.
         * .    If color correction is available, all colors on the stage are assumed to be in
         * the sRGB color space, which is the most standard color space. Source profiles of input devices are not considered during color correction.
         * No input color correction is applied; only the stage output is mapped to the main
         * monitor's ICC color profile.In general, the benefits of activating color management include predictable and consistent color, better conversion,
         * accurate proofing and more efficient cross-media output. Be aware, though, that color management does not provide
         * perfect conversions due to devices having a different gamut from each other or original images.
         * Nor does color management eliminate the need for custom or edited profiles.
         * Color profiles are dependent on browsers, operating systems (OS), OS extensions, output devices, and application support.Applying color correction degrades the Flash runtime performance.
         * A Flash runtime's color correction is document style color correction because
         * all SWF movies are considered documents with implicit sRGB profiles.
         * Use the Stage.colorCorrectionSupport property to tell the Flash runtime
         * to correct colors when displaying the SWF file (document) to the display color space.
         * Flash runtimes only compensates for differences between monitors, not for differences between input devices (camera/scanner/etc.).
         * The three possible values are strings with corresponding constants in the flash.display.ColorCorrection class:"default": Use the same color correction as the host system."on": Always perform color correction."off": Never perform color correction.
         */
        get: function () {
            //todo
            console.log("colorCorrection not implemented yet in flash/Stage");
            return "";
        },
        set: function (value) {
            //todo
            console.log("colorCorrection not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "colorCorrectionSupport", {
        /**
         * Specifies whether the Flash runtime is running on an operating system that supports
         * color correction and whether the color profile of the main (primary)
         * monitor can be read and understood by the Flash runtime. This property also returns the default state
         * of color correction on the host system (usually the browser).
         * Currently the return values can be:
         * The three possible values are strings with corresponding constants in the flash.display.ColorCorrectionSupport class:"unsupported": Color correction is not available."defaultOn": Always performs color correction."defaultOff": Never performs color correction.
    
         */
        get: function () {
            //todo
            console.log("colorCorrectionSupport not implemented yet in flash/Stage");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "contentsScaleFactor", {
        get: function () {
            //todo
            console.log("contentsScaleFactor not implemented yet in flash/Stage");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "displayContextInfo", {
        get: function () {
            //todo
            console.log("displayContextInfo not implemented yet in flash/Stage");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "displayState", {
        /**
         * A value from the StageDisplayState class that specifies which display state to use. The following
         * are valid values:
         *
         *   StageDisplayState.FULL_SCREEN Sets AIR application or Flash runtime to expand the
         * stage over the user's entire screen, with keyboard input disabled.StageDisplayState.FULL_SCREEN_INTERACTIVE Sets the AIR application to expand the
         * stage over the user's entire screen, with keyboard input allowed.
         * (Not available for content running in Flash Player.)StageDisplayState.NORMAL Sets the Flash runtime back to the standard stage display mode.The scaling behavior of the movie in full-screen mode is determined by the scaleMode
         * setting (set using the Stage.scaleMode property or the SWF file's embed
         * tag settings in the HTML file). If the scaleMode property is set to noScale
         * while the application transitions to full-screen mode, the Stage width and height
         * properties are updated, and the Stage dispatches a resize event. If any other scale mode is set,
         * the stage and its contents are scaled to fill the new screen dimensions. The Stage object retains its original
         * width and height values and does not dispatch a resize event.The following restrictions apply to SWF files that play within an HTML page (not those using the stand-alone
         * Flash Player or not running in the AIR runtime):To enable full-screen mode, add the allowFullScreen parameter to the object
         * and embed tags in the HTML page that includes the SWF file, with allowFullScreen set
         * to "true", as shown in the following example:
         *
         *   <codeblock>
         * <param name="allowFullScreen" value="true" />
         * ...
         * <embed src="example.swf" allowFullScreen="true" ... >
         * </codeblock>
         * An HTML page may also use a script to generate SWF-embedding tags. You need to alter the script
         * so that it inserts the proper allowFullScreen settings. HTML pages generated by Flash Professional and
         * Flash Builder use the AC_FL_RunContent() to embed references to SWF files, and you
         * need to add the allowFullScreen parameter settings, as in the following:
         * <codeblock>
         * AC_FL_RunContent( ... "allowFullScreen", "true", ... )
         * </codeblock>
         * Full-screen mode is initiated in response to a mouse click or key press by the user; the movie cannot change
         * Stage.displayState without user input. Flash runtimes restrict keyboard input  in full-screen mode.
         * Acceptable keys include keyboard shortcuts that terminate full-screen mode and non-printing keys such as arrows, space, Shift,
         * and Tab keys. Keyboard shortcuts that terminate full-screen mode are: Escape (Windows, Linux, and Mac), Control+W (Windows),
         * Command+W (Mac), and Alt+F4.
         * A Flash runtime dialog box appears over the movie when users enter full-screen mode to inform the users they are in
         * full-screen mode and that they can press the Escape key to end full-screen mode.Starting with Flash Player 9.0.115.0, full-screen works the same in windowless mode as it does in window mode.
         * If you set the Window Mode (wmode in the HTML) to Opaque Windowless (opaque)
         * or Transparent Windowless (transparent), full-screen can be initiated,
         * but the full-screen window will always be opaque.These restrictions are not present for SWF content running in the
         * stand-alone Flash Player or in AIR. AIR supports an interactive full-screen mode which allows keyboard input.For AIR content running in full-screen mode, the system screen saver
         * and power saving options are disabled while video content is playing and until either the video stops
         * or full-screen mode is exited.On Linux, setting displayState to StageDisplayState.FULL_SCREEN or
         * StageDisplayState.FULL_SCREEN_INTERACTIVE is an asynchronous operation.
         * @throws	SecurityError Calling the displayState property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         *   Trying to set the displayState property while the settings dialog is displayed, without a user response, or
         *   if the param or embed HTML tag's allowFullScreen attribute is not set to
         *   true throws a security error.
         */
        get: function () {
            //todo
            console.log("displayState not implemented yet in flash/Stage");
            return "";
        },
        set: function (value) {
            //todo
            console.log("displayState not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "focus", {
        /**
         * The interactive object with keyboard focus; or null if focus is not set
         * or if the focused object belongs to a security sandbox to which the calling object does not
         * have access.
         * @throws	Error Throws an error if focus cannot be set to the target.
         */
        get: function () {
            //todo: any is InteractiveObject
            //console.log("focus not implemented yet in flash/Stage");
            return null;
        },
        set: function (newFocus) {
            //todo: any is InteractiveObject
            //console.log("focus not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "frameRate", {
        /**
         * Gets and sets the frame rate of the stage. The frame rate is defined as frames per second.
         * By default the rate is set to the frame rate of the first SWF file loaded. Valid range for the frame rate
         * is from 0.01 to 1000 frames per second.
         *
         *   Note: An application might not be able to follow
         * high frame rate settings, either because the target platform is not fast enough or the player is
         * synchronized to the vertical blank timing of the display device (usually 60 Hz on LCD devices).
         * In some cases, a target platform might also choose to lower the maximum frame rate if it
         * anticipates high CPU usage.For content running in Adobe AIR, setting the frameRate property of one Stage
         * object changes the frame rate for all Stage objects (used by different NativeWindow objects).
         * @throws	SecurityError Calling the frameRate property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            return this._frameRate;
        },
        set: function (value) {
            this._frameRate = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "fullScreenHeight", {
        /**
         * Returns the height of the monitor that will be used when going to full screen size, if that state
         * is entered immediately. If the user has multiple monitors, the monitor that's used is the
         * monitor that most of the stage is on at the time.
         *
         *   Note: If the user has the opportunity to move the browser from one
         * monitor to another between retrieving the value and going to full screen
         * size, the value could be incorrect. If you retrieve the value in an event handler that
         * sets Stage.displayState to StageDisplayState.FULL_SCREEN, the value will be
         * correct.This is the pixel height of the monitor and is the same as the
         * stage height would be if Stage.align is set to StageAlign.TOP_LEFT
         * and Stage.scaleMode is set to StageScaleMode.NO_SCALE.
         */
        get: function () {
            //todo
            console.log("fullScreenHeight not implemented yet in flash/Stage");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "fullScreenSourceRect", {
        /**
         * Sets the Flash runtime to scale a specific region of the stage to full-screen mode.
         * If available, the Flash runtime scales in hardware, which uses the graphics and video card on a user's computer,
         * and generally displays content more quickly than software scaling.
         *
         *   When this property is set to a valid rectangle and the displayState property is set to full-screen mode,
         * the Flash runtime scales the specified area. The actual Stage size in pixels within ActionScript does not change.
         * The Flash runtime enforces a minimum limit for the size of the rectangle to accommodate the standard "Press Esc to exit full-screen mode" message.
         * This limit is usually around 260 by 30 pixels but can vary on platform and Flash runtime version.This property can only be set when the Flash runtime is not in full-screen mode.
         * To use this property correctly, set this property first, then set the displayState property to full-screen mode, as shown in the code examples.To enable scaling, set the fullScreenSourceRect property to a rectangle object:
         * <codeblock>
         *
         *   // valid, will enable hardware scaling
         * stage.fullScreenSourceRect = new Rectangle(0,0,320,240);
         *
         *   </codeblock>
         * To disable scaling, set the fullScreenSourceRect=null in ActionScript 3.0, and undefined in ActionScript 2.0.
         * <codeblock>
         *
         *   stage.fullScreenSourceRect = null;
         *
         *   </codeblock>
         * The end user also can select within Flash Player Display Settings to turn off hardware scaling, which is enabled by default.
         * For more information, see www.adobe.com/go/display_settings.
         */
        get: function () {
            //todo
            console.log("fullScreenSourceRect not implemented yet in flash/Stage");
            return null;
        },
        set: function (Rectangle$$1) {
            //todo
            console.log("fullScreenSourceRect not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "fullScreenWidth", {
        /**
         * Returns the width of the monitor that will be used when going to full screen size, if that state
         * is entered immediately. If the user has multiple monitors, the monitor that's used is the
         * monitor that most of the stage is on at the time.
         *
         *   Note: If the user has the opportunity to move the browser from one
         * monitor to another between retrieving the value and going to full screen
         * size, the value could be incorrect. If you retrieve the value in an event handler that
         * sets Stage.displayState to StageDisplayState.FULL_SCREEN, the value will be
         * correct.This is the pixel width of the monitor and is the same as the stage width would be if
         * Stage.align is set to StageAlign.TOP_LEFT and
         * Stage.scaleMode is set to StageScaleMode.NO_SCALE.
         */
        get: function () {
            //todo
            console.log("fullScreenWidth not implemented yet in flash/Stage");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "mouseLock", {
        get: function () {
            //todo
            console.log("mouseLock not implemented yet in flash/Stage");
            return false;
        },
        set: function (value) {
            //todo
            console.log("mouseLock not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "quality", {
        /**
         * A value from the StageQuality class that specifies which rendering quality is used.
         * The following are valid values:
         *
         *   StageQuality.LOW—Low rendering quality. Graphics are not
         * anti-aliased, and bitmaps are not smoothed, but runtimes still use mip-mapping.StageQuality.MEDIUM—Medium rendering quality. Graphics are
         * anti-aliased using a 2 x 2 pixel grid, bitmap smoothing is dependent on the Bitmap.smoothing setting.
         * Runtimes use mip-mapping. This setting is suitable for movies that do not contain text.StageQuality.HIGH—High rendering quality. Graphics are anti-aliased
         * using a 4 x 4 pixel grid, and bitmap smoothing is dependent on the Bitmap.smoothing setting.
         * Runtimes use mip-mapping. This is the default rendering quality setting that Flash Player uses.StageQuality.BEST—Very high rendering quality. Graphics are
         * anti-aliased using a 4 x 4 pixel grid. If Bitmap.smoothing is true the runtime uses a high quality
         * downscale algorithm that produces fewer artifacts (however, using StageQuality.BEST with Bitmap.smoothing set to true
         * slows performance significantly and is not a recommended setting).Higher quality settings produce better rendering of scaled bitmaps. However, higher
         * quality settings are computationally more expensive. In particular, when rendering scaled video,
         * using higher quality settings can reduce the frame rate.
         * In the desktop profile of Adobe AIR, quality can be set
         * to StageQuality.BEST or StageQuality.HIGH (and the default value
         * is StageQuality.HIGH). Attempting to set it to another value has no effect
         * (and the property remains unchanged). In the moble profile of AIR, all four quality settings
         * are available. The default value on mobile devices is StageQuality.MEDIUM.For content running in Adobe AIR, setting the quality property of one Stage
         * object changes the rendering quality for all Stage objects (used by different NativeWindow objects).
         * Note: The operating system draws the device fonts,
         * which are therefore unaffected by the quality property.
         * @throws	SecurityError Calling the quality property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            //todo
            //console.log("quality not implemented yet in flash/Stage");
            return "";
        },
        set: function (value) {
            //todo
            //console.log("quality not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "scaleMode", {
        /**
         * A value from the StageScaleMode class that specifies which scale mode to use.
         * The following are valid values:
         *
         *   StageScaleMode.EXACT_FIT—The entire application is visible
         * in the specified area without trying to preserve the original aspect ratio. Distortion can occur, and the application may appear stretched or compressed.
         * StageScaleMode.SHOW_ALL—The entire application is visible
         * in the specified area without distortion while maintaining the original aspect ratio of the application.
         * Borders can appear on two sides of the application.
         * StageScaleMode.NO_BORDER—The entire application fills the specified area,
         * without distortion but possibly with some cropping, while maintaining the original aspect ratio
         * of the application.
         * StageScaleMode.NO_SCALE—The entire application is fixed, so that
         * it remains unchanged even as the size of the player window changes. Cropping might
         * occur if the player window is smaller than the content.
         * @throws	SecurityError Calling the scaleMode property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            return this._scaleMode;
        },
        set: function (value) {
            this._scaleMode = value;
            this._resizeCallbackDelegate(null);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "showDefaultContextMenu", {
        /**
         * Specifies whether to show or hide the default items in the Flash runtime
         * context menu.
         *
         *   If the showDefaultContextMenu property is set to true (the
         * default), all context menu items appear. If the showDefaultContextMenu property
         * is set to false, only the Settings and About... menu items appear.
         * @throws	SecurityError Calling the showDefaultContextMenu property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            //todo
            console.log("showDefaultContextMenu not implemented yet in flash/Stage");
            return false;
        },
        set: function (value) {
            //todo
            console.log("showDefaultContextMenu not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "softKeyboardRect", {
        /**
         * The area of the stage that is currently covered by the software keyboard.
         *
         *   The area has a size of zero (0,0,0,0) when the soft keyboard is not visible.When the keyboard opens, the softKeyboardRect is set at the time the
         * softKeyboardActivate event is dispatched. If the keyboard changes size while open,
         * the runtime updates the softKeyboardRect property and dispatches an
         * additional softKeyboardActivate event.Note: On Android, the area covered by the keyboard is estimated when
         * the operating system does not provide the information necessary to determine the exact
         * area. This problem occurs in fullscreen mode and also when the keyboard opens in response to
         * an InteractiveObject receiving focus or invoking the requestSoftKeyboard() method.
         */
        get: function () {
            //todo
            console.log("softKeyboardRect not implemented yet in flash/Stage");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "stage3Ds", {
        get: function () {
            // todo: any is stage3d
            console.log("stage3Ds not implemented yet in flash/Stage");
            return this._stage3Ds;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "stageFocusRect", {
        /**
         * Specifies whether or not objects display a glowing border when they have focus.
         * @throws	SecurityError Calling the stageFocusRect property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            //todo
            console.log("stageFocusRect not implemented yet in flash/Stage");
            return false;
        },
        set: function (on) {
            //todo
            console.log("stageFocusRect not implemented yet in flash/Stage");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "stageHeight", {
        /**
         * The current height, in pixels, of the Stage.
         *
         *   If the value of the Stage.scaleMode property is set to StageScaleMode.NO_SCALE
         * when the user resizes the window, the Stage content maintains its size while the
         * stageHeight property changes to reflect the new height size of the screen area occupied by
         * the SWF file. (In the other scale modes, the stageHeight property always reflects the original
         * height of the SWF file.) You can add an event listener for the resize event and then use the
         * stageHeight property of the Stage class to determine the actual pixel dimension of the resized
         * Flash runtime window. The event listener allows you to control how
         * the screen content adjusts when the user resizes the window.Air for TV devices have slightly different behavior than desktop devices
         * when you set the stageHeight property.
         * If the Stage.scaleMode
         * property is set to StageScaleMode.NO_SCALE and you set the stageHeight
         * property, the stage height does not change until the next
         * frame of the SWF.Note: In an HTML page hosting the SWF file, both the object and embed tags' height attributes must be set to a percentage (such as 100%), not pixels. If the
         * settings are generated by JavaScript code, the height parameter of the AC_FL_RunContent()
         * method must be set to a percentage, too. This percentage is applied to the stageHeight
         * value.
         * @throws	SecurityError Calling the stageHeight property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            return this._stageHeight;
        },
        set: function (value) {
            this._stageHeight = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "stageVideos", {
        /**
         * A list of StageVideo objects available for playing external videos.
         *
         *   You can use only a limited number of StageVideo objects at a time.
         * When a SWF begins to run, the number of available StageVideo objects depends on the platform
         * and on available hardware.
         * To use a StageVideo object, assign a member of the stageVideos Vector object to a StageVideo variable.
         * All StageVideo objects are displayed on the stage behind any display objects.
         * The StageVideo objects are displayed on the stage in the order they appear in
         * the stageVideos Vector object. For example, if the stageVideos Vector object contains
         * three entries:The StageVideo object in the 0 index of the stageVideos Vector object is
         * displayed behind all StageVideo objects.The StageVideo object at index 1 is displayed in front
         * of the StageVideo object at index 0.The StageVideo object at index 2 is displayed in front
         * of the StageVideo object at index 1.Use the StageVideo.depth property to change this ordering.Note: AIR for TV devices support only one StageVideo object.
         */
        get: function () {
            //todo: any is StageVideo
            console.log("stageVideos not implemented yet in flash/Stage");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "stageWidth", {
        /**
         * Specifies the current width, in pixels, of the Stage.
         *
         *   If the value of the Stage.scaleMode property is set to StageScaleMode.NO_SCALE
         * when the user resizes the window, the Stage content maintains its defined size while the stageWidth
         * property changes to reflect the new width size of the screen area occupied by the SWF file. (In the other scale
         * modes, the stageWidth property always reflects the original width of the SWF file.) You can add an event
         * listener for the resize event and then use the stageWidth property of the Stage class to
         * determine the actual pixel dimension of the resized Flash runtime window. The event listener allows you to control how
         * the screen content adjusts when the user resizes the window.Air for TV devices have slightly different behavior than desktop devices
         * when you set the stageWidth property.
         * If the Stage.scaleMode
         * property is set to StageScaleMode.NO_SCALE and you set the stageWidth
         * property, the stage width does not change until the next
         * frame of the SWF.Note: In an HTML page hosting the SWF file, both the object and embed tags' width attributes must be set to a percentage (such as 100%), not pixels. If the
         * settings are generated by JavaScript code, the width parameter of the AC_FL_RunContent()
         * method must be set to a percentage, too. This percentage is applied to the stageWidth
         * value.
         * @throws	SecurityError Calling the stageWidth property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            return this._stageWidth;
        },
        set: function (value) {
            this._stageWidth = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "tabChildren", {
        /**
         * Determines whether the children of the object are tab enabled. Enables or disables tabbing for the
         * children of the object. The default is true.
         * Note: Do not use the tabChildren property with Flex.
         * Instead, use the mx.core.UIComponent.hasFocusableChildren property.
         * @throws	SecurityError Referencing the tabChildren property of a Stage object throws an exception for
         *   any caller that is not in the same security sandbox as the Stage owner (the main SWF file).
         *   To avoid this, the Stage owner can grant permission to the domain of the caller by calling
         *   the Security.allowDomain() method or the Security.allowInsecureDomain() method.
         *   For more information, see the "Security" chapter in the ActionScript 3.0 Developer's Guide.
         */
        get: function () {
            //todo
            console.log("tabChildren not implemented yet in flash/Stage");
            return false;
        },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "textSnapshot", {
        /**
         * Returns a TextSnapshot object for this DisplayObjectContainer instance.
         * @throws	IllegalOperationError Referencing the textSnapshot property of a Stage object throws an
         *   exception because the Stage class does not implement this property. To avoid this, call the
         *   textSnapshot property of a display object container other than the Stage object.
         */
        get: function () {
            //todo
            console.log("textSnapshot not implemented yet in flash/Stage");
            //todo: any is flash.text.TextSnapshot
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "wmodeGPU", {
        /**
         * Indicates whether GPU compositing is available and in use. The wmodeGPU value is trueonly
         * when all three of the following conditions exist:
         * GPU compositing has been requested.GPU compositing is available.GPU compositing is in use.Specifically, the wmodeGPU property indicates one of the following:GPU compositing has not been requested or is unavailable. In this case, the wmodeGPU property value is false.GPU compositing has been requested (if applicable and available), but the environment is operating in "fallback mode"
         * (not optimal rendering) due to limitations of the content. In this case, the wmodeGPU property value is true.GPU compositing has been requested (if applicable and available), and the environment is operating in the best mode. In this case, the
         * wmodeGPU property value is also true.In other words, the wmodeGPU property identifies the capability and state of the rendering environment. For runtimes
         * that do not support GPU compositing, such as AIR 1.5.2, the value is always false, because (as stated above) the value is
         * true only when GPU compositing has been requested, is available, and is in use.The wmodeGPU property is useful to determine, at runtime, whether or not GPU compositing is in use. The value of
         * wmodeGPU indicates if your content is going to be scaled by hardware, or not, so you can present graphics at the correct size.
         * You can also determine if you're rendering in a fast path or not, so that you can adjust your content complexity accordingly.For Flash Player in a browser, GPU compositing can be requested by the value of gpu for the wmode HTML
         * parameter in the page hosting the SWF file. For other configurations, GPU compositing can be requested in the header of a SWF file
         * (set using SWF authoring tools).However, the wmodeGPU property does not identify the current rendering performance. Even if GPU compositing is "in use" the rendering
         * process might not be operating in the best mode. To adjust your content for optimal rendering, use a Flash runtime debugger version,
         * and set the DisplayGPUBlendsetting in your mm.cfg file.Note: This property is always false when referenced
         * from ActionScript that runs before the runtime performs its first rendering
         * pass.  For example, if you examine wmodeGPU from a script in Frame 1 of
         * Adobe Flash Professional, and your SWF file is the first SWF file loaded in a new
         * instance of the runtime, then the wmodeGPU value is false.
         * To get an accurate value, wait until at least one rendering pass
         * has occurred. If you write an event listener for the
         * exitFrame event of any DisplayObject, the wmodeGPU value at
         * is the correct value.
         */
        get: function () {
            //todo
            console.log("wmodeGPU not implemented yet in flash/Stage");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Stage.prototype, "accessibilityProperties", {
        //empty functions to prevent inherited actions
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
     //todo: any is AccessibilityImplementation
    Object.defineProperty(Stage.prototype, "alpha", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "blendMode", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "cacheAsBitmap", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "contextMenu", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
     // todo: any is ContextMenu
    Object.defineProperty(Stage.prototype, "filters", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "focusRect", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "loaderInfo", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "mask", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "opaqueBackground", {
        //public set mouseEnabled (value:boolean){};
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "name", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "rotation", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "rotationX", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "rotationY", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "rotationZ", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "scale9Grid", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "scaleX", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "scaleY", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "scaleZ", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "scrollRect", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "tabEnabled", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "tabIndex", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "transform", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "visible", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "x", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "y", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    Object.defineProperty(Stage.prototype, "z", {
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    
    /**
     * Calling the invalidate() method signals Flash runtimes to alert display objects
     * on the next opportunity it has to render the display list (for example, when the playhead
     * advances to a new frame). After you call the invalidate() method, when the display
     * list is next rendered, the Flash runtime sends a render event to each display object that has
     * registered to listen for the render event. You must call the invalidate()
     * method each time you want the Flash runtime to send render events.
     *
     *   The render event gives you an opportunity to make changes to the display list
     * immediately before it is actually rendered. This lets you defer updates to the display list until the
     * latest opportunity. This can increase performance by eliminating unnecessary screen updates.The render event is dispatched only to display objects that are in the same
     * security domain as the code that calls the stage.invalidate() method,
     * or to display objects from a security domain that has been granted permission via the
     * Security.allowDomain() method.
     */
    Stage.prototype.invalidate = function () {
        //todo
        console.log("invalidate not implemented yet in flash/Stage");
    };
    /**
     * Determines whether the Stage.focus property returns null for
     * security reasons.
     * In other words, isFocusInaccessible returns true if the
     * object that has focus belongs to a security sandbox to which the SWF file does not have access.
     * @return	true if the object that has focus belongs to a security sandbox to which
     *   the SWF file does not have access.
     */
    Stage.prototype.isFocusInaccessible = function () {
        //todo
        console.log("isFocusInaccessible not implemented yet in flash/Stage");
        return false;
    };
    return Stage;
}(Sprite$1));
Stage._colorMaterials = {};
Stage._textureMaterials = {};
Stage._useTextureAtlasForColors = true;

var Texture = (function () {
    function Texture() {
    }
    // todo. can probably route directly to awayjs class
    Texture.fromBitmapData = function (bitmapData) {
        console.log("fromBitmapData not implemented yet in flash/Texture");
        return null;
    };
    Texture.prototype.uploadCompressedTextureFromByteArray = function (data, byteArrayOffset, async) {
        if (async === void 0) { async = false; }
        console.log("uploadCompressedTextureFromByteArray not implemented yet in flash/Texture");
    };
    Texture.prototype.uploadFromBitmapData = function (source, miplevel) {
        if (miplevel === void 0) { miplevel = 0; }
        console.log("uploadFromBitmapData not implemented yet in flash/Texture");
    };
    Texture.prototype.uploadFromByteArray = function (data, byteArrayOffset, miplevel) {
        if (miplevel === void 0) { miplevel = 0; }
        console.log("uploadFromByteArray not implemented yet in flash/Texture");
    };
    return Texture;
}());

var FocusEvent = (function (_super) {
    __extends(FocusEvent, _super);
    function FocusEvent() {
        return _super.apply(this, arguments) || this;
    }
    Object.defineProperty(FocusEvent.prototype, "isRelatedObjectInaccessible", {
        /**
         * If true, the relatedObject property is set to null for
         * reasons related to security sandboxes.  If the nominal value of relatedObject is a reference to a
         * DisplayObject in another sandbox, relatedObject is set to
         * null unless there is permission in both directions across this sandbox boundary.  Permission is
         * established by calling Security.allowDomain() from a SWF file, or by providing
         * a policy file from the server of an image file, and setting the LoaderContext.checkPolicyFile
         * property when loading the image.
         * @langversion	3.0
         * @playerversion	Flash 10
         * @playerversion	Lite 4
         */
        get: function () {
            console.log("isRelatedObjectInaccessible not implemented yet in flash/FocusEvent");
            return false;
        },
        set: function (value) {
            console.log("isRelatedObjectInaccessible not implemented yet in flash/FocusEvent");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FocusEvent.prototype, "keyCode", {
        /**
         * The key code value of the key pressed to trigger a keyFocusChange event.
         */
        get: function () {
            console.log("keyCode not implemented yet in flash/FocusEvent");
            return 0;
        },
        set: function (value) {
            console.log("keyCode not implemented yet in flash/FocusEvent");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FocusEvent.prototype, "relatedObject", {
        /**
         * A reference to the complementary InteractiveObject instance that is affected by the
         * change in focus. For example, when a focusOut event occurs, the
         * relatedObject represents the InteractiveObject instance that has gained focus.
         * The value of this property can be null in two circumstances: if there no related object,
         * or there is a related object, but it is in a security sandbox to which you don't have access.
         * Use the isRelatedObjectInaccessible() property to determine which of these reasons applies.
         */
        get: function () {
            console.log("relatedObject not implemented yet in flash/FocusEvent");
            return null;
        },
        set: function (value) {
            console.log("relatedObject not implemented yet in flash/FocusEvent");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FocusEvent.prototype, "shiftKey", {
        /**
         * Indicates whether the Shift key modifier is activated, in which case the value is
         * true. Otherwise, the value is false. This property is
         * used only if the FocusEvent is of type keyFocusChange.
         */
        get: function () {
            console.log("shiftKey not implemented yet in flash/FocusEvent");
            return false;
        },
        set: function (value) {
            console.log("shiftKey not implemented yet in flash/FocusEvent");
        },
        enumerable: true,
        configurable: true
    });
    FocusEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/IOErrorEvent");
        return null;
    };
    FocusEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/FocusEvent");
        return "";
    };
    return FocusEvent;
}(Event));
FocusEvent.FOCUS_IN = "focusIn";
FocusEvent.FOCUS_OUT = "focusOut";
FocusEvent.KEY_FOCUS_CHANGE = "keyFocusChange";
FocusEvent.MOUSE_FOCUS_CHANGE = "mouseFocusChange";

/**
 /// @eventType	flash.events.SampleDataEvent.SAMPLE_DATA
 [Event(name="sampleData", type="flash.events.SampleDataEvent")]
 * Dispatched when a Sound object requests new audio data or when a Microphone object
 * has new audio data to provide.
 *
 *   <p class="- topic/p ">This event has two uses:</p><ul class="- topic/ul "><li class="- topic/li ">To provide dynamically generated audio data for a Sound object</li><li class="- topic/li ">To get audio data for a Microphone object</li></ul><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Dynamically generating audio using the Sound object</b> Use the
 * <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event to play dynamically generated audio. In this environment,
 * the Sound object doesn't actually contain sound data. Instead, it acts as a socket for
 * sound data that is being streamed to it through the use of the function
 * you assign as the handler for the <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event. </p><p class="- topic/p ">In your function, you use the <codeph class="+ topic/ph pr-d/codeph ">ByteArray.writeFloat()</codeph> method to write to
 * the event's <codeph class="+ topic/ph pr-d/codeph ">data</codeph>) property, which contains the sampled data you
 * want to play.</p><p class="- topic/p ">If a Sound object has not loaded an MP3 file, when you call its <codeph class="+ topic/ph pr-d/codeph ">play()</codeph> method
 * the object starts dispatching <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> events, requesting sound samples.
 * The Sound object continues to send events as the sound plays back until you stop providing data,
 * or until the <codeph class="+ topic/ph pr-d/codeph ">stop()</codeph> method of the SoundChannel object is called.</p><p class="- topic/p ">Thes latency of the event varies from platform to platform, and it could change in future
 * versions of <ph class="- topic/ph ">Flash Player or </ph>AIR. Don't depend on a specific latency.
 * Instead calculate it using <codeph class="+ topic/ph pr-d/codeph ">((SampleDataEvent.position/44.1) - SoundChannelObject.position)</codeph>.</p><p class="- topic/p ">Provide between 2048 and 8192 samples to the <codeph class="+ topic/ph pr-d/codeph ">data</codeph> property of
 * the SampleDataEvent object. For best performance, provide as many samples as possible.
 * The fewer samples you provide, the more likely it is
 * that clicks and pops will occur during playback. This behavior can differ on various platforms
 * and can occur in various situations - for example, when resizing the browser.
 * You might write code that works on one platform when you provide only 2048 samples, but that same code
 * might not work as well when run on a different platform. If you require the lowest latency possible,
 * consider making the amount of data user-selectable.</p><p class="- topic/p ">If you provide fewer than 2048 samples, tha Sound object plays the remaining samples
 * and then stops the sound as if the end of a sound file was reached, generating
 * a <codeph class="+ topic/ph pr-d/codeph ">complete</codeph> event.</p><p class="- topic/p ">You can use the <codeph class="+ topic/ph pr-d/codeph ">extract()</codeph> method of a Sound object to extract its sound data,
 * which you can then write to the dynamic stream for playback.</p><p class="- topic/p ">When you use the <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event with a Sound object, the only Sound methods that
 * are enabled are <codeph class="+ topic/ph pr-d/codeph ">extract()</codeph> and <codeph class="+ topic/ph pr-d/codeph ">play()</codeph>. Calling any other methods or properties
 * results in an "invalid call" exception. All methods and properties of the SoundChannel object
 * are still enabled.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Capturing Microphone audio</b> Use the <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event
 * to capture audio data from a microphone. When you add an event listener for the
 * <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event, the Microphone dispatches the event as audio samples
 * become available.</p><p class="- topic/p ">In the event handler function, use the <codeph class="+ topic/ph pr-d/codeph ">ByteArray.readFloat()</codeph> method to read
 * the event's <codeph class="+ topic/ph pr-d/codeph ">data</codeph>) property, which contains the sampled data. The event will contain
 * multiple samples, so you should use a <codeph class="+ topic/ph pr-d/codeph ">while</codeph> loop to read the available data:</p><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">var soundBytes:ByteArray = new ByteArray();
 * while(event.data.bytesAvailable)
 * {
     * var sample:Number = event.data.readFloat();
     * soundBytes.writeFloat(sample);
     * }</codeblock>
 */
var SampleDataEvent = (function (_super) {
    __extends(SampleDataEvent, _super);
    /**
     * Creates an event object that contains information about audio data events.
     * Event objects are passed as parameters to event listeners.
     * @param	type	The type of the event. This value is:Event.SAMPLE_DATA.
     * @param	bubbles	Determines whether the Event object participates in the bubbling stage of the event flow.
     * @param	cancelable	Determines whether the Event object can be canceled.
     * @param	theposition	The position of the data in the audio stream.
     * @param	thedata	A byte array of data.
     */
    function SampleDataEvent(type, bubbles, cancelable, theposition, thedata) {
        if (bubbles === void 0) { bubbles = false; }
        if (cancelable === void 0) { cancelable = false; }
        if (theposition === void 0) { theposition = 0; }
        if (thedata === void 0) { thedata = null; }
        return _super.call(this, type, bubbles, cancelable) || this;
    }
    Object.defineProperty(SampleDataEvent.prototype, "data", {
        /**
         * The data in the audio stream.
         */
        get: function () {
            console.log("data not implemented yet in flash/SampleDataEvent");
            return null;
        },
        set: function (thedata) {
            console.log("data not implemented yet in flash/SampleDataEvent");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SampleDataEvent.prototype, "position", {
        /**
         * The position of the data in the audio stream.
         */
        get: function () {
            console.log("position not implemented yet in flash/SampleDataEvent");
            return 0;
        },
        set: function (theposition) {
            console.log("position not implemented yet in flash/SampleDataEvent");
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Creates a copy of the SampleDataEvent object and sets each property's value to match that of the original.
     * @return	A new SampleDataEvent object with property values that match those of the original.
     */
    SampleDataEvent.prototype.clone = function () {
        console.log("clone not implemented yet in flash/SampleDataEvent");
        return null;
    };
    /**
     * Returns a string that contains all the properties of the SampleDataEvent object. The string is in the following format:
     * [SampleDataEvent type=value bubbles=value cancelable=value theposition=value thedata=value]
     * @return	A string that contains all the properties of the SampleDataEvent object.
     */
    SampleDataEvent.prototype.toString = function () {
        console.log("toString not implemented yet in flash/SampleDataEvent");
        return "";
    };
    return SampleDataEvent;
}(Event));
/**
 * Defines the value of the type property of a SampleDataEvent event object.
 * This event has the following properties:PropertyValuebubblesfalsecancelablefalse; there is no default behavior to cancel.positionThe point from which audio data is provided.
 */
SampleDataEvent.SAMPLE_DATA = "sampleData";

// todo: i think we might need to create this as real adapter too

/**
/// @eventType	flash.events.TouchEvent.TOUCH_BEGIN
[Event(name="touchBegin", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_END
[Event(name="touchEnd", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_MOVE
[Event(name="touchMove", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_OUT
[Event(name="touchOut", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_OVER
[Event(name="touchOver", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_ROLL_OUT
[Event(name="touchRollOut", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_ROLL_OVER
[Event(name="touchRollOver", type="flash.events.TouchEvent")]

/// @eventType	flash.events.TouchEvent.TOUCH_TAP
[Event(name="touchTap", type="flash.events.TouchEvent")]

 * The TouchEvent class lets you handle events on devices that detect user contact with
 * the device (such as a finger on a touch screen).
 * When a user interacts with a device such as a mobile phone or tablet with a touch screen, the user typically
 * touches the screen with his or her fingers or a pointing device. You can develop applications that respond to
 * basic touch events (such as a single finger tap) with the TouchEvent class. Create event listeners using the event types defined in this class.
 * For user interaction with multiple points of contact (such as several fingers moving across a touch screen at the same time) use
 * the related GestureEvent, PressAndTapGestureEvent, and TransformGestureEvent classes. And, use the properties and methods of these classes
 * to construct event handlers that respond to the user touching the device.
 * <p class="- topic/p ">Use the Multitouch class to determine the current environment's support for touch interaction, and to
 * manage the support of touch interaction if the current environment supports it.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b> When objects are nested on the display list, touch events target the deepest possible
 * nested object that is visible in the display list. This object is called the target node. To have a target node's
 * ancestor (an object containing the target node in the display list) receive notification of a touch event, use
 * <codeph class="+ topic/ph pr-d/codeph ">EventDispatcher.addEventListener()</codeph> on the ancestor node with the type parameter set to the specific
 * touch event you want to detect.</p>
 */
var TouchEvent = (function (_super) {
    __extends(TouchEvent, _super);
    /**
     * Creates an Event object that contains information about touch events.
     * Event objects are passed as parameters to event listeners.
     * @param	type	The type of the event. Possible values are: TouchEvent.TOUCH_BEGIN,
     *   TouchEvent.TOUCH_END, TouchEvent.TOUCH_MOVE,
     *   TouchEvent.TOUCH_OUT, TouchEvent.TOUCH_OVER,
     *   TouchEvent.TOUCH_ROLL_OUT, TouchEvent.TOUCH_ROLL_OVER,
     *   and TouchEvent.TOUCH_TAP.
     * @param	bubbles	Determines whether the Event object participates in the bubbling phase of the event flow.
     * @param	cancelable	Determines whether the Event object can be canceled.
     * @param	touchPointID	A unique identification number (as an int) assigned to the touch point.
     * @param	isPrimaryTouchPoint	Indicates whether the first point of contact is mapped to mouse events.
     * @param	localX	The horizontal coordinate at which the event occurred relative to the containing sprite.
     * @param	localY	The vertical coordinate at which the event occurred relative to the containing sprite.
     * @param	sizeX	Width of the contact area.
     * @param	sizeY	Height of the contact area.
     * @param	pressure	A value between 0.0 and 1.0 indicating force of the contact with the device.
     *   If the device does not support detecting the pressure, the value is 1.0.
     * @param	relatedObject	The complementary InteractiveObject instance that is affected by the event. For example, when a touchOut event occurs,
     *   relatedObject represents the display list object to which the pointing device now points.
     * @param	ctrlKey	On Windows or Linux, indicates whether the Ctrl key is activated. On Mac, indicates whether either the Ctrl key or the Command key is activated.
     * @param	altKey	Indicates whether the Alt key is activated (Windows or Linux only).
     * @param	shiftKey	Indicates whether the Shift key is activated.
     * @param	commandKey	(AIR only) Indicates whether the Command key is activated (Mac only). This parameter is for Adobe AIR only; do not set it for Flash Player content.
     * @param	controlKey	(AIR only) Indicates whether the Control or Ctrl key is activated. This parameter is for Adobe AIR only; do not set it for Flash Player content.

     */
    function TouchEvent(type, bubbles, cancelable, touchPointID, isPrimaryTouchPoint, localX, localY, sizeX, sizeY, pressure, relatedObject, ctrlKey, altKey, shiftKey) {
        if (bubbles === void 0) { bubbles = true; }
        if (cancelable === void 0) { cancelable = false; }
        if (touchPointID === void 0) { touchPointID = 0; }
        if (isPrimaryTouchPoint === void 0) { isPrimaryTouchPoint = false; }
        if (localX === void 0) { localX = NaN; }
        if (localY === void 0) { localY = NaN; }
        if (sizeX === void 0) { sizeX = NaN; }
        if (sizeY === void 0) { sizeY = NaN; }
        if (pressure === void 0) { pressure = NaN; }
        if (relatedObject === void 0) { relatedObject = null; }
        if (ctrlKey === void 0) { ctrlKey = false; }
        if (altKey === void 0) { altKey = false; }
        if (shiftKey === void 0) { shiftKey = false; }
        return _super.call(this, type, bubbles, cancelable) || this;
    }
    Object.defineProperty(TouchEvent.prototype, "altKey", {
        /**
         * Indicates whether the Alt key is active (true) or inactive (false).
         * Supported for Windows and Linux operating systems only.
         * @internal	Reserved in case Desktop Player wants to capture this key in a future implementation.
         *   The Option key modifier on Macintosh system must be represented using this key modifier. So far, it seems
         *   only the Windows version is hooked up.
         */
        get: function () { return false; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "ctrlKey", {
        /**
         * On Windows or Linux, indicates whether the Ctrl key is active (true) or inactive (false).
         * On Macintosh, indicates whether either the Control key or the Command key is activated.
         */
        get: function () { return false; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "isPrimaryTouchPoint", {
        /**
         * Indicates whether the first point of contact is mapped to mouse events.
         */
        get: function () { return false; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "isRelatedObjectInaccessible", {
        /**
         * If true, the relatedObject property is set to null for
         * reasons related to security sandboxes.  If the nominal value of relatedObject is a reference to a
         * DisplayObject in another sandbox, relatedObject is set to
         * null unless there is permission in both directions across this sandbox boundary. Permission is
         * established by calling Security.allowDomain() from a SWF file, or by providing
         * a policy file from the server of an image file, and setting the LoaderContext.checkPolicyFile
         * property when loading the image.
         */
        get: function () { return false; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "localX", {
        /**
         * The horizontal coordinate at which the event occurred relative to the containing sprite.
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "localY", {
        /**
         * The vertical coordinate at which the event occurred relative to the containing sprite.
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "pressure", {
        /**
         * A value between 0.0 and 1.0 indicating force of the contact with the device.
         * If the device does not support detecting the pressure, the value is 1.0.
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "relatedObject", {
        /**
         * A reference to a display list object that is related to the event. For example, when a touchOut event occurs,
         * relatedObject represents the display list object to which the pointing device now points.
         * This property applies to the touchOut, touchOver, touchRollOut, and touchRollOver events.
         * The value of this property can be null in two circumstances: if there is no related object,
         * or there is a related object, but it is in a security sandbox to which you don't have access.
         * Use the isRelatedObjectInaccessible() property to determine which of these reasons applies.
         */
        get: function () {
            return null;
        },
        set: function (value) {
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "shiftKey", {
        /**
         * Indicates whether the Shift key is active (true) or inactive
         * (false).
         */
        get: function () { return false; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "sizeX", {
        /**
         * Width of the contact area.
         * @langversion	3.0
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "sizeY", {
        /**
         * Height of the contact area.
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "stageX", {
        /**
         * The horizontal coordinate at which the event occurred in global Stage coordinates.
         * This property is calculated when the localX property is set.
         */
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "stageY", {
        /**
         * The vertical coordinate at which the event occurred in global Stage coordinates.
         * This property is calculated when the localY property is set.
         */
        get: function () { return 0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TouchEvent.prototype, "touchPointID", {
        /**
         * A unique identification number (as an int) assigned to the touch point.
         */
        get: function () { return 0; },
        set: function (value) { },
        enumerable: true,
        configurable: true
    });
    /**
     * Creates a copy of the TouchEvent object and sets the value of each property to match that of the original.
     * @return	A new TouchEvent object with property values that match those of the original.
     */
    TouchEvent.prototype.clone = function () {
        return null;
    };
    /**
     * Returns a string that contains all the properties of the TouchEvent object. The string is in the following format:
     * [TouchEvent type=value bubbles=value cancelable=value ... ]
     * @return	A string that contains all the properties of the TouchEvent object.
     */
    TouchEvent.prototype.toString = function () { return ""; };
    /**
     * Instructs Flash Player or Adobe AIR to render after processing of this event completes, if the display list has been modified.
     */
    TouchEvent.prototype.updateAfterEvent = function () {
    };
    return TouchEvent;
}(Event));
/**
 * Defines the value of the type property of a TOUCH_BEGIN touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_BEGIN = "touchBegin";
/**
 * Defines the value of the type property of a TOUCH_END touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_END = "touchEnd";
/**
 * Defines the value of the type property of a TOUCH_MOVE touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_MOVE = "touchMove";
/**
 * Defines the value of the type property of a TOUCH_OUT touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_OUT = "touchOut";
/**
 * Defines the value of the type property of a TOUCH_OVER touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_OVER = "touchOver";
/**
 * Defines the value of the type property of a TOUCH_ROLL_OUT touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_ROLL_OUT = "touchRollOut";
/**
 * Defines the value of the type property of a TOUCH_ROLL_OVER touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_ROLL_OVER = "touchRollOver";
/**
 * Defines the value of the type property of a TOUCH_TAP touch event object.
 *
 *   The dispatched TouchEvent object has the following properties:PropertyValuealtKeytrue if the Alt key is active (Windows or Linux).bubblestruecancelablefalse; there is no default behavior to cancel.commandKeytrue on the Mac if the Command key is active; false if it is inactive. Always false on Windows.controlKeytrue if the Ctrl or Control key is active; false if it is inactive.ctrlKeytrue on Windows or Linux if the Ctrl key is active. true on Mac if either the Ctrl key or the Command key is active. Otherwise, false.currentTargetThe object that is actively processing the Event
 * object with an event listener.eventPhaseThe current phase in the event flow.isRelatedObjectInaccessibletrue if the relatedObject property is set to null because of security sandbox rules.localXThe horizontal coordinate at which the event occurred relative to the containing sprite.localYThe vertical coordinate at which the event occurred relative to the containing sprite.pressureA value between 0.0 and 1.0 indicating force of the contact with the device. If the device does not support detecting the pressure, the value is 1.0.relatedObjectA reference to a display list object related to the event.shiftKeytrue if the Shift key is active; false if it is inactive.sizeXWidth of the contact area.sizeYHeight of the contact area.stageXThe horizontal coordinate at which the event occurred in global stage coordinates.stageYThe vertical coordinate at which the event occurred in global stage coordinates.targetThe InteractiveObject instance under the touching device.
 * The target is not always the object in the display list
 * that registered the event listener. Use the currentTarget
 * property to access the object in the display list that is currently processing the event.touchPointIDA unique identification number (as an int) assigned to the touch point.
 */
TouchEvent.TOUCH_TAP = "touchTap";

var ExternalInterface = (function () {
    function ExternalInterface() {
    }
    ExternalInterface.addCallback = function (methodName, instance, method) {
        console.log("addCallback not implemented yet in flash/ExternalInterface");
        return false;
    };
    ExternalInterface.call = function (methodName, parameter1) {
        console.log("methodName not implemented yet in flash/ExternalInterface");
        return null;
    };
    return ExternalInterface;
}());

var BitmapFilter = (function () {
    function BitmapFilter() {
    }
    return BitmapFilter;
}());

var DropShadowFilter = (function (_super) {
    __extends(DropShadowFilter, _super);
    function DropShadowFilter(distance, angle, color, alpha, blurX, blurY, strength, quality, inner, knockout, hideObject) {
        if (color === void 0) { color = 0xffffff; }
        if (alpha === void 0) { alpha = 1; }
        if (blurX === void 0) { blurX = 1; }
        if (blurY === void 0) { blurY = 1; }
        if (strength === void 0) { strength = 1; }
        if (quality === void 0) { quality = 1; }
        if (inner === void 0) { inner = false; }
        if (knockout === void 0) { knockout = false; }
        if (hideObject === void 0) { hideObject = false; }
        return _super.call(this) || this;
    }
    DropShadowFilter.prototype.clone = function () {
        console.log("clone not implemented yet in flash/DropShadowFilter");
        return null;
    };
    return DropShadowFilter;
}(BitmapFilter));

var GlowFilter = (function (_super) {
    __extends(GlowFilter, _super);
    function GlowFilter(color, alpha, blurX, blurY, strength, quality, inner, knockout) {
        if (color === void 0) { color = 0xffffff; }
        if (alpha === void 0) { alpha = 1; }
        if (blurX === void 0) { blurX = 1; }
        if (blurY === void 0) { blurY = 1; }
        if (strength === void 0) { strength = 1; }
        if (quality === void 0) { quality = 1; }
        if (inner === void 0) { inner = false; }
        if (knockout === void 0) { knockout = false; }
        return _super.call(this) || this;
    }
    GlowFilter.prototype.clone = function () {
        console.log("clone not implemented yet in flash/GlowFilter");
        return null;
    };
    return GlowFilter;
}(BitmapFilter));

var GradientBevelFilter = (function (_super) {
    __extends(GradientBevelFilter, _super);
    function GradientBevelFilter(distance, angle, colors, alphas, ratios, blurX, blurY, strength, quality, type, knockout) {
        return _super.call(this) || this;
    }
    GradientBevelFilter.prototype.clone = function () {
        console.log("clone not implemented yet in flash/GradientBevelFilter");
        return null;
    };
    return GradientBevelFilter;
}(BitmapFilter));

//import { NumberParseResult } from "./NumberParseResult";
/**
 * The NumberFormatter class provides locale-sensitive formatting and parsing of numeric values. It can format <codeph class="+ topic/ph pr-d/codeph ">int</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">uint</codeph>, and <codeph class="+ topic/ph pr-d/codeph ">Number</codeph> objects.
 *
 *   <p class="- topic/p ">The NumberFormatter class uses the data and functionality provided by the operating system
 * and is designed to format numbers according to the conventions
 * of a specific locale, based on the user's preferences and features supported by the user's operating system.
 * The position of the negative symbol, the decimal separator,
 * the grouping separator, the grouping pattern, and other elements within the number format can vary depending on the locale.</p><p class="- topic/p ">If the operating system supports the requested locale, the number formatting properties
 * are set according to the conventions and defaults of the requested locale.
 * If the requested locale is not available, then the properties are set according to
 * a fallback or default system locale, which can be retrieved using the <codeph class="+ topic/ph pr-d/codeph ">actualLocaleIDName</codeph> property.
 * </p><p class="- topic/p ">
 * Due to the use of the user's settings, the use of formatting patterns
 * provided by the operating system, and the use of a fallback locale when a requested locale is not supported,
 * different users can see different formatting results, even when using the same locale ID.
 * </p>
 */
var NumberFormatter = (function () {
    /**
     * Constructs a new NumberFormatter object to format numbers according to
     * the conventions of a given locale.
     *
     *   This constructor determines if the current operating system supports the requested locale ID name.
     * If it is not supported then a fallback locale is used instead.
     * If a fallback locale is used then the the lastOperationStatus property
     * indicates the type of fallback, and the actualLocaleIDName property contains
     * the name of the fallback locale ID. To format based on the user's current operating system preferences, pass the value LocaleID.DEFAULT
     * in the requestedLocaleIDName parameter to the constructor.
     * When the constructor completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERRORWhen the requested locale ID name is not available then the lastOperationStatus
     * is set to one of the following:LastOperationStatus.USING_FALLBACK_WARNINGLastOperationStatus.USING_DEFAULT_WARNINGIf this class is not supported on the current operating system, then the lastOperationStatus property is set to:LastOperationStatus.UNSUPPORTED_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in
     * the LastOperationStatus class.For details on the warnings listed above and other possible values of the
     * lastOperationStatus property see the descriptions in the LastOperationStatus class.
     * @param	requestedLocaleIDName	The preferred locale ID name to use when determining number formats.
     * @throws	TypeError if the requestedLocaleIDName is null
     */
    function NumberFormatter(requestedLocaleIDName) {
    }
    Object.defineProperty(NumberFormatter.prototype, "actualLocaleIDName", {
        /**
         * The name of the actual locale ID used by this NumberFormatter object.
         *
         *   There are three possibilities for the value of the name, depending on operating system and the
         * value of the requestedLocaleIDName parameter passed to the Collator() constructor.If the requested locale was not LocaleID.DEFAULT and
         * the operating system provides support for the requested locale,
         * then the name returned is the same as the requestedLocaleIDName property.
         * If LocaleID.DEFAULT was used as the value for the requestedLocaleIDName
         * parameter to the constructor, then the name of the current locale specified by the user's operating system is
         * used. The LocaleID.DEFAULT value preserves user's customized setting in the OS.
         * Passing an explicit value as the requestedLocaleIDName parameter does not necessarily give the
         * same result as using the LocaleID.DEFAULT even if the two locale ID names are the same.
         * The user could have customized the locale settings on their machine, and by requesting an
         * explicit locale ID name rather than using LocaleID.DEFAULT your application would not
         * retrieve those customized settings.
         */
        get: function () {
            console.log("actualLocaleIDName not implemented yet in flash/NumberFormatter");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "decimalSeparator", {
        /**
         * The decimal separator character used for formatting or parsing numbers that have a decimal part.
         *
         *   This property is initially set based on the locale that is selected when the formatter object
         * is constructed.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("decimalSeparator not implemented yet in flash/NumberFormatter");
            return "";
        },
        set: function (value) {
            console.log("decimalSeparator not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "digitsType", {
        /**
         * Defines the set of digit characters to be used when formatting numbers.
         *
         *   Different languages and regions use different sets of characters to represent the
         * digits 0 through 9.  This property defines the set of digits to be used.The value of this property represents the Unicode value for the zero digit of a decimal digit set.
         * The valid values for this property are defined in the NationalDigitsType class.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("digitsType not implemented yet in flash/NumberFormatter");
            return 0;
        },
        set: function (value) {
            console.log("digitsType not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "fractionalDigits", {
        /**
         * The maximum number of digits that can appear after the decimal separator.
         *
         *   Numbers are rounded to the number of digits specified by this property. The rounding scheme
         * varies depending on the user's operating system.When the trailingZeros property is set to true, the fractional portion of the
         * number (after the decimal point) is padded with trailing zeros until its length matches the value of this
         * fractionalDigits property.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         */
        get: function () {
            console.log("fractionalDigits not implemented yet in flash/NumberFormatter");
            return 0;
        },
        set: function (value) {
            console.log("fractionalDigits not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "groupingPattern", {
        /**
         * Describes the placement of grouping separators within the formatted number string.
         *
         *   When the useGrouping property is set to true, the groupingPattern property is used
         * to define the placement and pattern used for the grouping separator.The grouping pattern is defined as a string containing numbers separated by semicolons and optionally may end
         * with an asterisk. For example: "3;2;*". Each number in the string represents the number of digits
         * in a group. The grouping separator is placed before each group of digits. An asterisk at the end of the string
         * indicates that groups with that number of digits should be repeated for the rest of the formatted string.
         * If there is no asterisk then there are no additional groups or separators for the rest of the formatted string. The first number in the string corresponds to the first group of digits to the left of the decimal separator.
         * Subsequent numbers define the number of digits in subsequent groups to the left. Thus the string "3;2;*"
         * indicates that a grouping separator is placed after the first group of 3 digits, followed by groups of 2 digits.
         * For example: 98,76,54,321The following table shows examples of formatting the number 123456789.12 with various grouping patterns.
         * The grouping separator is a comma and the decimal separator is a period.
         * Grouping PatternSample Format3;*123,456,789.123;2;*12,34,56,789.123123456,789.12Only a limited number of grouping sizes can be defined. On some operating systems, grouping patterns can only contain
         * two numbers plus an asterisk. Other operating systems can support up to four numbers and an asterisk.
         * For patterns without an asterisk, some operating systems only support one number while others support up to three numbers.
         * If the maximum number of grouping pattern elements is exceeded, then additional elements
         * are ignored and the lastOperationStatus property is set as described below.
         * When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("groupingPattern not implemented yet in flash/NumberFormatter");
            return "";
        },
        set: function (value) {
            console.log("groupingPattern not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "groupingSeparator", {
        /**
         * The character or string used for the grouping separator.
         *
         *   The value of this property is used as the grouping separator when formatting numbers with the
         * useGrouping property set to true. This
         * property is initially set based on the locale that is selected when the formatter object
         * is constructed.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("groupingSeparator not implemented yet in flash/NumberFormatter");
            return "";
        },
        set: function (value) {
            console.log("groupingSeparator not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "lastOperationStatus", {
        /**
         * The status of previous operation that this NumberFormatter object performed.
         * The lastOperationStatus property is set whenever the constructor or a method of
         * this class is called, or another property is set. For the possible values see the description for each method.
         */
        get: function () {
            console.log("lastOperationStatus not implemented yet in flash/NumberFormatter");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "leadingZero", {
        /**
         * Specifies whether a leading zero is included in a formatted number when there are no integer digits
         * to the left of the decimal separator.
         *
         *   When this property is set to true a leading zero is included to the left of the decimal separator
         * when formatting numeric values between -1.0 and 1.0.
         * When this property is set to false a leading zero is not included.For example if the number is 0.321 and this property is set true, then the leading
         * zero is included in the formatted string. If the property is set to false, the leading zero
         * is not included. In that case the string would just include the decimal separator followed by the decimal digits,
         * like .321. The following table shows examples of how numbers are formatted based on the values of this property and
         * the related fractionalDigits and trailingZeros properties.
         * trailingZerosleadingZerofractionalDigits0.120truetrue30.1200.000falsetrue30.120truefalse3.120.000falsefalse3.120When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("leadingZero not implemented yet in flash/NumberFormatter");
            return false;
        },
        set: function (value) {
            console.log("leadingZero not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "negativeNumberFormat", {
        /**
         * A numeric value that indicates a formatting pattern for negative numbers.
         * This pattern defines the location of the negative symbol
         * or parentheses in relation to the numeric portion of the formatted number.
         *
         *   The following table summarizes the possible formats for negative numbers. When a negative number is formatted,
         * the minus sign in the format is replaced with the value of
         * the negativeSymbol property and the 'n' character is replaced with the formatted numeric value.Negative number format typeFormat0(n)1-n2- n3n-4n -When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	ArgumentError if the assigned value is not a number between 0 and 4.
         */
        get: function () {
            console.log("negativeNumberFormat not implemented yet in flash/NumberFormatter");
            return 0;
        },
        set: function (value) {
            console.log("negativeNumberFormat not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "negativeSymbol", {
        /**
         * The negative symbol to be used when formatting negative values.
         *
         *   This symbol is used with the negative number
         * format when formatting a number that is less than zero. It is not used in negative number formats that do not include
         * a negative sign (e.g. when negative numbers are enclosed in parentheses).  This property is set to a default value for the actual locale selected when this
         * formatter is constructed. It can be set with a value to override the default setting.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	MemoryError if the system cannot allocate enough internal memory.
         */
        get: function () {
            console.log("negativeSymbol not implemented yet in flash/NumberFormatter");
            return "";
        },
        set: function (value) {
            console.log("negativeSymbol not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "requestedLocaleIDName", {
        /**
         * The name of the requested locale ID that was passed to the constructor of this NumberFormatter object.
         *
         *   If the LocaleID.DEFAULT value was used then the name returned is "i-default".
         * The actual locale used can differ from the requested locale when a fallback locale is applied.
         * The name of the actual locale can be retrieved using the actualLocaleIDName property.
         */
        get: function () {
            console.log("requestedLocaleIDName not implemented yet in flash/NumberFormatter");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "trailingZeros", {
        /**
         * Specifies whether trailing zeros are included in a formatted number.
         *
         *   When this property is set to true, trailing zeros are included in the fractional part
         * of the formatted number up to the limit specified by the fractionalDigits property.
         * When this property is set to false then no trailing zeros are shown.For example if the numeric value is 123.4, and this property is set true, and the fractionalDigits property
         * is set to 3, the formatted string would show trailing zeros, like 123.400 .
         * If this property is false, trailing zeros are not included, and the string shows just the decimal
         * separator followed by the non-zero decimal digits, like 123.4 .The following table shows examples of how numeric values are formatted based on the values of this property and
         * the related fractionalDigits and leadingZero properties.
         * trailingZerosleadingZerofractionalDigits0.120truetrue30.1200.000falsetrue30.120truefalse3.120.000falsefalse3.120When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         * @throws	TypeError if this property is assigned a null value.
         */
        get: function () {
            console.log("trailingZeros not implemented yet in flash/NumberFormatter");
            return false;
        },
        set: function (value) {
            console.log("trailingZeros not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NumberFormatter.prototype, "useGrouping", {
        /**
         * Enables the use of the grouping separator when formatting numbers.
         *
         *   When the useGrouping property is set to true, digits are grouped and
         * delimited by the grouping separator character.
         * For example: 123,456,789.22When the useGrouping property is set to false, digits are not grouped or separated.
         * For example: 123456789.22The symbol to be used as a grouping separator is defined by the groupingSeparator property. The number of digits
         * between grouping separators is defined by the groupingPattern property.When this property is assigned a value and there are no errors or warnings, the lastOperationStatus property
         * is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
         * LastOperationStatus class.
         */
        get: function () {
            console.log("useGrouping not implemented yet in flash/NumberFormatter");
            return false;
        },
        set: function (value) {
            console.log("useGrouping not implemented yet in flash/NumberFormatter");
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Formats an int value.
     *
     *   This function is equivalent to the formatNumber() method except that it takes an int value.
     * If the value passed in is too large or small, such as a value greater than 1.72e308 or less than 1.72e-308, then this function returns 0.
     *
     *   When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @param	value	An int value to format.
     * @return	A formatted number string.
     * @throws	MemoryError for any internal memory allocation problems.
     */
    NumberFormatter.prototype.formatInt = function (value) {
        console.log("formatInt not implemented yet in flash/NumberFormatter");
        return "";
    };
    /**
     * Formats a Number value.
     *
     *   This function formats the number based on the property values of the formatter. If the properties are
     * not modified after the the numberFormatter object is created, the numbers are formatted
     * according to the locale specific conventions provided by the operating system for the locale identified
     * by actualLocaleIDName.  To customize the format, the properties can be altered to control specific
     * aspects of formatting a number.
     * Very large numbers and very small magnitude numbers can be formatted with this function. However, the
     * number of significant digits is limited to the precision provided by the Number object. Scientific notation
     * is not supported.
     * When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @param	value	A Number value to format.
     * @return	A formatted number string.
     * @throws	MemoryError if there are any internal memory allocation problems.
     */
    NumberFormatter.prototype.formatNumber = function (value) {
        console.log("formatNumber not implemented yet in flash/NumberFormatter");
        return "";
    };
    /**
     * Formats a uint value.
     *
     *   This function is equivalent to the formatNumber() method except that it takes a uint.
     * If the value passed in is too large, such as a value greater than 1.72e308, then this function returns 0.
     *
     *   When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @param	value	A uint value.
     * @return	A formatted number string.
     * @throws	MemoryError if there are any internal memory allocation problems.
     */
    NumberFormatter.prototype.formatUint = function (value) {
        console.log("formatUint not implemented yet in flash/NumberFormatter");
        return "";
    };
    /**
     * Lists all of the locale ID names supported by this class.
     *
     *   If this class is not supported on the current operating system, this method returns a null value.When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @return	A vector of strings containing all of the locale ID names supported by this class.
     */
    NumberFormatter.getAvailableLocaleIDNames = function () {
        console.log("getAvailableLocaleIDNames not implemented yet in flash/NumberFormatter");
        return [];
    };
    /**
     * Parses a string and returns a NumberParseResult object containing the parsed elements.
     *
     *   The NumberParseResult object contains
     * the value of the first number found in the input string, the starting index for the number within the string, and the index
     * of the first character after the number in the string. If the string does not contain a number, the value property of the NumberParseResult is set to NaN and the
     * startIndex and endIndex properties are set to the hexadecimal value 0x7fffffff.
     * This function uses the value of the decimalSeparator property to determine the portion of the number
     * that contains fractional
     * digits, and the groupingSeparator property to determine which characters are allowed within the digits of a number,
     * and the negativeNumberFormat property to control how negative values are represented. The following table identifies the result of strings parsed for the various NegativeNumberFormat values:NegativeNumberFormatInput StringResult(n)"(123)" or "( 123 )""-123"-n"-123" or "- 123""-123"- n"-123" or "- 123""-123"n-"123-" or "123 -""-123"n -"123-" or "123 -""-123"A single white space is allowed between the number and the minus sign or parenthesis.Other properties are ignored when determining a valid number. Specifically the value of the
     * digitsType property is ignored and the digits can be from any of
     * the digit sets that are enumerated in the NationalDigitsType class. The values of the groupingPattern
     * and useGrouping properties do not influence the parsing of the number.
     * If numbers are preceded or followed in the string by a plus sign '+', the plus sign is treated as
     * a character that is not part of the number.
     * This function does not parse strings containing numbers in scientific notation (e.g. 1.23e40).When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @throws	TypeError if the parseString is null
     */
    NumberFormatter.prototype.parse = function (parseString) {
        // todo: any is NumberParseResult
        console.log("parse not implemented yet in flash/NumberFormatter");
        return null;
    };
    /**
     * Parses a string that contains only digits and optional whitespace characters and returns a Number.
     * If the string does not begin
     * with a number or contains characters other than whitespace that are not part of the number, then
     * this method returns NaN. White space before or after the numeric digits is ignored. A white space
     * character is a character that has a Space Separator (Zs) property in the Unicode Character Database (see http://www.unicode.org/ucd/).
     *
     *   If the numeric digit is preceded or followed by a plus sign '+' it is treated as a non-whitespace character.
     * The return value is NaN.
     * See the description of the parse function for more information about number parsing and what constitutes
     * a valid number.
     * When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @throws	TypeError if the parseString is null
     */
    NumberFormatter.prototype.parseNumber = function (parseString) {
        console.log("parseNumber not implemented yet in flash/NumberFormatter");
        return 0;
    };
    return NumberFormatter;
}());

/**
 * The StringTools class provides locale-sensitive case conversion methods.
 *
 *   <p class="- topic/p ">In some situations the
 * conversion between uppercase and lowercase letters is not a simple mapping from one character
 * to another and instead requires language- or context-specific processing.  For example:</p><ul class="- topic/ul "><li class="- topic/li ">In Turkish and Azeri,
 * the uppercase of the dotted lowercase <b class="+ topic/ph hi-d/b ">i</b> is an uppercase dotted <b class="+ topic/ph hi-d/b ">İ</b> (U+0130).
 * Similarly the lowercase of a
 * dotless uppercase <b class="+ topic/ph hi-d/b ">I</b>, is a lowercase dotless <b class="+ topic/ph hi-d/b ">ı</b> (U+0131). </li><li class="- topic/li ">The lowercase sharp S, <b class="+ topic/ph hi-d/b ">ß</b> (U+00DF), used in German
 * is converted to uppercase double SS.</li><li class="- topic/li ">In Greek there are two representations of the
 * lowercase sigma, <b class="+ topic/ph hi-d/b ">σ</b> (U+03C3) and <b class="+ topic/ph hi-d/b ">ς</b> (U+03C2), which both convert to the single
 * uppercase sigma <b class="+ topic/ph hi-d/b ">Σ</b> (U+03A3). </li></ul><p class="- topic/p ">
 * The <codeph class="+ topic/ph pr-d/codeph ">toLowerCase()</codeph> and <codeph class="+ topic/ph pr-d/codeph ">toUpperCase()</codeph> methods of this
 * class provide this special case conversion logic.
 * </p><p class="- topic/p ">
 * Due to the use of the user's settings, the use of case conversion rules
 * provided by the operating system, and the use of a fallback locale when a requested locale is not supported,
 * different users can see different case conversion results even when using the same locale ID.
 * </p>
 */
var StringTools = (function () {
    /**
     * Constructs a new StringTools object that provides case conversion and other utilities according to
     * the conventions of a given locale.
     *
     *   This constructor determines if the current operating system supports the requested locale ID name.
     * If it is not supported then a fallback locale is used instead.
     * If a fallback locale is used then the lastOperationStatus property
     * indicates the type of fallback, and the actualLocaleIDName property contains
     * the name of the fallback locale ID. When this constructor completes successfully the lastOperationStatus property is set to:LastOperationStatus.NO_ERRORWhen the requested locale ID name is not available then the lastOperationStatus
     * is set to one of the following:LastOperationStatus.USING_FALLBACK_WARNINGLastOperationStatus.USING_DEFAULT_WARNINGOtherwise the lastOperationStatus property is set to one of the constants defined in
     * the LastOperationStatus class.
     * @param	requestedLocaleIDName	The preferred locale ID name to use when determining date or time formats.
     * @throws	ArgumentError when the requestedLocaleIDName parameter is null
     */
    function StringTools(requestedLocaleIDName) {
    }
    Object.defineProperty(StringTools.prototype, "actualLocaleIDName", {
        /**
         * The name of the actual locale ID used by this StringTools object.
         *
         *   There are three possibilities for the value of the name, depending on operating system and the
         * value of the requestedLocaleIDName parameter passed to the StringTools() constructor.If the requested locale was not LocaleID.DEFAULT and
         * the operating system provides support for the requested locale,
         * then the name returned is the same as the requestedLocaleIDName property.
         * If LocaleID.DEFAULT was used as the value for the requestedLocaleIDName
         * parameter to the constructor, then the name of the current locale specified by the user's operating system is
         * used. The LocaleID.DEFAULT value preserves user's customized setting in the OS.
         * Passing an explicit value as the requestedLocaleIDName parameter does not necessarily give the
         * same result as using the LocaleID.DEFAULT even if the two locale ID names are the same.
         * The user could have customized the locale settings on the machine, and by requesting an
         * explicit locale ID name rather than using LocaleID.DEFAULT your application would not
         * retrieve those customized settings.
         */
        get: function () {
            console.log("actualLocaleIDName not implemented yet in flash/StringTools");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringTools.prototype, "lastOperationStatus", {
        /**
         * The status of the most recent operation that this StringTools object performed.
         * The lastOperationStatus property is set whenever the constructor or a method of
         * this class is called or another property is set. For the possible values see the description for each method.
         */
        get: function () {
            console.log("lastOperationStatus not implemented yet in flash/StringTools");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StringTools.prototype, "requestedLocaleIDName", {
        /**
         * The name of the requested locale ID that was passed to the constructor of this StringTools object.
         *
         *   If the LocaleID.DEFAULT value was used then the name returned is "i-default".
         * The actual locale used can differ from the requested locale when a fallback locale is applied.
         * The name of the actual locale can be retrieved using the actualLocaleIDName property.
         */
        get: function () {
            console.log("requestedLocaleIDName not implemented yet in flash/StringTools");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Lists all of the locale ID names supported by this class.
     *
     *   If this class is not supported on the current operating system, this method returns a null value.When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @return	A vector of strings containing all of the locale ID names supported by this class.
     */
    StringTools.getAvailableLocaleIDNames = function () {
        console.log("getAvailableLocaleIDNames not implemented yet in flash/StringTools");
        return [];
    };
    /**
     * Converts a string to lowercase according to language conventions.
     * Depending on the locale, the output string length can differ from the input string length.
     *
     *   When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @param	s	A string to convert to lowercase.
     * @return	The converted lowercase string.
     * @throws	ArgumentError when  the s parameter is null.
     */
    StringTools.prototype.toLowerCase = function (s) {
        console.log("toLowerCase not implemented yet in flash/StringTools");
        return "";
    };
    /**
     * Converts a string to uppercase according to language conventions.
     * Depending on the locale, the output string length can differ from the input string length.
     *
     *   When this method is called and it completes successfully, the lastOperationStatus property is set to:LastOperationStatus.NO_ERROROtherwise the lastOperationStatus property is set to one of the constants defined in the
     * LastOperationStatus class.
     * @param	s	A string to convert to uppercase.
     * @return	The converted uppercase string.
     * @throws	ArgumentError when the s parameter is null.
     */
    StringTools.prototype.toUpperCase = function (s) {
        console.log("toUpperCase not implemented yet in flash/StringTools");
        return "";
    };
    return StringTools;
}());

/**
 * The ID3Info class contains properties that reflect ID3 metadata. You can get additional
 * metadata for MP3 files by accessing the <codeph class="+ topic/ph pr-d/codeph ">id3</codeph>
 * property of the Sound class; for example, <codeph class="+ topic/ph pr-d/codeph ">mySound.id3.TIME</codeph>.
 * For more information, see the entry for <codeph class="+ topic/ph pr-d/codeph ">Sound.id3</codeph> and
 * the ID3 tag definitions at <xref href="http://www.id3.org" class="- topic/xref ">http://www.id3.org</xref>.
 */
var ID3Info = (function () {
    function ID3Info() {
    }
    return ID3Info;
}());

/**
 * Dispatched when a sound has finished playing.
 * @eventType	flash.events.Event.SOUND_COMPLETE
 * [Event(name="soundComplete", type="flash.events.Event")]
 *
 * The SoundChannel class controls a sound in an application. Every sound
 * is assigned to a sound channel, and the application can have multiple
 * sound channels that are mixed together. The SoundChannel class contains a <codeph class="+ topic/ph pr-d/codeph ">stop()</codeph> method,
 * properties for monitoring the amplitude (volume) of the channel, and a property for assigning a
 * SoundTransform object to the channel.
 */
var SoundChannel = (function (_super) {
    __extends(SoundChannel, _super);
    function SoundChannel() {
        return _super.call(this) || this;
    }
    // for AVM1:
    SoundChannel.prototype.axCallPublicProperty = function (value1, value2) {
        return null;
    };
    SoundChannel.prototype.axGetPublicProperty = function (value) {
        return null;
    };
    SoundChannel.prototype.axSetPublicProperty = function (value, value2) {
        return null;
    };
    SoundChannel.prototype.axHasPublicProperty = function (value) {
        return null;
    };
    SoundChannel.prototype.axDeletePublicProperty = function (value) {
        return null;
    };
    SoundChannel.prototype.axGetEnumerableKeys = function () {
        return [];
    };
    Object.defineProperty(SoundChannel.prototype, "leftPeak", {
        /**
         * The current amplitude (volume) of the left channel, from 0 (silent) to 1 (full amplitude).
         */
        get: function () {
            console.log("leftPeak not implemented yet in flash/SoundChannel");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundChannel.prototype, "position", {
        /**
         * When the sound is playing, the position property indicates in milliseconds the current point
         * that is being played in the sound file. When the sound is stopped or paused, the
         * position property indicates the last point that was played in the sound file.
         *
         *   A common use case is to save the value of the position property when the
         * sound is stopped. You can resume the sound later by restarting it from that saved position.
         * If the sound is looped, position is reset to 0 at the beginning of each loop.
         */
        get: function () {
            console.log("position not implemented yet in flash/SoundChannel");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundChannel.prototype, "rightPeak", {
        /**
         * The current amplitude (volume) of the right channel, from 0 (silent) to 1 (full amplitude).
         */
        get: function () {
            console.log("rightPeak not implemented yet in flash/SoundChannel");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundChannel.prototype, "soundTransform", {
        /**
         * The SoundTransform object assigned to the sound channel. A SoundTransform object
         * includes properties for setting volume, panning, left speaker assignment, and right
         * speaker assignment.
         */
        get: function () {
            return this._sndtranform;
        },
        set: function (value) {
            if (this._sound) {
                this._sound.adaptee.volume = value.volume;
                this._sound.adaptee.pan = value.pan;
            }
            this._sndtranform = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Stops the sound playing in the channel.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     */
    SoundChannel.prototype.stop = function () {
        this._sound.stop();
    };
    return SoundChannel;
}(EventDispatcher$1));

//
// C:\Users\80prozent\AppData\Local\FlashDevelop\Apps\flexairsdk\4.6.0+25.0.0\frameworks\libs\player\18.0\playerglobal.swc\flash\media\Sound
//
/**
 * Dispatched when data is received as a load operation progresses.
 * @eventType	flash.events.ProgressEvent.PROGRESS
 [Event(name="progress", type="flash.events.Progress [EventEvent")]
 
 * Dispatched when a load operation starts.
 * @eventType	flash.events.Event.OPEN
 [Event(name="open", type="flash.events. [EventEvent")]
 
 * Dispatched when an input/output error occurs that causes a load operation to fail.
 * @eventType	flash.events.IOErrorEvent.IO_ERROR
 [Event(name="ioError", type="flash.events.IOError [EventEvent")]
 
 * Dispatched by a Sound object when ID3 data is available for an MP3 sound.
 * @eventType	flash.events.Event.ID3
 [Event(name="id3", type="flash.events. [EventEvent")]
 
 * Dispatched when data has loaded successfully.
 * @eventType	flash.events.Event.COMPLETE
 [Event(name="complete", type="flash.events. [EventEvent")]
 
 * Dispatched when the runtime requests new audio data.
 * @eventType	flash.events.SampleDataEvent.SAMPLE_DATA
 [Event(name="sampleData", type="flash.events.SampleData [EventEvent")]
 
 * The Sound class lets you work with sound in an application. The Sound class
 * lets you create a Sound object, load and play an external MP3 file into that object,
 * close the sound stream, and access
 * data about the sound, such as information about the number of bytes in the stream and
 * ID3 metadata. More detailed control of the sound is performed through the sound source —
 * the SoundChannel or Microphone object for the sound — and through the properties
 * in the SoundTransform class that control the output of the sound to the computer's speakers.
 *
 *   <p class="- topic/p ">In Flash Player 10 and later and AIR 1.5 and later, you can also use this
 * class to work with sound that is generated dynamically.
 * In this case, the Sound object uses the function you assign to a <codeph class="+ topic/ph pr-d/codeph ">sampleData</codeph> event handler to
 * poll for sound data. The sound is played as it is retrieved from a ByteArray object that
 * you populate with sound data. You can use <codeph class="+ topic/ph pr-d/codeph ">Sound.extract()</codeph> to extract sound data from a
 * Sound object,
 * after which you can manipulate it before writing it back to the stream for playback.</p><p class="- topic/p ">To control sounds that are embedded in a SWF file, use the properties in the SoundMixer class.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note</b>: The ActionScript 3.0 Sound API differs from ActionScript 2.0.
 * In ActionScript 3.0, you cannot take sound objects and arrange them in a hierarchy
 * to control their properties.</p><p class="- topic/p ">When you use this class, consider the following security model: </p><ul class="- topic/ul "><li class="- topic/li ">Loading and playing a sound is not allowed if the calling file is in a network sandbox
 * and the sound file to be loaded is local.</li><li class="- topic/li ">By default, loading and playing a sound is not allowed if the calling file is local and
 * tries to load and play a remote sound. A user must grant explicit permission to allow this type of access.</li><li class="- topic/li ">Certain operations dealing with sound are restricted. The data in a loaded sound cannot
 * be accessed by a file in a different domain unless you implement a cross-domain policy file.
 * Sound-related APIs that fall under this restriction are <codeph class="+ topic/ph pr-d/codeph ">Sound.id3</codeph>,
 * <codeph class="+ topic/ph pr-d/codeph ">SoundMixer.computeSpectrum()</codeph>, <codeph class="+ topic/ph pr-d/codeph ">SoundMixer.bufferTime</codeph>,
 * and the <codeph class="+ topic/ph pr-d/codeph ">SoundTransform</codeph> class.</li></ul><p class="- topic/p ">However, in Adobe AIR, content in the <codeph class="+ topic/ph pr-d/codeph ">application</codeph> security sandbox (content
 * installed with the AIR application) are not restricted by these security limitations.</p><p class="- topic/p ">For more information related to security, see the Flash Player Developer Center Topic:
 * <xref href="http://www.adobe.com/go/devnet_security_en" scope="external" class="- topic/xref ">Security</xref>.</p>
 */
var Sound = (function (_super) {
    __extends(Sound, _super);
    /**
     * Creates a new Sound object. If you pass a valid URLRequest object to the
     * Sound constructor, the constructor automatically calls the load() function
     * for the Sound object.
     * If you do not pass a valid URLRequest object to the Sound constructor,
     * you must call the load() function for the Sound object yourself,
     * or the stream will not load.
     *
     *   Once load() is called on a Sound object, you can't later load
     * a different sound file into that Sound object. To load a different sound file,
     * create a new Sound object.
     *
     *   In Flash Player 10 and later and AIR 1.5 and later, instead of using load(),
     * you can use the sampleData event handler to load sound dynamically into the Sound object.
     * @param	stream	The URL that points to an external MP3 file.
     * @param	context	An optional SoundLoader context object, which can define the buffer time
     *   (the minimum number of milliseconds of MP3 data to hold in the Sound object's
     *   buffer) and can specify whether the application should check for a cross-domain
     *   policy file prior to loading the sound.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     */
    function Sound(stream, context) {
        if (stream === void 0) { stream = null; }
        if (context === void 0) { context = null; }
        var _this = _super.call(this) || this;
        _this.loopsToPlay = 0;
        return _this;
        //console.log("sound is not implemented yet in flash/Sound");
    }
    Object.defineProperty(Sound.prototype, "adaptee", {
        get: function () {
            return this._adaptee;
        },
        set: function (adaptee) {
            this._adaptee = adaptee;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "bytesLoaded", {
        /**
         * Returns the currently available number of bytes in this sound object. This property is
         * usually useful only for externally loaded files.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         * @refpath
         */
        get: function () {
            console.log("bytesLoaded not implemented yet in flash/Sound");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "bytesTotal", {
        /**
         * Returns the total number of bytes in this sound object.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         * @refpath
         */
        get: function () {
            console.log("bytesTotal not implemented yet in flash/Sound");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "id3", {
        /**
         * Provides access to the metadata that is part of an MP3 file.
         *
         *   MP3 sound files can contain ID3 tags, which provide metadata about the
         * file. If an MP3 sound that you load using the Sound.load()
         * method contains ID3 tags, you can query these properties. Only ID3 tags
         * that use the UTF-8 character set are supported.Flash Player 9 and later and AIR support
         * ID3 2.0 tags,
         * specifically 2.3 and 2.4. The following tables list the standard ID3 2.0 tags
         * and the type of content the tags represent. The Sound.id3 property provides
         * access to these tags through the format
         * my_sound.id3.COMM, my_sound.id3.TIME, and so on. The first
         * table describes tags that can be accessed either through the ID3 2.0 property name or
         * the ActionScript property name. The second table describes ID3 tags that are supported but do not have
         * predefined properties in ActionScript. ID3 2.0 tagCorresponding Sound class propertyCOMMSound.id3.commentTALBSound.id3.album TCONSound.id3.genreTIT2Sound.id3.songName TPE1Sound.id3.artistTRCKSound.id3.track TYERSound.id3.year The following table describes ID3 tags that are supported but do not have
         * predefined properties in the Sound class. You access them by calling
         * mySound.id3.TFLT, mySound.id3.TIME, and so on. NOTE: None of
         * these tags are supported in Flash Lite 4.PropertyDescriptionTFLTFile typeTIMETimeTIT1Content group descriptionTIT2Title/song name/content descriptionTIT3Subtitle/description refinementTKEYInitial keyTLANLanguagesTLENLengthTMEDMedia typeTOALOriginal album/movie/show titleTOFNOriginal filenameTOLYOriginal lyricists/text writersTOPEOriginal artists/performersTORYOriginal release yearTOWNFile owner/licenseeTPE1Lead performers/soloistsTPE2Band/orchestra/accompanimentTPE3Conductor/performer refinementTPE4Interpreted, remixed, or otherwise modified byTPOSPart of a setTPUBPublisherTRCKTrack number/position in setTRDARecording datesTRSNInternet radio station nameTRSOInternet radio station ownerTSIZSizeTSRCISRC (international standard recording code)TSSESoftware/hardware and settings used for encodingTYERYearWXXXURL link frameWhen using this property, consider the Flash Player security model:The id3 property of a Sound object is always permitted for SWF files
         * that are in the same security sandbox as the sound file. For files in other sandboxes, there
         * are security checks.When you load the sound, using the load() method of the Sound class, you can
         * specify a context parameter, which is a SoundLoaderContext object. If you set the
         * checkPolicyFile  property of the SoundLoaderContext object to true, Flash Player
         * checks for a URL policy file on the server from which the sound is loaded. If a
         * policy file exists and permits access from the domain of the loading SWF file, then the file is allowed
         * to access the id3 property of the Sound object; otherwise it is not.However, in Adobe AIR, content in the application security sandbox (content
         * installed with the AIR application) are not restricted by these security limitations.For more information related to security, see the Flash Player Developer Center Topic:
         * Security.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         */
        get: function () {
            console.log("id3 not implemented yet in flash/Sound");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "isBuffering", {
        /**
         * Returns the buffering state of external MP3 files. If the value is true,
         * any playback is
         * currently suspended while the object waits for more data.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         * @refpath
         */
        get: function () {
            console.log("isBuffering not implemented yet in flash/Sound");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "isURLInaccessible", {
        /**
         * Indicates if the Sound.url property has been
         * truncated. When the isURLInaccessible value is true the
         * Sound.url value is only the domain of the final URL from which the sound loaded.
         * For example, the property is truncated if the sound is loaded from http://www.adobe.com/assets/hello.mp3,
         * and the Sound.url property has the value http://www.adobe.com.
         * The isURLInaccessible value is true only when all of the following are also true:
         *
         *   An HTTP redirect occurred while loading the sound file.The SWF file calling Sound.load() is from a different domain than
         * the sound file's final URL.The SWF file calling Sound.load() does not have permission to access
         * the sound file.  Permission is granted to access the sound file the same way permission is granted
         * for the Sound.id3 property: establish a policy file and use the SoundLoaderContext.checkPolicyFile
         * property.Note: The isURLInaccessible property was added for Flash Player 10.1 and AIR 2.0.
         * However, this property is made available to SWF files of all versions when the
         * Flash runtime supports it. So, using some authoring tools in "strict mode" causes a compilation error. To work around the error
         * use the indirect syntax mySound["isURLInaccessible"], or disable strict mode. If you are using Flash Professional CS5
         * or Flex SDK 4.1, you can use and compile this API for runtimes released before Flash Player 10.1 and AIR 2.For application content in AIR, the value of this property is always false.
         * @langversion	3.0
         * @playerversion	Flash 10.1
         * @playerversion	AIR 2
         */
        get: function () {
            console.log("isURLInaccessible not implemented yet in flash/Sound");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "length", {
        /**
         * The length of the current sound in milliseconds.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         */
        get: function () {
            console.log("length not implemented yet in flash/Sound");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Sound.prototype, "url", {
        /**
         * The URL from which this sound was loaded. This property is applicable only to Sound
         * objects that were loaded using the Sound.load() method. For
         * Sound objects that are associated with a sound asset from a SWF file's library, the
         * value of the url property is null.
         *
         *   When you first call Sound.load(), the url property
         * initially has a value of null, because the final URL is not yet known.
         * The url property will have a non-null value as soon as an
         * open event is dispatched from the Sound object.The url property contains the final, absolute URL from which a sound was
         * loaded. The value of url is usually the same as the value passed to the
         * stream parameter of Sound.load().
         * However, if you passed a relative URL to Sound.load()
         * the value of the url property represents the absolute URL.
         * Additionally, if the original URL request is redirected by an HTTP server, the value
         * of the url property reflects the final URL from which the sound file was actually
         * downloaded.  This reporting of an absolute, final URL is equivalent to the behavior of
         * LoaderInfo.url.In some cases, the value of the url property is truncated; see the
         * isURLInaccessible property for details.
         * @langversion	3.0
         * @playerversion	Flash 9
         * @playerversion	Lite 4
         */
        get: function () {
            console.log("url not implemented yet in flash/Sound");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Closes the stream, causing any download of data to cease.
     * No data may be read from the stream after the close()
     * method is called.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     * @throws	IOError The stream could not be closed, or
     *   the stream was not open.
     */
    Sound.prototype.close = function () {
        console.log("close not implemented yet in flash/Sound");
    };
    /**
     * Extracts raw sound data from a Sound object.
     *
     *   This method is designed to be used when you are working
     * with dynamically generated audio, using a function you assign
     * to the sampleData event for a different Sound object.
     * That is, you can use this method to extract sound data from a Sound object.
     * Then you can write the data to the byte array that another Sound object is using
     * to stream dynamic audio.The audio data is placed in the target byte array starting from the current position of the byte array.
     * The audio data is always exposed as 44100 Hz Stereo. The sample type is a 32-bit floating-point value,
     * which can be converted to a Number using ByteArray.readFloat().
     * @param	target	A ByteArray object in which the extracted sound samples are placed.
     * @param	length	The number of sound samples to extract.
     *   A sample contains both the left and right channels — that is, two 32-bit floating-point values.
     * @param	startPosition	The sample at which extraction begins.
     *   If you don't specify a value, the first call to Sound.extract() starts at the beginning
     *   of the sound; subsequent calls without a value for startPosition
     *   progress sequentially through the file.
     * @return	The number of samples written to the ByteArray specified in the target parameter.
     * @langversion	3.0
     * @playerversion	Flash 10
     * @playerversion	AIR 1.5
     * @refpath
     */
    Sound.prototype.extract = function (target, length, startPosition) {
        if (startPosition === void 0) { startPosition = -1; }
        console.log("extract not implemented yet in flash/Sound");
        return 0;
    };
    /**
     * Initiates loading of an external MP3 file from the specified URL. If you provide
     * a valid URLRequest object to the Sound constructor, the constructor calls
     * Sound.load() for you. You only need to call Sound.load()
     * yourself if you
     * don't pass a valid URLRequest object to the Sound constructor or you pass a null
     * value.
     *
     *   Once load() is called on a Sound object, you can't later load
     * a different sound file into that Sound object. To load a different sound file,
     * create a new Sound object.When using this method, consider the following security model:Calling Sound.load() is not allowed if the calling file is in the
     * local-with-file-system sandbox and the sound is in a network sandbox.Access from the local-trusted or local-with-networking sandbox requires permission
     * from a website through a URL policy file.You cannot connect to commonly reserved ports.
     * For a complete list of blocked ports, see "Restricting Networking APIs" in the
     * ActionScript 3.0 Developer's Guide.You can prevent a SWF file from using this method by setting the
     * allowNetworking parameter of the object and embed
     * tags in the HTML page that contains the SWF content. In Flash Player 10 and later, if you use a multipart Content-Type (for example "multipart/form-data")
     * that contains an upload (indicated by a "filename" parameter in a "content-disposition" header within the POST body),
     * the POST operation is subject to the security rules applied to uploads:The POST operation must be performed in response to a user-initiated action, such as a mouse click or key press.If the POST operation is cross-domain (the POST target is not on the same server as the SWF file
     * that is sending the POST request),
     * the target server must provide a URL policy file that permits cross-domain access.Also, for any multipart Content-Type, the syntax must be valid (according to the RFC2046 standards).
     * If the syntax appears to be invalid, the POST operation is subject to the security rules applied to uploads.In Adobe AIR, content in the application security sandbox (content
     * installed with the AIR application) are not restricted by these security limitations.For more information related to security, see the Flash Player Developer Center Topic:
     * Security.
     * @param	stream	A URL that points to an external MP3 file.
     * @param	context	An optional SoundLoader context object, which can define the buffer time
     *   (the minimum number of milliseconds of MP3 data to hold in the Sound object's
     *   buffer) and can specify whether the application should check for a cross-domain
     *   policy file prior to loading the sound.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     * @throws	IOError A network error caused the load to fail.
     * @throws	SecurityError Local untrusted files may not communicate with
     *   the Internet. You can work around this by reclassifying this file
     *   as local-with-networking or trusted.
     * @throws	SecurityError You cannot connect to commonly reserved ports.
     *   For a complete list of blocked ports, see "Restricting Networking APIs" in the
     *   ActionScript 3.0 Developer's Guide.
     * @throws	IOError The digest property of the stream object is not
     *   null. You should only set the digest property of a URLRequest object
     *   when calling the URLLoader.load() method when loading a SWZ file (an Adobe
     *   platform component).
     */
    Sound.prototype.load = function (stream, context) {
        if (context === void 0) { context = null; }
        console.log("load not implemented yet in flash/Sound");
    };
    Sound.prototype.loadCompressedDataFromByteArray = function (bytes, bytesLength) {
        console.log("loadCompressedDataFromByteArray not implemented yet in flash/Sound");
    };
    Sound.prototype.loadPCMFromByteArray = function (bytes, samples, format, stereo, sampleRate) {
        if (format === void 0) { format = "float"; }
        if (stereo === void 0) { stereo = true; }
        if (sampleRate === void 0) { sampleRate = 44100; }
        console.log("loadPCMFromByteArray not implemented yet in flash/Sound");
    };
    Sound.prototype.soundCompleteInternal = function () {
        this.loopsToPlay--;
        if (this.loopsToPlay > 0) {
            this.stop();
            this.adaptee.play(0, false);
        }
        else {
            if (this._onCompleteCallback) {
                this._onCompleteCallback();
            }
        }
    };
    /**
     * Generates a new SoundChannel object to play back the sound. This method
     * returns a SoundChannel object, which you access to stop the sound and to monitor volume.
     * (To control the volume, panning, and balance, access the SoundTransform object assigned
     * to the sound channel.)
     * @param	startTime	The initial position in milliseconds at which playback should
     *   start.
     * @param	loops	Defines the number of times a sound loops back to the startTime value
     *   before the sound channel stops playback.
     * @param	sndTransform	The initial SoundTransform object assigned to the sound channel.
     * @return	A SoundChannel object, which you use to control the sound.
     *   This method returns null if you have no sound card
     *   or if you run out of available sound channels. The maximum number of
     *   sound channels available at once is 32.
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     */
    Sound.prototype.play = function (startTime, loops, sndTransform) {
        var _this = this;
        if (startTime === void 0) { startTime = 0; }
        if (loops === void 0) { loops = 0; }
        if (sndTransform === void 0) { sndTransform = null; }
        if (loops > 1) {
        }
        if (sndTransform) {
            this.adaptee.volume = sndTransform.volume;
            this.adaptee.pan = sndTransform.pan;
        }
        loops = isNaN(loops) || loops < 1 ? 1 : Math.floor(loops);
        this.loopsToPlay = loops;
        this._adaptee.onSoundComplete = function () { return _this.soundCompleteInternal(); };
        this._adaptee.play(startTime, false);
        var newSoundChannel = new SoundChannel();
        newSoundChannel._sound = this;
        newSoundChannel.soundTransform = sndTransform;
        //console.log("play not implemented yet in flash/Sound");
        // todo: should return a flash soundchannel
        return newSoundChannel;
    };
    Sound.prototype.stop = function () {
        this._adaptee.stop();
    };
    return Sound;
}(EventDispatcher$1));

/**
 * The SoundLoaderContext class provides security checks for files that load sound.
 * SoundLoaderContext objects are passed as an argument to the constructor and the
 * <codeph class="+ topic/ph pr-d/codeph ">load()</codeph> method of the Sound class.
 *
 */
var SoundLoaderContext = (function () {
    /**
     * Creates a new sound loader context object.
     * @param	bufferTime	The number of seconds to preload a streaming sound into a buffer
     *   before the sound starts to stream.
     * @param	checkPolicyFile	Specifies whether the existence of a URL policy file
     *   should be checked upon loading the object (true) or not.
     */
    function SoundLoaderContext(bufferTime, checkPolicyFile) {
        if (bufferTime === void 0) { bufferTime = 1000; }
        if (checkPolicyFile === void 0) { checkPolicyFile = false; }
    }
    return SoundLoaderContext;
}());

/**
 * The SoundTransform class contains properties for volume and panning.
 *
 */
var SoundTransform = (function () {
    /**
     * Creates a SoundTransform object.
     * @param	vol	The volume, ranging from 0 (silent) to 1 (full volume).
     * @param	panning	The left-to-right panning of the sound, ranging from -1 (full pan left)
     *   to 1 (full pan right). A value of 0 represents no panning (center).
     * @langversion	3.0
     * @playerversion	Flash 9
     * @playerversion	Lite 4
     * @refpath
     */
    function SoundTransform(vol, panning) {
        if (vol === void 0) { vol = 1; }
        if (panning === void 0) { panning = 0; }
        this._vol = 1;
        this._pan = 0.5;
    }
    // for AVM1:
    SoundTransform.prototype.axCallPublicProperty = function (value1, value2) {
        return null;
    };
    SoundTransform.prototype.axGetPublicProperty = function (value) {
        return null;
    };
    SoundTransform.prototype.axSetPublicProperty = function (value, value2) {
        return null;
    };
    SoundTransform.prototype.axHasPublicProperty = function (value) {
        return null;
    };
    SoundTransform.prototype.axDeletePublicProperty = function (value) {
        return null;
    };
    SoundTransform.prototype.axGetEnumerableKeys = function () {
        return [];
    };
    Object.defineProperty(SoundTransform.prototype, "leftToLeft", {
        /**
         * A value, from 0 (none) to 1 (all), specifying how much of the left input is played in the
         * left speaker.
         */
        get: function () {
            console.log("leftToLeft not implemented yet in flash/SoundTransform");
            return 0;
        },
        set: function (leftToLeft) {
            console.log("leftToLeft not implemented yet in flash/SoundTransform");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundTransform.prototype, "leftToRight", {
        /**
         * A value, from 0 (none) to 1 (all), specifying how much of the left input is played in the
         * right speaker.
         */
        get: function () {
            console.log("leftToRight not implemented yet in flash/SoundTransform");
            return 0;
        },
        set: function (leftToRight) {
            console.log("leftToRight not implemented yet in flash/SoundTransform");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundTransform.prototype, "pan", {
        /**
         * The left-to-right panning of the sound, ranging from -1 (full pan left)
         * to 1 (full pan right). A value of 0 represents no panning (balanced center between
         * right and left).
         */
        get: function () {
            return this._pan;
        },
        set: function (value) {
            this._pan = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundTransform.prototype, "rightToLeft", {
        /**
         * A value, from 0 (none) to 1 (all), specifying how much of the right input is played in the
         * left speaker.
         */
        get: function () {
            console.log("rightToLeft not implemented yet in flash/SoundTransform");
            return 0;
        },
        set: function (rightToLeft) {
            console.log("rightToLeft not implemented yet in flash/SoundTransform");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundTransform.prototype, "rightToRight", {
        /**
         * A value, from 0 (none) to 1 (all), specifying how much of the right input is played in the
         * right speaker.
         */
        get: function () {
            console.log("rightToRight not implemented yet in flash/SoundTransform");
            return 0;
        },
        set: function (rightToRight) {
            console.log("rightToRight not implemented yet in flash/SoundTransform");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SoundTransform.prototype, "volume", {
        /**
         * The volume, ranging from 0 (silent) to 1 (full volume).
         */
        get: function () {
            return this._vol;
        },
        set: function (value) {
            this._vol = value;
        },
        enumerable: true,
        configurable: true
    });
    return SoundTransform;
}());

function navigateToURL(url, target) {
    window.open(url.url, "_blank");
}

var FileReference = (function (_super) {
    __extends(FileReference, _super);
    function FileReference() {
        return _super.call(this) || this;
    }
    //Displays a file-browsing dialog box that lets the user select a file to upload.
    FileReference.prototype.browse = function (typelist) {
        console.log("browse not implemented yet in flash/FileReference");
        return false;
    };
    //Starts the upload of the file to a remote server.
    FileReference.prototype.upload = function (url) {
        console.log("upload not implemented yet in flash/FileReference");
        return false;
    };
    //Starts the load of a local file selected by a user.
    FileReference.prototype.load = function () {
        console.log("load not implemented yet in flash/FileReference");
    };
    //Opens a dialog box that lets the user save a file to the local filesystem.
    FileReference.prototype.save = function (data, defaultFileName) {
        if (defaultFileName === void 0) { defaultFileName = null; }
        console.log("save not implemented yet in flash/FileReference");
    };
    //Requests permission to access filesystem.
    FileReference.prototype.requestPermission = function () {
        console.log("upload not implemented yet in flash/FileReference");
    };
    //Opens a dialog box that lets the user download a file from a remote server.
    FileReference.prototype.download = function (url, defaultFileName) {
        console.log("download not implemented yet in flash/FileReference");
        return false;
    };
    //Cancels any ongoing upload or download operation on this FileReference object.
    FileReference.prototype.cancel = function () {
        console.log("cancel not implemented yet in flash/FileReference");
    };
    return FileReference;
}(EventDispatcher$1));

var URLLoader$1 = (function (_super) {
    __extends(URLLoader$$1, _super);
    function URLLoader$$1() {
        var _this = _super.call(this) || this;
        _this._adaptee = new _awayjs_core.URLLoader();
        _this._completeCallbackDelegate = function (event) { return _this.completeCallback(event); };
        _this._progressCallbackDelegate = function (event) { return _this.progressCallback(event); };
        _this.eventMapping[Event.COMPLETE] = {
            adaptedType: _awayjs_core.URLLoaderEvent.LOAD_COMPLETE,
            addListener: _this.initListener,
            removeListener: _this.removeListener,
            callback: _this._completeCallbackDelegate
        };
        _this.eventMapping[ProgressEvent.PROGRESS] = {
            adaptedType: _awayjs_core.URLLoaderEvent.LOAD_PROGRESS,
            addListener: _this.initListener,
            removeListener: _this.removeListener,
            callback: _this._progressCallbackDelegate
        };
        return _this;
    }
    Object.defineProperty(URLLoader$$1.prototype, "data", {
        get: function () {
            return this._adaptee.data;
        },
        enumerable: true,
        configurable: true
    });
    URLLoader$$1.prototype.initListener = function (type, callback) {
        this._adaptee.addEventListener(type, callback);
    };
    URLLoader$$1.prototype.removeListener = function (type, callback) {
        this._adaptee.removeEventListener(type, callback);
    };
    URLLoader$$1.prototype.progressCallback = function (event) {
        if (event === void 0) { event = null; }
        var newEvent = new ProgressEvent(ProgressEvent.PROGRESS, null, null, event.urlLoader.bytesLoaded, event.urlLoader.bytesTotal);
        newEvent.currentTarget = this;
        this.dispatchEvent(newEvent);
    };
    URLLoader$$1.prototype.completeCallback = function (event) {
        if (event === void 0) { event = null; }
        var newEvent = new Event(Event.COMPLETE);
        newEvent.currentTarget = this;
        this.dispatchEvent(newEvent);
    };
    URLLoader$$1.prototype.load = function (request) {
        this._adaptee.load(request);
    };
    
    return URLLoader$$1;
}(EventDispatcher$1));

var SharedObject = (function () {
    function SharedObject(name) {
        this._object_name = name;
        if (typeof (Storage) !== "undefined") {
            this.data = JSON.parse(localStorage.getItem(name));
        }
        if (this.data == null) {
            console.log("no shared object found");
            this.data = {};
        }
    }
    SharedObject.getLocal = function (name, localPath, secure) {
        return new SharedObject(name);
    };
    SharedObject.getRemote = function (name, remotePath, persistence, secure) {
        return new SharedObject(name);
    };
    SharedObject.prototype.flush = function (minDiscSapce) {
        if (minDiscSapce === void 0) { minDiscSapce = 0; }
        if (typeof (Storage) !== "undefined") {
            localStorage.setItem(this._object_name, JSON.stringify(this.data));
        }
        else {
            console.log("no local storage available");
        }
    };
    SharedObject.prototype.clear = function () {
    };
    SharedObject.prototype.close = function () {
    };
    SharedObject.prototype.connect = function (myConnection, params) {
        if (params === void 0) { params = null; }
    };
    SharedObject.prototype.setDirty = function (propertyname) {
    };
    SharedObject.prototype.setProperty = function (propertyname, value) {
    };
    SharedObject.prototype.send = function (args) {
    };
    return SharedObject;
}());

/**
 * The Sample class creates objects that hold memory analysis information over distinct durations.
 * For Flash Player debugger version only.
 */
var Sample = (function () {
    function Sample() {
    }
    return Sample;
}());

/**
 * The NewObjectSample class represents objects that are created within a <codeph class="+ topic/ph pr-d/codeph ">getSamples()</codeph> stream.
 * For Flash Player debugger version only.
 */
var NewObjectSample = (function (_super) {
    __extends(NewObjectSample, _super);
    function NewObjectSample() {
        return _super.call(this) || this;
    }
    Object.defineProperty(NewObjectSample.prototype, "object", {
        /**
         * The NewObjectSample object if it still exists. If the object has been garbage collected, this property is
         * undefined and a corresponding DeleteObjectSample exists. For Flash Player debugger version only.
         */
        get: function () {
            console.log("object not implemented yet in flash/NewObjectSample");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NewObjectSample.prototype, "size", {
        /**
         * The NewObjectSample object size. If the object has been garbagecollected, this property is
         * undefined and a corresponding DeleteObjectSample exists. For FlashPlayer debugger version only.
         */
        get: function () {
            console.log("size not implemented yet in flash/NewObjectSample");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    return NewObjectSample;
}(Sample));

/**
 * The ApplicationDomain class is a container for discrete groups of class definitions.
 * Application domains are used to partition classes that are in the same security domain.
 * They allow multiple definitions of the same class to exist and allow children to reuse parent
 * definitions.
 *
 *   <p class="- topic/p ">Application domains are used when an external SWF file is loaded through the Loader class.
 * All ActionScript 3.0 definitions in the loaded SWF file are stored in the application
 * domain, which is specified by the <codeph class="+ topic/ph pr-d/codeph ">applicationDomain</codeph> property of the LoaderContext
 * object that you pass as a <codeph class="+ topic/ph pr-d/codeph ">context</codeph> parameter of the Loader object's <codeph class="+ topic/ph pr-d/codeph ">load()</codeph> or
 * <codeph class="+ topic/ph pr-d/codeph ">loadBytes()</codeph> method. The LoaderInfo object also contains an
 * <codeph class="+ topic/ph pr-d/codeph ">applicationDomain</codeph> property, which is read-only.</p><p class="- topic/p ">All code in a SWF file is defined to exist in an application domain. The current application
 * domain is where your main application runs. The system domain contains all application domains,
 * including the current domain, which means that it contains all Flash Player classes.</p><p class="- topic/p ">Every application domain, except the system domain, has an associated parent domain.
 * The parent domain of your main application's application domain is the system domain.
 * Loaded classes are defined only when their parent doesn't already define them.
 * You cannot override a loaded class definition with a newer definition.</p><p class="- topic/p ">For usage examples of application domains, see the <i class="+ topic/ph hi-d/i ">ActionScript 3.0 Developer's Guide</i>.</p><p class="- topic/p ">The <codeph class="+ topic/ph pr-d/codeph ">ApplicationDomain()</codeph> constructor function allows you to create an ApplicationDomain object.</p>
 *
 * @internal	Security considerations for application domains are discussed in the
 *   applicationDomain property entries of URLRequest and LoaderInfo.
 */
var ApplicationDomain = (function () {
    /**
     * Creates a new application domain.
     * @param	parentDomain	If no parent domain is passed in, this application domain takes the system domain as its parent.
     */
    function ApplicationDomain(parentDomain) {
        if (parentDomain === void 0) { parentDomain = null; }
        if (parentDomain == null && ApplicationDomain._currentDomain != null) {
            ApplicationDomain.currentDomain;
            parentDomain = ApplicationDomain.getSystemDomain();
        }
        this._parentDomain = parentDomain;
        this._definitions = {};
        this._font_definitions = {};
        this._audio_definitions = {};
    }
    ApplicationDomain.getSystemDomain = function () {
        if (ApplicationDomain._systemDomain == null)
            ApplicationDomain._systemDomain = new ApplicationDomain();
        return ApplicationDomain._systemDomain;
    };
    Object.defineProperty(ApplicationDomain, "currentDomain", {
        /**
         * Gets the current application domain in which your code is executing.
         * @internal	Question: Do you call System.currentDomain? or Loader.currentDomain or request.currentDomain?
         */
        get: function () {
            if (ApplicationDomain._systemDomain == null)
                ApplicationDomain._systemDomain = new ApplicationDomain();
            if (ApplicationDomain._currentDomain == null)
                ApplicationDomain._currentDomain = new ApplicationDomain(ApplicationDomain._systemDomain);
            return ApplicationDomain._currentDomain;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ApplicationDomain.prototype, "domainMemory", {
        /**
         * Gets and sets the object on which domain-global memory operations
         * will operate within this ApplicationDomain.
         */
        get: function () {
            console.log("domainMemory not implemented yet in flash/ApplicationDomain");
            return null;
        },
        set: function (mem) {
            console.log("domainMemory not implemented yet in flash/ApplicationDomain");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ApplicationDomain, "MIN_DOMAIN_MEMORY_LENGTH", {
        /**
         * Gets the minimum memory object length required to be used as
         * ApplicationDomain.domainMemory.
         */
        get: function () {
            console.log("MIN_DOMAIN_MEMORY_LENGTH not implemented yet in flash/ApplicationDomain");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ApplicationDomain.prototype, "parentDomain", {
        /**
         * Gets the parent domain of this application domain.
         */
        get: function () {
            return this._parentDomain;
        },
        enumerable: true,
        configurable: true
    });
    ApplicationDomain.prototype.addDefinition = function (name, asset) {
        this._definitions[name] = asset;
    };
    ApplicationDomain.prototype.addAudioDefinition = function (name, asset) {
        this._audio_definitions[name] = asset;
    };
    ApplicationDomain.prototype.addFontDefinition = function (name, asset) {
        this._font_definitions[name] = asset;
    };
    /**
     * Gets a public definition from the specified application domain.
     * The definition can be that of a class, a namespace, or a function.
     * @param	name	The name of the definition.
     * @return	The object associated with the definition.
     * @internal	throws SecurityError The definition belongs to a domain to which
     *   the calling code does not have access.
     * @throws	ReferenceError No public definition exists with the
     *   specified name.
     */
    ApplicationDomain.prototype.getDefinition = function (name) {
        if (this._definitions[name]) {
            var newAdapter = this._definitions[name].adapter.clone();
            if (newAdapter.adaptee.isAsset(_awayjs_scene.MovieClip)) {
                newAdapter.adaptee.currentFrameIndex = 0;
            }
            return newAdapter;
        }
        else if (this._font_definitions[name]) {
            return this._font_definitions[name];
        }
        else if (this._audio_definitions[name]) {
            var sound = new Sound();
            sound.adaptee = this._audio_definitions[name];
            //sound.adaptee.adapter=sound;
            return sound;
        }
        return null;
    };
    ApplicationDomain.prototype.getFontDefinition = function (name) {
        return this._font_definitions[name];
    };
    ApplicationDomain.prototype.getAudioDefinition = function (name) {
        var sound = new Sound();
        sound.adaptee = this._audio_definitions[name];
        //sound.adaptee.adapter=sound;
        return sound;
    };
    ApplicationDomain.prototype.getQualifiedDefinitionNames = function () {
        var allDefinitionsnames = [];
        for (var key in this._definitions) {
            if (this._definitions.hasOwnProperty(key)) {
                allDefinitionsnames[allDefinitionsnames.length] = key;
            }
        }
        return allDefinitionsnames;
    };
    /**
     * Checks to see if a public definition exists within the specified application domain.
     * The definition can be that of a class, a namespace, or a function.
     * @param	name	The name of the definition.
     * @return	A value of true if the specified definition exists; otherwise, false.
     */
    ApplicationDomain.prototype.hasDefinition = function (name) {
        return this._definitions.hasOwnProperty(name);
    };
    ApplicationDomain.prototype.hasFontDefinition = function (name) {
        return this._font_definitions.hasOwnProperty(name);
    };
    ApplicationDomain.prototype.hasAudioDefinition = function (name) {
        return this._audio_definitions.hasOwnProperty(name);
    };
    return ApplicationDomain;
}());

var Capabilities = (function () {
    function Capabilities() {
    }
    Object.defineProperty(Capabilities, "playerType", {
        get: function () {
            return "StandAlone"; //"Plugin"
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Capabilities, "touchscreenType", {
        get: function () {
            return "none"; //"Plugin"
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Capabilities, "screenDPI", {
        get: function () {
            return 0; //"Plugin"
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Capabilities, "screenResolutionX", {
        get: function () {
            return screen.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Capabilities, "screenResolutionY", {
        get: function () {
            return screen.height;
        },
        enumerable: true,
        configurable: true
    });
    return Capabilities;
}());

/**
 * Dispatched when a user has completed an
 * input method editor (IME) composition
 * and the reading string is available.
 * @eventType	flash.events.IMEEvent.IME_COMPOSITION
 * [Event(name="imeComposition", type="flash.events.IMEEvent")]

 * The IME class lets you directly manipulate the operating system's input method
 * editor (IME) in the Flash runtime application that is running on a client computer. You can
 * determine whether an IME is installed, whether or not the IME is currently enabled, and which IME is
 * enabled. You can disable or enable the IME in the application, and you can perform other limited
 * functions, depending on the operating system.
 *
 *   <p class="- topic/p "><i class="+ topic/ph hi-d/i ">AIR profile support:</i> This feature is supported
 * on desktop operating systems, but it is not supported on all mobile devices. It is also not supported on
 * AIR for TV devices. You can test for support at run time using the <codeph class="+ topic/ph pr-d/codeph ">IME.isSupported</codeph> property. See
 * <xref href="http://help.adobe.com/en_US/air/build/WS144092a96ffef7cc16ddeea2126bb46b82f-8000.html" class="- topic/xref ">
 * AIR Profile Support</xref> for more information regarding API support across multiple profiles.</p><p class="- topic/p ">IMEs let users type non-ASCII text characters in multibyte languages
 * such as Chinese, Japanese, and Korean. For more information on working with IMEs, see the
 * documentation for the operating system for which you are developing applications.
 * For additional resources, see the following websites:
 * <ul class="- topic/ul "><li class="- topic/li "><xref href="http://www.microsoft.com/globaldev/default.mspx" scope="external" class="- topic/xref ">http://www.microsoft.com/globaldev/default.mspx</xref></li><li class="- topic/li "><xref href="http://developer.apple.com/documentation/" scope="external" class="- topic/xref ">http://developer.apple.com/documentation/</xref></li><li class="- topic/li "><xref href="http://java.sun.com" scope="external" class="- topic/xref ">http://java.sun.com</xref></li></ul></p><p class="- topic/p ">If an IME is not active on the user's computer, calls to IME methods or properties,
 * other than <codeph class="+ topic/ph pr-d/codeph ">Capabilities.hasIME</codeph>, will fail. Once you manually activate an IME, subsequent ActionScript
 * calls to IME methods and properties will work as expected. For example, if you are using a
 * Japanese IME, it must be activated before any IME method or property is called.</p><p class="- topic/p ">The following table shows the platform coverage of this class:</p><adobetable class="innertable"><tgroup cols="4" class="- topic/tgroup "><thead class="- topic/thead "><row class="- topic/row "><entry class="- topic/entry ">Capability</entry><entry class="- topic/entry ">Windows</entry><entry class="- topic/entry ">Mac OSX</entry><entry class="- topic/entry ">Linux</entry></row></thead><tbody class="- topic/tbody "><row class="- topic/row "><entry class="- topic/entry ">Determine whether the IME is installed: <codeph class="+ topic/ph pr-d/codeph ">Capabilities.hasIME</codeph></entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry></row><row class="- topic/row "><entry class="- topic/entry ">Set IME on or off: <codeph class="+ topic/ph pr-d/codeph ">IME.enabled</codeph></entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry></row><row class="- topic/row "><entry class="- topic/entry ">Find out whether IME is on or off: <codeph class="+ topic/ph pr-d/codeph ">IME.enabled</codeph></entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes</entry></row><row class="- topic/row "><entry class="- topic/entry ">Get or set IME conversion mode: <codeph class="+ topic/ph pr-d/codeph ">IME.conversionMode</codeph></entry><entry class="- topic/entry ">Yes</entry><entry class="- topic/entry ">Yes ~~~~</entry><entry class="- topic/entry ">No</entry></row><row class="- topic/row "><entry class="- topic/entry ">Send IME the string to be converted: <codeph class="+ topic/ph pr-d/codeph ">IME.setCompositionString()</codeph></entry><entry class="- topic/entry ">Yes ~~</entry><entry class="- topic/entry ">No</entry><entry class="- topic/entry ">No</entry></row><row class="- topic/row "><entry class="- topic/entry ">Get from IME the original string before conversion: <codeph class="+ topic/ph pr-d/codeph ">System.ime.addEventListener()</codeph></entry><entry class="- topic/entry ">Yes ~~</entry><entry class="- topic/entry ">No</entry><entry class="- topic/entry ">No</entry></row><row class="- topic/row "><entry class="- topic/entry ">Send request to convert to IME: <codeph class="+ topic/ph pr-d/codeph ">IME.doConversion()</codeph></entry><entry class="- topic/entry ">Yes ~~</entry><entry class="- topic/entry ">No</entry><entry class="- topic/entry ">No</entry></row></tbody></tgroup></adobetable><p class="- topic/p ">~~ Not all Windows IMEs support all of these operations. The only IME
 * that supports them all is the Japanese IME.</p><p class="- topic/p ">~~~~ On the Macintosh, only the Japanese IME supports these methods, and third-party IMEs do not support them.</p><p class="- topic/p ">The ActionScript 3.0 version of this class does not support Macintosh Classic.</p>
 */
var IME = (function (_super) {
    __extends(IME, _super);
    function IME() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IME, "conversionMode", {
        /**
         * The conversion mode of the current IME.
         * Possible values are IME mode string constants that indicate the conversion mode:
         * ALPHANUMERIC_FULLALPHANUMERIC_HALFCHINESEJAPANESE_HIRAGANAJAPANESE_KATAKANA_FULLJAPANESE_KATAKANA_HALFKOREANUNKNOWN (read-only value; this value cannot be set)
         * @throws	Error A set attempt was not successful.
         */
        get: function () {
            console.log("conversionMode not implemented yet in flash/IME");
            return "";
        },
        set: function (mode) {
            console.log("conversionMode not implemented yet in flash/IME");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IME, "enabled", {
        /**
         * Indicates whether the system IME is enabled (true) or disabled (false).
         * An enabled IME performs multibyte input; a disabled IME performs alphanumeric input.
         * @throws	Error A set attempt was not successful.
         */
        get: function () {
            console.log("enabled not implemented yet in flash/IME");
            return false;
        },
        set: function (enabled) {
            console.log("enabled not implemented yet in flash/IME");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IME, "isSupported", {
        /**
         * The isSupported property is set to true if the IME class is
         * available on the current platform, otherwise it is set to false.
         */
        get: function () {
            console.log("isSupported not implemented yet in flash/IME");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Causes the runtime to abandon any composition that is in progress. Call this method when the user clicks
     * outside of the composition area or when the interactive object that has focus is being destroyed or reset.
     * The runtime confirms the composition by calling confirmComposition() in the client. The
     * runtime also resets the IME to inform the operating system that the composition has been abandoned.
     */
    IME.compositionAbandoned = function () {
        console.log("compositionAbandoned not implemented yet in flash/IME");
    };
    /**
     * Call this method when the selection within the composition has been updated, either interactively or
     * programmatically.
     * @param	start	Specifies the offset in bytes of the start of the selection.
     * @param	end	Specifies the offset in bytes of the end of the selection.
     */
    IME.compositionSelectionChanged = function (start, end) {
        console.log("compositionSelectionChanged not implemented yet in flash/IME");
    };
    /**
     * Instructs the IME to select the first candidate for the current composition string.
     * @throws	Error The call was not successful.
     */
    IME.doConversion = function () {
        console.log("doConversion not implemented yet in flash/IME");
    };
    /**
     * Sets the IME composition string. When this string is set, the user
     * can select IME candidates before committing the result to the text
     * field that currently has focus.
     * If no text field has focus, this method fails and throws an error.
     * @param	composition	The string to send to the IME.
     * @throws	Error The call is not successful.
     */
    IME.setCompositionString = function (composition) {
        console.log("setCompositionString not implemented yet in flash/IME");
    };
    return IME;
}(EventDispatcher$1));

var LoaderContext = (function () {
    function LoaderContext(checkPolicyFile, applicationDomain, securityDomain) {
        if (checkPolicyFile === void 0) { checkPolicyFile = false; }
        if (applicationDomain === void 0) { applicationDomain = null; }
        if (securityDomain === void 0) { securityDomain = null; }
        this._applicationDomain = applicationDomain;
    }
    Object.defineProperty(LoaderContext.prototype, "applicationDomain", {
        get: function () {
            return this._applicationDomain;
        },
        set: function (value) {
            this._applicationDomain = value;
        },
        enumerable: true,
        configurable: true
    });
    return LoaderContext;
}());

var SecurityDomain = (function () {
    function SecurityDomain() {
    }
    return SecurityDomain;
}());

/**
 * The System class contains properties related to local settings and operations. Among these are <ph class="- topic/ph ">
 * settings for camers and microphones, operations with shared objects and</ph> the use of the Clipboard.
 *
 *   <p class="- topic/p ">Additional properties and methods are in other classes within the flash.system package:
 * the Capabilities class, <ph class="- topic/ph ">the IME class,</ph> and the
 * Security class.</p><p class="- topic/p ">This class contains only static methods and properties. You cannot
 * create new instances of the System class.</p>
 */
var System = (function () {
    function System() {
    }
    Object.defineProperty(System, "freeMemory", {
        /**
         * The amount of memory (in bytes) that is allocated to
         * Adobe® Flash® Player or
         * Adobe® AIR® and that is not in use. This unused portion of
         * allocated memory (System.totalMemory) fluctuates as garbage collection takes place.
         * Use this property to monitor garbage collection.
         */
        get: function () {
            console.log("freeMemory not implemented yet in flash/System");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "ime", {
        /**
         * The currently installed system IME.
         * To register for imeComposition events, call
         * addEventListener() on this instance.
         */
        get: function () {
            console.log("ime not implemented yet in flash/System");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "privateMemory", {
        /**
         * The entire amount of memory (in bytes) used by an application. This is the amount of resident private memory for the entire process.
         *
         *   AIR developers should use this property to determine the entire memory consumption of an application.For Flash Player, this includes the memory used by the container application,
         * such as the web browser.
         */
        get: function () {
            console.log("privateMemory not implemented yet in flash/System");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "processCPUUsage", {
        get: function () {
            console.log("processCPUUsage not implemented yet in flash/System");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "totalMemory", {
        /**
         * The amount of memory (in bytes) currently in use that has been directly allocated by
         * Flash Player or AIR.
         *
         *   This property does not return all memory used by an Adobe AIR application or by
         * the application (such as a browser) containing Flash Player content. The browser or
         * operating system may consume other memory. The System.privateMemory property reflects all memory used by
         * an application.If the amount of memory allocated is greater than the maximum value for a uint object (uint.MAX_VALUE,
         * or 4,294,967,295), then this property is set to 0. The System.totalMemoryNumber property allows
         * larger values.
         */
        get: function () {
            console.log("totalMemory not implemented yet in flash/System");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "totalMemoryNumber", {
        /**
         * The amount of memory (in bytes) currently in use that has been directly allocated by
         * Flash Player or AIR.
         *
         *   This property is expressed as a Number, which allows higher values than the
         * System.totalMemory property, which is of type int.This property does not return all memory used by an Adobe AIR application or by
         * the application (such as a browser) containing Flash Player content. The browser or
         * operating system may consume other memory. The System.privateMemory property reflects all memory used by
         * an application.
         */
        get: function () {
            console.log("totalMemoryNumber not implemented yet in flash/System");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "useCodePage", {
        /**
         * A Boolean value that determines which code page to use to interpret external text files.
         * When the property is set to false, external text files are interpretted as Unicode.
         * (These files must be encoded as Unicode when you save them.) When the property is set to
         * true, external text files are interpretted using the traditional code page of the
         * operating system running the application. The default value of useCodePage is false.
         *
         *   Text that you load as an external file (using Loader.load(), the URLLoader class or
         * URLStream) must have been saved as Unicode in order for the application to recognize it
         * as Unicode. To encode external files as Unicode, save the files in an application that
         * supports Unicode, such as Notepad on Windows.If you load external text files that are not Unicode-encoded, set useCodePage to true.
         * Add the following as the first line of code of the file that
         * is loading the data (for Flash Professional, add it to the first frame):System.useCodePage = true;When this code is present, the application interprets external text
         * using the traditional code page of the operating system.
         * For example, this is generally CP1252 for an English Windows operating
         * system and Shift-JIS for a Japanese operating system.If you set useCodePage to true,
         * Flash Player 6 and later treat text as Flash Player 5 does. (Flash Player 5
         * treated all text as if it were in the traditional code page of the operating
         * system running the player.)If you set useCodePage to true, remember that the
         * traditional code page of the operating system running the application must include
         * the characters used in your external text file in order to display your text.
         * For example, if you load an external text file that contains Chinese characters,
         * those characters cannot display on a system that uses the CP1252 code page because
         * that code page does not include Chinese characters.To ensure that users on all platforms can view external text files used in your
         * application, you should encode all external text files as Unicode and leave
         * useCodePage set to false. This way, the application
         * (Flash Player 6 and later, or AIR) interprets the text as Unicode.
         */
        get: function () {
            console.log("useCodePage not implemented yet in flash/System");
            return false;
        },
        set: function (value) {
            console.log("useCodePage not implemented yet in flash/System");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(System, "vmVersion", {
        get: function () {
            console.log("vmVersion not implemented yet in flash/System");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Makes the specified XML object immediately available for garbage collection.
     * This method will remove parent and child connections between all the nodes
     * for the specified XML node.
     * @param	node	XML reference that should be made available for garbage collection.
     */
    System.disposeXML = function (node) {
        console.log("disposeXML not implemented yet in flash/System");
    };
    /**
     * Closes Flash Player.
     *
     *   For the standalone Flash Player debugger version only.AIR applications should call the NativeApplication.exit() method to exit the application.
     * @param	code	A value to pass to the operating system. Typically, if
     *   the process exits normally, the value is 0.
     */
    System.exit = function (code) {
        console.log("exit not implemented yet in flash/System");
    };
    /**
     * Forces the garbage collection process.
     *
     *   For the Flash Player debugger version and AIR applications only.
     * In an AIR application, the System.gc() method is only enabled in content running in the AIR Debug Launcher
     * (ADL) or, in an installed applcation, in content in the application security sandbox.
     */
    System.gc = function () {
        console.log("gc not implemented yet in flash/System");
    };
    /**
     * Pauses Flash Player or the AIR Debug Launcher (ADL).
     * After calling this method, nothing in the application continues except the delivery of Socket events.
     *
     *   For the Flash Player debugger version or the AIR Debug Launcher (ADL) only.
     */
    System.pause = function () {
        console.log("pause not implemented yet in flash/System");
    };
    System.pauseForGCIfCollectionImminent = function (imminence) {
        if (imminence === void 0) { imminence = 0.75; }
        console.log("pauseForGCIfCollectionImminent not implemented yet in flash/System");
    };
    /**
     * Resumes the application after calling System.pause().
     *
     *   For the Flash Player debugger version or the AIR Debug Launcher (ADL) only.
     */
    System.resume = function () {
        console.log("resume not implemented yet in flash/System");
    };
    /**
     * Replaces the contents of the Clipboard with a specified text string. This method works from any security
     * context when called as a result of a user event (such as a keyboard or input device event handler).
     *
     *   This method is provided for SWF content running in Flash Player 9. It allows only adding
     * String content to the Clipboard.Flash Player 10 content and content in the application security sandbox in an AIR application can call
     * the Clipboard.setData() method.
     * @param	string	A plain-text string of characters to put on the system Clipboard, replacing its current contents (if any).
     */
    System.setClipboard = function (string) {
        console.log("setClipboard not implemented yet in flash/System");
    };
    return System;
}());

//
// C:\Users\80prozent\AppData\Local\FlashDevelop\Apps\flexairsdk\4.6.0+25.0.0\frameworks\libs\player\18.0\playerglobal.swc\flash\text\StyleSheet
//
/**
 * The StyleSheet class lets you create a StyleSheet object that contains text
 * formatting rules for font size, color, and other styles. You can then apply
 * styles defined by a style sheet to a TextField object that contains HTML- or
 * XML-formatted text. The text in the TextField object is automatically
 * formatted according to the tag styles defined by the StyleSheet object.
 * You can use text styles to define new formatting tags, redefine built-in HTML
 * tags, or create style classes that you can apply to certain HTML tags.
 *
 *   <p class="- topic/p ">To apply styles to a TextField object, assign the StyleSheet
 * object to a TextField object's <codeph class="+ topic/ph pr-d/codeph ">styleSheet</codeph> property.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b> A text field with a style sheet is not editable. In other words, a text field with the <codeph class="+ topic/ph pr-d/codeph ">type</codeph> property set to <codeph class="+ topic/ph pr-d/codeph ">TextFieldType.INPUT</codeph> applies the StyleSheet to the default text for the text field, but the content will no longer be editable by the user. Consider using the TextFormat class to assign styles to input text fields.</p><p class="- topic/p ">Flash Player supports a subset of properties in the original CSS1 specification
 * (<xref href="http://www.w3.org/TR/REC-CSS1" scope="external" class="- topic/xref ">www.w3.org/TR/REC-CSS1</xref>).
 * The following table shows the supported Cascading Style Sheet (CSS) properties and values, as well as their corresponding
 * ActionScript property names. (Each ActionScript property name is derived from the corresponding
 * CSS property name; if the name contains a hyphen, the hyphen is omitted and the subsequent character is capitalized.)</p><adobetable class="innertable"><tgroup cols="3" class="- topic/tgroup "><thead class="- topic/thead "><row class="- topic/row "><entry class="- topic/entry ">CSS property</entry><entry class="- topic/entry ">ActionScript property</entry><entry class="- topic/entry ">Usage and supported values</entry></row></thead><tbody class="- topic/tbody "><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">color</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">color</codeph></entry><entry class="- topic/entry ">Only hexadecimal color values are supported. Named colors (such as <codeph class="+ topic/ph pr-d/codeph ">blue</codeph>)
 * are not supported. Colors are written in the following format: <codeph class="+ topic/ph pr-d/codeph ">#FF0000</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">display</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">display</codeph></entry><entry class="- topic/entry ">Supported values are <codeph class="+ topic/ph pr-d/codeph ">inline</codeph>, <codeph class="+ topic/ph pr-d/codeph ">block</codeph>, and <codeph class="+ topic/ph pr-d/codeph ">none</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">font-family</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">fontFamily</codeph></entry><entry class="- topic/entry ">A comma-separated list of fonts to use, in descending order of desirability. Any font
 * family name can be used. If you specify a generic font name, it is converted to an
 * appropriate device font. The following font conversions are available: <codeph class="+ topic/ph pr-d/codeph ">mono</codeph> is
 * converted to <codeph class="+ topic/ph pr-d/codeph ">_typewriter</codeph>, <codeph class="+ topic/ph pr-d/codeph ">sans-serif</codeph> is converted to
 * <codeph class="+ topic/ph pr-d/codeph ">_sans</codeph>, and <codeph class="+ topic/ph pr-d/codeph ">serif</codeph> is converted to <codeph class="+ topic/ph pr-d/codeph ">_serif</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">font-size</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">fontSize</codeph></entry><entry class="- topic/entry ">Only the numeric part of the value is used. Units (px, pt) are not parsed; pixels and points
 * are equivalent.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">font-style</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">fontStyle</codeph></entry><entry class="- topic/entry ">Recognized values are <codeph class="+ topic/ph pr-d/codeph ">normal</codeph> and <codeph class="+ topic/ph pr-d/codeph ">italic</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">font-weight</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">fontWeight</codeph></entry><entry class="- topic/entry ">Recognized values are <codeph class="+ topic/ph pr-d/codeph ">normal</codeph> and <codeph class="+ topic/ph pr-d/codeph ">bold</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">kerning</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">kerning</codeph></entry><entry class="- topic/entry ">Recognized values are <codeph class="+ topic/ph pr-d/codeph ">true</codeph> and <codeph class="+ topic/ph pr-d/codeph ">false</codeph>.
 * Kerning is supported for embedded fonts only. Certain fonts, such as Courier New, do not support kerning.
 * The kerning property is only supported in SWF files created in Windows, not in SWF files created on the
 * Macintosh. However, these SWF files can be played in non-Windows versions of Flash Player and the kerning
 * still applies.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">leading</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">leading</codeph></entry><entry class="- topic/entry ">The amount of space that is uniformly distributed between lines. The value specifies the
 * number of pixels that are added after each line. A negative value condenses the space
 * between lines. Only the numeric part of the value is used. Units (px, pt) are not parsed;
 * pixels and points are equivalent.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">letter-spacing</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">letterSpacing</codeph></entry><entry class="- topic/entry ">The amount of space that is uniformly distributed between characters.
 * The value specifies the number of pixels that are added after each
 * character. A negative value condenses the space between characters. Only the numeric part of the
 * value is used. Units (px, pt) are not parsed; pixels and points are equivalent.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">margin-left</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">marginLeft</codeph></entry><entry class="- topic/entry ">Only the numeric part of the value is used. Units (px, pt) are not parsed; pixels and points
 * are equivalent. </entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">margin-right</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">marginRight</codeph></entry><entry class="- topic/entry ">Only the numeric part of the value is used. Units (px, pt) are not parsed; pixels and
 * points are equivalent.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">text-align</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">textAlign</codeph></entry><entry class="- topic/entry ">Recognized values are <codeph class="+ topic/ph pr-d/codeph ">left</codeph>, <codeph class="+ topic/ph pr-d/codeph ">center</codeph>, <codeph class="+ topic/ph pr-d/codeph ">right</codeph>, and
 * <codeph class="+ topic/ph pr-d/codeph ">justify</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">text-decoration</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">textDecoration</codeph></entry><entry class="- topic/entry ">Recognized values are <codeph class="+ topic/ph pr-d/codeph ">none</codeph> and <codeph class="+ topic/ph pr-d/codeph ">underline</codeph>.</entry></row><row class="- topic/row "><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">text-indent</codeph></entry><entry class="- topic/entry "><codeph class="+ topic/ph pr-d/codeph ">textIndent</codeph></entry><entry class="- topic/entry ">Only the numeric part of the value is used. Units (px, pt) are not parsed; pixels and
 * points are equivalent. </entry></row></tbody></tgroup></adobetable><p class="- topic/p "><ph outputclass="flexonly" class="- topic/ph ">You can use the StyleSheet class to perform low-level text rendering.
 * However, in Flex, you typically use the Label, Text, TextArea, and TextInput controls to process text.</ph></p>
 *
 */
var StyleSheet = (function (_super) {
    __extends(StyleSheet, _super);
    /**
     * Creates a new StyleSheet object.
     */
    function StyleSheet() {
        return _super.call(this) || this;
    }
    Object.defineProperty(StyleSheet.prototype, "styleNames", {
        /**
         * An array that contains the names (as strings) of all of the styles registered
         * in this style sheet.
         */
        get: function () {
            console.log("styleNames not implemented yet in flash/Stylesheet");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Removes all styles from the style sheet object.
     */
    StyleSheet.prototype.clear = function () {
        console.log("clear not implemented yet in flash/Stylesheet");
    };
    /**
     * Returns a copy of the style object associated with the style named styleName.
     * If there is no style object associated with styleName,
     * null is returned.
     * @param	styleName	A string that specifies the name of the style to retrieve.
     * @return	An object.
     */
    StyleSheet.prototype.getStyle = function (styleName) {
        console.log("getStyle not implemented yet in flash/Stylesheet");
        return null;
    };
    /**
     * Parses the CSS in CSSText and loads the style sheet with it. If a style in
     * CSSText is already in styleSheet, the properties in
     * styleSheet are retained, and only the ones in CSSText
     * are added or changed in styleSheet.
     *
     *   To extend the native CSS parsing capability, you can override this method by creating a subclass
     * of the StyleSheet class.
     * @param	CSSText	The CSS text to parse (a string).
     */
    StyleSheet.prototype.parseCSS = function (CSSText) {
        console.log("parseCSS not implemented yet in flash/Stylesheet");
    };
    /**
     * Adds a new style with the specified name to the style sheet object.
     * If the named style does not already exist in the style sheet, it is added.
     * If the named style already exists in the style sheet, it is replaced.
     * If the styleObject parameter is null, the named style is removed.
     *
     *   Flash Player creates a copy of the style object that you pass to this method.For a list of supported styles, see the table in the description for the StyleSheet class.
     * @param	styleName	A string that specifies the name of the style to add to the style sheet.
     * @param	styleObject	An object that describes the style, or null.
     */
    StyleSheet.prototype.setStyle = function (styleName, styleObject) {
        console.log("setStyle not implemented yet in flash/Stylesheet");
    };
    /**
     * Extends the CSS parsing capability. Advanced developers can override this method by extending the
     * StyleSheet class.
     * @param	formatObject	An object that describes the style, containing style rules as properties of the object,
     *   or null.
     * @return	A TextFormat object containing the result of the mapping of CSS rules
     *   to text format properties.
     */
    StyleSheet.prototype.transform = function (formatObject) {
        console.log("transform not implemented yet in flash/Stylesheet");
        return null;
    };
    return StyleSheet;
}(EventDispatcher$1));

var Mouse = (function () {
    function Mouse() {
    }
    Object.defineProperty(Mouse, "cursor", {
        /*
         The name of the native cursor.
         */
        get: function () {
            return Mouse._cursor;
        },
        set: function (value) {
            Mouse._cursor = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Mouse, "supportsCursor", {
        /*
         [read-only] Indicates whether the computer or device displays a persistent cursor.
         */
        get: function () {
            return true;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Mouse, "supportsNativeCursor", {
        /*
         [read-only] Indicates whether the current configuration supports native cursors.
         */
        get: function () {
            return true;
        },
        enumerable: true,
        configurable: true
    });
    /*
     Hides the pointer.
     */
    Mouse.hide = function () {
    };
    /*
     Displays the pointer.
     */
    Mouse.show = function () {
    };
    /*
     Registers a native cursor under the given name, with the given data.
     */
    Mouse.registerCursor = function (name, cursor) {
    };
    /*
     Unregisters a native cursor under the given name, with the given data.
     */
    Mouse.unregisterCursor = function (name) {
    };
    return Mouse;
}());

/**
 * The Multitouch class manages and provides information about the current environment's support for handling
 * contact from user input devices, including contact that has two or more touch points (such as a user's fingers on a touch screen).
 * When a user interacts with a device such as a mobile phone or tablet with a touch screen, the user typically
 * touches the screen with his or her fingers or a pointing device. While there is a broad range of pointing devices,
 * such as a mouse or a stylus, many of these devices only have a single point of contact with an application. For pointing
 * devices with a single point of contact,
 * user interaction events can be handled as a mouse event, or using a basic set of touch events (called "touch point" events).
 * However, for pointing devices that have several
 * points of contact and perform complex movement, such as the human hand, Flash runtimes support an additional set of event handling API called gesture events. The API
 * for handling user interaction with these gesture events includes the following classes:
 * <p class="- topic/p "><ul class="- topic/ul "><li class="- topic/li ">flash.events.TouchEvent</li><li class="- topic/li ">flash.events.GestureEvent</li><li class="- topic/li ">flash.events.GesturePhase</li><li class="- topic/li ">flash.events.TransformGestureEvent</li><li class="- topic/li ">flash.events.PressAndTapGestureEvent</li></ul></p><p class="- topic/p ">Use the listed classes to write code that handles touch events. Use the Multitouch class to determine the
 * current environment's support for touch interaction, and to manage the support of touch interaction if
 * the current environment supports touch input.</p><p class="- topic/p ">You cannot create a Multitouch object directly from ActionScript code. If you call <codeph class="+ topic/ph pr-d/codeph ">new Multitouch()</codeph>, an exception is thrown.</p><p class="- topic/p "><b class="+ topic/ph hi-d/b ">Note:</b> The Multitouch feature is not supported for SWF files embedded in HTML running on Mac OS.</p>
 *
 */
var Multitouch = (function () {
    function Multitouch() {
    }
    Object.defineProperty(Multitouch, "inputMode", {
        /**
         * Identifies the multi-touch mode for touch and gesture event handling. Use this property to manage
         * whether or not events are dispatched as touch events with multiple points of contact and specific events
         * for different gestures (such as rotation and pan), or only a single point of contact (such as tap), or
         * none at all (contact is handled as a mouse event). To set this property, use values from the flash.ui.MultitouchInputMode class.
         */
        get: function () {
            //console.log("inputMode not implemented yet in flash/Multitouch");
            return "";
        },
        set: function (value) {
            //console.log("inputMode not implemented yet in flash/Multitouch");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Multitouch, "mapTouchToMouse", {
        get: function () {
            //console.log("mapTouchToMouse not implemented yet in flash/Multitouch");
            return false;
        },
        set: function (value) {
            //console.log("mapTouchToMouse not implemented yet in flash/Multitouch");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Multitouch, "maxTouchPoints", {
        /**
         * The maximum number of concurrent touch points supported by the current environment.
         */
        get: function () {
            //console.log("maxTouchPoints not implemented yet in flash/Multitouch");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Multitouch, "supportedGestures", {
        /**
         * A Vector array (a typed array of string values) of multi-touch contact types supported in the current environment. The array of strings
         * can be used as event types to register event listeners. Possible values are constants from the GestureEvent, PressAndTapGestureEvent, and
         * TransformGestureEvent classes (such as GESTURE_PAN).
         * If the Flash runtime is in an environment that does not support any multi-touch gestures, the value is null.Note: For Mac OS 10.5.3 and later, Multitouch.supportedGestures returns
         * non-null values (possibly indicating incorrectly that gesture events are supported) even if the current hardware does not support gesture input.Use this property to test for multi-touch gesture support. Then, use event handlers for the available multi-touch
         * gestures. For those gestures that are not supported in the current evironment, you'll need to create alternative
         * event handling.
         */
        get: function () {
            //console.log("supportedGestures not implemented yet in flash/Multitouch");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Multitouch, "supportsGestureEvents", {
        /**
         * Indicates whether the current environment supports gesture input, such as rotating two fingers
         * around a touch screen. Gesture events are listed in the TransformGestureEvent, PressAndTapGestureEvent, and GestureEvent classes.
         * Note:  For Mac OS 10.5.3 and later, this value is always true. Multitouch.supportsGestureEvent returns
         * true even if the hardware does not support gesture events.
         */
        get: function () {
            //console.log("supportsGestureEvents not implemented yet in flash/Multitouch");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Multitouch, "supportsTouchEvents", {
        /**
         * Indicates whether the current environment supports basic touch input, such as a single finger tap.
         * Touch events are listed in the TouchEvent class.
         */
        get: function () {
            //console.log("supportsTouchEvents not implemented yet in flash/Multitouch");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    return Multitouch;
}());

/**
 * The MultitouchInputMode class provides values for the <codeph class="+ topic/ph pr-d/codeph ">inputMode</codeph> property in the flash.ui.Multitouch class.
 * These values set the type of touch events the Flash runtime dispatches when the user interacts with a touch-enabled device.
 */
var MultitouchInputMode = (function () {
    function MultitouchInputMode() {
    }
    return MultitouchInputMode;
}());
/**
 * Specifies that TransformGestureEvent, PressAndTapGestureEvent, and GestureEvent events are dispatched for the related user interaction supported by the current environment,
 * and other touch events (such as a simple tap) are interpreted as mouse events.
 */
MultitouchInputMode.GESTURE = "gesture";
/**
 * Specifies that all user contact with a touch-enabled device is interpreted as a type of mouse event.
 */
MultitouchInputMode.NONE = "none";
/**
 * Specifies that events are dispatched only for basic touch events, such as a single finger tap. When you use this setting,
 * events listed in the TouchEvent class are dispatched; events listed in the TransformGestureEvent, PressAndTapGestureEvent, and GestureEvent classes are not dispatched.
 */
MultitouchInputMode.TOUCH_POINT = "touchPoint";

/**
 * Cancels a specified setInterval() call.
 * @param	id	The ID of the setInterval() call, which you set to a variable,
 *   as in the following:
 * @langversion	3.0
 * @playerversion	Flash 9
 */
/**
 * Cancels a specified setInterval() call.
 * @param	id	The ID of the setInterval() call, which you set to a variable,
 *   as in the following:
 * @langversion	3.0
 * @playerversion	Flash 9
 */ var clearInterval = window.clearInterval;

/**
 * Cancels a specified setTimeout() call.
 * @param	id	The ID of the setTimeout() call, which you set to a variable,
 *   as in the following:
 * @langversion	3.0
 * @playerversion	Flash 9
 */
/**
 * Cancels a specified setTimeout() call.
 * @param	id	The ID of the setTimeout() call, which you set to a variable,
 *   as in the following:
 * @langversion	3.0
 * @playerversion	Flash 9
 */ var clearTimeout = window.clearTimeout;

/**
 * Produces an XML object that describes the ActionScript object named as the parameter of
 * the method. This method implements the programming concept of reflection for the
 * ActionScript language.
 * If the value parameter is an instance of a type, the returned XML object includes all the instance properties of that type,
 * but does not include any static properties. You can check for this condition when you parse the XML object by examining the value of the <type> tag's isStatic attribute, which is false when the value parameter is an instance of a type.To obtain the static properties of a type, pass the type itself for the value parameter. The returned XML object includes not only the type's static properties, but also all of its instance properties.
 * The instance properties are nested inside a tag named <factory> to distinguish them from the static properties.
 * In this case, the isStatic attribute of the <type> tag is true.Note: If you need only to traverse an object's inheritance hierarchy and do not need the other information provided by describeType(),
 * use the getQualifiedClassName() and getQualifiedSuperclassName() functions instead.The following table describes some of the tags and attributes of the XML object generated by describeType()
 * (all class and interface names returned are in fully qualified format):TagAttributeDescription<type> The root tag of the XML object. nameThe name of the ActionScript object's data type. baseThe immediate superclass of the ActionScript object's defining class. If the ActionScript object is a class object, the value is Class. isDynamictrue if the ActionScript object's defining class is dynamic; false otherwise. If the ActionScript object is a class object, the value is true because the Class class is dynamic. isFinaltrue if the ActionScript object's defining class is final; false otherwise. isStatictrue if the ActionScript object is a class object or constructor function; false otherwise. This attribute is named isStatic because if it is true, any tags that are not nested inside the factory tag are static.<extendsClass> There is a separate extendsClass tag for each superclass of the ActionScript object's defining class. typeThe name of a superclass that the ActionScript object's defining class extends.<implementsInterface> There is a separate implementsInterface tag for each interface implemented by the ActionScript object's defining class or any of its superclasses. typeThe name of an interface that the ActionScript object's defining class implements.<accessor> An accessor is a property defined by getter and setter functions. nameThe name of the accessor. accessThe access rights of the property. Possible values include readonly, writeonly, and readwrite. typeThe data type of the property. declaredByThe class that contains the associated getter or setter functions.<constant> A constant is a property defined with the const statement. nameThe name of the constant. typeThe data type of the constant.<method> A method is a function declared as part of a class definition. nameThe name of the method. declaredByThe class that contains the method definition. returnTypeThe data type of the method's return value.<parameter> There is a separate parameter tag for each parameter that a method defines. This tag is always nested inside a <method> tag. indexA number corresponding to the order in which the parameter appears in the method's parameter list. The first parameter has a value of 1. typeThe data type of the parameter. optionaltrue if the parameter is optional; false otherwise.<variable> A variable is a property defined with the var statement. nameThe name of the variable. typeThe data type of the variable.<factory> If the ActionScript object is a class object or constructor function, all instance properties and methods are nested inside this tag. If the isStatic attribute of the <type> tag is true, all properties and methods that are not nested within the <factory> tag are static. This tag appears only if the ActionScript object is a class object or constructor function.
 * @param	value	The object for which a type description is desired. Any ActionScript value
 *   may be passed to this method including all available ActionScript types, object
 *   instances, primitive types such as uint, and class objects.
 * @return	An XML object containing details about the object that was passed in as a parameter.
 *   It provides the following information about the object:
 *
 *     The class of the objectThe attributes of the classThe inheritance tree from the class to its base classesThe interfaces implemented by the classThe declared instance properties of the classThe declared static properties of the classThe instance methods of the classThe static methods of the class For each method of the class, the name, number of parameters, return type,
 *   and parameter types Note:describeType() only shows public properties and methods, and will not show
 *   properties and methods that are private, package internal or in custom namespaces.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
var describeType = function (value) {
    //todo: any is XML
    console.log("describeType is not implemented yet in flash/utils");
};

/**
 * Returns an escaped copy of the input string encoded as either UTF-8 or system code page, depending on the value of System.useCodePage.
 * Use of System.useCodePage allows legacy content encoded in local code pages to be accessed by the runtime, but only on systems using that legacy code page.
 * For example, Japanese data encoded as Shift-JIS will only be escaped and unescaped properly on an OS using a Japanese default code page.
 * @param	value	The string to be escaped.
 * @return	An escaped copy of the input string.  If System.useCodePage is true, the escaped string is encoded in the system code page.
 *   If System.useCodePage is false, the escaped string is encoded in UTF-8.
 *   For example, the input string "Crüe" will be escaped as "Cr%C3%BCe" on all systems if System.useCodePage is false.
 *   If system.useCodePage is true, and the system uses a Latin code page, "Crüe" will be escaped as "Cr%FCe".
 *   If the system uses a non Latin code page that does not contain the letter 'ü' the result will probably be "Cr?e".
 *   Unescaping "Cr%C3%BCe" with System.useCodePage set to true will produce different undesired results on different systems, such as "CrÃ¼e" on a Latin system.
 *   Similarly, unescaping "Cr%FCe" with System.useCodePage set to false could produce "Cre" or "Cr?e" or other variations depending on the code page of the system.
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
var escapeMultiByte = function (value) {
    console.log("escapeMultiByte is not implemented yet in flash/utils");
    return "";
};

var getAliasName = function (value) {
    console.log("getAliasName is not implemented yet in flash/utils");
    return "";
};

/**
 * Returns a reference to the class object of the class specified by the name parameter.
 * @param	name	The name of a class.
 * @return	Returns a reference to the class object of the class specified by the name parameter.
 * @throws	ReferenceError No public definition exists with the
 *   specified name.
 */
/**
 * Returns a reference to the class object of the class specified by the name parameter.
 * @param	name	The name of a class.
 * @return	Returns a reference to the class object of the class specified by the name parameter.
 * @throws	ReferenceError No public definition exists with the
 *   specified name.
 */ var getDefinitionByName = function (name) {
    //todo
    throw ("getDefinitionByName is not implemented yet in flash/utils");
};

/**
 * Returns the fully qualified class name of an object.
 * @param	value	The object for which a fully qualified class name is desired. Any ActionScript value
 *   may be passed to this method including all available ActionScript types, object
 *   instances, primitive types such as uint, and class objects.
 * @return	A string containing the fully qualified class name.
 */
/**
 * Returns the fully qualified class name of an object.
 * @param	value	The object for which a fully qualified class name is desired. Any ActionScript value
 *   may be passed to this method including all available ActionScript types, object
 *   instances, primitive types such as uint, and class objects.
 * @return	A string containing the fully qualified class name.
 */ var getQualifiedClassName = function (value) {
    if (value.name)
        return value.name;
    else {
        return value.constructor.name;
    }
};

/**
 * Returns the fully qualified class name of the base class of the object specified by the value
 * parameter. This function provides a quicker way of retrieving the base class name than describeType(), but also
 * doesn't provide all the information describeType() does.
 * After you retrieve the name of a class with this function, you can convert the class name to a class reference with the getDefinitionByName() function.Note: This function restricts itself to instance hierarchies, whereas the describeType() function
 * uses class object hierarchies if the value parameter is a data type. Calling describeType() on a data type returns the
 * superclass based on the class object hierarchy, in which all class objects inherit from Class. The getQualifiedSuperclassName()
 * function, however, ignores the class object hierarchy and returns the superclass based on the more familiar instance hierarchy.
 * For example, calling getQualifiedSuperclassName(String)
 * returns Object although technically the String class object inherits from Class. In other words, the results are
 * the same whether you use an instance of a type or the type itself.
 * @param	value	Any value.
 * @return	A fully qualified base class name, or null if none exists.
 */
/**
 * Returns the fully qualified class name of the base class of the object specified by the value
 * parameter. This function provides a quicker way of retrieving the base class name than describeType(), but also
 * doesn't provide all the information describeType() does.
 * After you retrieve the name of a class with this function, you can convert the class name to a class reference with the getDefinitionByName() function.Note: This function restricts itself to instance hierarchies, whereas the describeType() function
 * uses class object hierarchies if the value parameter is a data type. Calling describeType() on a data type returns the
 * superclass based on the class object hierarchy, in which all class objects inherit from Class. The getQualifiedSuperclassName()
 * function, however, ignores the class object hierarchy and returns the superclass based on the more familiar instance hierarchy.
 * For example, calling getQualifiedSuperclassName(String)
 * returns Object although technically the String class object inherits from Class. In other words, the results are
 * the same whether you use an instance of a type or the type itself.
 * @param	value	Any value.
 * @return	A fully qualified base class name, or null if none exists.
 */ var getQualifiedSuperclassName = function (name) {
    //todo
    console.log("getQualifiedSuperclassName is not implemented yet in flash/utils");
    return "";
};

/**
 * Used to compute relative time. For a Flash runtime processing ActionScript 3.0, this method returns the number of milliseconds that have elapsed
 * since the Flash runtime virtual machine for ActionScript 3.0 (AVM2) started. For a Flash runtime processing ActionScript 2.0, this method returns
 * the number of milliseconds since the Flash runtime began initialization. Flash runtimes use two
 * virtual machines to process ActionScript. AVM1 is the ActionScript virtual machine used to run ActionScript 1.0 and 2.0.
 * AVM2 is the ActionScript virtual machine used to run ActionScript 3.0. The getTimer() method behavior for AVM1 is different than the
 * behavior for AVM2.
 * For a calendar date (timestamp), see the Date object.
 * @return	The number of milliseconds since the runtime was initialized (while processing ActionScript 2.0), or since the virtual machine started (while
 *   processing ActionScript 3.0). If the runtime starts playing one
 *   SWF file, and another SWF file is loaded later, the return value is relative to when the first SWF file was
 *   loaded.
 */

/**
 * Runs a function at a specified interval (in milliseconds).
 *
 *   Instead of using the setInterval() method, consider
 * creating a Timer object, with the specified interval, using 0 as the repeatCount
 * parameter (which sets the timer to repeat indefinitely).If you intend to use the clearInterval() method to cancel the
 * setInterval() call, be sure to assign the setInterval() call to a
 * variable (which the clearInterval() function will later reference).
 * If you do not call the clearInterval() function to cancel the
 * setInterval() call, the object containing the set timeout closure
 * function will not be garbage collected.
 * @param	closure	The name of the function to execute. Do not include quotation marks or
 *   parentheses, and do not specify parameters of the function to call. For example, use
 *   functionName, not functionName() or functionName(param).
 * @param	delay	The interval, in milliseconds.
 * @param	arguments	An optional list of arguments that are passed to the closure function.
 * @return	Unique numeric identifier for the timed process. Use this identifier to cancel
 *   the process, by calling the clearInterval() method.
 */
/**
 * Runs a function at a specified interval (in milliseconds).
 *
 *   Instead of using the setInterval() method, consider
 * creating a Timer object, with the specified interval, using 0 as the repeatCount
 * parameter (which sets the timer to repeat indefinitely).If you intend to use the clearInterval() method to cancel the
 * setInterval() call, be sure to assign the setInterval() call to a
 * variable (which the clearInterval() function will later reference).
 * If you do not call the clearInterval() function to cancel the
 * setInterval() call, the object containing the set timeout closure
 * function will not be garbage collected.
 * @param	closure	The name of the function to execute. Do not include quotation marks or
 *   parentheses, and do not specify parameters of the function to call. For example, use
 *   functionName, not functionName() or functionName(param).
 * @param	delay	The interval, in milliseconds.
 * @param	arguments	An optional list of arguments that are passed to the closure function.
 * @return	Unique numeric identifier for the timed process. Use this identifier to cancel
 *   the process, by calling the clearInterval() method.
 */ var setInterval$1 = window.setInterval;

/**
 * Runs a specified function after a specified delay (in milliseconds).
 *
 *   Instead of using this method, consider
 * creating a Timer object, with the specified interval, using 1 as the repeatCount
 * parameter (which sets the timer to run only once).If you intend to use the clearTimeout() method to cancel the
 * setTimeout() call, be sure to assign the setTimeout() call to a
 * variable (which the clearTimeout() function will later reference).
 * If you do not call the clearTimeout() function to cancel the
 * setTimeout() call, the object containing the set timeout closure
 * function will not be garbage collected.
 * @param	closure	The name of the function to execute. Do not include quotation marks or
 *   parentheses, and do not specify parameters of the function to call. For example, use
 *   functionName, not functionName() or functionName(param).
 * @param	delay	The delay, in milliseconds, until the function is executed.
 * @param	arguments	An optional list of arguments that are passed to the closure function.
 * @return	Unique numeric identifier for the timed process. Use this identifier to cancel
 *   the process, by calling the clearTimeout() method.
 */
/**
 * Runs a specified function after a specified delay (in milliseconds).
 *
 *   Instead of using this method, consider
 * creating a Timer object, with the specified interval, using 1 as the repeatCount
 * parameter (which sets the timer to run only once).If you intend to use the clearTimeout() method to cancel the
 * setTimeout() call, be sure to assign the setTimeout() call to a
 * variable (which the clearTimeout() function will later reference).
 * If you do not call the clearTimeout() function to cancel the
 * setTimeout() call, the object containing the set timeout closure
 * function will not be garbage collected.
 * @param	closure	The name of the function to execute. Do not include quotation marks or
 *   parentheses, and do not specify parameters of the function to call. For example, use
 *   functionName, not functionName() or functionName(param).
 * @param	delay	The delay, in milliseconds, until the function is executed.
 * @param	arguments	An optional list of arguments that are passed to the closure function.
 * @return	Unique numeric identifier for the timed process. Use this identifier to cancel
 *   the process, by calling the clearTimeout() method.
 */ var setTimeout = window.setTimeout;

/**
 * Returns an unescaped copy of the input string, which is decoded from either system code page page or UTF-8 depending on the value of System.useCodePage.
 * Use of System.useCodePage allows legacy content encoded in local code pages to be accessed by the runtime, but only on systems using that legacy code page.
 * For example, Japanese data encoded as Shift-JIS will only be escaped and unescaped properly on an OS using a Japanese default code page.
 * @param	value	The escaped string to be unescaped.
 * @return	An unescaped copy of the input string.  If System.useCodePage is true, the escaped string is decoded from the system code page.
 *   If System.useCodePage is false, the escaped string is decoded from UTF-8.
 *   For example, if the input string is "Crüe" and System.useCodePage is false, the result will be "CrÃ¼e" on all systems.
 *   If System.useCodePage is true and the input string is "Cr%FCe", and the system uses a Latin code page, the result will also be "CrÃ¼e".
 *   Unescaping "Cr%C3%BCe" with System.useCodePage set to true will produce different undesired results on different systems, such as "CrÃÂ¼e" on a Latin system.
 *   Similarly, unescaping "Cr%FCe" with System.useCodePage set to false could produce "Cre" or "Cr?e" or other variations depending on the code page of the system.
 */
var unescapeMultiByte = function (value) {
    console.log("unescapeMultiByte is not implemented yet in flash/utils");
    return "";
};

var AwayDate = (function () {
    // todo check why this differs from the header file i converted from as3
    // just made it compatible for compile right now
    function AwayDate(param1, param2, param3) {
        if (param1 === void 0) { param1 = 0; }
        if (param2 === void 0) { param2 = 0; }
        if (param3 === void 0) { param3 = 0; }
    }
    AwayDate.UTC = function (year, month, date, hour, minute, second, millisecond) {
        return 0;
    };
    AwayDate.prototype.getDate = function () { return 0; };
    AwayDate.prototype.getDay = function () { return 0; };
    AwayDate.prototype.getFullYear = function () { return 0; };
    AwayDate.prototype.getHours = function () { return 0; };
    AwayDate.prototype.getMilliseconds = function () { return 0; };
    AwayDate.prototype.getMinutes = function () { return 0; };
    AwayDate.prototype.getMonth = function () { return 0; };
    AwayDate.prototype.getSeconds = function () { return 0; };
    AwayDate.prototype.getTime = function () { return 0; };
    AwayDate.prototype.getTimezoneOffset = function () { return 0; };
    AwayDate.prototype.getUTCDate = function () { return 0; };
    AwayDate.prototype.getUTCDay = function () { return 0; };
    AwayDate.prototype.getUTCFullYear = function () { return 0; };
    AwayDate.prototype.getUTCHours = function () { return 0; };
    AwayDate.prototype.getUTCMilliseconds = function () { return 0; };
    AwayDate.prototype.getUTCMinutes = function () { return 0; };
    AwayDate.prototype.getUTCMonth = function () { return 0; };
    AwayDate.prototype.getUTCSeconds = function () { return 0; };
    AwayDate.prototype.getYear = function () { return 0; };
    AwayDate.prototype.setDate = function (date) { return 0; };
    AwayDate.prototype.setFullYear = function (year, month, date) { return 0; };
    AwayDate.prototype.setHours = function (hour) { return 0; };
    AwayDate.prototype.setMilliseconds = function (millisecond) { return 0; };
    AwayDate.prototype.setMinutes = function (minute) { return 0; };
    AwayDate.prototype.setMonth = function (month, date) { return 0; };
    AwayDate.prototype.setSeconds = function (second) { return 0; };
    AwayDate.prototype.setTime = function (millisecond) { return 0; };
    AwayDate.prototype.setUTCDate = function (date) { return 0; };
    AwayDate.prototype.setUTCFullYear = function (year, month, date) { return 0; };
    AwayDate.prototype.setUTCHours = function (hour, minute, second, millisecond) { return 0; };
    AwayDate.prototype.setUTCMilliseconds = function (millisecond) { return 0; };
    AwayDate.prototype.setUTCMinutes = function (minute, second, millisecond) { return 0; };
    AwayDate.prototype.setUTCMonth = function (month, date) { return 0; };
    AwayDate.prototype.setUTCSeconds = function (second, millisecond) { return 0; };
    AwayDate.prototype.setYear = function (year) { return 0; };
    AwayDate.prototype.toString = function () { return ""; };
    AwayDate.prototype.valueOf = function () { return 0; };
    // Mobile specific
    AwayDate.prototype.getLocaleLongDate = function () { return ""; };
    AwayDate.prototype.getLocaleShortDate = function () { return ""; };
    AwayDate.prototype.getLocaleTime = function () { return ""; };
    return AwayDate;
}());

var Dictionary = Object;

var Endian = (function () {
    function Endian() {
    }
    return Endian;
}());
/**
 * Indicates the most significant byte of the multibyte number appears first in the sequence of bytes.
 * The hexadecimal number 0x12345678 has 4 bytes (2 hexadecimal digits per byte).
 */
Endian.BIG_ENDIAN = "bigEndian";
/**
 * Indicates the least significant byte of the multibyte number appears first in the sequence of bytes.
 * The hexadecimal number 0x12345678 has 4 bytes (2 hexadecimal digits per byte).
 */
Endian.LITTLE_ENDIAN = "littleEndian";

// win flash this is located in flash.trace.Trace, but i didnt want to create a new folder just for it, so i put it into utils
var Trace = (function (_super) {
    __extends(Trace, _super);
    function Trace() {
        return _super.apply(this, arguments) || this;
    }
    Trace.getLevel = function (target) {
        if (target === void 0) { target = 2; }
        console.log("getLevel is not implemented yet in flash/Trace");
        return 0;
    };
    Trace.getListener = function () {
        console.log("getListener is not implemented yet in flash/Trace");
        return null;
    };
    Trace.setLevel = function (l, target) {
        if (target === void 0) { target = 2; }
        console.log("setLevel is not implemented yet in flash/Trace");
    };
    Trace.setListener = function (f) {
        console.log("setListener is not implemented yet in flash/Trace");
    };
    return Trace;
}(Object));

/**
 * The XMLNode class represents the legacy XML object
 * that was present in ActionScript 2.0 and that was renamed in ActionScript 3.0.
 * In ActionScript 3.0, consider using the new top-level <xref href="../../XML.html" class="- topic/xref ">XML</xref>
 * class and related classes instead,
 * which support E4X (ECMAScript for XML).
 * The XMLNode class is present for backward compatibility.
 */
var XMLNode = (function () {
    /**
     * Creates a new XMLNode object. You must use the constructor to create an XMLNode object before you
     * call any of the methods of the XMLNode class.
     * Note: Use the createElement() and createTextNode()
     * methods to add elements and text nodes to an XML document tree.
     * @param	type	The node type: either 1 for an XML element or 3 for a text node.
     * @param	value	The XML text parsed to create the new XMLNode object.
     */
    function XMLNode(type, value) {
    }
    // for AVM1:
    XMLNode.prototype.axCallPublicProperty = function (value1, value2) {
        return null;
    };
    XMLNode.prototype.axGetPublicProperty = function (value) {
        return null;
    };
    XMLNode.prototype.axSetPublicProperty = function (value, value2) {
        return null;
    };
    XMLNode.prototype.removeChild = function (child) {
    };
    Object.defineProperty(XMLNode.prototype, "attributes", {
        /**
         * An object containing all of the attributes of the specified XMLNode instance. The
         * XMLNode.attributes object contains one variable for each attribute of the XMLNode instance.
         * Because these variables are defined as part of the object, they are generally referred to as
         * properties of the object. The value of each attribute is stored in the corresponding property as a
         * string. For example, if you have an attribute named color, you would retrieve
         * that attribute's value
         * by specifying color as the property name, as the following code shows:
         *
         *   var myColor:String = doc.firstChild.attributes.color
         */
        get: function () {
            console.log("attributes not implemented yet in flash/XMLNode");
            return null;
        },
        set: function (value) {
            console.log("attributes not implemented yet in flash/XMLNode");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XMLNode.prototype, "childNodes", {
        /**
         * An array of the specified XMLNode object's children. Each element in the array is a reference
         * to an XMLNode object that represents a child node. This is a read-only property and cannot be
         * used to manipulate child nodes. Use the appendChild(), insertBefore(),
         * and removeNode()  methods to manipulate child nodes.
         *
         *   This property is undefined for text nodes (nodeType == 3).
         */
        get: function () {
            console.log("childNodes not implemented yet in flash/XMLNode");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XMLNode.prototype, "localName", {
        /**
         * The local name portion of the XML node's name. This is the element name without
         * the namespace prefix. For example, the node
         * <contact:mailbox/>bob@example.com</contact:mailbox>
         *   has the local name "mailbox", and the prefix "contact", which comprise the full
         *   element name "contact.mailbox".
         *
         *     You can access the namespace prefix through the prefix property of
         *   the XML node object. The nodeName property returns the full name
         *   (including the prefix and the local name).
         */
        get: function () {
            console.log("localName not implemented yet in flash/XMLNode");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XMLNode.prototype, "namespaceURI", {
        /**
         * If the XML node has a prefix, namespaceURI is the value of the xmlns
         * declaration for that prefix (the URI), which is typically called the namespace URI.
         * The xmlns declaration is in the current node or in a node higher in the XML
         * hierarchy.
         *
         *   If the XML node does not have a prefix, the value of the namespaceURI property
         * depends on whether there is a default namespace defined (as in
         * xmlns="http://www.example.com/"). If there is a default namespace, the value of
         * the namespaceURI property is the value of the default namespace.
         * If there is no default namespace, the namespaceURI property for
         * that node is an empty string ("").You can use the getNamespaceForPrefix() method to identify the namespace associated with a
         * specific prefix. The namespaceURI property returns the prefix associated with the node name.
         */
        get: function () {
            console.log("namespaceURI not implemented yet in flash/XMLNode");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(XMLNode.prototype, "prefix", {
        /**
         * The prefix portion of the XML node name. For example, the node
         * <contact:mailbox/>bob@example.com</contact:mailbox> prefix
         *   "contact" and the local name "mailbox", which comprise the full element name "contact.mailbox".
         *
         *     The nodeName property of an XML node object returns the full name
         *   (including the prefix and the  local name). You can access the local name portion of the
         *   element's name via the localName property.
         */
        get: function () {
            console.log("prefix not implemented yet in flash/XMLNode");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Appends the specified node to the XML object's child list. This method operates directly on the
     * node referenced by the childNode parameter; it does not append a copy of the
     * node. If the node to be appended already exists in another tree structure, appending the node to the
     * new location will remove it from its current location. If the childNode
     * parameter refers to a node that already exists in another XML tree structure, the appended child node
     * is placed in the new tree structure after it is removed from its existing parent node.
     * @param	node	An XMLNode that represents the node to be moved from its current location to the child
     *   list of the my_xml object.
     */
    XMLNode.prototype.appendChild = function (node) {
        console.log("appendChild not implemented yet in flash/XMLNode");
    };
    /**
     * Constructs and returns a new XML node of the same type, name, value, and attributes as the
     * specified XML object. If deep is set to true, all child nodes are
     * recursively cloned, resulting in an exact copy of the original object's document tree.
     * The clone of the node that is returned is no longer associated with the tree of the cloned item.
     * Consequently, nextSibling, parentNode, and previousSibling
     * all have a value of null. If the deep parameter is set to
     * false, or the my_xml node has no child nodes,
     * firstChild and lastChild are also null.
     * @param	deep	A Boolean value; if set to true, the children of the specified XML object will be recursively cloned.
     * @return	An XMLNode Object.
     */
    XMLNode.prototype.cloneNode = function (deep) {
        console.log("cloneNode not implemented yet in flash/XMLNode");
        return null;
    };
    /**
     * Returns the namespace URI that is associated with the specified prefix for the node. To determine
     * the URI, getPrefixForNamespace() searches up the XML hierarchy from the node, as
     * necessary, and returns the namespace URI of the first xmlns declaration for the
     * given prefix.
     *
     *   If no namespace is defined for the specified prefix, the method returns null.If you specify an empty string ("") as the prefix and there is a
     * default namespace defined for the node (as in xmlns="http://www.example.com/"),
     * the method returns that default namespace URI.
     * @param	prefix	The prefix for which the method returns the associated namespace.
     * @return	The namespace that is associated with the specified prefix.
     * @refpath
     */
    XMLNode.prototype.getNamespaceForPrefix = function (prefix) {
        console.log("getNamespaceForPrefix not implemented yet in flash/XMLNode");
        return "";
    };
    /**
     * Returns the prefix that is associated with the specified namespace URI for the node. To determine
     * the prefix, getPrefixForNamespace() searches up the XML hierarchy from the node, as
     * necessary, and returns the prefix of the first xmlns declaration with a namespace URI
     * that matches ns.
     *
     *   If there is no xmlns
     * assignment for the given URI, the method returns null. If there is an
     * xmlns assignment for the given URI but no prefix is associated with the assignment,
     * the method returns an empty string
     * ("").
     * @param	ns	The namespace URI for which the method returns the associated prefix.
     * @return	The prefix associated with the specified namespace.
     */
    XMLNode.prototype.getPrefixForNamespace = function (ns) {
        console.log("getPrefixForNamespace not implemented yet in flash/XMLNode");
        return "";
    };
    /**
     * Indicates whether the specified XMLNode object has child nodes. This property is true if the
     * specified XMLNode object has child nodes; otherwise, it is false.
     * @return	Returns true if the
     *   specified XMLNode object has child nodes; otherwise, false.
     */
    XMLNode.prototype.hasChildNodes = function () {
        console.log("hasChildNodes not implemented yet in flash/XMLNode");
        return false;
    };
    /**
     * Inserts a new child node into the XML object's child list, before the
     * beforeNode node. If the beforeNode parameter is undefined
     * or null, the node is added using the appendChild() method. If beforeNode
     * is not a child of my_xml, the insertion fails.
     * @param	node	The XMLNode object to be inserted.
     * @param	before	The XMLNode object before the insertion point for the childNode.
     */
    XMLNode.prototype.insertBefore = function (node, before) {
        console.log("insertBefore not implemented yet in flash/XMLNode");
    };
    /**
     * Removes the specified XML object from its parent. Also deletes all descendants of the node.
     */
    XMLNode.prototype.removeNode = function () {
        console.log("removeNode not implemented yet in flash/XMLNode");
    };
    /**
     * Evaluates the specified XMLNode object, constructs a textual representation of the XML structure,
     * including the node, children, and attributes, and returns the result as a string.
     *
     *   For top-level XMLDocument objects (those created with the constructor),
     * the XMLDocument.toString() method outputs the document's XML declaration
     * (stored in the XMLDocument.xmlDecl property), followed by the document's
     * DOCTYPE declaration (stored in the XMLDocument.docTypeDecl property),
     * followed by the text representation of all XML nodes in the object. The XML declaration is not
     * output if the XMLDocument.xmlDecl property is null.
     * The DOCTYPE declaration is not output if the
     * XMLDocument.docTypeDecl property is null.
     * @return	The string representing the XMLNode object.
     */
    XMLNode.prototype.toString = function () {
        console.log("toString not implemented yet in flash/XMLNode");
        return "";
    };
    return XMLNode;
}());

/**
 * The XMLNodeType class contains constants used with
 * <codeph class="+ topic/ph pr-d/codeph ">XMLNode.nodeType</codeph>. The values are defined
 * by the NodeType enumeration in the
 * W3C DOM Level 1 recommendation:
 * <xref href="http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001/level-one-core.html" scope="external" class="- topic/xref ">http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001/level-one-core.html</xref>
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
var XMLNodeType = (function () {
    function XMLNodeType() {
        // todo: why does this have a constructor ? it just provides static props...
    }
    return XMLNodeType;
}());
//80pro todo: all values above 100 are value i assigned, maybe worth to check what they was in original as3
XMLNodeType.CDATA_NODE = 100;
XMLNodeType.COMMENT_NODE = 101;
XMLNodeType.DOCUMENT_TYPE_NODE = 102;
/**
 * Specifies that the node is an element.
 * This constant is used with XMLNode.nodeType.
 * The value is defined by the NodeType enumeration in the
 * W3C DOM Level 1 recommendation:
 * http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001/level-one-core.html
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
XMLNodeType.ELEMENT_NODE = 1;
XMLNodeType.PROCESSING_INSTRUCTION_NODE = 103;
/**
 * Specifies that the node is a text node.
 * This constant is used with XMLNode.nodeType.
 * The value is defined by the NodeType enumeration in the
 * W3C DOM Level 1 recommendation:
 * http://www.w3.org/TR/1998/REC-DOM-Level-1-19981001/level-one-core.html
 * @langversion	3.0
 * @playerversion	Flash 9
 * @playerversion	Lite 4
 */
XMLNodeType.TEXT_NODE = 3;
XMLNodeType.XML_DECLARATION = 104;

var XML = (function (_super) {
    __extends(XML, _super);
    function XML(text) {
        return _super.call(this, XMLNodeType.XML_DECLARATION, "null") || this;
    }
    XML.prototype.addRequestHeader = function (header, headerValue) {
        console.log("addRequestHeader not implemented yet in flash/XML");
    };
    XML.prototype.createElement = function (name) {
        console.log("createElement not implemented yet in flash/XML");
        return null;
    };
    XML.prototype.createTextNode = function (value) {
        console.log("createTextNode not implemented yet in flash/XML");
        return null;
    };
    XML.prototype.getBytesLoaded = function () {
        console.log("getBytesLoaded not implemented yet in flash/XML");
        return 0;
    };
    XML.prototype.getBytesTotal = function () {
        console.log("getBytesTotal not implemented yet in flash/XML");
        return 0;
    };
    // Central API
    XML.prototype.getRequestHeaders = function () {
        console.log("getRequestHeaders not implemented yet in flash/XML");
        return null;
    };
    // Central API
    XML.prototype.getRequestHeader = function (key) {
        console.log("getRequestHeader not implemented yet in flash/XML");
        return null;
    };
    // Central API
    XML.prototype.getResponseHeaders = function () {
        console.log("getResponseHeaders not implemented yet in flash/XML");
        return null;
    };
    // Central API
    XML.prototype.getResponseHeader = function (key) {
        console.log("getResponseHeader not implemented yet in flash/XML");
        return null;
    };
    // Central API
    XML.prototype.getResponseBody = function () {
        console.log("getResponseBody not implemented yet in flash/XML");
        return null;
    };
    XML.prototype.load = function (url) {
        console.log("load not implemented yet in flash/XML");
        return false;
    };
    XML.prototype.parseXML = function (value) {
        console.log("parseXML not implemented yet in flash/XML");
    };
    XML.prototype.send = function (url, target, method) {
        console.log("send not implemented yet in flash/XML");
        return false;
    };
    XML.prototype.sendAndLoad = function (url, resultXML) {
        console.log("sendAndLoad not implemented yet in flash/XML");
    };
    XML.prototype.onLoad = function (success) {
        console.log("onLoad not implemented yet in flash/XML");
    };
    XML.prototype.onData = function (src) {
        console.log("onData not implemented yet in flash/XML");
    };
    return XML;
}(XMLNode));

/**
 * The XMLDocument class represents the legacy XML object
 * that was present in ActionScript 2.0. It was renamed in ActionScript 3.0
 * to XMLDocument to avoid name conflicts with the new
 * XML class in ActionScript 3.0. In ActionScript 3.0,
 * it is recommended that you use the new
 * <xref href="../../XML.html" class="- topic/xref ">XML</xref> class and related classes,
 * which support E4X (ECMAScript for XML).
 *
 *   <p class="- topic/p ">The XMLDocument class, as well as XMLNode and XMLNodeType, are present for backward
 * compatibility. The functionality for loading XML documents can now be found in the
 * URLLoader class.</p>
 */
var XMLDocumentAway = (function (_super) {
    __extends(XMLDocumentAway, _super);
    /**
     * Creates a new XMLDocument object. You must use the constructor to create an XMLDocument object before you call any of the methods of the XMLDocument class.
     * Note: Use the createElement() and createTextNode() methods to add elements and text nodes to an XML document tree.
     * @param	source	The XML text parsed to create the new XMLDocument object.
     */
    function XMLDocumentAway(source) {
        if (source === void 0) { source = null; }
        return _super.call(this, XMLNodeType.DOCUMENT_TYPE_NODE, "null") || this;
    }
    // for AVM1:
    XMLDocumentAway.prototype.axCallPublicProperty = function (value1, value2) {
        return null;
    };
    XMLDocumentAway.prototype.axGetPublicProperty = function (value) {
        return null;
    };
    XMLDocumentAway.prototype.axSetPublicProperty = function (value, value2) {
        return null;
    };
    /**
     * Creates a new XMLNode object with the name specified in the parameter.
     * The new node initially has no parent, no children, and no siblings.
     * The method returns a reference to the newly created XMLNode object
     * that represents the element. This method and the XMLDocument.createTextNode()
     * method are the constructor methods for creating nodes for an XMLDocument object.
     * @param	name	The tag name of the XMLDocument element being created.
     * @return	An XMLNode object.
     * */
    XMLDocumentAway.prototype.createElement = function (name) {
        console.log("createElement not implemented yet in flash/XMLDocument");
        return null;
    };
    /**
     * Creates a new XML text node with the specified text. The new node initially has no parent, and text nodes cannot have children or siblings. This method returns a reference to the XMLDocument object that represents the new text node. This method and the XMLDocument.createElement() method are the constructor methods for creating nodes for an XMLDocument object.
     * @param	text	The text used to create the new text node.
     * @return	An XMLNode object.
     */
    XMLDocumentAway.prototype.createTextNode = function (text) {
        console.log("createTextNode not implemented yet in flash/XMLDocument");
        return null;
    };
    /**
     * Parses the XML text specified in the value parameter
     * and populates the specified XMLDocument object with the resulting XML tree. Any existing trees in the XMLDocument object are discarded.
     * @param	source	The XML text to be parsed and passed to the specified XMLDocument object.
     */
    XMLDocumentAway.prototype.parseXML = function (source) {
        console.log("parseXML not implemented yet in flash/XMLDocument");
    };
    /**
     * Returns a string representation of the XML object.
     * @return	A string representation of the XML object.
     */
    XMLDocumentAway.prototype.toString = function () {
        console.log("toString not implemented yet in flash/XMLDocument");
        return "";
    };
    return XMLDocumentAway;
}(XMLNode));

/**
 * The XMLList class contains methods for working with one or more XML elements. An XMLList object
 * can represent one or more XML objects or elements (including multiple nodes or attributes), so
 * you can call methods on the elements as a group or on the individual elements in the collection.
 * <p class="- topic/p ">If an XMLList object has only one XML element, you can use the XML class methods on the
 * XMLList object directly. In the following example, <codeph class="+ topic/ph pr-d/codeph ">example.two</codeph> is an XMLList
 * object of length 1, so you can call any XML method on it.</p><codeblock xml:space="preserve" class="+ topic/pre pr-d/codeblock ">
 * var example2 = &lt;example&gt;&lt;two&gt;2&lt;/two&gt;&lt;/example&gt;;</codeblock><p class="- topic/p ">If you attempt to use XML class methods with an XMLList object containing more than one XML
 * object, an exception is thrown; instead, iterate over the XMLList collection (using a
 * <codeph class="+ topic/ph pr-d/codeph ">for each..in</codeph> statement, for example) and apply the methods to each XML object in
 * the collection.</p>
 */
var XMLList = (function () {
    /**
     * Creates a new XMLList object.
     * @param	value	Any object that can be converted to an XMLList object by using the top-level XMLList() function.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    function XMLList(value) {
        if (value === void 0) { value = null; }
    }
    XMLList.prototype.addNamespace = function (ns) {
        console.log("addNamespace not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.appendChild = function (child) {
        console.log("appendChild not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Calls the attribute() method of each XML object and returns an XMLList object
     * of the results. The results match the given attributeName parameter. If there is no
     * match, the attribute() method returns an empty XMLList object.
     * @param	attributeName	The name of the attribute that you want to include in an XMLList object.
     * @return	An XMLList object of matching XML objects or an empty XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.attribute = function (arg) {
        console.log("attribute not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Calls the attributes() method of each XML object and
     * returns an XMLList object of attributes for each XML object.
     * @return	An XMLList object of attributes for each XML object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.attributes = function () {
        console.log("attributes not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Calls the child() method of each XML object and returns an XMLList object that
     * contains the results in order.
     * @param	propertyName	The element name or integer of the XML child.
     * @return	An XMLList object of child nodes that match the input parameter.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.child = function (propertyName) {
        console.log("child not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.childIndex = function () {
        console.log("childIndex not implemented yet in flash/XMLList");
        return 0;
    };
    /**
     * Calls the children() method of each XML object and
     * returns an XMLList object that contains the results.
     * @return	An XMLList object of the children in the XML objects.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.children = function () {
        console.log("children not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Calls the comments() method of each XML object and returns
     * an XMLList of comments.
     * @return	An XMLList of the comments in the XML objects.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.comments = function () {
        console.log("comments not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Checks whether the XMLList object contains an XML object that is equal to the given
     * value parameter.
     * @param	value	An XML object to compare against the current XMLList object.
     * @return	If the XMLList contains the XML object declared in the value parameter,
     *   then true; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.contains = function (value) {
        console.log("contains not implemented yet in flash/XMLList");
        return false;
    };
    /**
     * Returns a copy of the given XMLList object. The copy is a duplicate of the entire tree of nodes.
     * The copied XML object has no parent and returns null if you attempt to call the parent() method.
     * @return	The copy of the XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.copy = function () {
        console.log("copy not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Returns all descendants (children, grandchildren, great-grandchildren, and so on) of the XML object
     * that have the given name parameter. The name parameter can be a
     * QName object, a String data type, or any other data type that is then converted to a String
     * data type.
     *
     *   To return all descendants, use
     * the asterisk (~~) parameter. If no parameter is passed,
     * the string "~~" is passed and returns all descendants of the XML object.
     * @param	name	The name of the element to match.
     * @return	An XMLList object of the matching descendants (children, grandchildren, and so on) of the XML objects
     *   in the original list. If there are no descendants, returns an empty XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.descendants = function (name) {
        if (name === void 0) { name = "*"; }
        console.log("descendants not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Calls the elements() method of each XML object. The name parameter is
     * passed to the descendants() method. If no parameter is passed, the string "~~" is passed to the
     * descendants() method.
     * @param	name	The name of the elements to match.
     * @return	An XMLList object of the matching child elements of the XML objects.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.elements = function (name) {
        if (name === void 0) { name = "*"; }
        console.log("elements not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Checks whether the XMLList object contains complex content. An XMLList object is
     * considered to contain complex content if it is not empty and either of the following conditions is true:
     *
     *   The XMLList object contains a single XML item with complex content.The XMLList object contains elements.
     * @return	If the XMLList object contains complex content, then true; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.hasComplexContent = function () {
        console.log("hasComplexContent not implemented yet in flash/XMLList");
        return false;
    };
    /**
     * Checks for the property specified by p.
     * @param	p	The property to match.
     * @return	If the parameter exists, then true; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.hasOwnProperty = function (P) {
        if (P === void 0) { P = null; }
        console.log("hasOwnProperty not implemented yet in flash/XMLList");
        return false;
    };
    /**
     * Checks whether the XMLList object contains simple content. An XMLList object is
     * considered to contain simple content if one or more of the following
     * conditions is true:
     * The XMLList object is emptyThe XMLList object contains a single XML item with simple contentThe XMLList object contains no elements
     * @return	If the XMLList contains simple content, then true; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.hasSimpleContent = function () {
        console.log("hasSimpleContent not implemented yet in flash/XMLList");
        return false;
    };
    XMLList.prototype.inScopeNamespaces = function () {
        console.log("inScopeNamespaces not implemented yet in flash/XMLList");
        return [];
    };
    XMLList.prototype.insertChildAfter = function (child1, child2) {
        console.log("insertChildAfter not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.insertChildBefore = function (child1, child2) {
        console.log("insertChildBefore not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Returns the number of properties in the XMLList object.
     * @return	The number of properties in the XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.length = function () {
        console.log("length not implemented yet in flash/XMLList");
        return 0;
    };
    XMLList.prototype.localName = function () {
        console.log("localName not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.name = function () {
        console.log("name not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.namespace = function (prefix) {
        if (prefix === void 0) { prefix = null; }
        console.log("namespace not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.namespaceDeclarations = function () {
        console.log("namespaceDeclarations not implemented yet in flash/XMLList");
        return [];
    };
    XMLList.prototype.nodeKind = function () {
        console.log("nodeKind not implemented yet in flash/XMLList");
        return "";
    };
    /**
     * Merges adjacent text nodes and eliminates empty text nodes for each
     * of the following: all text nodes in the XMLList, all the XML objects
     * contained in the XMLList, and the descendants of all the XML objects in
     * the XMLList.
     * @return	The normalized XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.normalize = function () {
        console.log("normalize not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Returns the parent of the XMLList object if all items in the XMLList object have the same parent.
     * If the XMLList object has no parent or different parents, the method returns undefined.
     * @return	Returns the parent XML object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.parent = function () {
        console.log("parent not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.prependChild = function (value) {
        console.log("prependChild not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * If a name parameter is provided, lists all the children of the XMLList object that
     * contain processing instructions with that name. With no parameters, the method lists all the
     * children of the XMLList object that contain any processing instructions.
     * @param	name	The name of the processing instructions to match.
     * @return	An XMLList object that contains the processing instructions for each XML object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.processingInstructions = function (name) {
        if (name === void 0) { name = "*"; }
        console.log("processingInstructions not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Checks whether the property p is in the set of properties that can be iterated in a for..in statement
     * applied to the XMLList object. This is true only if toNumber(p) is greater than or equal to 0
     * and less than the length of the XMLList object.
     * @param	p	The index of a property to check.
     * @return	If the property can be iterated in a for..in statement, then true; otherwise false.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.propertyIsEnumerable = function (P) {
        if (P === void 0) { P = null; }
        console.log("propertyIsEnumerable not implemented yet in flash/XMLList");
        return false;
    };
    XMLList.prototype.removeNamespace = function (ns) {
        console.log("removeNamespace not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.replace = function (propertyName, value) {
        console.log("replace not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.setChildren = function (value) {
        console.log("setChildren not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.setLocalName = function (name) {
        console.log("setLocalName not implemented yet in flash/XMLList");
    };
    XMLList.prototype.setName = function (name) {
        console.log("setName not implemented yet in flash/XMLList");
    };
    XMLList.prototype.setNamespace = function (ns) {
        console.log("setNamespace not implemented yet in flash/XMLList");
    };
    /**
     * Calls the text() method of each XML
     * object and returns an XMLList object that contains the results.
     * @return	An XMLList object of all XML properties of the XMLList object that represent XML text nodes.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.text = function () {
        console.log("text not implemented yet in flash/XMLList");
        return null;
    };
    XMLList.prototype.toJSON = function (k) {
        console.log("toJSON not implemented yet in flash/XMLList");
        return null;
    };
    /**
     * Returns a string representation of all the XML objects in an XMLList object. The rules for
     * this conversion depend on whether the XML object has simple content or complex content:
     *
     *   If the XML object has simple content, toString() returns the string contents of the
     * XML object with  the following stripped out: the start tag, attributes, namespace declarations, and
     * end tag. If the XML object has complex content, toString() returns an XML encoded string
     * representing the entire XML object, including the start tag, attributes, namespace declarations,
     * and end tag.To return the entire XML object every time, use the toXMLString() method.
     * @return	The string representation of the XML object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.toString = function () {
        console.log("toString not implemented yet in flash/XMLList");
        return "";
    };
    /**
     * Returns a string representation of all the XML objects in an XMLList object.
     * Unlike the toString() method, the toXMLString()
     * method always returns the start tag, attributes,
     * and end tag of the XML object, regardless of whether the XML object has simple content
     * or complex content. (The toString() method strips out these items for XML
     * objects that contain simple content.)
     * @return	The string representation of the XML object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.toXMLString = function () {
        console.log("toXMLString not implemented yet in flash/XMLList");
        return "";
    };
    /**
     * Returns the XMLList object.
     * @return	Returns the current XMLList object.
     * @langversion	3.0
     * @playerversion	Flash 9
     */
    XMLList.prototype.valueOf = function () {
        console.log("valueOf not implemented yet in flash/XMLList");
        return null;
    };
    return XMLList;
}());

var RegisterCode = (function () {
    function RegisterCode() {
    }
    return RegisterCode;
}());

//enable parsers
_awayjs_core.Loader.enableParser(_awayjs_core.WaveAudioParser);
_awayjs_core.Loader.enableParser(_awayjs_stage.Image2DParser);
_awayjs_core.Loader.enableParser(_awayjs_stage.ImageCubeParser);
_awayjs_core.Loader.enableParser(_awayjs_stage.TextureAtlasParser);
//register view nodes
/*
PartitionBase.registerAbstraction(CameraNode, Camera);
PartitionBase.registerAbstraction(EntityNode, Sprite);
PartitionBase.registerAbstraction(EntityNode, DisplayObjectContainer);
PartitionBase.registerAbstraction(EntityNode, Scene);
PartitionBase.registerAbstraction(EntityNode, MorphSprite);
PartitionBase.registerAbstraction(EntityNode, MovieClip);
PartitionBase.registerAbstraction(EntityNode, Billboard);
PartitionBase.registerAbstraction(EntityNode, LineSegment);
PartitionBase.registerAbstraction(EntityNode, TextField);
PartitionBase.registerAbstraction(SkyboxNode, Skybox);
*/

var SystemUtil = (function () {
    function SystemUtil() {
    }
    return SystemUtil;
}());
SystemUtil.platform = "AwayJS";

var RenderTexture = (function () {
    function RenderTexture() {
    }
    return RenderTexture;
}());

var Touch = (function () {
    function Touch() {
    }
    return Touch;
}());

var ResizeEvent = (function (_super) {
    __extends(ResizeEvent, _super);
    function ResizeEvent() {
        return _super.apply(this, arguments) || this;
    }
    return ResizeEvent;
}(_awayjs_core.EventBase));

var Quad = (function (_super) {
    __extends(Quad, _super);
    function Quad(param1, param2, param3) {
        if (param1 === void 0) { param1 = 0; }
        if (param2 === void 0) { param2 = 0; }
        if (param3 === void 0) { param3 = 0; }
        return _super.call(this) || this;
    }
    return Quad;
}(Sprite$1));

var Image = (function () {
    function Image() {
    }
    return Image;
}());

/// Dispatched when the display list is about to be rendered.
/*[Event(name="render", type="starling.events.Event")]*/
/// Dispatched when a fatal error is encountered.
/*[Event(name="fatalError", tFype="starling.events.Event")]*/
/// Dispatched when the root class has been created.
/*[Event(name="rootCreated", type="starling.events.Event")]*/
/// Dispatched when a new render context is created.
/*[Event(name="context3DCreate", type="starling.events.Event")]*/
/**
 * The Starling class represents the core of the Starling framework.
 * <p>The Starling framework makes it possible to create 2D applications and games that make
 * use of the Stage3D architecture introduced in Flash Player 11. It implements a display tree
 * system that is very similar to that of conventional Flash, while leveraging modern GPUs
 * to speed up rendering.</p><p>The Starling class represents the link between the conventional Flash display tree and
 * the Starling display tree. To create a Starling-powered application, you have to create
 * an instance of the Starling class:</p><pre>var starling:Starling = new Starling(Game, stage);</pre><p>The first parameter has to be a Starling display object class, e.g. a subclass of
 * <codeph>starling.display.Sprite</codeph>. In the sample above, the class "Game" is the
 * application root. An instance of "Game" will be created as soon as Starling is initialized.
 * The second parameter is the conventional (Flash) stage object. Per default, Starling will
 * display its contents directly below the stage.</p><p>It is recommended to store the Starling instance as a member variable, to make sure
 * that the Garbage Collector does not destroy it. After creating the Starling object, you
 * have to start it up like this:</p><pre>starling.start();</pre><p>It will now render the contents of the "Game" class in the frame rate that is set up for
 * the application (as defined in the Flash stage).</p><b>Context3D Profiles</b><p>Stage3D supports different rendering profiles, and Starling works with all of them. The
 * last parameter of the Starling constructor allows you to choose which profile you want.
 * The following profiles are available:</p><ul><li>BASELINE_CONSTRAINED: provides the broadest hardware reach. If you develop for the
 * browser, this is the profile you should test with.</li><li>BASELINE: recommend for any mobile application, as it allows Starling to use a more
 * memory efficient texture type (RectangleTextures). It also supports more complex
 * AGAL code.</li><li>BASELINE_EXTENDED: adds support for textures up to 4096x4096 pixels. This is
 * especially useful on mobile devices with very high resolutions.</li></ul><p>The recommendation is to deploy your app with the profile "auto" (which makes Starling
 * pick the best available of those three), but test it in all available profiles.</p><b>Accessing the Starling object</b><p>From within your application, you can access the current Starling object anytime
 * through the static method <codeph>Starling.current</codeph>. It will return the active Starling
 * instance (most applications will only have one Starling object, anyway).</p><b>Viewport</b><p>The area the Starling content is rendered into is, per default, the complete size of the
 * stage. You can, however, use the "viewPort" property to change it. This can be  useful
 * when you want to render only into a part of the screen, or if the player size changes. For
 * the latter, you can listen to the RESIZE-event dispatched by the Starling
 * stage.</p><b>Native overlay</b><p>Sometimes you will want to display native Flash content on top of Starling. That's what the
 * <codeph>nativeOverlay</codeph> property is for. It returns a Flash Sprite lying directly
 * on top of the Starling content. You can add conventional Flash objects to that overlay.</p><p>Beware, though, that conventional Flash content on top of 3D content can lead to
 * performance penalties on some (mobile) platforms. For that reason, always remove all child
 * objects from the overlay when you don't need them any longer. Starling will remove the
 * overlay from the display list when it's empty.</p><b>Multitouch</b><p>Starling supports multitouch input on devices that provide it. During development,
 * where most of us are working with a conventional mouse and keyboard, Starling can simulate
 * multitouch events with the help of the "Shift" and "Ctrl" (Mac: "Cmd") keys. Activate
 * this feature by enabling the <codeph>simulateMultitouch</codeph> property.</p><b>Handling a lost render context</b><p>On some operating systems and under certain conditions (e.g. returning from system
 * sleep), Starling's stage3D render context may be lost. Starling can recover from a lost
 * context if the class property "handleLostContext" is set to "true". Keep in mind, however,
 * that this comes at the price of increased memory consumption; Starling will cache textures
 * in RAM to be able to restore them when the context is lost. (Except if you use the
 * 'AssetManager' for your textures. It is smart enough to recreate a texture directly
 * from its origin.)</p><p>In case you want to react to a context loss, Starling dispatches an event with
 * the type "Event.CONTEXT3D_CREATE" when the context is restored. You can recreate any
 * invalid resources in a corresponding event listener.</p><b>Sharing a 3D Context</b><p>Per default, Starling handles the Stage3D context itself. If you want to combine
 * Starling with another Stage3D engine, however, this may not be what you want. In this case,
 * you can make use of the <codeph>shareContext</codeph> property:</p><ol><li>Manually create and configure a context3D object that both frameworks can work with
 * (through <codeph>stage3D.requestContext3D</codeph> and
 * <codeph>context.configureBackBuffer</codeph>).</li><li>Initialize Starling with the stage3D instance that contains that configured context.
 * This will automatically enable <codeph>shareContext</codeph>.</li><li>Call <codeph>start()</codeph> on your Starling instance (as usual). This will make
 * Starling queue input events (keyboard/mouse/touch).</li><li>Create a game loop (e.g. using the native <codeph>ENTER_FRAME</codeph> event) and let it
 * call Starling's <codeph>nextFrame</codeph> as well as the equivalent method of the other
 * Stage3D engine. Surround those calls with <codeph>context.clear()</codeph> and
 * <codeph>context.present()</codeph>.</li></ol><p>The Starling wiki contains a <xref href="http://goo.gl/BsXzw">tutorial</xref> with more
 * information about this topic.</p>
 */
var Starling = (function (_super) {
    __extends(Starling, _super);
    /**
     * Creates a new Starling instance.
     * @param	rootClass	A subclass of 'starling.display.DisplayObject'. It will be created
     *   as soon as initialization is finished and will become the first child
     *   of the Starling stage. Pass null if you don't want to
     *   create a root object right away. (You can use the
     *   rootClass property later to make that happen.)
     * @param	stage	The Flash (2D) stage.
     * @param	viewPort	A rectangle describing the area into which the content will be
     *   rendered. Default: stage size
     * @param	stage3D	The Stage3D object into which the content will be rendered. If it
     *   already contains a context, sharedContext will be set
     *   to true. Default: the first available Stage3D.
     * @param	renderMode	The Context3D render mode that should be requested.
     *   Use this parameter if you want to force "software" rendering.
     * @param	profile	The Context3D profile that should be requested.
     *   If you pass a profile String, this profile is enforced.Pass an Array of profiles to make Starling pick the first
     *   one that works (starting with the first array element).Pass the String "auto" to make Starling pick the best available
     *   profile automatically.
     */
    function Starling(rootClass, stage, viewPort, stage3D, renderMode, profile) {
        if (viewPort === void 0) { viewPort = null; }
        if (stage3D === void 0) { stage3D = null; }
        if (renderMode === void 0) { renderMode = "auto"; }
        if (profile === void 0) { profile = "baselineConstrained"; }
        //todo: any is Stage3D
        return _super.call(this) || this;
    }
    Object.defineProperty(Starling, "all", {
        /// All Starling instances. CAUTION: not a copy, but the actual object! Do not modify!
        get: function () {
            console.log("all not implemented yet in starling/Starling");
            return [];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "antiAliasing", {
        /// The antialiasing level. 0 - no antialasing, 16 - maximum antialiasing.
        get: function () {
            console.log("antiAliasing not implemented yet in starling/Starling");
            return 0;
        },
        set: function (value) {
            console.log("antiAliasing not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "backBufferHeight", {
        /**
         * Returns the current height of the back buffer. In most cases, this value is in pixels;
         * however, if the app is running on an HiDPI display with an activated
         * 'supportHighResolutions' setting, you have to multiply with 'backBufferPixelsPerPoint'
         * for the actual pixel count.
         */
        get: function () {
            console.log("backBufferHeight not implemented yet in starling/Starling");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "backBufferPixelsPerPoint", {
        /**
         * The number of pixel per point returned by the 'backBufferWidth/Height' properties.
         * Except for desktop HiDPI displays with an activated 'supportHighResolutions' setting,
         * this will always return '1'.
         */
        get: function () {
            console.log("backBufferPixelsPerPoint not implemented yet in starling/Starling");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "backBufferWidth", {
        /**
         * Returns the current width of the back buffer. In most cases, this value is in pixels;
         * however, if the app is running on an HiDPI display with an activated
         * 'supportHighResolutions' setting, you have to multiply with 'backBufferPixelsPerPoint'
         * for the actual pixel count.
         */
        get: function () {
            console.log("backBufferWidth not implemented yet in starling/Starling");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "contentScaleFactor", {
        /**
         * The ratio between viewPort width and stage width. Useful for choosing a different
         * set of textures depending on the display resolution.
         */
        get: function () {
            console.log("contentScaleFactor not implemented yet in starling/Starling");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "contentScaleFactor", {
        /**
         * The ratio between viewPort width and stage width. Useful for choosing a different
         * set of textures depending on the display resolution.
         */
        get: function () {
            console.log("contentScaleFactor not implemented yet in starling/Starling");
            return 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "context", {
        /// The render context of this instance.
        get: function () {
            console.log("context not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "context", {
        /// The render context of this instance.
        get: function () {
            console.log("context not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "contextData", {
        //todo any is Objects.Dictionary
        /**
         * A dictionary that can be used to save custom data related to the current context.
         * If you need to share data that is bound to a specific stage3D instance
         * (e.g. textures), use this dictionary instead of creating a static class variable.
         * The Dictionary is actually bound to the stage3D instance, thus it survives a
         * context loss.
         */
        get: function () {
            //todo any is Objects.Dictionary
            console.log("contextData not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "contextValid", {
        /**
         * Indicates if the Context3D object is currently valid (i.e. it hasn't been lost or
         * disposed).
         */
        get: function () {
            console.log("contextValid not implemented yet in starling/Starling");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "current", {
        /// The currently active Starling instance.
        get: function () {
            console.log("current not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "enableErrorChecking", {
        /**
         * Indicates if Stage3D render methods will report errors. Activate only when needed,
         * as this has a negative impact on performance.
         */
        get: function () {
            console.log("enableErrorChecking not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("enableErrorChecking not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "handleLostContext", {
        /**
         * Indicates if Starling should automatically recover from a lost device context.
         * On some systems, an upcoming screensaver or entering sleep mode may
         * invalidate the render context. This setting indicates if Starling should recover from
         * such incidents.
         * Beware: if used carelessly, this property may have a huge impact on memory
         * consumption. That's because, by default, it will make Starling keep a copy of each
         * texture in memory.However, this downside can be avoided by using the "AssetManager" to load textures.
         * The AssetManager is smart enough to restore them directly from their sources. You can
         * also do this by setting up "root.onRestore" on your manually loaded textures.A context loss can happen on almost every platform. It's very common on Windows
         * and Android, but rare on OS X and iOS (e.g. it may occur when opening up the camera
         * roll). It's recommended to always enable this property, while using the AssetManager
         * for texture loading.
         */
        get: function () {
            console.log("handleLostContext not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("handleLostContext not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "isStarted", {
        /// Indicates if this Starling instance is started.
        get: function () {
            console.log("isStarted not implemented yet in starling/Starling");
            return false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "juggler", {
        /// The default juggler of this instance. Will be advanced once per frame.
        get: function () {
            console.log("juggler not implemented yet in starling/Starling");
            //todo any is Jugglerg.animation.Juggler
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "juggler", {
        /// The default juggler of this instance. Will be advanced once per frame.
        get: function () {
            console.log("juggler not implemented yet in starling/Starling");
            //todo any is Jugglerg.animation.Juggler
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling, "multitouchEnabled", {
        /// Indicates if multitouch input should be supported.
        get: function () {
            console.log("multitouchEnabled not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("multitouchEnabled not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "nativeOverlay", {
        /**
         * A Flash Sprite placed directly on top of the Starling content. Use it to display native
         * Flash components.
         */
        get: function () {
            console.log("nativeOverlay not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "nativeStage", {
        /// The Flash (2D) stage object Starling renders beneath.
        get: function () {
            console.log("nativeStage not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "profile", {
        /**
         * The Context3D profile used for rendering. Beware that if you are using a shared
         * context in AIR 3.9 / Flash Player 11 or below, this is simply what you passed to
         * the Starling constructor.
         */
        get: function () {
            console.log("profile not implemented yet in starling/Starling");
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "root", {
        /**
         * The instance of the root class provided in the constructor. Available as soon as
         * the event 'ROOT_CREATED' has been dispatched.
         */
        get: function () {
            console.log("root not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "rootClass", {
        /**
         * The class that will be instantiated by Starling as the 'root' display object.
         * Must be a subclass of 'starling.display.DisplayObject'.
         * If you passed null as first parameter to the Starling constructor,
         * you can use this property to set the root class at a later time. As soon as the class
         * is instantiated, Starling will dispatch a ROOT_CREATED event.Beware: you cannot change the root class once the root object has been
         * instantiated.
         */
        get: function () {
            console.log("rootClass not implemented yet in starling/Starling");
            return null;
        },
        set: function (value) {
            console.log("rootClass not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "shareContext", {
        /**
         * Indicates if the Context3D render calls are managed externally to Starling,
         * to allow other frameworks to share the Stage3D instance.
         */
        get: function () {
            console.log("shareContext not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("shareContext not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "showStats", {
        /**
         * Indicates if a small statistics box (with FPS, memory usage and draw count) is
         * displayed.
         * Beware that the memory usage should be taken with a grain of salt. The value is
         * determined via System.totalMemory and does not take texture memory
         * into account. It is recommended to use Adobe Scout for reliable and comprehensive
         * memory analysis.
         */
        get: function () {
            console.log("showStats not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("showStats not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "simulateMultitouch", {
        /// Indicates if multitouch simulation with "Shift" and "Ctrl"/"Cmd"-keys is enabled.
        get: function () {
            console.log("simulateMultitouch not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("simulateMultitouch not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "stage", {
        /// The Starling stage object, which is the root of the display tree that is rendered.
        get: function () {
            console.log("stage not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "stage3D", {
        /// The Flash Stage3D object Starling renders into.
        get: function () {
            //todo:any is Stage3D
            console.log("stage3D not implemented yet in starling/Starling");
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "supportHighResolutions", {
        /**
         * Indicates that if the device supports HiDPI screens Starling will attempt to allocate
         * a larger back buffer than indicated via the viewPort size. Note that this is used
         * on Desktop only; mobile AIR apps still use the "requestedDisplayResolution" parameter
         * the application descriptor XML.
         */
        get: function () {
            console.log("supportHighResolutions not implemented yet in starling/Starling");
            return false;
        },
        set: function (value) {
            console.log("supportHighResolutions not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "touchProcessor", {
        /**
         * The TouchProcessor is passed all mouse and touch input and is responsible for
         * dispatching TouchEvents to the Starling display tree. If you want to handle these
         * types of input manually, pass your own custom subclass to this property.
         */
        get: function () {
            //todo: any is TouchProcessor
            console.log("touchProcessor not implemented yet in starling/Starling");
            return null;
        },
        set: function (value) {
            //todo: TouchProcessor
            console.log("touchProcessor not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Starling.prototype, "viewPort", {
        /// The viewport into which Starling contents will be rendered.
        get: function () {
            console.log("viewPort not implemented yet in starling/Starling");
            return null;
        },
        set: function (value) {
            console.log("viewPort not implemented yet in starling/Starling");
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Dispatches ENTER_FRAME events on the display list, advances the Juggler
     * and processes touches.
     */
    Starling.prototype.advanceTime = function (passedTime) {
        console.log("advanceTime not implemented yet in starling/Starling");
    };
    /// Deletes the vertex- and fragment-programs of a certain name.
    Starling.prototype.deleteProgram = function (name) {
        console.log("deleteProgram not implemented yet in starling/Starling");
    };
    /**
     * Disposes all children of the stage and the render context; removes all registered
     * event listeners.
     */
    Starling.prototype.dispose = function () {
        console.log("dispose not implemented yet in starling/Starling");
    };
    /// Returns the vertex- and fragment-programs registered under a certain name.
    Starling.prototype.getProgram = function (name) {
        //todo: any is Program3D
        console.log("getProgram not implemented yet in starling/Starling");
        return null;
    };
    /// Indicates if a set of vertex- and fragment-programs is registered under a certain name.
    Starling.prototype.hasProgram = function (name) {
        console.log("hasProgram not implemented yet in starling/Starling");
        return false;
    };
    /// Make this Starling instance the current one.
    Starling.prototype.makeCurrent = function () {
        console.log("makeCurrent not implemented yet in starling/Starling");
    };
    /**
     * Calls advanceTime() (with the time that has passed since the last frame)
     * and render().
     */
    Starling.prototype.nextFrame = function () {
        console.log("nextFrame not implemented yet in starling/Starling");
    };
    /**
     * Registers a compiled shader-program under a certain name.
     * If the name was already used, the previous program is overwritten.
     */
    Starling.prototype.registerProgram = function (name, vertexShader, fragmentShader) {
        //todo: any is Program3D
        console.log("registerProgram not implemented yet in starling/Starling");
        return null;
    };
    /**
     * Compiles a shader-program and registers it under a certain name.
     * If the name was already used, the previous program is overwritten.
     */
    Starling.prototype.registerProgramFromSource = function (name, vertexShader, fragmentShader) {
        //todo: any is Program3D
        console.log("registerProgramFromSource not implemented yet in starling/Starling");
        return null;
    };
    /**
     * Renders the complete display list. Before rendering, the context is cleared; afterwards,
     * it is presented (to avoid this, enable shareContext).
     * This method also dispatches an Event.RENDER-event on the Starling
     * instance. That's the last opportunity to make changes before the display list is
     * rendered.
     */
    Starling.prototype.render = function () {
        console.log("render not implemented yet in starling/Starling");
    };
    /// Displays the statistics box at a certain position.
    Starling.prototype.showStatsAt = function (hAlign, vAlign, scale) {
        if (hAlign === void 0) { hAlign = "left"; }
        if (vAlign === void 0) { vAlign = "top"; }
        if (scale === void 0) { scale = 1; }
        console.log("showStatsAt not implemented yet in starling/Starling");
    };
    /**
     * As soon as Starling is started, it will queue input events (keyboard/mouse/touch);
     * furthermore, the method nextFrame will be called once per Flash Player
     * frame. (Except when shareContext is enabled: in that case, you have to
     * call that method manually.)
     */
    Starling.prototype.start = function () {
        console.log("start not implemented yet in starling/Starling");
    };
    /**
     * Stops all logic and input processing, effectively freezing the app in its current state.
     * Per default, rendering will continue: that's because the classic display list
     * is only updated when stage3D is. (If Starling stopped rendering, conventional Flash
     * contents would freeze, as well.)
     *
     *   However, if you don't need classic Flash contents, you can stop rendering, too.
     * On some mobile systems (e.g. iOS), you are even required to do so if you have
     * activated background code execution.
     */
    Starling.prototype.stop = function (suspendRendering) {
        if (suspendRendering === void 0) { suspendRendering = false; }
        console.log("stop not implemented yet in starling/Starling");
    };
    /**
     * Stops Starling right away and displays an error message on the native overlay.
     * This method will also cause Starling to dispatch a FATAL_ERROR event.
     */
    Starling.prototype.stopWithFatalError = function (message) {
        console.log("stopWithFatalError not implemented yet in starling/Starling");
    };
    return Starling;
}(EventDispatcher$1));
/// The version of the Starling framework.
Starling.VERSION = "1.7";

exports.Clipboard = Clipboard;
exports.ClipboardFormats = ClipboardFormats;
exports.Bitmap = Bitmap;
exports.BitmapData = BitmapData;
exports.BitmapDataChannel = _awayjs_stage.BitmapImageChannel;
exports.BlendMode = _awayjs_stage.BlendMode;
exports.CapsStyle = _awayjs_graphics.CapsStyle;
exports.DisplayObject = DisplayObject$1;
exports.DisplayObjectContainer = DisplayObjectContainer$1;
exports.GradientType = _awayjs_graphics.GradientType;
exports.Graphics = _awayjs_graphics.Graphics;
exports.GraphicsPath = _awayjs_graphics.GraphicsPath;
exports.GraphicsPathCommand = _awayjs_graphics.GraphicsPathCommand;
exports.GraphicsPathWinding = _awayjs_graphics.GraphicsPathWinding;
exports.InteractiveObject = InteractiveObject;
exports.InterpolationMethod = _awayjs_graphics.InterpolationMethod;
exports.JointStyle = _awayjs_graphics.JointStyle;
exports.LineScaleMode = _awayjs_graphics.LineScaleMode;
exports.Loader = Loader$1;
exports.LoaderInfo = LoaderInfo;
exports.MovieClip = MovieClip$1;
exports.PixelSnapping = _awayjs_graphics.PixelSnapping;
exports.Shape = Sprite$1;
exports.SimpleButton = SimpleButton;
exports.SpreadMethod = _awayjs_graphics.SpreadMethod;
exports.Sprite = Sprite$1;
exports.Stage = Stage;
exports.StageAlign = StageAlign;
exports.StageScaleMode = StageScaleMode;
exports.TriangleCulling = _awayjs_graphics.TriangleCulling;
exports.Context3D = _awayjs_stage.ContextWebGL;
exports.Context3DClearMask = _awayjs_stage.ContextGLClearMask;
exports.Context3DProgramType = _awayjs_stage.ContextGLProgramType;
exports.Texture = Texture;
exports.ErrorEvent = ErrorEvent;
exports.Event = Event;
exports.EventDispatcher = EventDispatcher$1;
exports.FocusEvent = FocusEvent;
exports.IOErrorEvent = IOErrorEvent;
exports.KeyboardEvent = KeyboardEvent;
exports.MouseEvent = MouseEvent$1;
exports.ProgressEvent = ProgressEvent;
exports.SampleDataEvent = SampleDataEvent;
exports.TextEvent = TextEvent;
exports.TimerEvent = _awayjs_core.TimerEvent;
exports.TouchEvent = TouchEvent;
exports.ExternalInterface = ExternalInterface;
exports.FlashSceneGraphFactory = FlashSceneGraphFactory;
exports.BitmapFilter = BitmapFilter;
exports.DropShadowFilter = DropShadowFilter;
exports.GlowFilter = GlowFilter;
exports.GradientBevelFilter = GradientBevelFilter;
exports.NumberFormatter = NumberFormatter;
exports.StringTools = StringTools;
exports.ColorTransform = _awayjs_core.ColorTransform;
exports.Matrix = _awayjs_core.Matrix;
exports.Matrix3D = _awayjs_core.Matrix3D;
exports.Orientation3D = _awayjs_core.Orientation3D;
exports.PerspectiveProjection = _awayjs_core.PerspectiveProjection;
exports.Point = _awayjs_core.Point;
exports.Rectangle = _awayjs_core.Rectangle;
exports.Transform = _awayjs_core.Transform;
exports.Utils3D = _awayjs_core.Matrix3D;
exports.Vector3D = _awayjs_core.Vector3D;
exports.ID3Info = ID3Info;
exports.Sound = Sound;
exports.SoundChannel = SoundChannel;
exports.SoundLoaderContext = SoundLoaderContext;
exports.SoundTransform = SoundTransform;
exports.navigateToURL = navigateToURL;
exports.FileReference = FileReference;
exports.URLLoader = URLLoader$1;
exports.URLLoaderDataFormat = _awayjs_core.URLLoaderDataFormat;
exports.URLRequest = _awayjs_core.URLRequest;
exports.URLRequestMethod = _awayjs_core.URLRequestMethod;
exports.URLVariables = _awayjs_core.URLVariables;
exports.SharedObject = SharedObject;
exports.NewObjectSample = NewObjectSample;
exports.Sample = Sample;
exports.ApplicationDomain = ApplicationDomain;
exports.Capabilities = Capabilities;
exports.IME = IME;
exports.LoaderContext = LoaderContext;
exports.SecurityDomain = SecurityDomain;
exports.System = System;
exports.AntiAliasType = _awayjs_scene.AntiAliasType;
exports.Font = _awayjs_scene.Font;
exports.GridFitType = _awayjs_scene.GridFitType;
exports.StyleSheet = StyleSheet;
exports.TextField = TextField$1;
exports.TextFieldAutoSize = _awayjs_scene.TextFieldAutoSize;
exports.TextFieldType = _awayjs_scene.TextFieldType;
exports.TextFormat = _awayjs_scene.TextFormat;
exports.TextFormatAlign = _awayjs_scene.TextFormatAlign;
exports.TextInteractionMode = _awayjs_scene.TextInteractionMode;
exports.TextLineMetrics = _awayjs_scene.TextLineMetrics;
exports.Keyboard = _awayjs_core.Keyboard;
exports.Mouse = Mouse;
exports.Multitouch = Multitouch;
exports.MultitouchInputMode = MultitouchInputMode;
exports.clearInterval = clearInterval;
exports.clearTimeout = clearTimeout;
exports.describeType = describeType;
exports.escapeMultiByte = escapeMultiByte;
exports.getAliasName = getAliasName;
exports.getDefinitionByName = getDefinitionByName;
exports.getQualifiedClassName = getQualifiedClassName;
exports.getQualifiedSuperclassName = getQualifiedSuperclassName;
exports.getTimer = _awayjs_core.getTimer;
exports.setInterval = setInterval$1;
exports.setTimeout = setTimeout;
exports.unescapeMultiByte = unescapeMultiByte;
exports.AwayDate = AwayDate;
exports.ByteArray = _awayjs_core.ByteArray;
exports.Dictionary = Dictionary;
exports.Endian = Endian;
exports.Timer = _awayjs_core.Timer;
exports.Trace = Trace;
exports.XML = XML;
exports.XMLDocumentAway = XMLDocumentAway;
exports.XMLList = XMLList;
exports.XMLNode = XMLNode;
exports.XMLNodeType = XMLNodeType;
exports.AssetLibrary = _awayjs_core.AssetLibrary;
exports.SystemUtil = SystemUtil;
exports.RenderTexture = RenderTexture;
exports.Touch = Touch;
exports.ResizeEvent = ResizeEvent;
exports.Quad = Quad;
exports.Image = Image;
exports.Starling = Starling;
exports.RegisterCode = RegisterCode;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=as3web-flash.umd.js.map
